import{h as y}from"./axios--FnjuHWf.js";import{d as b,r as d,b as f,c as V,e,f as o,g as w,a as m,h as x}from"./index-eJPIzJhh.js";const g={style:{"background-color":"#d2d2fa",height:"100vh",display:"grid","place-items":"center"}},k={style:{"background-color":"#fff",width:"70%",height:"70%","border-radius":"10px",padding:"20px",overflow:"auto"}},U=e("div",{style:{display:"flex","justify-content":"space-between","align-items":"center"}},[e("div",{style:{"font-size":"20px","font-weight":"bold"}},"基址偏移"),e("div",{style:{display:"flex","justify-content":"space-between","align-items":"center"}})],-1),B={style:{"margin-top":"20px"}},C=e("label",null,"手机号: ",-1),E=e("br",null,null,-1),N=e("label",null,"昵称: ",-1),P=e("br",null,null,-1),j=e("label",null,"微信账号: ",-1),z=e("br",null,null,-1),K=e("label",null,"密钥（key）: ",-1),T=e("br",null,null,-1),Y=e("label",null,"微信数据库路径: ",-1),q=e("br",null,null,-1),G=b({__name:"BiasView",setup(A){const i=d(""),r=d(""),c=d(""),s=d(""),u=d(""),a=d(""),v=async()=>{try{if(s.value===""&&u.value===""){a.value="key与wxdbPath必须填写一个";return}a.value=await y.post("/api/biasaddr",{mobile:i.value,name:r.value,account:c.value,key:s.value,wxdbPath:u.value}),a.value=`{版本号:昵称,账号,手机号,邮箱,KEY}
`+a.value}catch(p){return a.value=`Error fetching data: 
`+p,console.error("Error fetching data:",p),[]}};return(p,l)=>{const n=m("el-input"),_=m("el-button"),h=m("el-divider");return f(),V("div",g,[e("div",k,[U,e("div",B,[C,o(n,{placeholder:"请输入手机号",modelValue:i.value,"onUpdate:modelValue":l[0]||(l[0]=t=>i.value=t),style:{width:"80%"}},null,8,["modelValue"]),E,N,o(n,{placeholder:"请输入昵称",modelValue:r.value,"onUpdate:modelValue":l[1]||(l[1]=t=>r.value=t),style:{width:"80%"}},null,8,["modelValue"]),P,j,o(n,{placeholder:"请输入微信号",modelValue:c.value,"onUpdate:modelValue":l[2]||(l[2]=t=>c.value=t),style:{width:"80%"}},null,8,["modelValue"]),z,K,o(n,{placeholder:"请输入密钥（key）（可选）",modelValue:s.value,"onUpdate:modelValue":l[3]||(l[3]=t=>s.value=t),style:{width:"80%"}},null,8,["modelValue"]),T,Y,o(n,{placeholder:"请输入微信数据库路径（可选）",modelValue:u.value,"onUpdate:modelValue":l[4]||(l[4]=t=>u.value=t),style:{width:"75%"}},null,8,["modelValue"]),q,o(_,{style:{"margin-top":"10px",width:"50%"},type:"success",onClick:v},{default:w(()=>[x("偏移")]),_:1}),o(h),o(n,{type:"textarea",rows:10,readonly:"",placeholder:"输出结果",modelValue:a.value,"onUpdate:modelValue":l[5]||(l[5]=t=>a.value=t),style:{width:"100%",color:"#00bd7e"}},null,8,["modelValue"])])])])}}});export{G as default};
