import{d as ob,o as lL,b as sb,c as lb,_ as uL,f as fL}from"./index-eJPIzJhh.js";/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var jc=function(r,e){return jc=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,a){t.__proto__=a}||function(t,a){for(var n in a)Object.prototype.hasOwnProperty.call(a,n)&&(t[n]=a[n])},jc(r,e)};function k(r,e){if(typeof e!="function"&&e!==null)throw new TypeError("Class extends value "+String(e)+" is not a constructor or null");jc(r,e);function t(){this.constructor=r}r.prototype=e===null?Object.create(e):(t.prototype=e.prototype,new t)}var hL=function(){function r(){this.firefox=!1,this.ie=!1,this.edge=!1,this.newEdge=!1,this.weChat=!1}return r}(),vL=function(){function r(){this.browser=new hL,this.node=!1,this.wxa=!1,this.worker=!1,this.svgSupported=!1,this.touchEventsSupported=!1,this.pointerEventsSupported=!1,this.domSupported=!1,this.transformSupported=!1,this.transform3dSupported=!1,this.hasGlobalWindow=typeof window<"u"}return r}(),mt=new vL;typeof wx=="object"&&typeof wx.getSystemInfoSync=="function"?(mt.wxa=!0,mt.touchEventsSupported=!0):typeof document>"u"&&typeof self<"u"?mt.worker=!0:typeof navigator>"u"||navigator.userAgent.indexOf("Node.js")===0?(mt.node=!0,mt.svgSupported=!0):cL(navigator.userAgent,mt);function cL(r,e){var t=e.browser,a=r.match(/Firefox\/([\d.]+)/),n=r.match(/MSIE\s([\d.]+)/)||r.match(/Trident\/.+?rv:(([\d.]+))/),i=r.match(/Edge?\/([\d.]+)/),o=/micromessenger/i.test(r);a&&(t.firefox=!0,t.version=a[1]),n&&(t.ie=!0,t.version=n[1]),i&&(t.edge=!0,t.version=i[1],t.newEdge=+i[1].split(".")[0]>18),o&&(t.weChat=!0),e.svgSupported=typeof SVGRect<"u",e.touchEventsSupported="ontouchstart"in window&&!t.ie&&!t.edge,e.pointerEventsSupported="onpointerdown"in window&&(t.edge||t.ie&&+t.version>=11),e.domSupported=typeof document<"u";var s=document.documentElement.style;e.transform3dSupported=(t.ie&&"transition"in s||t.edge||"WebKitCSSMatrix"in window&&"m11"in new WebKitCSSMatrix||"MozPerspective"in s)&&!("OTransition"in s),e.transformSupported=e.transform3dSupported||t.ie&&+t.version>=9}var Fd=12,ub="sans-serif",Fa=Fd+"px "+ub,pL=20,dL=100,gL="007LLmW'55;N0500LLLLLLLLLL00NNNLzWW\\\\WQb\\0FWLg\\bWb\\WQ\\WrWWQ000CL5LLFLL0LL**F*gLLLL5F0LF\\FFF5.5N";function yL(r){var e={};if(typeof JSON>"u")return e;for(var t=0;t<r.length;t++){var a=String.fromCharCode(t+32),n=(r.charCodeAt(t)-pL)/dL;e[a]=n}return e}var mL=yL(gL),Ha={createCanvas:function(){return typeof document<"u"&&document.createElement("canvas")},measureText:function(){var r,e;return function(t,a){if(!r){var n=Ha.createCanvas();r=n&&n.getContext("2d")}if(r)return e!==a&&(e=r.font=a||Fa),r.measureText(t);t=t||"",a=a||Fa;var i=/(\d+)px/.exec(a),o=i&&+i[1]||Fd,s=0;if(a.indexOf("mono")>=0)s=o*t.length;else for(var l=0;l<t.length;l++){var u=mL[t[l]];s+=u==null?o:u*o}return{width:s}}}(),loadImage:function(r,e,t){var a=new Image;return a.onload=e,a.onerror=t,a.src=r,a}},fb=zr(["Function","RegExp","Date","Error","CanvasGradient","CanvasPattern","Image","Canvas"],function(r,e){return r["[object "+e+"]"]=!0,r},{}),hb=zr(["Int8","Uint8","Uint8Clamped","Int16","Uint16","Int32","Uint32","Float32","Float64"],function(r,e){return r["[object "+e+"Array]"]=!0,r},{}),oo=Object.prototype.toString,Wf=Array.prototype,_L=Wf.forEach,SL=Wf.filter,Hd=Wf.slice,xL=Wf.map,em=(function(){}).constructor,Al=em?em.prototype:null,Wd="__proto__",wL=2311;function vb(){return wL++}function $d(){for(var r=[],e=0;e<arguments.length;e++)r[e]=arguments[e];typeof console<"u"&&console.error.apply(console,r)}function rt(r){if(r==null||typeof r!="object")return r;var e=r,t=oo.call(r);if(t==="[object Array]"){if(!vs(r)){e=[];for(var a=0,n=r.length;a<n;a++)e[a]=rt(r[a])}}else if(hb[t]){if(!vs(r)){var i=r.constructor;if(i.from)e=i.from(r);else{e=new i(r.length);for(var a=0,n=r.length;a<n;a++)e[a]=r[a]}}}else if(!fb[t]&&!vs(r)&&!Ki(r)){e={};for(var o in r)r.hasOwnProperty(o)&&o!==Wd&&(e[o]=rt(r[o]))}return e}function ft(r,e,t){if(!tt(e)||!tt(r))return t?rt(e):r;for(var a in e)if(e.hasOwnProperty(a)&&a!==Wd){var n=r[a],i=e[a];tt(i)&&tt(n)&&!z(i)&&!z(n)&&!Ki(i)&&!Ki(n)&&!rm(i)&&!rm(n)&&!vs(i)&&!vs(n)?ft(n,i,t):(t||!(a in r))&&(r[a]=rt(e[a]))}return r}function Ud(r,e){for(var t=r[0],a=1,n=r.length;a<n;a++)t=ft(t,r[a],e);return t}function V(r,e){if(Object.assign)Object.assign(r,e);else for(var t in e)e.hasOwnProperty(t)&&t!==Wd&&(r[t]=e[t]);return r}function j(r,e,t){for(var a=_t(e),n=0;n<a.length;n++){var i=a[n];(t?e[i]!=null:r[i]==null)&&(r[i]=e[i])}return r}function vt(r,e){if(r){if(r.indexOf)return r.indexOf(e);for(var t=0,a=r.length;t<a;t++)if(r[t]===e)return t}return-1}function bL(r,e){var t=r.prototype;function a(){}a.prototype=e.prototype,r.prototype=new a;for(var n in t)t.hasOwnProperty(n)&&(r.prototype[n]=t[n]);r.prototype.constructor=r,r.superClass=e}function Kt(r,e,t){if(r="prototype"in r?r.prototype:r,e="prototype"in e?e.prototype:e,Object.getOwnPropertyNames)for(var a=Object.getOwnPropertyNames(e),n=0;n<a.length;n++){var i=a[n];i!=="constructor"&&(t?e[i]!=null:r[i]==null)&&(r[i]=e[i])}else j(r,e,t)}function ge(r){return!r||typeof r=="string"?!1:typeof r.length=="number"}function C(r,e,t){if(r&&e)if(r.forEach&&r.forEach===_L)r.forEach(e,t);else if(r.length===+r.length)for(var a=0,n=r.length;a<n;a++)e.call(t,r[a],a,r);else for(var i in r)r.hasOwnProperty(i)&&e.call(t,r[i],i,r)}function G(r,e,t){if(!r)return[];if(!e)return Yd(r);if(r.map&&r.map===xL)return r.map(e,t);for(var a=[],n=0,i=r.length;n<i;n++)a.push(e.call(t,r[n],n,r));return a}function zr(r,e,t,a){if(r&&e){for(var n=0,i=r.length;n<i;n++)t=e.call(a,t,r[n],n,r);return t}}function Lt(r,e,t){if(!r)return[];if(!e)return Yd(r);if(r.filter&&r.filter===SL)return r.filter(e,t);for(var a=[],n=0,i=r.length;n<i;n++)e.call(t,r[n],n,r)&&a.push(r[n]);return a}function TL(r,e,t){if(r&&e){for(var a=0,n=r.length;a<n;a++)if(e.call(t,r[a],a,r))return r[a]}}function _t(r){if(!r)return[];if(Object.keys)return Object.keys(r);var e=[];for(var t in r)r.hasOwnProperty(t)&&e.push(t);return e}function AL(r,e){for(var t=[],a=2;a<arguments.length;a++)t[a-2]=arguments[a];return function(){return r.apply(e,t.concat(Hd.call(arguments)))}}var U=Al&&K(Al.bind)?Al.call.bind(Al.bind):AL;function ot(r){for(var e=[],t=1;t<arguments.length;t++)e[t-1]=arguments[t];return function(){return r.apply(this,e.concat(Hd.call(arguments)))}}function z(r){return Array.isArray?Array.isArray(r):oo.call(r)==="[object Array]"}function K(r){return typeof r=="function"}function $(r){return typeof r=="string"}function tp(r){return oo.call(r)==="[object String]"}function Ct(r){return typeof r=="number"}function tt(r){var e=typeof r;return e==="function"||!!r&&e==="object"}function rm(r){return!!fb[oo.call(r)]}function Ne(r){return!!hb[oo.call(r)]}function Ki(r){return typeof r=="object"&&typeof r.nodeType=="number"&&typeof r.ownerDocument=="object"}function $f(r){return r.colorStops!=null}function CL(r){return r.image!=null}function DL(r){return oo.call(r)==="[object RegExp]"}function Is(r){return r!==r}function ie(){for(var r=[],e=0;e<arguments.length;e++)r[e]=arguments[e];for(var t=0,a=r.length;t<a;t++)if(r[t]!=null)return r[t]}function it(r,e){return r??e}function Br(r,e,t){return r??e??t}function Yd(r){for(var e=[],t=1;t<arguments.length;t++)e[t-1]=arguments[t];return Hd.apply(r,e)}function Zd(r){if(typeof r=="number")return[r,r,r,r];var e=r.length;return e===2?[r[0],r[1],r[0],r[1]]:e===3?[r[0],r[1],r[2],r[1]]:r}function Ae(r,e){if(!r)throw new Error(e)}function dr(r){return r==null?null:typeof r.trim=="function"?r.trim():r.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")}var cb="__ec_primitive__";function Xu(r){r[cb]=!0}function vs(r){return r[cb]}var ML=function(){function r(){this.data={}}return r.prototype.delete=function(e){var t=this.has(e);return t&&delete this.data[e],t},r.prototype.has=function(e){return this.data.hasOwnProperty(e)},r.prototype.get=function(e){return this.data[e]},r.prototype.set=function(e,t){return this.data[e]=t,this},r.prototype.keys=function(){return _t(this.data)},r.prototype.forEach=function(e){var t=this.data;for(var a in t)t.hasOwnProperty(a)&&e(t[a],a)},r}(),pb=typeof Map=="function";function IL(){return pb?new Map:new ML}var LL=function(){function r(e){var t=z(e);this.data=IL();var a=this;e instanceof r?e.each(n):e&&C(e,n);function n(i,o){t?a.set(i,o):a.set(o,i)}}return r.prototype.hasKey=function(e){return this.data.has(e)},r.prototype.get=function(e){return this.data.get(e)},r.prototype.set=function(e,t){return this.data.set(e,t),t},r.prototype.each=function(e,t){this.data.forEach(function(a,n){e.call(t,a,n)})},r.prototype.keys=function(){var e=this.data.keys();return pb?Array.from(e):e},r.prototype.removeKey=function(e){this.data.delete(e)},r}();function Z(r){return new LL(r)}function qu(r,e){for(var t=new r.constructor(r.length+e.length),a=0;a<r.length;a++)t[a]=r[a];for(var n=r.length,a=0;a<e.length;a++)t[a+n]=e[a];return t}function Uf(r,e){var t;if(Object.create)t=Object.create(r);else{var a=function(){};a.prototype=r,t=new a}return e&&V(t,e),t}function db(r){var e=r.style;e.webkitUserSelect="none",e.userSelect="none",e.webkitTapHighlightColor="rgba(0,0,0,0)",e["-webkit-touch-callout"]="none"}function Y(r,e){return r.hasOwnProperty(e)}function Yt(){}var Mu=180/Math.PI;function ii(r,e){return r==null&&(r=0),e==null&&(e=0),[r,e]}function Se(r,e){return r[0]=e[0],r[1]=e[1],r}function ta(r){return[r[0],r[1]]}function PL(r,e,t){return r[0]=e,r[1]=t,r}function am(r,e,t){return r[0]=e[0]+t[0],r[1]=e[1]+t[1],r}function ep(r,e,t,a){return r[0]=e[0]+t[0]*a,r[1]=e[1]+t[1]*a,r}function On(r,e,t){return r[0]=e[0]-t[0],r[1]=e[1]-t[1],r}function rp(r){return Math.sqrt(RL(r))}function RL(r){return r[0]*r[0]+r[1]*r[1]}function Iu(r,e,t){return r[0]=e[0]*t,r[1]=e[1]*t,r}function so(r,e){var t=rp(e);return t===0?(r[0]=0,r[1]=0):(r[0]=e[0]/t,r[1]=e[1]/t),r}function ap(r,e){return Math.sqrt((r[0]-e[0])*(r[0]-e[0])+(r[1]-e[1])*(r[1]-e[1]))}var Ma=ap;function EL(r,e){return(r[0]-e[0])*(r[0]-e[0])+(r[1]-e[1])*(r[1]-e[1])}var Wn=EL;function Lu(r,e,t,a){return r[0]=e[0]+a*(t[0]-e[0]),r[1]=e[1]+a*(t[1]-e[1]),r}function se(r,e,t){var a=e[0],n=e[1];return r[0]=t[0]*a+t[2]*n+t[4],r[1]=t[1]*a+t[3]*n+t[5],r}function Ia(r,e,t){return r[0]=Math.min(e[0],t[0]),r[1]=Math.min(e[1],t[1]),r}function La(r,e,t){return r[0]=Math.max(e[0],t[0]),r[1]=Math.max(e[1],t[1]),r}var pi=function(){function r(e,t){this.target=e,this.topTarget=t&&t.topTarget}return r}(),kL=function(){function r(e){this.handler=e,e.on("mousedown",this._dragStart,this),e.on("mousemove",this._drag,this),e.on("mouseup",this._dragEnd,this)}return r.prototype._dragStart=function(e){for(var t=e.target;t&&!t.draggable;)t=t.parent||t.__hostTarget;t&&(this._draggingTarget=t,t.dragging=!0,this._x=e.offsetX,this._y=e.offsetY,this.handler.dispatchToElement(new pi(t,e),"dragstart",e.event))},r.prototype._drag=function(e){var t=this._draggingTarget;if(t){var a=e.offsetX,n=e.offsetY,i=a-this._x,o=n-this._y;this._x=a,this._y=n,t.drift(i,o,e),this.handler.dispatchToElement(new pi(t,e),"drag",e.event);var s=this.handler.findHover(a,n,t).target,l=this._dropTarget;this._dropTarget=s,t!==s&&(l&&s!==l&&this.handler.dispatchToElement(new pi(l,e),"dragleave",e.event),s&&s!==l&&this.handler.dispatchToElement(new pi(s,e),"dragenter",e.event))}},r.prototype._dragEnd=function(e){var t=this._draggingTarget;t&&(t.dragging=!1),this.handler.dispatchToElement(new pi(t,e),"dragend",e.event),this._dropTarget&&this.handler.dispatchToElement(new pi(this._dropTarget,e),"drop",e.event),this._draggingTarget=null,this._dropTarget=null},r}(),OL=function(){function r(e){e&&(this._$eventProcessor=e)}return r.prototype.on=function(e,t,a,n){this._$handlers||(this._$handlers={});var i=this._$handlers;if(typeof t=="function"&&(n=a,a=t,t=null),!a||!e)return this;var o=this._$eventProcessor;t!=null&&o&&o.normalizeQuery&&(t=o.normalizeQuery(t)),i[e]||(i[e]=[]);for(var s=0;s<i[e].length;s++)if(i[e][s].h===a)return this;var l={h:a,query:t,ctx:n||this,callAtLast:a.zrEventfulCallAtLast},u=i[e].length-1,f=i[e][u];return f&&f.callAtLast?i[e].splice(u,0,l):i[e].push(l),this},r.prototype.isSilent=function(e){var t=this._$handlers;return!t||!t[e]||!t[e].length},r.prototype.off=function(e,t){var a=this._$handlers;if(!a)return this;if(!e)return this._$handlers={},this;if(t){if(a[e]){for(var n=[],i=0,o=a[e].length;i<o;i++)a[e][i].h!==t&&n.push(a[e][i]);a[e]=n}a[e]&&a[e].length===0&&delete a[e]}else delete a[e];return this},r.prototype.trigger=function(e){for(var t=[],a=1;a<arguments.length;a++)t[a-1]=arguments[a];if(!this._$handlers)return this;var n=this._$handlers[e],i=this._$eventProcessor;if(n)for(var o=t.length,s=n.length,l=0;l<s;l++){var u=n[l];if(!(i&&i.filter&&u.query!=null&&!i.filter(e,u.query)))switch(o){case 0:u.h.call(u.ctx);break;case 1:u.h.call(u.ctx,t[0]);break;case 2:u.h.call(u.ctx,t[0],t[1]);break;default:u.h.apply(u.ctx,t);break}}return i&&i.afterTrigger&&i.afterTrigger(e),this},r.prototype.triggerWithContext=function(e){for(var t=[],a=1;a<arguments.length;a++)t[a-1]=arguments[a];if(!this._$handlers)return this;var n=this._$handlers[e],i=this._$eventProcessor;if(n)for(var o=t.length,s=t[o-1],l=n.length,u=0;u<l;u++){var f=n[u];if(!(i&&i.filter&&f.query!=null&&!i.filter(e,f.query)))switch(o){case 0:f.h.call(s);break;case 1:f.h.call(s,t[0]);break;case 2:f.h.call(s,t[0],t[1]);break;default:f.h.apply(s,t.slice(1,o-1));break}}return i&&i.afterTrigger&&i.afterTrigger(e),this},r}();const or=OL;var NL=Math.log(2);function np(r,e,t,a,n,i){var o=a+"-"+n,s=r.length;if(i.hasOwnProperty(o))return i[o];if(e===1){var l=Math.round(Math.log((1<<s)-1&~n)/NL);return r[t][l]}for(var u=a|1<<t,f=t+1;a&1<<f;)f++;for(var h=0,v=0,c=0;v<s;v++){var p=1<<v;p&n||(h+=(c%2?-1:1)*r[t][v]*np(r,e-1,f,u,n|p,i),c++)}return i[o]=h,h}function nm(r,e){var t=[[r[0],r[1],1,0,0,0,-e[0]*r[0],-e[0]*r[1]],[0,0,0,r[0],r[1],1,-e[1]*r[0],-e[1]*r[1]],[r[2],r[3],1,0,0,0,-e[2]*r[2],-e[2]*r[3]],[0,0,0,r[2],r[3],1,-e[3]*r[2],-e[3]*r[3]],[r[4],r[5],1,0,0,0,-e[4]*r[4],-e[4]*r[5]],[0,0,0,r[4],r[5],1,-e[5]*r[4],-e[5]*r[5]],[r[6],r[7],1,0,0,0,-e[6]*r[6],-e[6]*r[7]],[0,0,0,r[6],r[7],1,-e[7]*r[6],-e[7]*r[7]]],a={},n=np(t,8,0,0,0,a);if(n!==0){for(var i=[],o=0;o<8;o++)for(var s=0;s<8;s++)i[s]==null&&(i[s]=0),i[s]+=((o+s)%2?-1:1)*np(t,7,o===0?1:0,1<<o,1<<s,a)/n*e[o];return function(l,u,f){var h=u*i[6]+f*i[7]+1;l[0]=(u*i[0]+f*i[1]+i[2])/h,l[1]=(u*i[3]+f*i[4]+i[5])/h}}}var im="___zrEVENTSAVED",Ih=[];function BL(r,e,t,a,n){return ip(Ih,e,a,n,!0)&&ip(r,t,Ih[0],Ih[1])}function ip(r,e,t,a,n){if(e.getBoundingClientRect&&mt.domSupported&&!gb(e)){var i=e[im]||(e[im]={}),o=VL(e,i),s=zL(o,i,n);if(s)return s(r,t,a),!0}return!1}function VL(r,e){var t=e.markers;if(t)return t;t=e.markers=[];for(var a=["left","right"],n=["top","bottom"],i=0;i<4;i++){var o=document.createElement("div"),s=o.style,l=i%2,u=(i>>1)%2;s.cssText=["position: absolute","visibility: hidden","padding: 0","margin: 0","border-width: 0","user-select: none","width:0","height:0",a[l]+":0",n[u]+":0",a[1-l]+":auto",n[1-u]+":auto",""].join("!important;"),r.appendChild(o),t.push(o)}return t}function zL(r,e,t){for(var a=t?"invTrans":"trans",n=e[a],i=e.srcCoords,o=[],s=[],l=!0,u=0;u<4;u++){var f=r[u].getBoundingClientRect(),h=2*u,v=f.left,c=f.top;o.push(v,c),l=l&&i&&v===i[h]&&c===i[h+1],s.push(r[u].offsetLeft,r[u].offsetTop)}return l&&n?n:(e.srcCoords=o,e[a]=t?nm(s,o):nm(o,s))}function gb(r){return r.nodeName.toUpperCase()==="CANVAS"}var GL=/([&<>"'])/g,FL={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"};function Re(r){return r==null?"":(r+"").replace(GL,function(e,t){return FL[t]})}var HL=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,Lh=[],WL=mt.browser.firefox&&+mt.browser.version.split(".")[0]<39;function op(r,e,t,a){return t=t||{},a?om(r,e,t):WL&&e.layerX!=null&&e.layerX!==e.offsetX?(t.zrX=e.layerX,t.zrY=e.layerY):e.offsetX!=null?(t.zrX=e.offsetX,t.zrY=e.offsetY):om(r,e,t),t}function om(r,e,t){if(mt.domSupported&&r.getBoundingClientRect){var a=e.clientX,n=e.clientY;if(gb(r)){var i=r.getBoundingClientRect();t.zrX=a-i.left,t.zrY=n-i.top;return}else if(ip(Lh,r,a,n)){t.zrX=Lh[0],t.zrY=Lh[1];return}}t.zrX=t.zrY=0}function Xd(r){return r||window.event}function qe(r,e,t){if(e=Xd(e),e.zrX!=null)return e;var a=e.type,n=a&&a.indexOf("touch")>=0;if(n){var o=a!=="touchend"?e.targetTouches[0]:e.changedTouches[0];o&&op(r,o,e,t)}else{op(r,e,e,t);var i=$L(e);e.zrDelta=i?i/120:-(e.detail||0)/3}var s=e.button;return e.which==null&&s!==void 0&&HL.test(e.type)&&(e.which=s&1?1:s&2?3:s&4?2:0),e}function $L(r){var e=r.wheelDelta;if(e)return e;var t=r.deltaX,a=r.deltaY;if(t==null||a==null)return e;var n=Math.abs(a!==0?a:t),i=a>0?-1:a<0?1:t>0?-1:1;return 3*n*i}function sp(r,e,t,a){r.addEventListener(e,t,a)}function UL(r,e,t,a){r.removeEventListener(e,t,a)}var ia=function(r){r.preventDefault(),r.stopPropagation(),r.cancelBubble=!0};function sm(r){return r.which===2||r.which===3}var YL=function(){function r(){this._track=[]}return r.prototype.recognize=function(e,t,a){return this._doTrack(e,t,a),this._recognize(e)},r.prototype.clear=function(){return this._track.length=0,this},r.prototype._doTrack=function(e,t,a){var n=e.touches;if(n){for(var i={points:[],touches:[],target:t,event:e},o=0,s=n.length;o<s;o++){var l=n[o],u=op(a,l,{});i.points.push([u.zrX,u.zrY]),i.touches.push(l)}this._track.push(i)}},r.prototype._recognize=function(e){for(var t in Ph)if(Ph.hasOwnProperty(t)){var a=Ph[t](this._track,e);if(a)return a}},r}();function lm(r){var e=r[1][0]-r[0][0],t=r[1][1]-r[0][1];return Math.sqrt(e*e+t*t)}function ZL(r){return[(r[0][0]+r[1][0])/2,(r[0][1]+r[1][1])/2]}var Ph={pinch:function(r,e){var t=r.length;if(t){var a=(r[t-1]||{}).points,n=(r[t-2]||{}).points||a;if(n&&n.length>1&&a&&a.length>1){var i=lm(a)/lm(n);!isFinite(i)&&(i=1),e.pinchScale=i;var o=ZL(a);return e.pinchX=o[0],e.pinchY=o[1],{type:"pinch",target:r[0].target,event:e}}}}};function Fe(){return[1,0,0,1,0,0]}function Yf(r){return r[0]=1,r[1]=0,r[2]=0,r[3]=1,r[4]=0,r[5]=0,r}function qd(r,e){return r[0]=e[0],r[1]=e[1],r[2]=e[2],r[3]=e[3],r[4]=e[4],r[5]=e[5],r}function ea(r,e,t){var a=e[0]*t[0]+e[2]*t[1],n=e[1]*t[0]+e[3]*t[1],i=e[0]*t[2]+e[2]*t[3],o=e[1]*t[2]+e[3]*t[3],s=e[0]*t[4]+e[2]*t[5]+e[4],l=e[1]*t[4]+e[3]*t[5]+e[5];return r[0]=a,r[1]=n,r[2]=i,r[3]=o,r[4]=s,r[5]=l,r}function Gr(r,e,t){return r[0]=e[0],r[1]=e[1],r[2]=e[2],r[3]=e[3],r[4]=e[4]+t[0],r[5]=e[5]+t[1],r}function oi(r,e,t,a){a===void 0&&(a=[0,0]);var n=e[0],i=e[2],o=e[4],s=e[1],l=e[3],u=e[5],f=Math.sin(t),h=Math.cos(t);return r[0]=n*h+s*f,r[1]=-n*f+s*h,r[2]=i*h+l*f,r[3]=-i*f+h*l,r[4]=h*(o-a[0])+f*(u-a[1])+a[0],r[5]=h*(u-a[1])-f*(o-a[0])+a[1],r}function Kd(r,e,t){var a=t[0],n=t[1];return r[0]=e[0]*a,r[1]=e[1]*n,r[2]=e[2]*a,r[3]=e[3]*n,r[4]=e[4]*a,r[5]=e[5]*n,r}function lo(r,e){var t=e[0],a=e[2],n=e[4],i=e[1],o=e[3],s=e[5],l=t*o-i*a;return l?(l=1/l,r[0]=o*l,r[1]=-i*l,r[2]=-a*l,r[3]=t*l,r[4]=(a*s-o*n)*l,r[5]=(i*n-t*s)*l,r):null}function XL(r){var e=Fe();return qd(e,r),e}var ut=function(){function r(e,t){this.x=e||0,this.y=t||0}return r.prototype.copy=function(e){return this.x=e.x,this.y=e.y,this},r.prototype.clone=function(){return new r(this.x,this.y)},r.prototype.set=function(e,t){return this.x=e,this.y=t,this},r.prototype.equal=function(e){return e.x===this.x&&e.y===this.y},r.prototype.add=function(e){return this.x+=e.x,this.y+=e.y,this},r.prototype.scale=function(e){this.x*=e,this.y*=e},r.prototype.scaleAndAdd=function(e,t){this.x+=e.x*t,this.y+=e.y*t},r.prototype.sub=function(e){return this.x-=e.x,this.y-=e.y,this},r.prototype.dot=function(e){return this.x*e.x+this.y*e.y},r.prototype.len=function(){return Math.sqrt(this.x*this.x+this.y*this.y)},r.prototype.lenSquare=function(){return this.x*this.x+this.y*this.y},r.prototype.normalize=function(){var e=this.len();return this.x/=e,this.y/=e,this},r.prototype.distance=function(e){var t=this.x-e.x,a=this.y-e.y;return Math.sqrt(t*t+a*a)},r.prototype.distanceSquare=function(e){var t=this.x-e.x,a=this.y-e.y;return t*t+a*a},r.prototype.negate=function(){return this.x=-this.x,this.y=-this.y,this},r.prototype.transform=function(e){if(e){var t=this.x,a=this.y;return this.x=e[0]*t+e[2]*a+e[4],this.y=e[1]*t+e[3]*a+e[5],this}},r.prototype.toArray=function(e){return e[0]=this.x,e[1]=this.y,e},r.prototype.fromArray=function(e){this.x=e[0],this.y=e[1]},r.set=function(e,t,a){e.x=t,e.y=a},r.copy=function(e,t){e.x=t.x,e.y=t.y},r.len=function(e){return Math.sqrt(e.x*e.x+e.y*e.y)},r.lenSquare=function(e){return e.x*e.x+e.y*e.y},r.dot=function(e,t){return e.x*t.x+e.y*t.y},r.add=function(e,t,a){e.x=t.x+a.x,e.y=t.y+a.y},r.sub=function(e,t,a){e.x=t.x-a.x,e.y=t.y-a.y},r.scale=function(e,t,a){e.x=t.x*a,e.y=t.y*a},r.scaleAndAdd=function(e,t,a,n){e.x=t.x+a.x*n,e.y=t.y+a.y*n},r.lerp=function(e,t,a,n){var i=1-n;e.x=i*t.x+n*a.x,e.y=i*t.y+n*a.y},r}(),Cl=Math.min,Dl=Math.max,tn=new ut,en=new ut,rn=new ut,an=new ut,Ao=new ut,Co=new ut,qL=function(){function r(e,t,a,n){a<0&&(e=e+a,a=-a),n<0&&(t=t+n,n=-n),this.x=e,this.y=t,this.width=a,this.height=n}return r.prototype.union=function(e){var t=Cl(e.x,this.x),a=Cl(e.y,this.y);isFinite(this.x)&&isFinite(this.width)?this.width=Dl(e.x+e.width,this.x+this.width)-t:this.width=e.width,isFinite(this.y)&&isFinite(this.height)?this.height=Dl(e.y+e.height,this.y+this.height)-a:this.height=e.height,this.x=t,this.y=a},r.prototype.applyTransform=function(e){r.applyTransform(this,this,e)},r.prototype.calculateTransform=function(e){var t=this,a=e.width/t.width,n=e.height/t.height,i=Fe();return Gr(i,i,[-t.x,-t.y]),Kd(i,i,[a,n]),Gr(i,i,[e.x,e.y]),i},r.prototype.intersect=function(e,t){if(!e)return!1;e instanceof r||(e=r.create(e));var a=this,n=a.x,i=a.x+a.width,o=a.y,s=a.y+a.height,l=e.x,u=e.x+e.width,f=e.y,h=e.y+e.height,v=!(i<l||u<n||s<f||h<o);if(t){var c=1/0,p=0,d=Math.abs(i-l),g=Math.abs(u-n),y=Math.abs(s-f),m=Math.abs(h-o),_=Math.min(d,g),S=Math.min(y,m);i<l||u<n?_>p&&(p=_,d<g?ut.set(Co,-d,0):ut.set(Co,g,0)):_<c&&(c=_,d<g?ut.set(Ao,d,0):ut.set(Ao,-g,0)),s<f||h<o?S>p&&(p=S,y<m?ut.set(Co,0,-y):ut.set(Co,0,m)):_<c&&(c=_,y<m?ut.set(Ao,0,y):ut.set(Ao,0,-m))}return t&&ut.copy(t,v?Ao:Co),v},r.prototype.contain=function(e,t){var a=this;return e>=a.x&&e<=a.x+a.width&&t>=a.y&&t<=a.y+a.height},r.prototype.clone=function(){return new r(this.x,this.y,this.width,this.height)},r.prototype.copy=function(e){r.copy(this,e)},r.prototype.plain=function(){return{x:this.x,y:this.y,width:this.width,height:this.height}},r.prototype.isFinite=function(){return isFinite(this.x)&&isFinite(this.y)&&isFinite(this.width)&&isFinite(this.height)},r.prototype.isZero=function(){return this.width===0||this.height===0},r.create=function(e){return new r(e.x,e.y,e.width,e.height)},r.copy=function(e,t){e.x=t.x,e.y=t.y,e.width=t.width,e.height=t.height},r.applyTransform=function(e,t,a){if(!a){e!==t&&r.copy(e,t);return}if(a[1]<1e-5&&a[1]>-1e-5&&a[2]<1e-5&&a[2]>-1e-5){var n=a[0],i=a[3],o=a[4],s=a[5];e.x=t.x*n+o,e.y=t.y*i+s,e.width=t.width*n,e.height=t.height*i,e.width<0&&(e.x+=e.width,e.width=-e.width),e.height<0&&(e.y+=e.height,e.height=-e.height);return}tn.x=rn.x=t.x,tn.y=an.y=t.y,en.x=an.x=t.x+t.width,en.y=rn.y=t.y+t.height,tn.transform(a),an.transform(a),en.transform(a),rn.transform(a),e.x=Cl(tn.x,en.x,rn.x,an.x),e.y=Cl(tn.y,en.y,rn.y,an.y);var l=Dl(tn.x,en.x,rn.x,an.x),u=Dl(tn.y,en.y,rn.y,an.y);e.width=l-e.x,e.height=u-e.y},r}();const ht=qL;var yb="silent";function KL(r,e,t){return{type:r,event:t,target:e.target,topTarget:e.topTarget,cancelBubble:!1,offsetX:t.zrX,offsetY:t.zrY,gestureEvent:t.gestureEvent,pinchX:t.pinchX,pinchY:t.pinchY,pinchScale:t.pinchScale,wheelDelta:t.zrDelta,zrByTouch:t.zrByTouch,which:t.which,stop:QL}}function QL(){ia(this.event)}var JL=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.handler=null,t}return e.prototype.dispose=function(){},e.prototype.setCursor=function(){},e}(or),Do=function(){function r(e,t){this.x=e,this.y=t}return r}(),jL=["click","dblclick","mousewheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],Rh=new ht(0,0,0,0),mb=function(r){k(e,r);function e(t,a,n,i,o){var s=r.call(this)||this;return s._hovered=new Do(0,0),s.storage=t,s.painter=a,s.painterRoot=i,s._pointerSize=o,n=n||new JL,s.proxy=null,s.setHandlerProxy(n),s._draggingMgr=new kL(s),s}return e.prototype.setHandlerProxy=function(t){this.proxy&&this.proxy.dispose(),t&&(C(jL,function(a){t.on&&t.on(a,this[a],this)},this),t.handler=this),this.proxy=t},e.prototype.mousemove=function(t){var a=t.zrX,n=t.zrY,i=_b(this,a,n),o=this._hovered,s=o.target;s&&!s.__zr&&(o=this.findHover(o.x,o.y),s=o.target);var l=this._hovered=i?new Do(a,n):this.findHover(a,n),u=l.target,f=this.proxy;f.setCursor&&f.setCursor(u?u.cursor:"default"),s&&u!==s&&this.dispatchToElement(o,"mouseout",t),this.dispatchToElement(l,"mousemove",t),u&&u!==s&&this.dispatchToElement(l,"mouseover",t)},e.prototype.mouseout=function(t){var a=t.zrEventControl;a!=="only_globalout"&&this.dispatchToElement(this._hovered,"mouseout",t),a!=="no_globalout"&&this.trigger("globalout",{type:"globalout",event:t})},e.prototype.resize=function(){this._hovered=new Do(0,0)},e.prototype.dispatch=function(t,a){var n=this[t];n&&n.call(this,a)},e.prototype.dispose=function(){this.proxy.dispose(),this.storage=null,this.proxy=null,this.painter=null},e.prototype.setCursorStyle=function(t){var a=this.proxy;a.setCursor&&a.setCursor(t)},e.prototype.dispatchToElement=function(t,a,n){t=t||{};var i=t.target;if(!(i&&i.silent)){for(var o="on"+a,s=KL(a,t,n);i&&(i[o]&&(s.cancelBubble=!!i[o].call(i,s)),i.trigger(a,s),i=i.__hostTarget?i.__hostTarget:i.parent,!s.cancelBubble););s.cancelBubble||(this.trigger(a,s),this.painter&&this.painter.eachOtherLayer&&this.painter.eachOtherLayer(function(l){typeof l[o]=="function"&&l[o].call(l,s),l.trigger&&l.trigger(a,s)}))}},e.prototype.findHover=function(t,a,n){var i=this.storage.getDisplayList(),o=new Do(t,a);if(um(i,o,t,a,n),this._pointerSize&&!o.target){for(var s=[],l=this._pointerSize,u=l/2,f=new ht(t-u,a-u,l,l),h=i.length-1;h>=0;h--){var v=i[h];v!==n&&!v.ignore&&!v.ignoreCoarsePointer&&(!v.parent||!v.parent.ignoreCoarsePointer)&&(Rh.copy(v.getBoundingRect()),v.transform&&Rh.applyTransform(v.transform),Rh.intersect(f)&&s.push(v))}if(s.length)for(var c=4,p=Math.PI/12,d=Math.PI*2,g=0;g<u;g+=c)for(var y=0;y<d;y+=p){var m=t+g*Math.cos(y),_=a+g*Math.sin(y);if(um(s,o,m,_,n),o.target)return o}}return o},e.prototype.processGesture=function(t,a){this._gestureMgr||(this._gestureMgr=new YL);var n=this._gestureMgr;a==="start"&&n.clear();var i=n.recognize(t,this.findHover(t.zrX,t.zrY,null).target,this.proxy.dom);if(a==="end"&&n.clear(),i){var o=i.type;t.gestureEvent=o;var s=new Do;s.target=i.target,this.dispatchToElement(s,o,i.event)}},e}(or);C(["click","mousedown","mouseup","mousewheel","dblclick","contextmenu"],function(r){mb.prototype[r]=function(e){var t=e.zrX,a=e.zrY,n=_b(this,t,a),i,o;if((r!=="mouseup"||!n)&&(i=this.findHover(t,a),o=i.target),r==="mousedown")this._downEl=o,this._downPoint=[e.zrX,e.zrY],this._upEl=o;else if(r==="mouseup")this._upEl=o;else if(r==="click"){if(this._downEl!==this._upEl||!this._downPoint||Ma(this._downPoint,[e.zrX,e.zrY])>4)return;this._downPoint=null}this.dispatchToElement(i,r,e)}});function t2(r,e,t){if(r[r.rectHover?"rectContain":"contain"](e,t)){for(var a=r,n=void 0,i=!1;a;){if(a.ignoreClip&&(i=!0),!i){var o=a.getClipPath();if(o&&!o.contain(e,t))return!1}a.silent&&(n=!0);var s=a.__hostTarget;a=s||a.parent}return n?yb:!0}return!1}function um(r,e,t,a,n){for(var i=r.length-1;i>=0;i--){var o=r[i],s=void 0;if(o!==n&&!o.ignore&&(s=t2(o,t,a))&&(!e.topTarget&&(e.topTarget=o),s!==yb)){e.target=o;break}}}function _b(r,e,t){var a=r.painter;return e<0||e>a.getWidth()||t<0||t>a.getHeight()}const e2=mb;var Sb=32,Mo=7;function r2(r){for(var e=0;r>=Sb;)e|=r&1,r>>=1;return r+e}function fm(r,e,t,a){var n=e+1;if(n===t)return 1;if(a(r[n++],r[e])<0){for(;n<t&&a(r[n],r[n-1])<0;)n++;a2(r,e,n)}else for(;n<t&&a(r[n],r[n-1])>=0;)n++;return n-e}function a2(r,e,t){for(t--;e<t;){var a=r[e];r[e++]=r[t],r[t--]=a}}function hm(r,e,t,a,n){for(a===e&&a++;a<t;a++){for(var i=r[a],o=e,s=a,l;o<s;)l=o+s>>>1,n(i,r[l])<0?s=l:o=l+1;var u=a-o;switch(u){case 3:r[o+3]=r[o+2];case 2:r[o+2]=r[o+1];case 1:r[o+1]=r[o];break;default:for(;u>0;)r[o+u]=r[o+u-1],u--}r[o]=i}}function Eh(r,e,t,a,n,i){var o=0,s=0,l=1;if(i(r,e[t+n])>0){for(s=a-n;l<s&&i(r,e[t+n+l])>0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=n,l+=n}else{for(s=n+1;l<s&&i(r,e[t+n-l])<=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=n-l,l=n-u}for(o++;o<l;){var f=o+(l-o>>>1);i(r,e[t+f])>0?o=f+1:l=f}return l}function kh(r,e,t,a,n,i){var o=0,s=0,l=1;if(i(r,e[t+n])<0){for(s=n+1;l<s&&i(r,e[t+n-l])<0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=n-l,l=n-u}else{for(s=a-n;l<s&&i(r,e[t+n+l])>=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=n,l+=n}for(o++;o<l;){var f=o+(l-o>>>1);i(r,e[t+f])<0?l=f:o=f+1}return l}function n2(r,e){var t=Mo,a,n,i=0,o=[];a=[],n=[];function s(c,p){a[i]=c,n[i]=p,i+=1}function l(){for(;i>1;){var c=i-2;if(c>=1&&n[c-1]<=n[c]+n[c+1]||c>=2&&n[c-2]<=n[c]+n[c-1])n[c-1]<n[c+1]&&c--;else if(n[c]>n[c+1])break;f(c)}}function u(){for(;i>1;){var c=i-2;c>0&&n[c-1]<n[c+1]&&c--,f(c)}}function f(c){var p=a[c],d=n[c],g=a[c+1],y=n[c+1];n[c]=d+y,c===i-3&&(a[c+1]=a[c+2],n[c+1]=n[c+2]),i--;var m=kh(r[g],r,p,d,0,e);p+=m,d-=m,d!==0&&(y=Eh(r[p+d-1],r,g,y,y-1,e),y!==0&&(d<=y?h(p,d,g,y):v(p,d,g,y)))}function h(c,p,d,g){var y=0;for(y=0;y<p;y++)o[y]=r[c+y];var m=0,_=d,S=c;if(r[S++]=r[_++],--g===0){for(y=0;y<p;y++)r[S+y]=o[m+y];return}if(p===1){for(y=0;y<g;y++)r[S+y]=r[_+y];r[S+g]=o[m];return}for(var w=t,x,b,T;;){x=0,b=0,T=!1;do if(e(r[_],o[m])<0){if(r[S++]=r[_++],b++,x=0,--g===0){T=!0;break}}else if(r[S++]=o[m++],x++,b=0,--p===1){T=!0;break}while((x|b)<w);if(T)break;do{if(x=kh(r[_],o,m,p,0,e),x!==0){for(y=0;y<x;y++)r[S+y]=o[m+y];if(S+=x,m+=x,p-=x,p<=1){T=!0;break}}if(r[S++]=r[_++],--g===0){T=!0;break}if(b=Eh(o[m],r,_,g,0,e),b!==0){for(y=0;y<b;y++)r[S+y]=r[_+y];if(S+=b,_+=b,g-=b,g===0){T=!0;break}}if(r[S++]=o[m++],--p===1){T=!0;break}w--}while(x>=Mo||b>=Mo);if(T)break;w<0&&(w=0),w+=2}if(t=w,t<1&&(t=1),p===1){for(y=0;y<g;y++)r[S+y]=r[_+y];r[S+g]=o[m]}else{if(p===0)throw new Error;for(y=0;y<p;y++)r[S+y]=o[m+y]}}function v(c,p,d,g){var y=0;for(y=0;y<g;y++)o[y]=r[d+y];var m=c+p-1,_=g-1,S=d+g-1,w=0,x=0;if(r[S--]=r[m--],--p===0){for(w=S-(g-1),y=0;y<g;y++)r[w+y]=o[y];return}if(g===1){for(S-=p,m-=p,x=S+1,w=m+1,y=p-1;y>=0;y--)r[x+y]=r[w+y];r[S]=o[_];return}for(var b=t;;){var T=0,A=0,D=!1;do if(e(o[_],r[m])<0){if(r[S--]=r[m--],T++,A=0,--p===0){D=!0;break}}else if(r[S--]=o[_--],A++,T=0,--g===1){D=!0;break}while((T|A)<b);if(D)break;do{if(T=p-kh(o[_],r,c,p,p-1,e),T!==0){for(S-=T,m-=T,p-=T,x=S+1,w=m+1,y=T-1;y>=0;y--)r[x+y]=r[w+y];if(p===0){D=!0;break}}if(r[S--]=o[_--],--g===1){D=!0;break}if(A=g-Eh(r[m],o,0,g,g-1,e),A!==0){for(S-=A,_-=A,g-=A,x=S+1,w=_+1,y=0;y<A;y++)r[x+y]=o[w+y];if(g<=1){D=!0;break}}if(r[S--]=r[m--],--p===0){D=!0;break}b--}while(T>=Mo||A>=Mo);if(D)break;b<0&&(b=0),b+=2}if(t=b,t<1&&(t=1),g===1){for(S-=p,m-=p,x=S+1,w=m+1,y=p-1;y>=0;y--)r[x+y]=r[w+y];r[S]=o[_]}else{if(g===0)throw new Error;for(w=S-(g-1),y=0;y<g;y++)r[w+y]=o[y]}}return{mergeRuns:l,forceMergeRuns:u,pushRun:s}}function Pu(r,e,t,a){t||(t=0),a||(a=r.length);var n=a-t;if(!(n<2)){var i=0;if(n<Sb){i=fm(r,t,a,e),hm(r,t,a,t+i,e);return}var o=n2(r,e),s=r2(n);do{if(i=fm(r,t,a,e),i<s){var l=n;l>s&&(l=s),hm(r,t,t+l,t+i,e),i=l}o.pushRun(t,i),o.mergeRuns(),n-=i,t+=i}while(n!==0);o.forceMergeRuns()}}var ze=1,ts=2,Oi=4,vm=!1;function Oh(){vm||(vm=!0,console.warn("z / z2 / zlevel of displayable is invalid, which may cause unexpected errors"))}function cm(r,e){return r.zlevel===e.zlevel?r.z===e.z?r.z2-e.z2:r.z-e.z:r.zlevel-e.zlevel}var i2=function(){function r(){this._roots=[],this._displayList=[],this._displayListLen=0,this.displayableSortFunc=cm}return r.prototype.traverse=function(e,t){for(var a=0;a<this._roots.length;a++)this._roots[a].traverse(e,t)},r.prototype.getDisplayList=function(e,t){t=t||!1;var a=this._displayList;return(e||!a.length)&&this.updateDisplayList(t),a},r.prototype.updateDisplayList=function(e){this._displayListLen=0;for(var t=this._roots,a=this._displayList,n=0,i=t.length;n<i;n++)this._updateAndAddDisplayable(t[n],null,e);a.length=this._displayListLen,Pu(a,cm)},r.prototype._updateAndAddDisplayable=function(e,t,a){if(!(e.ignore&&!a)){e.beforeUpdate(),e.update(),e.afterUpdate();var n=e.getClipPath();if(e.ignoreClip)t=null;else if(n){t?t=t.slice():t=[];for(var i=n,o=e;i;)i.parent=o,i.updateTransform(),t.push(i),o=i,i=i.getClipPath()}if(e.childrenRef){for(var s=e.childrenRef(),l=0;l<s.length;l++){var u=s[l];e.__dirty&&(u.__dirty|=ze),this._updateAndAddDisplayable(u,t,a)}e.__dirty=0}else{var f=e;t&&t.length?f.__clipPaths=t:f.__clipPaths&&f.__clipPaths.length>0&&(f.__clipPaths=[]),isNaN(f.z)&&(Oh(),f.z=0),isNaN(f.z2)&&(Oh(),f.z2=0),isNaN(f.zlevel)&&(Oh(),f.zlevel=0),this._displayList[this._displayListLen++]=f}var h=e.getDecalElement&&e.getDecalElement();h&&this._updateAndAddDisplayable(h,t,a);var v=e.getTextGuideLine();v&&this._updateAndAddDisplayable(v,t,a);var c=e.getTextContent();c&&this._updateAndAddDisplayable(c,t,a)}},r.prototype.addRoot=function(e){e.__zr&&e.__zr.storage===this||this._roots.push(e)},r.prototype.delRoot=function(e){if(e instanceof Array){for(var t=0,a=e.length;t<a;t++)this.delRoot(e[t]);return}var n=vt(this._roots,e);n>=0&&this._roots.splice(n,1)},r.prototype.delAllRoots=function(){this._roots=[],this._displayList=[],this._displayListLen=0},r.prototype.getRoots=function(){return this._roots},r.prototype.dispose=function(){this._displayList=null,this._roots=null},r}(),xb;xb=mt.hasGlobalWindow&&(window.requestAnimationFrame&&window.requestAnimationFrame.bind(window)||window.msRequestAnimationFrame&&window.msRequestAnimationFrame.bind(window)||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame)||function(r){return setTimeout(r,16)};const lp=xb;var cs={linear:function(r){return r},quadraticIn:function(r){return r*r},quadraticOut:function(r){return r*(2-r)},quadraticInOut:function(r){return(r*=2)<1?.5*r*r:-.5*(--r*(r-2)-1)},cubicIn:function(r){return r*r*r},cubicOut:function(r){return--r*r*r+1},cubicInOut:function(r){return(r*=2)<1?.5*r*r*r:.5*((r-=2)*r*r+2)},quarticIn:function(r){return r*r*r*r},quarticOut:function(r){return 1- --r*r*r*r},quarticInOut:function(r){return(r*=2)<1?.5*r*r*r*r:-.5*((r-=2)*r*r*r-2)},quinticIn:function(r){return r*r*r*r*r},quinticOut:function(r){return--r*r*r*r*r+1},quinticInOut:function(r){return(r*=2)<1?.5*r*r*r*r*r:.5*((r-=2)*r*r*r*r+2)},sinusoidalIn:function(r){return 1-Math.cos(r*Math.PI/2)},sinusoidalOut:function(r){return Math.sin(r*Math.PI/2)},sinusoidalInOut:function(r){return .5*(1-Math.cos(Math.PI*r))},exponentialIn:function(r){return r===0?0:Math.pow(1024,r-1)},exponentialOut:function(r){return r===1?1:1-Math.pow(2,-10*r)},exponentialInOut:function(r){return r===0?0:r===1?1:(r*=2)<1?.5*Math.pow(1024,r-1):.5*(-Math.pow(2,-10*(r-1))+2)},circularIn:function(r){return 1-Math.sqrt(1-r*r)},circularOut:function(r){return Math.sqrt(1- --r*r)},circularInOut:function(r){return(r*=2)<1?-.5*(Math.sqrt(1-r*r)-1):.5*(Math.sqrt(1-(r-=2)*r)+1)},elasticIn:function(r){var e,t=.1,a=.4;return r===0?0:r===1?1:(!t||t<1?(t=1,e=a/4):e=a*Math.asin(1/t)/(2*Math.PI),-(t*Math.pow(2,10*(r-=1))*Math.sin((r-e)*(2*Math.PI)/a)))},elasticOut:function(r){var e,t=.1,a=.4;return r===0?0:r===1?1:(!t||t<1?(t=1,e=a/4):e=a*Math.asin(1/t)/(2*Math.PI),t*Math.pow(2,-10*r)*Math.sin((r-e)*(2*Math.PI)/a)+1)},elasticInOut:function(r){var e,t=.1,a=.4;return r===0?0:r===1?1:(!t||t<1?(t=1,e=a/4):e=a*Math.asin(1/t)/(2*Math.PI),(r*=2)<1?-.5*(t*Math.pow(2,10*(r-=1))*Math.sin((r-e)*(2*Math.PI)/a)):t*Math.pow(2,-10*(r-=1))*Math.sin((r-e)*(2*Math.PI)/a)*.5+1)},backIn:function(r){var e=1.70158;return r*r*((e+1)*r-e)},backOut:function(r){var e=1.70158;return--r*r*((e+1)*r+e)+1},backInOut:function(r){var e=2.5949095;return(r*=2)<1?.5*(r*r*((e+1)*r-e)):.5*((r-=2)*r*((e+1)*r+e)+2)},bounceIn:function(r){return 1-cs.bounceOut(1-r)},bounceOut:function(r){return r<1/2.75?7.5625*r*r:r<2/2.75?7.5625*(r-=1.5/2.75)*r+.75:r<2.5/2.75?7.5625*(r-=2.25/2.75)*r+.9375:7.5625*(r-=2.625/2.75)*r+.984375},bounceInOut:function(r){return r<.5?cs.bounceIn(r*2)*.5:cs.bounceOut(r*2-1)*.5+.5}},Ml=Math.pow,Ba=Math.sqrt,Ku=1e-8,wb=1e-4,pm=Ba(3),Il=1/3,Pr=ii(),je=ii(),$i=ii();function Pa(r){return r>-Ku&&r<Ku}function bb(r){return r>Ku||r<-Ku}function jt(r,e,t,a,n){var i=1-n;return i*i*(i*r+3*n*e)+n*n*(n*a+3*i*t)}function dm(r,e,t,a,n){var i=1-n;return 3*(((e-r)*i+2*(t-e)*n)*i+(a-t)*n*n)}function Qu(r,e,t,a,n,i){var o=a+3*(e-t)-r,s=3*(t-e*2+r),l=3*(e-r),u=r-n,f=s*s-3*o*l,h=s*l-9*o*u,v=l*l-3*s*u,c=0;if(Pa(f)&&Pa(h))if(Pa(s))i[0]=0;else{var p=-l/s;p>=0&&p<=1&&(i[c++]=p)}else{var d=h*h-4*f*v;if(Pa(d)){var g=h/f,p=-s/o+g,y=-g/2;p>=0&&p<=1&&(i[c++]=p),y>=0&&y<=1&&(i[c++]=y)}else if(d>0){var m=Ba(d),_=f*s+1.5*o*(-h+m),S=f*s+1.5*o*(-h-m);_<0?_=-Ml(-_,Il):_=Ml(_,Il),S<0?S=-Ml(-S,Il):S=Ml(S,Il);var p=(-s-(_+S))/(3*o);p>=0&&p<=1&&(i[c++]=p)}else{var w=(2*f*s-3*o*h)/(2*Ba(f*f*f)),x=Math.acos(w)/3,b=Ba(f),T=Math.cos(x),p=(-s-2*b*T)/(3*o),y=(-s+b*(T+pm*Math.sin(x)))/(3*o),A=(-s+b*(T-pm*Math.sin(x)))/(3*o);p>=0&&p<=1&&(i[c++]=p),y>=0&&y<=1&&(i[c++]=y),A>=0&&A<=1&&(i[c++]=A)}}return c}function Tb(r,e,t,a,n){var i=6*t-12*e+6*r,o=9*e+3*a-3*r-9*t,s=3*e-3*r,l=0;if(Pa(o)){if(bb(i)){var u=-s/i;u>=0&&u<=1&&(n[l++]=u)}}else{var f=i*i-4*o*s;if(Pa(f))n[0]=-i/(2*o);else if(f>0){var h=Ba(f),u=(-i+h)/(2*o),v=(-i-h)/(2*o);u>=0&&u<=1&&(n[l++]=u),v>=0&&v<=1&&(n[l++]=v)}}return l}function Wa(r,e,t,a,n,i){var o=(e-r)*n+r,s=(t-e)*n+e,l=(a-t)*n+t,u=(s-o)*n+o,f=(l-s)*n+s,h=(f-u)*n+u;i[0]=r,i[1]=o,i[2]=u,i[3]=h,i[4]=h,i[5]=f,i[6]=l,i[7]=a}function Ab(r,e,t,a,n,i,o,s,l,u,f){var h,v=.005,c=1/0,p,d,g,y;Pr[0]=l,Pr[1]=u;for(var m=0;m<1;m+=.05)je[0]=jt(r,t,n,o,m),je[1]=jt(e,a,i,s,m),g=Wn(Pr,je),g<c&&(h=m,c=g);c=1/0;for(var _=0;_<32&&!(v<wb);_++)p=h-v,d=h+v,je[0]=jt(r,t,n,o,p),je[1]=jt(e,a,i,s,p),g=Wn(je,Pr),p>=0&&g<c?(h=p,c=g):($i[0]=jt(r,t,n,o,d),$i[1]=jt(e,a,i,s,d),y=Wn($i,Pr),d<=1&&y<c?(h=d,c=y):v*=.5);return f&&(f[0]=jt(r,t,n,o,h),f[1]=jt(e,a,i,s,h)),Ba(c)}function o2(r,e,t,a,n,i,o,s,l){for(var u=r,f=e,h=0,v=1/l,c=1;c<=l;c++){var p=c*v,d=jt(r,t,n,o,p),g=jt(e,a,i,s,p),y=d-u,m=g-f;h+=Math.sqrt(y*y+m*m),u=d,f=g}return h}function ne(r,e,t,a){var n=1-a;return n*(n*r+2*a*e)+a*a*t}function up(r,e,t,a){return 2*((1-a)*(e-r)+a*(t-e))}function s2(r,e,t,a,n){var i=r-2*e+t,o=2*(e-r),s=r-a,l=0;if(Pa(i)){if(bb(o)){var u=-s/o;u>=0&&u<=1&&(n[l++]=u)}}else{var f=o*o-4*i*s;if(Pa(f)){var u=-o/(2*i);u>=0&&u<=1&&(n[l++]=u)}else if(f>0){var h=Ba(f),u=(-o+h)/(2*i),v=(-o-h)/(2*i);u>=0&&u<=1&&(n[l++]=u),v>=0&&v<=1&&(n[l++]=v)}}return l}function Cb(r,e,t){var a=r+t-2*e;return a===0?.5:(r-e)/a}function Ls(r,e,t,a,n){var i=(e-r)*a+r,o=(t-e)*a+e,s=(o-i)*a+i;n[0]=r,n[1]=i,n[2]=s,n[3]=s,n[4]=o,n[5]=t}function Db(r,e,t,a,n,i,o,s,l){var u,f=.005,h=1/0;Pr[0]=o,Pr[1]=s;for(var v=0;v<1;v+=.05){je[0]=ne(r,t,n,v),je[1]=ne(e,a,i,v);var c=Wn(Pr,je);c<h&&(u=v,h=c)}h=1/0;for(var p=0;p<32&&!(f<wb);p++){var d=u-f,g=u+f;je[0]=ne(r,t,n,d),je[1]=ne(e,a,i,d);var c=Wn(je,Pr);if(d>=0&&c<h)u=d,h=c;else{$i[0]=ne(r,t,n,g),$i[1]=ne(e,a,i,g);var y=Wn($i,Pr);g<=1&&y<h?(u=g,h=y):f*=.5}}return l&&(l[0]=ne(r,t,n,u),l[1]=ne(e,a,i,u)),Ba(h)}function l2(r,e,t,a,n,i,o){for(var s=r,l=e,u=0,f=1/o,h=1;h<=o;h++){var v=h*f,c=ne(r,t,n,v),p=ne(e,a,i,v),d=c-s,g=p-l;u+=Math.sqrt(d*d+g*g),s=c,l=p}return u}var u2=/cubic-bezier\(([0-9,\.e ]+)\)/;function Qd(r){var e=r&&u2.exec(r);if(e){var t=e[1].split(","),a=+dr(t[0]),n=+dr(t[1]),i=+dr(t[2]),o=+dr(t[3]);if(isNaN(a+n+i+o))return;var s=[];return function(l){return l<=0?0:l>=1?1:Qu(0,a,i,1,l,s)&&jt(0,n,o,1,s[0])}}}var f2=function(){function r(e){this._inited=!1,this._startTime=0,this._pausedTime=0,this._paused=!1,this._life=e.life||1e3,this._delay=e.delay||0,this.loop=e.loop||!1,this.onframe=e.onframe||Yt,this.ondestroy=e.ondestroy||Yt,this.onrestart=e.onrestart||Yt,e.easing&&this.setEasing(e.easing)}return r.prototype.step=function(e,t){if(this._inited||(this._startTime=e+this._delay,this._inited=!0),this._paused){this._pausedTime+=t;return}var a=this._life,n=e-this._startTime-this._pausedTime,i=n/a;i<0&&(i=0),i=Math.min(i,1);var o=this.easingFunc,s=o?o(i):i;if(this.onframe(s),i===1)if(this.loop){var l=n%a;this._startTime=e-l,this._pausedTime=0,this.onrestart()}else return!0;return!1},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){this._paused=!1},r.prototype.setEasing=function(e){this.easing=e,this.easingFunc=K(e)?e:cs[e]||Qd(e)},r}();const h2=f2;var Mb=function(){function r(e){this.value=e}return r}(),v2=function(){function r(){this._len=0}return r.prototype.insert=function(e){var t=new Mb(e);return this.insertEntry(t),t},r.prototype.insertEntry=function(e){this.head?(this.tail.next=e,e.prev=this.tail,e.next=null,this.tail=e):this.head=this.tail=e,this._len++},r.prototype.remove=function(e){var t=e.prev,a=e.next;t?t.next=a:this.head=a,a?a.prev=t:this.tail=t,e.next=e.prev=null,this._len--},r.prototype.len=function(){return this._len},r.prototype.clear=function(){this.head=this.tail=null,this._len=0},r}(),nl=function(){function r(e){this._list=new v2,this._maxSize=10,this._map={},this._maxSize=e}return r.prototype.put=function(e,t){var a=this._list,n=this._map,i=null;if(n[e]==null){var o=a.len(),s=this._lastRemovedEntry;if(o>=this._maxSize&&o>0){var l=a.head;a.remove(l),delete n[l.key],i=l.value,this._lastRemovedEntry=l}s?s.value=t:s=new Mb(t),s.key=e,a.insertEntry(s),n[e]=s}return i},r.prototype.get=function(e){var t=this._map[e],a=this._list;if(t!=null)return t!==a.tail&&(a.remove(t),a.insertEntry(t)),t.value},r.prototype.clear=function(){this._list.clear(),this._map={}},r.prototype.len=function(){return this._list.len()},r}(),gm={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function yr(r){return r=Math.round(r),r<0?0:r>255?255:r}function c2(r){return r=Math.round(r),r<0?0:r>360?360:r}function Ps(r){return r<0?0:r>1?1:r}function Nh(r){var e=r;return e.length&&e.charAt(e.length-1)==="%"?yr(parseFloat(e)/100*255):yr(parseInt(e,10))}function $n(r){var e=r;return e.length&&e.charAt(e.length-1)==="%"?Ps(parseFloat(e)/100):Ps(parseFloat(e))}function Bh(r,e,t){return t<0?t+=1:t>1&&(t-=1),t*6<1?r+(e-r)*t*6:t*2<1?e:t*3<2?r+(e-r)*(2/3-t)*6:r}function Ra(r,e,t){return r+(e-r)*t}function Xe(r,e,t,a,n){return r[0]=e,r[1]=t,r[2]=a,r[3]=n,r}function fp(r,e){return r[0]=e[0],r[1]=e[1],r[2]=e[2],r[3]=e[3],r}var Ib=new nl(20),Ll=null;function di(r,e){Ll&&fp(Ll,e),Ll=Ib.put(r,Ll||e.slice())}function He(r,e){if(r){e=e||[];var t=Ib.get(r);if(t)return fp(e,t);r=r+"";var a=r.replace(/ /g,"").toLowerCase();if(a in gm)return fp(e,gm[a]),di(r,e),e;var n=a.length;if(a.charAt(0)==="#"){if(n===4||n===5){var i=parseInt(a.slice(1,4),16);if(!(i>=0&&i<=4095)){Xe(e,0,0,0,1);return}return Xe(e,(i&3840)>>4|(i&3840)>>8,i&240|(i&240)>>4,i&15|(i&15)<<4,n===5?parseInt(a.slice(4),16)/15:1),di(r,e),e}else if(n===7||n===9){var i=parseInt(a.slice(1,7),16);if(!(i>=0&&i<=16777215)){Xe(e,0,0,0,1);return}return Xe(e,(i&16711680)>>16,(i&65280)>>8,i&255,n===9?parseInt(a.slice(7),16)/255:1),di(r,e),e}return}var o=a.indexOf("("),s=a.indexOf(")");if(o!==-1&&s+1===n){var l=a.substr(0,o),u=a.substr(o+1,s-(o+1)).split(","),f=1;switch(l){case"rgba":if(u.length!==4)return u.length===3?Xe(e,+u[0],+u[1],+u[2],1):Xe(e,0,0,0,1);f=$n(u.pop());case"rgb":if(u.length>=3)return Xe(e,Nh(u[0]),Nh(u[1]),Nh(u[2]),u.length===3?f:$n(u[3])),di(r,e),e;Xe(e,0,0,0,1);return;case"hsla":if(u.length!==4){Xe(e,0,0,0,1);return}return u[3]=$n(u[3]),hp(u,e),di(r,e),e;case"hsl":if(u.length!==3){Xe(e,0,0,0,1);return}return hp(u,e),di(r,e),e;default:return}}Xe(e,0,0,0,1)}}function hp(r,e){var t=(parseFloat(r[0])%360+360)%360/360,a=$n(r[1]),n=$n(r[2]),i=n<=.5?n*(a+1):n+a-n*a,o=n*2-i;return e=e||[],Xe(e,yr(Bh(o,i,t+1/3)*255),yr(Bh(o,i,t)*255),yr(Bh(o,i,t-1/3)*255),1),r.length===4&&(e[3]=r[3]),e}function p2(r){if(r){var e=r[0]/255,t=r[1]/255,a=r[2]/255,n=Math.min(e,t,a),i=Math.max(e,t,a),o=i-n,s=(i+n)/2,l,u;if(o===0)l=0,u=0;else{s<.5?u=o/(i+n):u=o/(2-i-n);var f=((i-e)/6+o/2)/o,h=((i-t)/6+o/2)/o,v=((i-a)/6+o/2)/o;e===i?l=v-h:t===i?l=1/3+f-v:a===i&&(l=2/3+h-f),l<0&&(l+=1),l>1&&(l-=1)}var c=[l*360,u,s];return r[3]!=null&&c.push(r[3]),c}}function vp(r,e){var t=He(r);if(t){for(var a=0;a<3;a++)e<0?t[a]=t[a]*(1-e)|0:t[a]=(255-t[a])*e+t[a]|0,t[a]>255?t[a]=255:t[a]<0&&(t[a]=0);return ra(t,t.length===4?"rgba":"rgb")}}function Vh(r,e,t){if(!(!(e&&e.length)||!(r>=0&&r<=1))){t=t||[];var a=r*(e.length-1),n=Math.floor(a),i=Math.ceil(a),o=e[n],s=e[i],l=a-n;return t[0]=yr(Ra(o[0],s[0],l)),t[1]=yr(Ra(o[1],s[1],l)),t[2]=yr(Ra(o[2],s[2],l)),t[3]=Ps(Ra(o[3],s[3],l)),t}}function d2(r,e,t){if(!(!(e&&e.length)||!(r>=0&&r<=1))){var a=r*(e.length-1),n=Math.floor(a),i=Math.ceil(a),o=He(e[n]),s=He(e[i]),l=a-n,u=ra([yr(Ra(o[0],s[0],l)),yr(Ra(o[1],s[1],l)),yr(Ra(o[2],s[2],l)),Ps(Ra(o[3],s[3],l))],"rgba");return t?{color:u,leftIndex:n,rightIndex:i,value:a}:u}}function ps(r,e,t,a){var n=He(r);if(r)return n=p2(n),e!=null&&(n[0]=c2(e)),t!=null&&(n[1]=$n(t)),a!=null&&(n[2]=$n(a)),ra(hp(n),"rgba")}function Ju(r,e){var t=He(r);if(t&&e!=null)return t[3]=Ps(e),ra(t,"rgba")}function ra(r,e){if(!(!r||!r.length)){var t=r[0]+","+r[1]+","+r[2];return(e==="rgba"||e==="hsva"||e==="hsla")&&(t+=","+r[3]),e+"("+t+")"}}function ju(r,e){var t=He(r);return t?(.299*t[0]+.587*t[1]+.114*t[2])*t[3]/255+(1-t[3])*e:0}var ym=new nl(100);function cp(r){if($(r)){var e=ym.get(r);return e||(e=vp(r,-.1),ym.put(r,e)),e}else if($f(r)){var t=V({},r);return t.colorStops=G(r.colorStops,function(a){return{offset:a.offset,color:vp(a.color,-.1)}}),t}return r}var tf=Math.round;function Rs(r){var e;if(!r||r==="transparent")r="none";else if(typeof r=="string"&&r.indexOf("rgba")>-1){var t=He(r);t&&(r="rgb("+t[0]+","+t[1]+","+t[2]+")",e=t[3])}return{color:r,opacity:e??1}}var mm=1e-4;function Ea(r){return r<mm&&r>-mm}function Pl(r){return tf(r*1e3)/1e3}function pp(r){return tf(r*1e4)/1e4}function g2(r){return"matrix("+Pl(r[0])+","+Pl(r[1])+","+Pl(r[2])+","+Pl(r[3])+","+pp(r[4])+","+pp(r[5])+")"}var y2={left:"start",right:"end",center:"middle",middle:"middle"};function m2(r,e,t){return t==="top"?r+=e/2:t==="bottom"&&(r-=e/2),r}function _2(r){return r&&(r.shadowBlur||r.shadowOffsetX||r.shadowOffsetY)}function S2(r){var e=r.style,t=r.getGlobalScale();return[e.shadowColor,(e.shadowBlur||0).toFixed(2),(e.shadowOffsetX||0).toFixed(2),(e.shadowOffsetY||0).toFixed(2),t[0],t[1]].join(",")}function Lb(r){return r&&!!r.image}function x2(r){return r&&!!r.svgElement}function Jd(r){return Lb(r)||x2(r)}function Pb(r){return r.type==="linear"}function Rb(r){return r.type==="radial"}function Eb(r){return r&&(r.type==="linear"||r.type==="radial")}function Zf(r){return"url(#"+r+")"}function kb(r){var e=r.getGlobalScale(),t=Math.max(e[0],e[1]);return Math.max(Math.ceil(Math.log(t)/Math.log(10)),1)}function Ob(r){var e=r.x||0,t=r.y||0,a=(r.rotation||0)*Mu,n=it(r.scaleX,1),i=it(r.scaleY,1),o=r.skewX||0,s=r.skewY||0,l=[];return(e||t)&&l.push("translate("+e+"px,"+t+"px)"),a&&l.push("rotate("+a+")"),(n!==1||i!==1)&&l.push("scale("+n+","+i+")"),(o||s)&&l.push("skew("+tf(o*Mu)+"deg, "+tf(s*Mu)+"deg)"),l.join(" ")}var w2=function(){return mt.hasGlobalWindow&&K(window.btoa)?function(r){return window.btoa(unescape(encodeURIComponent(r)))}:typeof Buffer<"u"?function(r){return Buffer.from(r).toString("base64")}:function(r){return null}}(),dp=Array.prototype.slice;function Kr(r,e,t){return(e-r)*t+r}function zh(r,e,t,a){for(var n=e.length,i=0;i<n;i++)r[i]=Kr(e[i],t[i],a);return r}function b2(r,e,t,a){for(var n=e.length,i=n&&e[0].length,o=0;o<n;o++){r[o]||(r[o]=[]);for(var s=0;s<i;s++)r[o][s]=Kr(e[o][s],t[o][s],a)}return r}function Rl(r,e,t,a){for(var n=e.length,i=0;i<n;i++)r[i]=e[i]+t[i]*a;return r}function _m(r,e,t,a){for(var n=e.length,i=n&&e[0].length,o=0;o<n;o++){r[o]||(r[o]=[]);for(var s=0;s<i;s++)r[o][s]=e[o][s]+t[o][s]*a}return r}function T2(r,e){for(var t=r.length,a=e.length,n=t>a?e:r,i=Math.min(t,a),o=n[i-1]||{color:[0,0,0,0],offset:0},s=i;s<Math.max(t,a);s++)n.push({offset:o.offset,color:o.color.slice()})}function A2(r,e,t){var a=r,n=e;if(!(!a.push||!n.push)){var i=a.length,o=n.length;if(i!==o){var s=i>o;if(s)a.length=o;else for(var l=i;l<o;l++)a.push(t===1?n[l]:dp.call(n[l]))}for(var u=a[0]&&a[0].length,l=0;l<a.length;l++)if(t===1)isNaN(a[l])&&(a[l]=n[l]);else for(var f=0;f<u;f++)isNaN(a[l][f])&&(a[l][f]=n[l][f])}}function ds(r){if(ge(r)){var e=r.length;if(ge(r[0])){for(var t=[],a=0;a<e;a++)t.push(dp.call(r[a]));return t}return dp.call(r)}return r}function Ru(r){return r[0]=Math.floor(r[0])||0,r[1]=Math.floor(r[1])||0,r[2]=Math.floor(r[2])||0,r[3]=r[3]==null?1:r[3],"rgba("+r.join(",")+")"}function C2(r){return ge(r&&r[0])?2:1}var El=0,Eu=1,Nb=2,es=3,gp=4,yp=5,Sm=6;function xm(r){return r===gp||r===yp}function kl(r){return r===Eu||r===Nb}var Io=[0,0,0,0],D2=function(){function r(e){this.keyframes=[],this.discrete=!1,this._invalid=!1,this._needsSort=!1,this._lastFr=0,this._lastFrP=0,this.propName=e}return r.prototype.isFinished=function(){return this._finished},r.prototype.setFinished=function(){this._finished=!0,this._additiveTrack&&this._additiveTrack.setFinished()},r.prototype.needsAnimate=function(){return this.keyframes.length>=1},r.prototype.getAdditiveTrack=function(){return this._additiveTrack},r.prototype.addKeyframe=function(e,t,a){this._needsSort=!0;var n=this.keyframes,i=n.length,o=!1,s=Sm,l=t;if(ge(t)){var u=C2(t);s=u,(u===1&&!Ct(t[0])||u===2&&!Ct(t[0][0]))&&(o=!0)}else if(Ct(t)&&!Is(t))s=El;else if($(t))if(!isNaN(+t))s=El;else{var f=He(t);f&&(l=f,s=es)}else if($f(t)){var h=V({},l);h.colorStops=G(t.colorStops,function(c){return{offset:c.offset,color:He(c.color)}}),Pb(t)?s=gp:Rb(t)&&(s=yp),l=h}i===0?this.valType=s:(s!==this.valType||s===Sm)&&(o=!0),this.discrete=this.discrete||o;var v={time:e,value:l,rawValue:t,percent:0};return a&&(v.easing=a,v.easingFunc=K(a)?a:cs[a]||Qd(a)),n.push(v),v},r.prototype.prepare=function(e,t){var a=this.keyframes;this._needsSort&&a.sort(function(d,g){return d.time-g.time});for(var n=this.valType,i=a.length,o=a[i-1],s=this.discrete,l=kl(n),u=xm(n),f=0;f<i;f++){var h=a[f],v=h.value,c=o.value;h.percent=h.time/e,s||(l&&f!==i-1?A2(v,c,n):u&&T2(v.colorStops,c.colorStops))}if(!s&&n!==yp&&t&&this.needsAnimate()&&t.needsAnimate()&&n===t.valType&&!t._finished){this._additiveTrack=t;for(var p=a[0].value,f=0;f<i;f++)n===El?a[f].additiveValue=a[f].value-p:n===es?a[f].additiveValue=Rl([],a[f].value,p,-1):kl(n)&&(a[f].additiveValue=n===Eu?Rl([],a[f].value,p,-1):_m([],a[f].value,p,-1))}},r.prototype.step=function(e,t){if(!this._finished){this._additiveTrack&&this._additiveTrack._finished&&(this._additiveTrack=null);var a=this._additiveTrack!=null,n=a?"additiveValue":"value",i=this.valType,o=this.keyframes,s=o.length,l=this.propName,u=i===es,f,h=this._lastFr,v=Math.min,c,p;if(s===1)c=p=o[0];else{if(t<0)f=0;else if(t<this._lastFrP){var d=v(h+1,s-1);for(f=d;f>=0&&!(o[f].percent<=t);f--);f=v(f,s-2)}else{for(f=h;f<s&&!(o[f].percent>t);f++);f=v(f-1,s-2)}p=o[f+1],c=o[f]}if(c&&p){this._lastFr=f,this._lastFrP=t;var g=p.percent-c.percent,y=g===0?1:v((t-c.percent)/g,1);p.easingFunc&&(y=p.easingFunc(y));var m=a?this._additiveValue:u?Io:e[l];if((kl(i)||u)&&!m&&(m=this._additiveValue=[]),this.discrete)e[l]=y<1?c.rawValue:p.rawValue;else if(kl(i))i===Eu?zh(m,c[n],p[n],y):b2(m,c[n],p[n],y);else if(xm(i)){var _=c[n],S=p[n],w=i===gp;e[l]={type:w?"linear":"radial",x:Kr(_.x,S.x,y),y:Kr(_.y,S.y,y),colorStops:G(_.colorStops,function(b,T){var A=S.colorStops[T];return{offset:Kr(b.offset,A.offset,y),color:Ru(zh([],b.color,A.color,y))}}),global:S.global},w?(e[l].x2=Kr(_.x2,S.x2,y),e[l].y2=Kr(_.y2,S.y2,y)):e[l].r=Kr(_.r,S.r,y)}else if(u)zh(m,c[n],p[n],y),a||(e[l]=Ru(m));else{var x=Kr(c[n],p[n],y);a?this._additiveValue=x:e[l]=x}a&&this._addToTarget(e)}}},r.prototype._addToTarget=function(e){var t=this.valType,a=this.propName,n=this._additiveValue;t===El?e[a]=e[a]+n:t===es?(He(e[a],Io),Rl(Io,Io,n,1),e[a]=Ru(Io)):t===Eu?Rl(e[a],e[a],n,1):t===Nb&&_m(e[a],e[a],n,1)},r}(),jd=function(){function r(e,t,a,n){if(this._tracks={},this._trackKeys=[],this._maxTime=0,this._started=0,this._clip=null,this._target=e,this._loop=t,t&&n){$d("Can' use additive animation on looped animation.");return}this._additiveAnimators=n,this._allowDiscrete=a}return r.prototype.getMaxTime=function(){return this._maxTime},r.prototype.getDelay=function(){return this._delay},r.prototype.getLoop=function(){return this._loop},r.prototype.getTarget=function(){return this._target},r.prototype.changeTarget=function(e){this._target=e},r.prototype.when=function(e,t,a){return this.whenWithKeys(e,t,_t(t),a)},r.prototype.whenWithKeys=function(e,t,a,n){for(var i=this._tracks,o=0;o<a.length;o++){var s=a[o],l=i[s];if(!l){l=i[s]=new D2(s);var u=void 0,f=this._getAdditiveTrack(s);if(f){var h=f.keyframes,v=h[h.length-1];u=v&&v.value,f.valType===es&&u&&(u=Ru(u))}else u=this._target[s];if(u==null)continue;e>0&&l.addKeyframe(0,ds(u),n),this._trackKeys.push(s)}l.addKeyframe(e,ds(t[s]),n)}return this._maxTime=Math.max(this._maxTime,e),this},r.prototype.pause=function(){this._clip.pause(),this._paused=!0},r.prototype.resume=function(){this._clip.resume(),this._paused=!1},r.prototype.isPaused=function(){return!!this._paused},r.prototype.duration=function(e){return this._maxTime=e,this._force=!0,this},r.prototype._doneCallback=function(){this._setTracksFinished(),this._clip=null;var e=this._doneCbs;if(e)for(var t=e.length,a=0;a<t;a++)e[a].call(this)},r.prototype._abortedCallback=function(){this._setTracksFinished();var e=this.animation,t=this._abortedCbs;if(e&&e.removeClip(this._clip),this._clip=null,t)for(var a=0;a<t.length;a++)t[a].call(this)},r.prototype._setTracksFinished=function(){for(var e=this._tracks,t=this._trackKeys,a=0;a<t.length;a++)e[t[a]].setFinished()},r.prototype._getAdditiveTrack=function(e){var t,a=this._additiveAnimators;if(a)for(var n=0;n<a.length;n++){var i=a[n].getTrack(e);i&&(t=i)}return t},r.prototype.start=function(e){if(!(this._started>0)){this._started=1;for(var t=this,a=[],n=this._maxTime||0,i=0;i<this._trackKeys.length;i++){var o=this._trackKeys[i],s=this._tracks[o],l=this._getAdditiveTrack(o),u=s.keyframes,f=u.length;if(s.prepare(n,l),s.needsAnimate())if(!this._allowDiscrete&&s.discrete){var h=u[f-1];h&&(t._target[s.propName]=h.rawValue),s.setFinished()}else a.push(s)}if(a.length||this._force){var v=new h2({life:n,loop:this._loop,delay:this._delay||0,onframe:function(c){t._started=2;var p=t._additiveAnimators;if(p){for(var d=!1,g=0;g<p.length;g++)if(p[g]._clip){d=!0;break}d||(t._additiveAnimators=null)}for(var g=0;g<a.length;g++)a[g].step(t._target,c);var y=t._onframeCbs;if(y)for(var g=0;g<y.length;g++)y[g](t._target,c)},ondestroy:function(){t._doneCallback()}});this._clip=v,this.animation&&this.animation.addClip(v),e&&v.setEasing(e)}else this._doneCallback();return this}},r.prototype.stop=function(e){if(this._clip){var t=this._clip;e&&t.onframe(1),this._abortedCallback()}},r.prototype.delay=function(e){return this._delay=e,this},r.prototype.during=function(e){return e&&(this._onframeCbs||(this._onframeCbs=[]),this._onframeCbs.push(e)),this},r.prototype.done=function(e){return e&&(this._doneCbs||(this._doneCbs=[]),this._doneCbs.push(e)),this},r.prototype.aborted=function(e){return e&&(this._abortedCbs||(this._abortedCbs=[]),this._abortedCbs.push(e)),this},r.prototype.getClip=function(){return this._clip},r.prototype.getTrack=function(e){return this._tracks[e]},r.prototype.getTracks=function(){var e=this;return G(this._trackKeys,function(t){return e._tracks[t]})},r.prototype.stopTracks=function(e,t){if(!e.length||!this._clip)return!0;for(var a=this._tracks,n=this._trackKeys,i=0;i<e.length;i++){var o=a[e[i]];o&&!o.isFinished()&&(t?o.step(this._target,1):this._started===1&&o.step(this._target,0),o.setFinished())}for(var s=!0,i=0;i<n.length;i++)if(!a[n[i]].isFinished()){s=!1;break}return s&&this._abortedCallback(),s},r.prototype.saveTo=function(e,t,a){if(e){t=t||this._trackKeys;for(var n=0;n<t.length;n++){var i=t[n],o=this._tracks[i];if(!(!o||o.isFinished())){var s=o.keyframes,l=s[a?0:s.length-1];l&&(e[i]=ds(l.rawValue))}}}},r.prototype.__changeFinalValue=function(e,t){t=t||_t(e);for(var a=0;a<t.length;a++){var n=t[a],i=this._tracks[n];if(i){var o=i.keyframes;if(o.length>1){var s=o.pop();i.addKeyframe(s.time,e[n]),i.prepare(this._maxTime,i.getAdditiveTrack())}}}},r}();function Gi(){return new Date().getTime()}var M2=function(r){k(e,r);function e(t){var a=r.call(this)||this;return a._running=!1,a._time=0,a._pausedTime=0,a._pauseStart=0,a._paused=!1,t=t||{},a.stage=t.stage||{},a}return e.prototype.addClip=function(t){t.animation&&this.removeClip(t),this._head?(this._tail.next=t,t.prev=this._tail,t.next=null,this._tail=t):this._head=this._tail=t,t.animation=this},e.prototype.addAnimator=function(t){t.animation=this;var a=t.getClip();a&&this.addClip(a)},e.prototype.removeClip=function(t){if(t.animation){var a=t.prev,n=t.next;a?a.next=n:this._head=n,n?n.prev=a:this._tail=a,t.next=t.prev=t.animation=null}},e.prototype.removeAnimator=function(t){var a=t.getClip();a&&this.removeClip(a),t.animation=null},e.prototype.update=function(t){for(var a=Gi()-this._pausedTime,n=a-this._time,i=this._head;i;){var o=i.next,s=i.step(a,n);s&&(i.ondestroy(),this.removeClip(i)),i=o}this._time=a,t||(this.trigger("frame",n),this.stage.update&&this.stage.update())},e.prototype._startLoop=function(){var t=this;this._running=!0;function a(){t._running&&(lp(a),!t._paused&&t.update())}lp(a)},e.prototype.start=function(){this._running||(this._time=Gi(),this._pausedTime=0,this._startLoop())},e.prototype.stop=function(){this._running=!1},e.prototype.pause=function(){this._paused||(this._pauseStart=Gi(),this._paused=!0)},e.prototype.resume=function(){this._paused&&(this._pausedTime+=Gi()-this._pauseStart,this._paused=!1)},e.prototype.clear=function(){for(var t=this._head;t;){var a=t.next;t.prev=t.next=t.animation=null,t=a}this._head=this._tail=null},e.prototype.isFinished=function(){return this._head==null},e.prototype.animate=function(t,a){a=a||{},this.start();var n=new jd(t,a.loop);return this.addAnimator(n),n},e}(or),I2=300,Gh=mt.domSupported,Fh=function(){var r=["click","dblclick","mousewheel","wheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],e=["touchstart","touchend","touchmove"],t={pointerdown:1,pointerup:1,pointermove:1,pointerout:1},a=G(r,function(n){var i=n.replace("mouse","pointer");return t.hasOwnProperty(i)?i:n});return{mouse:r,touch:e,pointer:a}}(),wm={mouse:["mousemove","mouseup"],pointer:["pointermove","pointerup"]},bm=!1;function mp(r){var e=r.pointerType;return e==="pen"||e==="touch"}function L2(r){r.touching=!0,r.touchTimer!=null&&(clearTimeout(r.touchTimer),r.touchTimer=null),r.touchTimer=setTimeout(function(){r.touching=!1,r.touchTimer=null},700)}function Hh(r){r&&(r.zrByTouch=!0)}function P2(r,e){return qe(r.dom,new R2(r,e),!0)}function Bb(r,e){for(var t=e,a=!1;t&&t.nodeType!==9&&!(a=t.domBelongToZr||t!==e&&t===r.painterRoot);)t=t.parentNode;return a}var R2=function(){function r(e,t){this.stopPropagation=Yt,this.stopImmediatePropagation=Yt,this.preventDefault=Yt,this.type=t.type,this.target=this.currentTarget=e.dom,this.pointerType=t.pointerType,this.clientX=t.clientX,this.clientY=t.clientY}return r}(),vr={mousedown:function(r){r=qe(this.dom,r),this.__mayPointerCapture=[r.zrX,r.zrY],this.trigger("mousedown",r)},mousemove:function(r){r=qe(this.dom,r);var e=this.__mayPointerCapture;e&&(r.zrX!==e[0]||r.zrY!==e[1])&&this.__togglePointerCapture(!0),this.trigger("mousemove",r)},mouseup:function(r){r=qe(this.dom,r),this.__togglePointerCapture(!1),this.trigger("mouseup",r)},mouseout:function(r){r=qe(this.dom,r);var e=r.toElement||r.relatedTarget;Bb(this,e)||(this.__pointerCapturing&&(r.zrEventControl="no_globalout"),this.trigger("mouseout",r))},wheel:function(r){bm=!0,r=qe(this.dom,r),this.trigger("mousewheel",r)},mousewheel:function(r){bm||(r=qe(this.dom,r),this.trigger("mousewheel",r))},touchstart:function(r){r=qe(this.dom,r),Hh(r),this.__lastTouchMoment=new Date,this.handler.processGesture(r,"start"),vr.mousemove.call(this,r),vr.mousedown.call(this,r)},touchmove:function(r){r=qe(this.dom,r),Hh(r),this.handler.processGesture(r,"change"),vr.mousemove.call(this,r)},touchend:function(r){r=qe(this.dom,r),Hh(r),this.handler.processGesture(r,"end"),vr.mouseup.call(this,r),+new Date-+this.__lastTouchMoment<I2&&vr.click.call(this,r)},pointerdown:function(r){vr.mousedown.call(this,r)},pointermove:function(r){mp(r)||vr.mousemove.call(this,r)},pointerup:function(r){vr.mouseup.call(this,r)},pointerout:function(r){mp(r)||vr.mouseout.call(this,r)}};C(["click","dblclick","contextmenu"],function(r){vr[r]=function(e){e=qe(this.dom,e),this.trigger(r,e)}});var _p={pointermove:function(r){mp(r)||_p.mousemove.call(this,r)},pointerup:function(r){_p.mouseup.call(this,r)},mousemove:function(r){this.trigger("mousemove",r)},mouseup:function(r){var e=this.__pointerCapturing;this.__togglePointerCapture(!1),this.trigger("mouseup",r),e&&(r.zrEventControl="only_globalout",this.trigger("mouseout",r))}};function E2(r,e){var t=e.domHandlers;mt.pointerEventsSupported?C(Fh.pointer,function(a){ku(e,a,function(n){t[a].call(r,n)})}):(mt.touchEventsSupported&&C(Fh.touch,function(a){ku(e,a,function(n){t[a].call(r,n),L2(e)})}),C(Fh.mouse,function(a){ku(e,a,function(n){n=Xd(n),e.touching||t[a].call(r,n)})}))}function k2(r,e){mt.pointerEventsSupported?C(wm.pointer,t):mt.touchEventsSupported||C(wm.mouse,t);function t(a){function n(i){i=Xd(i),Bb(r,i.target)||(i=P2(r,i),e.domHandlers[a].call(r,i))}ku(e,a,n,{capture:!0})}}function ku(r,e,t,a){r.mounted[e]=t,r.listenerOpts[e]=a,sp(r.domTarget,e,t,a)}function Wh(r){var e=r.mounted;for(var t in e)e.hasOwnProperty(t)&&UL(r.domTarget,t,e[t],r.listenerOpts[t]);r.mounted={}}var Tm=function(){function r(e,t){this.mounted={},this.listenerOpts={},this.touching=!1,this.domTarget=e,this.domHandlers=t}return r}(),O2=function(r){k(e,r);function e(t,a){var n=r.call(this)||this;return n.__pointerCapturing=!1,n.dom=t,n.painterRoot=a,n._localHandlerScope=new Tm(t,vr),Gh&&(n._globalHandlerScope=new Tm(document,_p)),E2(n,n._localHandlerScope),n}return e.prototype.dispose=function(){Wh(this._localHandlerScope),Gh&&Wh(this._globalHandlerScope)},e.prototype.setCursor=function(t){this.dom.style&&(this.dom.style.cursor=t||"default")},e.prototype.__togglePointerCapture=function(t){if(this.__mayPointerCapture=null,Gh&&+this.__pointerCapturing^+t){this.__pointerCapturing=t;var a=this._globalHandlerScope;t?k2(this,a):Wh(a)}},e}(or);const N2=O2;var Vb=1;mt.hasGlobalWindow&&(Vb=Math.max(window.devicePixelRatio||window.screen&&window.screen.deviceXDPI/window.screen.logicalXDPI||1,1));var ef=Vb,Sp=.4,xp="#333",wp="#ccc",B2="#eee",Am=Yf,Cm=5e-5;function nn(r){return r>Cm||r<-Cm}var on=[],gi=[],$h=Fe(),Uh=Math.abs,Jr=function(){function r(){}return r.prototype.getLocalTransform=function(e){return r.getLocalTransform(this,e)},r.prototype.setPosition=function(e){this.x=e[0],this.y=e[1]},r.prototype.setScale=function(e){this.scaleX=e[0],this.scaleY=e[1]},r.prototype.setSkew=function(e){this.skewX=e[0],this.skewY=e[1]},r.prototype.setOrigin=function(e){this.originX=e[0],this.originY=e[1]},r.prototype.needLocalTransform=function(){return nn(this.rotation)||nn(this.x)||nn(this.y)||nn(this.scaleX-1)||nn(this.scaleY-1)||nn(this.skewX)||nn(this.skewY)},r.prototype.updateTransform=function(){var e=this.parent&&this.parent.transform,t=this.needLocalTransform(),a=this.transform;if(!(t||e)){a&&(Am(a),this.invTransform=null);return}a=a||Fe(),t?this.getLocalTransform(a):Am(a),e&&(t?ea(a,e,a):qd(a,e)),this.transform=a,this._resolveGlobalScaleRatio(a)},r.prototype._resolveGlobalScaleRatio=function(e){var t=this.globalScaleRatio;if(t!=null&&t!==1){this.getGlobalScale(on);var a=on[0]<0?-1:1,n=on[1]<0?-1:1,i=((on[0]-a)*t+a)/on[0]||0,o=((on[1]-n)*t+n)/on[1]||0;e[0]*=i,e[1]*=i,e[2]*=o,e[3]*=o}this.invTransform=this.invTransform||Fe(),lo(this.invTransform,e)},r.prototype.getComputedTransform=function(){for(var e=this,t=[];e;)t.push(e),e=e.parent;for(;e=t.pop();)e.updateTransform();return this.transform},r.prototype.setLocalTransform=function(e){if(e){var t=e[0]*e[0]+e[1]*e[1],a=e[2]*e[2]+e[3]*e[3],n=Math.atan2(e[1],e[0]),i=Math.PI/2+n-Math.atan2(e[3],e[2]);a=Math.sqrt(a)*Math.cos(i),t=Math.sqrt(t),this.skewX=i,this.skewY=0,this.rotation=-n,this.x=+e[4],this.y=+e[5],this.scaleX=t,this.scaleY=a,this.originX=0,this.originY=0}},r.prototype.decomposeTransform=function(){if(this.transform){var e=this.parent,t=this.transform;e&&e.transform&&(e.invTransform=e.invTransform||Fe(),ea(gi,e.invTransform,t),t=gi);var a=this.originX,n=this.originY;(a||n)&&($h[4]=a,$h[5]=n,ea(gi,t,$h),gi[4]-=a,gi[5]-=n,t=gi),this.setLocalTransform(t)}},r.prototype.getGlobalScale=function(e){var t=this.transform;return e=e||[],t?(e[0]=Math.sqrt(t[0]*t[0]+t[1]*t[1]),e[1]=Math.sqrt(t[2]*t[2]+t[3]*t[3]),t[0]<0&&(e[0]=-e[0]),t[3]<0&&(e[1]=-e[1]),e):(e[0]=1,e[1]=1,e)},r.prototype.transformCoordToLocal=function(e,t){var a=[e,t],n=this.invTransform;return n&&se(a,a,n),a},r.prototype.transformCoordToGlobal=function(e,t){var a=[e,t],n=this.transform;return n&&se(a,a,n),a},r.prototype.getLineScale=function(){var e=this.transform;return e&&Uh(e[0]-1)>1e-10&&Uh(e[3]-1)>1e-10?Math.sqrt(Uh(e[0]*e[3]-e[2]*e[1])):1},r.prototype.copyTransform=function(e){zb(this,e)},r.getLocalTransform=function(e,t){t=t||[];var a=e.originX||0,n=e.originY||0,i=e.scaleX,o=e.scaleY,s=e.anchorX,l=e.anchorY,u=e.rotation||0,f=e.x,h=e.y,v=e.skewX?Math.tan(e.skewX):0,c=e.skewY?Math.tan(-e.skewY):0;if(a||n||s||l){var p=a+s,d=n+l;t[4]=-p*i-v*d*o,t[5]=-d*o-c*p*i}else t[4]=t[5]=0;return t[0]=i,t[3]=o,t[1]=c*i,t[2]=v*o,u&&oi(t,t,u),t[4]+=a+f,t[5]+=n+h,t},r.initDefaultProps=function(){var e=r.prototype;e.scaleX=e.scaleY=e.globalScaleRatio=1,e.x=e.y=e.originX=e.originY=e.skewX=e.skewY=e.rotation=e.anchorX=e.anchorY=0}(),r}(),Fr=["x","y","originX","originY","anchorX","anchorY","rotation","scaleX","scaleY","skewX","skewY"];function zb(r,e){for(var t=0;t<Fr.length;t++){var a=Fr[t];r[a]=e[a]}}var Dm={};function We(r,e){e=e||Fa;var t=Dm[e];t||(t=Dm[e]=new nl(500));var a=t.get(r);return a==null&&(a=Ha.measureText(r,e).width,t.put(r,a)),a}function Mm(r,e,t,a){var n=We(r,e),i=Xf(e),o=rs(0,n,t),s=Ni(0,i,a),l=new ht(o,s,n,i);return l}function il(r,e,t,a){var n=((r||"")+"").split(`
`),i=n.length;if(i===1)return Mm(n[0],e,t,a);for(var o=new ht(0,0,0,0),s=0;s<n.length;s++){var l=Mm(n[s],e,t,a);s===0?o.copy(l):o.union(l)}return o}function rs(r,e,t){return t==="right"?r-=e:t==="center"&&(r-=e/2),r}function Ni(r,e,t){return t==="middle"?r-=e/2:t==="bottom"&&(r-=e),r}function Xf(r){return We("国",r)}function _r(r,e){return typeof r=="string"?r.lastIndexOf("%")>=0?parseFloat(r)/100*e:parseFloat(r):r}function rf(r,e,t){var a=e.position||"inside",n=e.distance!=null?e.distance:5,i=t.height,o=t.width,s=i/2,l=t.x,u=t.y,f="left",h="top";if(a instanceof Array)l+=_r(a[0],t.width),u+=_r(a[1],t.height),f=null,h=null;else switch(a){case"left":l-=n,u+=s,f="right",h="middle";break;case"right":l+=n+o,u+=s,h="middle";break;case"top":l+=o/2,u-=n,f="center",h="bottom";break;case"bottom":l+=o/2,u+=i+n,f="center";break;case"inside":l+=o/2,u+=s,f="center",h="middle";break;case"insideLeft":l+=n,u+=s,h="middle";break;case"insideRight":l+=o-n,u+=s,f="right",h="middle";break;case"insideTop":l+=o/2,u+=n,f="center";break;case"insideBottom":l+=o/2,u+=i-n,f="center",h="bottom";break;case"insideTopLeft":l+=n,u+=n;break;case"insideTopRight":l+=o-n,u+=n,f="right";break;case"insideBottomLeft":l+=n,u+=i-n,h="bottom";break;case"insideBottomRight":l+=o-n,u+=i-n,f="right",h="bottom";break}return r=r||{},r.x=l,r.y=u,r.align=f,r.verticalAlign=h,r}var Yh="__zr_normal__",Zh=Fr.concat(["ignore"]),V2=zr(Fr,function(r,e){return r[e]=!0,r},{ignore:!1}),yi={},z2=new ht(0,0,0,0),tg=function(){function r(e){this.id=vb(),this.animators=[],this.currentStates=[],this.states={},this._init(e)}return r.prototype._init=function(e){this.attr(e)},r.prototype.drift=function(e,t,a){switch(this.draggable){case"horizontal":t=0;break;case"vertical":e=0;break}var n=this.transform;n||(n=this.transform=[1,0,0,1,0,0]),n[4]+=e,n[5]+=t,this.decomposeTransform(),this.markRedraw()},r.prototype.beforeUpdate=function(){},r.prototype.afterUpdate=function(){},r.prototype.update=function(){this.updateTransform(),this.__dirty&&this.updateInnerText()},r.prototype.updateInnerText=function(e){var t=this._textContent;if(t&&(!t.ignore||e)){this.textConfig||(this.textConfig={});var a=this.textConfig,n=a.local,i=t.innerTransformable,o=void 0,s=void 0,l=!1;i.parent=n?this:null;var u=!1;if(i.copyTransform(t),a.position!=null){var f=z2;a.layoutRect?f.copy(a.layoutRect):f.copy(this.getBoundingRect()),n||f.applyTransform(this.transform),this.calculateTextPosition?this.calculateTextPosition(yi,a,f):rf(yi,a,f),i.x=yi.x,i.y=yi.y,o=yi.align,s=yi.verticalAlign;var h=a.origin;if(h&&a.rotation!=null){var v=void 0,c=void 0;h==="center"?(v=f.width*.5,c=f.height*.5):(v=_r(h[0],f.width),c=_r(h[1],f.height)),u=!0,i.originX=-i.x+v+(n?0:f.x),i.originY=-i.y+c+(n?0:f.y)}}a.rotation!=null&&(i.rotation=a.rotation);var p=a.offset;p&&(i.x+=p[0],i.y+=p[1],u||(i.originX=-p[0],i.originY=-p[1]));var d=a.inside==null?typeof a.position=="string"&&a.position.indexOf("inside")>=0:a.inside,g=this._innerTextDefaultStyle||(this._innerTextDefaultStyle={}),y=void 0,m=void 0,_=void 0;d&&this.canBeInsideText()?(y=a.insideFill,m=a.insideStroke,(y==null||y==="auto")&&(y=this.getInsideTextFill()),(m==null||m==="auto")&&(m=this.getInsideTextStroke(y),_=!0)):(y=a.outsideFill,m=a.outsideStroke,(y==null||y==="auto")&&(y=this.getOutsideFill()),(m==null||m==="auto")&&(m=this.getOutsideStroke(y),_=!0)),y=y||"#000",(y!==g.fill||m!==g.stroke||_!==g.autoStroke||o!==g.align||s!==g.verticalAlign)&&(l=!0,g.fill=y,g.stroke=m,g.autoStroke=_,g.align=o,g.verticalAlign=s,t.setDefaultTextStyle(g)),t.__dirty|=ze,l&&t.dirtyStyle(!0)}},r.prototype.canBeInsideText=function(){return!0},r.prototype.getInsideTextFill=function(){return"#fff"},r.prototype.getInsideTextStroke=function(e){return"#000"},r.prototype.getOutsideFill=function(){return this.__zr&&this.__zr.isDarkMode()?wp:xp},r.prototype.getOutsideStroke=function(e){var t=this.__zr&&this.__zr.getBackgroundColor(),a=typeof t=="string"&&He(t);a||(a=[255,255,255,1]);for(var n=a[3],i=this.__zr.isDarkMode(),o=0;o<3;o++)a[o]=a[o]*n+(i?0:255)*(1-n);return a[3]=1,ra(a,"rgba")},r.prototype.traverse=function(e,t){},r.prototype.attrKV=function(e,t){e==="textConfig"?this.setTextConfig(t):e==="textContent"?this.setTextContent(t):e==="clipPath"?this.setClipPath(t):e==="extra"?(this.extra=this.extra||{},V(this.extra,t)):this[e]=t},r.prototype.hide=function(){this.ignore=!0,this.markRedraw()},r.prototype.show=function(){this.ignore=!1,this.markRedraw()},r.prototype.attr=function(e,t){if(typeof e=="string")this.attrKV(e,t);else if(tt(e))for(var a=e,n=_t(a),i=0;i<n.length;i++){var o=n[i];this.attrKV(o,e[o])}return this.markRedraw(),this},r.prototype.saveCurrentToNormalState=function(e){this._innerSaveToNormal(e);for(var t=this._normalState,a=0;a<this.animators.length;a++){var n=this.animators[a],i=n.__fromStateTransition;if(!(n.getLoop()||i&&i!==Yh)){var o=n.targetName,s=o?t[o]:t;n.saveTo(s)}}},r.prototype._innerSaveToNormal=function(e){var t=this._normalState;t||(t=this._normalState={}),e.textConfig&&!t.textConfig&&(t.textConfig=this.textConfig),this._savePrimaryToNormal(e,t,Zh)},r.prototype._savePrimaryToNormal=function(e,t,a){for(var n=0;n<a.length;n++){var i=a[n];e[i]!=null&&!(i in t)&&(t[i]=this[i])}},r.prototype.hasState=function(){return this.currentStates.length>0},r.prototype.getState=function(e){return this.states[e]},r.prototype.ensureState=function(e){var t=this.states;return t[e]||(t[e]={}),t[e]},r.prototype.clearStates=function(e){this.useState(Yh,!1,e)},r.prototype.useState=function(e,t,a,n){var i=e===Yh,o=this.hasState();if(!(!o&&i)){var s=this.currentStates,l=this.stateTransition;if(!(vt(s,e)>=0&&(t||s.length===1))){var u;if(this.stateProxy&&!i&&(u=this.stateProxy(e)),u||(u=this.states&&this.states[e]),!u&&!i){$d("State "+e+" not exists.");return}i||this.saveCurrentToNormalState(u);var f=!!(u&&u.hoverLayer||n);f&&this._toggleHoverLayerFlag(!0),this._applyStateObj(e,u,this._normalState,t,!a&&!this.__inHover&&l&&l.duration>0,l);var h=this._textContent,v=this._textGuide;return h&&h.useState(e,t,a,f),v&&v.useState(e,t,a,f),i?(this.currentStates=[],this._normalState={}):t?this.currentStates.push(e):this.currentStates=[e],this._updateAnimationTargets(),this.markRedraw(),!f&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~ze),u}}},r.prototype.useStates=function(e,t,a){if(!e.length)this.clearStates();else{var n=[],i=this.currentStates,o=e.length,s=o===i.length;if(s){for(var l=0;l<o;l++)if(e[l]!==i[l]){s=!1;break}}if(s)return;for(var l=0;l<o;l++){var u=e[l],f=void 0;this.stateProxy&&(f=this.stateProxy(u,e)),f||(f=this.states[u]),f&&n.push(f)}var h=n[o-1],v=!!(h&&h.hoverLayer||a);v&&this._toggleHoverLayerFlag(!0);var c=this._mergeStates(n),p=this.stateTransition;this.saveCurrentToNormalState(c),this._applyStateObj(e.join(","),c,this._normalState,!1,!t&&!this.__inHover&&p&&p.duration>0,p);var d=this._textContent,g=this._textGuide;d&&d.useStates(e,t,v),g&&g.useStates(e,t,v),this._updateAnimationTargets(),this.currentStates=e.slice(),this.markRedraw(),!v&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~ze)}},r.prototype.isSilent=function(){for(var e=this.silent,t=this.parent;!e&&t;){if(t.silent){e=!0;break}t=t.parent}return e},r.prototype._updateAnimationTargets=function(){for(var e=0;e<this.animators.length;e++){var t=this.animators[e];t.targetName&&t.changeTarget(this[t.targetName])}},r.prototype.removeState=function(e){var t=vt(this.currentStates,e);if(t>=0){var a=this.currentStates.slice();a.splice(t,1),this.useStates(a)}},r.prototype.replaceState=function(e,t,a){var n=this.currentStates.slice(),i=vt(n,e),o=vt(n,t)>=0;i>=0?o?n.splice(i,1):n[i]=t:a&&!o&&n.push(t),this.useStates(n)},r.prototype.toggleState=function(e,t){t?this.useState(e,!0):this.removeState(e)},r.prototype._mergeStates=function(e){for(var t={},a,n=0;n<e.length;n++){var i=e[n];V(t,i),i.textConfig&&(a=a||{},V(a,i.textConfig))}return a&&(t.textConfig=a),t},r.prototype._applyStateObj=function(e,t,a,n,i,o){var s=!(t&&n);t&&t.textConfig?(this.textConfig=V({},n?this.textConfig:a.textConfig),V(this.textConfig,t.textConfig)):s&&a.textConfig&&(this.textConfig=a.textConfig);for(var l={},u=!1,f=0;f<Zh.length;f++){var h=Zh[f],v=i&&V2[h];t&&t[h]!=null?v?(u=!0,l[h]=t[h]):this[h]=t[h]:s&&a[h]!=null&&(v?(u=!0,l[h]=a[h]):this[h]=a[h])}if(!i)for(var f=0;f<this.animators.length;f++){var c=this.animators[f],p=c.targetName;c.getLoop()||c.__changeFinalValue(p?(t||a)[p]:t||a)}u&&this._transitionState(e,l,o)},r.prototype._attachComponent=function(e){if(!(e.__zr&&!e.__hostTarget)&&e!==this){var t=this.__zr;t&&e.addSelfToZr(t),e.__zr=t,e.__hostTarget=this}},r.prototype._detachComponent=function(e){e.__zr&&e.removeSelfFromZr(e.__zr),e.__zr=null,e.__hostTarget=null},r.prototype.getClipPath=function(){return this._clipPath},r.prototype.setClipPath=function(e){this._clipPath&&this._clipPath!==e&&this.removeClipPath(),this._attachComponent(e),this._clipPath=e,this.markRedraw()},r.prototype.removeClipPath=function(){var e=this._clipPath;e&&(this._detachComponent(e),this._clipPath=null,this.markRedraw())},r.prototype.getTextContent=function(){return this._textContent},r.prototype.setTextContent=function(e){var t=this._textContent;t!==e&&(t&&t!==e&&this.removeTextContent(),e.innerTransformable=new Jr,this._attachComponent(e),this._textContent=e,this.markRedraw())},r.prototype.setTextConfig=function(e){this.textConfig||(this.textConfig={}),V(this.textConfig,e),this.markRedraw()},r.prototype.removeTextConfig=function(){this.textConfig=null,this.markRedraw()},r.prototype.removeTextContent=function(){var e=this._textContent;e&&(e.innerTransformable=null,this._detachComponent(e),this._textContent=null,this._innerTextDefaultStyle=null,this.markRedraw())},r.prototype.getTextGuideLine=function(){return this._textGuide},r.prototype.setTextGuideLine=function(e){this._textGuide&&this._textGuide!==e&&this.removeTextGuideLine(),this._attachComponent(e),this._textGuide=e,this.markRedraw()},r.prototype.removeTextGuideLine=function(){var e=this._textGuide;e&&(this._detachComponent(e),this._textGuide=null,this.markRedraw())},r.prototype.markRedraw=function(){this.__dirty|=ze;var e=this.__zr;e&&(this.__inHover?e.refreshHover():e.refresh()),this.__hostTarget&&this.__hostTarget.markRedraw()},r.prototype.dirty=function(){this.markRedraw()},r.prototype._toggleHoverLayerFlag=function(e){this.__inHover=e;var t=this._textContent,a=this._textGuide;t&&(t.__inHover=e),a&&(a.__inHover=e)},r.prototype.addSelfToZr=function(e){if(this.__zr!==e){this.__zr=e;var t=this.animators;if(t)for(var a=0;a<t.length;a++)e.animation.addAnimator(t[a]);this._clipPath&&this._clipPath.addSelfToZr(e),this._textContent&&this._textContent.addSelfToZr(e),this._textGuide&&this._textGuide.addSelfToZr(e)}},r.prototype.removeSelfFromZr=function(e){if(this.__zr){this.__zr=null;var t=this.animators;if(t)for(var a=0;a<t.length;a++)e.animation.removeAnimator(t[a]);this._clipPath&&this._clipPath.removeSelfFromZr(e),this._textContent&&this._textContent.removeSelfFromZr(e),this._textGuide&&this._textGuide.removeSelfFromZr(e)}},r.prototype.animate=function(e,t,a){var n=e?this[e]:this,i=new jd(n,t,a);return e&&(i.targetName=e),this.addAnimator(i,e),i},r.prototype.addAnimator=function(e,t){var a=this.__zr,n=this;e.during(function(){n.updateDuringAnimation(t)}).done(function(){var i=n.animators,o=vt(i,e);o>=0&&i.splice(o,1)}),this.animators.push(e),a&&a.animation.addAnimator(e),a&&a.wakeUp()},r.prototype.updateDuringAnimation=function(e){this.markRedraw()},r.prototype.stopAnimation=function(e,t){for(var a=this.animators,n=a.length,i=[],o=0;o<n;o++){var s=a[o];!e||e===s.scope?s.stop(t):i.push(s)}return this.animators=i,this},r.prototype.animateTo=function(e,t,a){Xh(this,e,t,a)},r.prototype.animateFrom=function(e,t,a){Xh(this,e,t,a,!0)},r.prototype._transitionState=function(e,t,a,n){for(var i=Xh(this,t,a,n),o=0;o<i.length;o++)i[o].__fromStateTransition=e},r.prototype.getBoundingRect=function(){return null},r.prototype.getPaintRect=function(){return null},r.initDefaultProps=function(){var e=r.prototype;e.type="element",e.name="",e.ignore=e.silent=e.isGroup=e.draggable=e.dragging=e.ignoreClip=e.__inHover=!1,e.__dirty=ze;function t(a,n,i,o){Object.defineProperty(e,a,{get:function(){if(!this[n]){var l=this[n]=[];s(this,l)}return this[n]},set:function(l){this[i]=l[0],this[o]=l[1],this[n]=l,s(this,l)}});function s(l,u){Object.defineProperty(u,0,{get:function(){return l[i]},set:function(f){l[i]=f}}),Object.defineProperty(u,1,{get:function(){return l[o]},set:function(f){l[o]=f}})}}Object.defineProperty&&(t("position","_legacyPos","x","y"),t("scale","_legacyScale","scaleX","scaleY"),t("origin","_legacyOrigin","originX","originY"))}(),r}();Kt(tg,or);Kt(tg,Jr);function Xh(r,e,t,a,n){t=t||{};var i=[];Gb(r,"",r,e,t,a,i,n);var o=i.length,s=!1,l=t.done,u=t.aborted,f=function(){s=!0,o--,o<=0&&(s?l&&l():u&&u())},h=function(){o--,o<=0&&(s?l&&l():u&&u())};o||l&&l(),i.length>0&&t.during&&i[0].during(function(p,d){t.during(d)});for(var v=0;v<i.length;v++){var c=i[v];f&&c.done(f),h&&c.aborted(h),t.force&&c.duration(t.duration),c.start(t.easing)}return i}function qh(r,e,t){for(var a=0;a<t;a++)r[a]=e[a]}function G2(r){return ge(r[0])}function F2(r,e,t){if(ge(e[t]))if(ge(r[t])||(r[t]=[]),Ne(e[t])){var a=e[t].length;r[t].length!==a&&(r[t]=new e[t].constructor(a),qh(r[t],e[t],a))}else{var n=e[t],i=r[t],o=n.length;if(G2(n))for(var s=n[0].length,l=0;l<o;l++)i[l]?qh(i[l],n[l],s):i[l]=Array.prototype.slice.call(n[l]);else qh(i,n,o);i.length=n.length}else r[t]=e[t]}function H2(r,e){return r===e||ge(r)&&ge(e)&&W2(r,e)}function W2(r,e){var t=r.length;if(t!==e.length)return!1;for(var a=0;a<t;a++)if(r[a]!==e[a])return!1;return!0}function Gb(r,e,t,a,n,i,o,s){for(var l=_t(a),u=n.duration,f=n.delay,h=n.additive,v=n.setToFinal,c=!tt(i),p=r.animators,d=[],g=0;g<l.length;g++){var y=l[g],m=a[y];if(m!=null&&t[y]!=null&&(c||i[y]))if(tt(m)&&!ge(m)&&!$f(m)){if(e){s||(t[y]=m,r.updateDuringAnimation(e));continue}Gb(r,y,t[y],m,n,i&&i[y],o,s)}else d.push(y);else s||(t[y]=m,r.updateDuringAnimation(e),d.push(y))}var _=d.length;if(!h&&_)for(var S=0;S<p.length;S++){var w=p[S];if(w.targetName===e){var x=w.stopTracks(d);if(x){var b=vt(p,w);p.splice(b,1)}}}if(n.force||(d=Lt(d,function(M){return!H2(a[M],t[M])}),_=d.length),_>0||n.force&&!o.length){var T=void 0,A=void 0,D=void 0;if(s){A={},v&&(T={});for(var S=0;S<_;S++){var y=d[S];A[y]=t[y],v?T[y]=a[y]:t[y]=a[y]}}else if(v){D={};for(var S=0;S<_;S++){var y=d[S];D[y]=ds(t[y]),F2(t,a,y)}}var w=new jd(t,!1,!1,h?Lt(p,function(I){return I.targetName===e}):null);w.targetName=e,n.scope&&(w.scope=n.scope),v&&T&&w.whenWithKeys(0,T,d),D&&w.whenWithKeys(0,D,d),w.whenWithKeys(u??500,s?A:a,d).delay(f||0),r.addAnimator(w,e),o.push(w)}}const Fb=tg;var at=function(r){k(e,r);function e(t){var a=r.call(this)||this;return a.isGroup=!0,a._children=[],a.attr(t),a}return e.prototype.childrenRef=function(){return this._children},e.prototype.children=function(){return this._children.slice()},e.prototype.childAt=function(t){return this._children[t]},e.prototype.childOfName=function(t){for(var a=this._children,n=0;n<a.length;n++)if(a[n].name===t)return a[n]},e.prototype.childCount=function(){return this._children.length},e.prototype.add=function(t){return t&&t!==this&&t.parent!==this&&(this._children.push(t),this._doAdd(t)),this},e.prototype.addBefore=function(t,a){if(t&&t!==this&&t.parent!==this&&a&&a.parent===this){var n=this._children,i=n.indexOf(a);i>=0&&(n.splice(i,0,t),this._doAdd(t))}return this},e.prototype.replace=function(t,a){var n=vt(this._children,t);return n>=0&&this.replaceAt(a,n),this},e.prototype.replaceAt=function(t,a){var n=this._children,i=n[a];if(t&&t!==this&&t.parent!==this&&t!==i){n[a]=t,i.parent=null;var o=this.__zr;o&&i.removeSelfFromZr(o),this._doAdd(t)}return this},e.prototype._doAdd=function(t){t.parent&&t.parent.remove(t),t.parent=this;var a=this.__zr;a&&a!==t.__zr&&t.addSelfToZr(a),a&&a.refresh()},e.prototype.remove=function(t){var a=this.__zr,n=this._children,i=vt(n,t);return i<0?this:(n.splice(i,1),t.parent=null,a&&t.removeSelfFromZr(a),a&&a.refresh(),this)},e.prototype.removeAll=function(){for(var t=this._children,a=this.__zr,n=0;n<t.length;n++){var i=t[n];a&&i.removeSelfFromZr(a),i.parent=null}return t.length=0,this},e.prototype.eachChild=function(t,a){for(var n=this._children,i=0;i<n.length;i++){var o=n[i];t.call(a,o,i)}return this},e.prototype.traverse=function(t,a){for(var n=0;n<this._children.length;n++){var i=this._children[n],o=t.call(a,i);i.isGroup&&!o&&i.traverse(t,a)}return this},e.prototype.addSelfToZr=function(t){r.prototype.addSelfToZr.call(this,t);for(var a=0;a<this._children.length;a++){var n=this._children[a];n.addSelfToZr(t)}},e.prototype.removeSelfFromZr=function(t){r.prototype.removeSelfFromZr.call(this,t);for(var a=0;a<this._children.length;a++){var n=this._children[a];n.removeSelfFromZr(t)}},e.prototype.getBoundingRect=function(t){for(var a=new ht(0,0,0,0),n=t||this._children,i=[],o=null,s=0;s<n.length;s++){var l=n[s];if(!(l.ignore||l.invisible)){var u=l.getBoundingRect(),f=l.getLocalTransform(i);f?(ht.applyTransform(a,u,f),o=o||a.clone(),o.union(a)):(o=o||u.clone(),o.union(u))}}return o||a},e}(Fb);at.prototype.type="group";/*!
* ZRender, a high performance 2d drawing library.
*
* Copyright (c) 2013, Baidu Inc.
* All rights reserved.
*
* LICENSE
* https://github.com/ecomfe/zrender/blob/master/LICENSE.txt
*/var Ou={},Hb={};function $2(r){delete Hb[r]}function U2(r){if(!r)return!1;if(typeof r=="string")return ju(r,1)<Sp;if(r.colorStops){for(var e=r.colorStops,t=0,a=e.length,n=0;n<a;n++)t+=ju(e[n].color,1);return t/=a,t<Sp}return!1}var Y2=function(){function r(e,t,a){var n=this;this._sleepAfterStill=10,this._stillFrameAccum=0,this._needsRefresh=!0,this._needsRefreshHover=!0,this._darkMode=!1,a=a||{},this.dom=t,this.id=e;var i=new i2,o=a.renderer||"canvas";Ou[o]||(o=_t(Ou)[0]),a.useDirtyRect=a.useDirtyRect==null?!1:a.useDirtyRect;var s=new Ou[o](t,i,a,e),l=a.ssr||s.ssrOnly;this.storage=i,this.painter=s;var u=!mt.node&&!mt.worker&&!l?new N2(s.getViewportRoot(),s.root):null,f=a.useCoarsePointer,h=f==null||f==="auto"?mt.touchEventsSupported:!!f,v=44,c;h&&(c=it(a.pointerSize,v)),this.handler=new e2(i,s,u,s.root,c),this.animation=new M2({stage:{update:l?null:function(){return n._flush(!0)}}}),l||this.animation.start()}return r.prototype.add=function(e){this._disposed||!e||(this.storage.addRoot(e),e.addSelfToZr(this),this.refresh())},r.prototype.remove=function(e){this._disposed||!e||(this.storage.delRoot(e),e.removeSelfFromZr(this),this.refresh())},r.prototype.configLayer=function(e,t){this._disposed||(this.painter.configLayer&&this.painter.configLayer(e,t),this.refresh())},r.prototype.setBackgroundColor=function(e){this._disposed||(this.painter.setBackgroundColor&&this.painter.setBackgroundColor(e),this.refresh(),this._backgroundColor=e,this._darkMode=U2(e))},r.prototype.getBackgroundColor=function(){return this._backgroundColor},r.prototype.setDarkMode=function(e){this._darkMode=e},r.prototype.isDarkMode=function(){return this._darkMode},r.prototype.refreshImmediately=function(e){this._disposed||(e||this.animation.update(!0),this._needsRefresh=!1,this.painter.refresh(),this._needsRefresh=!1)},r.prototype.refresh=function(){this._disposed||(this._needsRefresh=!0,this.animation.start())},r.prototype.flush=function(){this._disposed||this._flush(!1)},r.prototype._flush=function(e){var t,a=Gi();this._needsRefresh&&(t=!0,this.refreshImmediately(e)),this._needsRefreshHover&&(t=!0,this.refreshHoverImmediately());var n=Gi();t?(this._stillFrameAccum=0,this.trigger("rendered",{elapsedTime:n-a})):this._sleepAfterStill>0&&(this._stillFrameAccum++,this._stillFrameAccum>this._sleepAfterStill&&this.animation.stop())},r.prototype.setSleepAfterStill=function(e){this._sleepAfterStill=e},r.prototype.wakeUp=function(){this._disposed||(this.animation.start(),this._stillFrameAccum=0)},r.prototype.refreshHover=function(){this._needsRefreshHover=!0},r.prototype.refreshHoverImmediately=function(){this._disposed||(this._needsRefreshHover=!1,this.painter.refreshHover&&this.painter.getType()==="canvas"&&this.painter.refreshHover())},r.prototype.resize=function(e){this._disposed||(e=e||{},this.painter.resize(e.width,e.height),this.handler.resize())},r.prototype.clearAnimation=function(){this._disposed||this.animation.clear()},r.prototype.getWidth=function(){if(!this._disposed)return this.painter.getWidth()},r.prototype.getHeight=function(){if(!this._disposed)return this.painter.getHeight()},r.prototype.setCursorStyle=function(e){this._disposed||this.handler.setCursorStyle(e)},r.prototype.findHover=function(e,t){if(!this._disposed)return this.handler.findHover(e,t)},r.prototype.on=function(e,t,a){return this._disposed||this.handler.on(e,t,a),this},r.prototype.off=function(e,t){this._disposed||this.handler.off(e,t)},r.prototype.trigger=function(e,t){this._disposed||this.handler.trigger(e,t)},r.prototype.clear=function(){if(!this._disposed){for(var e=this.storage.getRoots(),t=0;t<e.length;t++)e[t]instanceof at&&e[t].removeSelfFromZr(this);this.storage.delAllRoots(),this.painter.clear()}},r.prototype.dispose=function(){this._disposed||(this.animation.stop(),this.clear(),this.storage.dispose(),this.painter.dispose(),this.handler.dispose(),this.animation=this.storage=this.painter=this.handler=null,this._disposed=!0,$2(this.id))},r}();function Im(r,e){var t=new Y2(vb(),r,e);return Hb[t.id]=t,t}function Z2(r,e){Ou[r]=e}var bp;function X2(r){if(typeof bp=="function")return bp(r)}function q2(r){bp=r}var Lm=1e-4,Wb=20;function K2(r){return r.replace(/^\s+|\s+$/g,"")}function It(r,e,t,a){var n=e[0],i=e[1],o=t[0],s=t[1],l=i-n,u=s-o;if(l===0)return u===0?o:(o+s)/2;if(a)if(l>0){if(r<=n)return o;if(r>=i)return s}else{if(r>=n)return o;if(r<=i)return s}else{if(r===n)return o;if(r===i)return s}return(r-n)/l*u+o}function W(r,e){switch(r){case"center":case"middle":r="50%";break;case"left":case"top":r="0%";break;case"right":case"bottom":r="100%";break}return $(r)?K2(r).match(/%$/)?parseFloat(r)/100*e:parseFloat(r):r==null?NaN:+r}function $t(r,e,t){return e==null&&(e=10),e=Math.min(Math.max(0,e),Wb),r=(+r).toFixed(e),t?r:+r}function ar(r){return r.sort(function(e,t){return e-t}),r}function Er(r){if(r=+r,isNaN(r))return 0;if(r>1e-14){for(var e=1,t=0;t<15;t++,e*=10)if(Math.round(r*e)/e===r)return t}return Q2(r)}function Q2(r){var e=r.toString().toLowerCase(),t=e.indexOf("e"),a=t>0?+e.slice(t+1):0,n=t>0?t:e.length,i=e.indexOf("."),o=i<0?0:n-1-i;return Math.max(0,o-a)}function $b(r,e){var t=Math.log,a=Math.LN10,n=Math.floor(t(r[1]-r[0])/a),i=Math.round(t(Math.abs(e[1]-e[0]))/a),o=Math.min(Math.max(-n+i,0),20);return isFinite(o)?o:20}function J2(r,e){var t=zr(r,function(c,p){return c+(isNaN(p)?0:p)},0);if(t===0)return[];for(var a=Math.pow(10,e),n=G(r,function(c){return(isNaN(c)?0:c)/t*a*100}),i=a*100,o=G(n,function(c){return Math.floor(c)}),s=zr(o,function(c,p){return c+p},0),l=G(n,function(c,p){return c-o[p]});s<i;){for(var u=Number.NEGATIVE_INFINITY,f=null,h=0,v=l.length;h<v;++h)l[h]>u&&(u=l[h],f=h);++o[f],l[f]=0,++s}return G(o,function(c){return c/a})}function j2(r,e){var t=Math.max(Er(r),Er(e)),a=r+e;return t>Wb?a:$t(a,t)}var Pm=9007199254740991;function Ub(r){var e=Math.PI*2;return(r%e+e)%e}function Es(r){return r>-Lm&&r<Lm}var tP=/^(?:(\d{4})(?:[-\/](\d{1,2})(?:[-\/](\d{1,2})(?:[T ](\d{1,2})(?::(\d{1,2})(?::(\d{1,2})(?:[.,](\d+))?)?)?(Z|[\+\-]\d\d:?\d\d)?)?)?)?)?$/;function Hr(r){if(r instanceof Date)return r;if($(r)){var e=tP.exec(r);if(!e)return new Date(NaN);if(e[8]){var t=+e[4]||0;return e[8].toUpperCase()!=="Z"&&(t-=+e[8].slice(0,3)),new Date(Date.UTC(+e[1],+(e[2]||1)-1,+e[3]||1,t,+(e[5]||0),+e[6]||0,e[7]?+e[7].substring(0,3):0))}else return new Date(+e[1],+(e[2]||1)-1,+e[3]||1,+e[4]||0,+(e[5]||0),+e[6]||0,e[7]?+e[7].substring(0,3):0)}else if(r==null)return new Date(NaN);return new Date(Math.round(r))}function eP(r){return Math.pow(10,eg(r))}function eg(r){if(r===0)return 0;var e=Math.floor(Math.log(r)/Math.LN10);return r/Math.pow(10,e)>=10&&e++,e}function Yb(r,e){var t=eg(r),a=Math.pow(10,t),n=r/a,i;return e?n<1.5?i=1:n<2.5?i=2:n<4?i=3:n<7?i=5:i=10:n<1?i=1:n<2?i=2:n<3?i=3:n<5?i=5:i=10,r=i*a,t>=-20?+r.toFixed(t<0?-t:0):r}function Kh(r,e){var t=(r.length-1)*e+1,a=Math.floor(t),n=+r[a-1],i=t-a;return i?n+i*(r[a]-n):n}function Rm(r){r.sort(function(l,u){return s(l,u,0)?-1:1});for(var e=-1/0,t=1,a=0;a<r.length;){for(var n=r[a].interval,i=r[a].close,o=0;o<2;o++)n[o]<=e&&(n[o]=e,i[o]=o?1:1-t),e=n[o],t=i[o];n[0]===n[1]&&i[0]*i[1]!==1?r.splice(a,1):a++}return r;function s(l,u,f){return l.interval[f]<u.interval[f]||l.interval[f]===u.interval[f]&&(l.close[f]-u.close[f]===(f?-1:1)||!f&&s(l,u,1))}}function oa(r){var e=parseFloat(r);return e==r&&(e!==0||!$(r)||r.indexOf("x")<=0)?e:NaN}function Zb(r){return!isNaN(oa(r))}function Xb(){return Math.round(Math.random()*9)}function qb(r,e){return e===0?r:qb(e,r%e)}function Em(r,e){return r==null?e:e==null?r:r*e/qb(r,e)}function Mt(r){throw new Error(r)}function km(r,e,t){return(e-r)*t+r}var Kb="series\0",Qb="\0_ec_\0";function Pt(r){return r instanceof Array?r:r==null?[]:[r]}function Jn(r,e,t){if(r){r[e]=r[e]||{},r.emphasis=r.emphasis||{},r.emphasis[e]=r.emphasis[e]||{};for(var a=0,n=t.length;a<n;a++){var i=t[a];!r.emphasis[e].hasOwnProperty(i)&&r[e].hasOwnProperty(i)&&(r.emphasis[e][i]=r[e][i])}}}var Om=["fontStyle","fontWeight","fontSize","fontFamily","rich","tag","color","textBorderColor","textBorderWidth","width","height","lineHeight","align","verticalAlign","baseline","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY","backgroundColor","borderColor","borderWidth","borderRadius","padding"];function uo(r){return tt(r)&&!z(r)&&!(r instanceof Date)?r.value:r}function rP(r){return tt(r)&&!(r instanceof Array)}function Jb(r,e,t){var a=t==="normalMerge",n=t==="replaceMerge",i=t==="replaceAll";r=r||[],e=(e||[]).slice();var o=Z();C(e,function(l,u){if(!tt(l)){e[u]=null;return}});var s=aP(r,o,t);return(a||n)&&nP(s,r,o,e),a&&iP(s,e),a||n?oP(s,e,n):i&&sP(s,e),lP(s),s}function aP(r,e,t){var a=[];if(t==="replaceAll")return a;for(var n=0;n<r.length;n++){var i=r[n];i&&i.id!=null&&e.set(i.id,n),a.push({existing:t==="replaceMerge"||ks(i)?null:i,newOption:null,keyInfo:null,brandNew:null})}return a}function nP(r,e,t,a){C(a,function(n,i){if(!(!n||n.id==null)){var o=gs(n.id),s=t.get(o);if(s!=null){var l=r[s];Ae(!l.newOption,'Duplicated option on id "'+o+'".'),l.newOption=n,l.existing=e[s],a[i]=null}}})}function iP(r,e){C(e,function(t,a){if(!(!t||t.name==null))for(var n=0;n<r.length;n++){var i=r[n].existing;if(!r[n].newOption&&i&&(i.id==null||t.id==null)&&!ks(t)&&!ks(i)&&jb("name",i,t)){r[n].newOption=t,e[a]=null;return}}})}function oP(r,e,t){C(e,function(a){if(a){for(var n,i=0;(n=r[i])&&(n.newOption||ks(n.existing)||n.existing&&a.id!=null&&!jb("id",a,n.existing));)i++;n?(n.newOption=a,n.brandNew=t):r.push({newOption:a,brandNew:t,existing:null,keyInfo:null}),i++}})}function sP(r,e){C(e,function(t){r.push({newOption:t,brandNew:!0,existing:null,keyInfo:null})})}function lP(r){var e=Z();C(r,function(t){var a=t.existing;a&&e.set(a.id,t)}),C(r,function(t){var a=t.newOption;Ae(!a||a.id==null||!e.get(a.id)||e.get(a.id)===t,"id duplicates: "+(a&&a.id)),a&&a.id!=null&&e.set(a.id,t),!t.keyInfo&&(t.keyInfo={})}),C(r,function(t,a){var n=t.existing,i=t.newOption,o=t.keyInfo;if(tt(i)){if(o.name=i.name!=null?gs(i.name):n?n.name:Kb+a,n)o.id=gs(n.id);else if(i.id!=null)o.id=gs(i.id);else{var s=0;do o.id="\0"+o.name+"\0"+s++;while(e.get(o.id))}e.set(o.id,t)}})}function jb(r,e,t){var a=Qt(e[r],null),n=Qt(t[r],null);return a!=null&&n!=null&&a===n}function gs(r){return Qt(r,"")}function Qt(r,e){return r==null?e:$(r)?r:Ct(r)||tp(r)?r+"":e}function rg(r){var e=r.name;return!!(e&&e.indexOf(Kb))}function ks(r){return r&&r.id!=null&&gs(r.id).indexOf(Qb)===0}function uP(r){return Qb+r}function fP(r,e,t){C(r,function(a){var n=a.newOption;tt(n)&&(a.keyInfo.mainType=e,a.keyInfo.subType=hP(e,n,a.existing,t))})}function hP(r,e,t,a){var n=e.type?e.type:t?t.subType:a.determineSubType(r,e);return n}function vP(r,e){var t={},a={};return n(r||[],t),n(e||[],a,t),[i(t),i(a)];function n(o,s,l){for(var u=0,f=o.length;u<f;u++){var h=Qt(o[u].seriesId,null);if(h==null)return;for(var v=Pt(o[u].dataIndex),c=l&&l[h],p=0,d=v.length;p<d;p++){var g=v[p];c&&c[g]?c[g]=null:(s[h]||(s[h]={}))[g]=1}}}function i(o,s){var l=[];for(var u in o)if(o.hasOwnProperty(u)&&o[u]!=null)if(s)l.push(+u);else{var f=i(o[u],!0);f.length&&l.push({seriesId:u,dataIndex:f})}return l}}function jn(r,e){if(e.dataIndexInside!=null)return e.dataIndexInside;if(e.dataIndex!=null)return z(e.dataIndex)?G(e.dataIndex,function(t){return r.indexOfRawIndex(t)}):r.indexOfRawIndex(e.dataIndex);if(e.name!=null)return z(e.name)?G(e.name,function(t){return r.indexOfName(t)}):r.indexOfName(e.name)}function bt(){var r="__ec_inner_"+cP++;return function(e){return e[r]||(e[r]={})}}var cP=Xb();function ys(r,e,t){var a=ag(e,t),n=a.mainTypeSpecified,i=a.queryOptionMap,o=a.others,s=o,l=t?t.defaultMainType:null;return!n&&l&&i.set(l,{}),i.each(function(u,f){var h=ol(r,f,u,{useDefault:l===f,enableAll:t&&t.enableAll!=null?t.enableAll:!0,enableNone:t&&t.enableNone!=null?t.enableNone:!0});s[f+"Models"]=h.models,s[f+"Model"]=h.models[0]}),s}function ag(r,e){var t;if($(r)){var a={};a[r+"Index"]=0,t=a}else t=r;var n=Z(),i={},o=!1;return C(t,function(s,l){if(l==="dataIndex"||l==="dataIndexInside"){i[l]=s;return}var u=l.match(/^(\w+)(Index|Id|Name)$/)||[],f=u[1],h=(u[2]||"").toLowerCase();if(!(!f||!h||e&&e.includeMainTypes&&vt(e.includeMainTypes,f)<0)){o=o||!!f;var v=n.get(f)||n.set(f,{});v[h]=s}}),{mainTypeSpecified:o,queryOptionMap:n,others:i}}var Xt={useDefault:!0,enableAll:!1,enableNone:!1},pP={useDefault:!1,enableAll:!0,enableNone:!0};function ol(r,e,t,a){a=a||Xt;var n=t.index,i=t.id,o=t.name,s={models:null,specified:n!=null||i!=null||o!=null};if(!s.specified){var l=void 0;return s.models=a.useDefault&&(l=r.getComponent(e))?[l]:[],s}return n==="none"||n===!1?(Ae(a.enableNone,'`"none"` or `false` is not a valid value on index option.'),s.models=[],s):(n==="all"&&(Ae(a.enableAll,'`"all"` is not a valid value on index option.'),n=i=o=null),s.models=r.queryComponents({mainType:e,index:n,id:i,name:o}),s)}function tT(r,e,t){r.setAttribute?r.setAttribute(e,t):r[e]=t}function dP(r,e){return r.getAttribute?r.getAttribute(e):r[e]}function gP(r){return r==="auto"?mt.domSupported?"html":"richText":r||"html"}function Tp(r,e){var t=Z(),a=[];return C(r,function(n){var i=e(n);(t.get(i)||(a.push(i),t.set(i,[]))).push(n)}),{keys:a,buckets:t}}function eT(r,e,t,a,n){var i=e==null||e==="auto";if(a==null)return a;if(Ct(a)){var o=km(t||0,a,n);return $t(o,i?Math.max(Er(t||0),Er(a)):e)}else{if($(a))return n<1?t:a;for(var s=[],l=t,u=a,f=Math.max(l?l.length:0,u.length),h=0;h<f;++h){var v=r.getDimensionInfo(h);if(v&&v.type==="ordinal")s[h]=(n<1&&l?l:u)[h];else{var c=l&&l[h]?l[h]:0,p=u[h],o=km(c,p,n);s[h]=$t(o,i?Math.max(Er(c),Er(p)):e)}}return s}}var yP=".",sn="___EC__COMPONENT__CONTAINER___",rT="___EC__EXTENDED_CLASS___";function kr(r){var e={main:"",sub:""};if(r){var t=r.split(yP);e.main=t[0]||"",e.sub=t[1]||""}return e}function mP(r){Ae(/^[a-zA-Z0-9_]+([.][a-zA-Z0-9_]+)?$/.test(r),'componentType "'+r+'" illegal')}function _P(r){return!!(r&&r[rT])}function ng(r,e){r.$constructor=r,r.extend=function(t){var a=this,n;return SP(a)?n=function(i){k(o,i);function o(){return i.apply(this,arguments)||this}return o}(a):(n=function(){(t.$constructor||a).apply(this,arguments)},bL(n,this)),V(n.prototype,t),n[rT]=!0,n.extend=this.extend,n.superCall=bP,n.superApply=TP,n.superClass=a,n}}function SP(r){return K(r)&&/^class\s/.test(Function.prototype.toString.call(r))}function aT(r,e){r.extend=e.extend}var xP=Math.round(Math.random()*10);function wP(r){var e=["__\0is_clz",xP++].join("_");r.prototype[e]=!0,r.isInstance=function(t){return!!(t&&t[e])}}function bP(r,e){for(var t=[],a=2;a<arguments.length;a++)t[a-2]=arguments[a];return this.superClass.prototype[e].apply(r,t)}function TP(r,e,t){return this.superClass.prototype[e].apply(r,t)}function qf(r){var e={};r.registerClass=function(a){var n=a.type||a.prototype.type;if(n){mP(n),a.prototype.type=n;var i=kr(n);if(!i.sub)e[i.main]=a;else if(i.sub!==sn){var o=t(i);o[i.sub]=a}}return a},r.getClass=function(a,n,i){var o=e[a];if(o&&o[sn]&&(o=n?o[n]:null),i&&!o)throw new Error(n?"Component "+a+"."+(n||"")+" is used but not imported.":a+".type should be specified.");return o},r.getClassesByMainType=function(a){var n=kr(a),i=[],o=e[n.main];return o&&o[sn]?C(o,function(s,l){l!==sn&&i.push(s)}):i.push(o),i},r.hasClass=function(a){var n=kr(a);return!!e[n.main]},r.getAllClassMainTypes=function(){var a=[];return C(e,function(n,i){a.push(i)}),a},r.hasSubTypes=function(a){var n=kr(a),i=e[n.main];return i&&i[sn]};function t(a){var n=e[a.main];return(!n||!n[sn])&&(n=e[a.main]={},n[sn]=!0),n}}function ti(r,e){for(var t=0;t<r.length;t++)r[t][1]||(r[t][1]=r[t][0]);return e=e||!1,function(a,n,i){for(var o={},s=0;s<r.length;s++){var l=r[s][1];if(!(n&&vt(n,l)>=0||i&&vt(i,l)<0)){var u=a.getShallow(l,e);u!=null&&(o[r[s][0]]=u)}}return o}}var AP=[["fill","color"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["opacity"],["shadowColor"]],CP=ti(AP),DP=function(){function r(){}return r.prototype.getAreaStyle=function(e,t){return CP(this,e,t)},r}(),Ap=new nl(50);function MP(r){if(typeof r=="string"){var e=Ap.get(r);return e&&e.image}else return r}function ig(r,e,t,a,n){if(r)if(typeof r=="string"){if(e&&e.__zrImageSrc===r||!t)return e;var i=Ap.get(r),o={hostEl:t,cb:a,cbPayload:n};return i?(e=i.image,!Kf(e)&&i.pending.push(o)):(e=Ha.loadImage(r,Nm,Nm),e.__zrImageSrc=r,Ap.put(r,e.__cachedImgObj={image:e,pending:[o]})),e}else return r;else return e}function Nm(){var r=this.__cachedImgObj;this.onload=this.onerror=this.__cachedImgObj=null;for(var e=0;e<r.pending.length;e++){var t=r.pending[e],a=t.cb;a&&a(this,t.cbPayload),t.hostEl.dirty()}r.pending.length=0}function Kf(r){return r&&r.width&&r.height}var Qh=/\{([a-zA-Z0-9_]+)\|([^}]*)\}/g;function IP(r,e,t,a,n){if(!e)return"";var i=(r+"").split(`
`);n=nT(e,t,a,n);for(var o=0,s=i.length;o<s;o++)i[o]=iT(i[o],n);return i.join(`
`)}function nT(r,e,t,a){a=a||{};var n=V({},a);n.font=e,t=it(t,"..."),n.maxIterations=it(a.maxIterations,2);var i=n.minChar=it(a.minChar,0);n.cnCharWidth=We("国",e);var o=n.ascCharWidth=We("a",e);n.placeholder=it(a.placeholder,"");for(var s=r=Math.max(0,r-1),l=0;l<i&&s>=o;l++)s-=o;var u=We(t,e);return u>s&&(t="",u=0),s=r-u,n.ellipsis=t,n.ellipsisWidth=u,n.contentWidth=s,n.containerWidth=r,n}function iT(r,e){var t=e.containerWidth,a=e.font,n=e.contentWidth;if(!t)return"";var i=We(r,a);if(i<=t)return r;for(var o=0;;o++){if(i<=n||o>=e.maxIterations){r+=e.ellipsis;break}var s=o===0?LP(r,n,e.ascCharWidth,e.cnCharWidth):i>0?Math.floor(r.length*n/i):0;r=r.substr(0,s),i=We(r,a)}return r===""&&(r=e.placeholder),r}function LP(r,e,t,a){for(var n=0,i=0,o=r.length;i<o&&n<e;i++){var s=r.charCodeAt(i);n+=0<=s&&s<=127?t:a}return i}function PP(r,e){r!=null&&(r+="");var t=e.overflow,a=e.padding,n=e.font,i=t==="truncate",o=Xf(n),s=it(e.lineHeight,o),l=!!e.backgroundColor,u=e.lineOverflow==="truncate",f=e.width,h;f!=null&&(t==="break"||t==="breakAll")?h=r?oT(r,e.font,f,t==="breakAll",0).lines:[]:h=r?r.split(`
`):[];var v=h.length*s,c=it(e.height,v);if(v>c&&u){var p=Math.floor(c/s);h=h.slice(0,p)}if(r&&i&&f!=null)for(var d=nT(f,n,e.ellipsis,{minChar:e.truncateMinChar,placeholder:e.placeholder}),g=0;g<h.length;g++)h[g]=iT(h[g],d);for(var y=c,m=0,g=0;g<h.length;g++)m=Math.max(We(h[g],n),m);f==null&&(f=m);var _=m;return a&&(y+=a[0]+a[2],_+=a[1]+a[3],f+=a[1]+a[3]),l&&(_=f),{lines:h,height:c,outerWidth:_,outerHeight:y,lineHeight:s,calculatedLineHeight:o,contentWidth:m,contentHeight:v,width:f}}var RP=function(){function r(){}return r}(),Bm=function(){function r(e){this.tokens=[],e&&(this.tokens=e)}return r}(),EP=function(){function r(){this.width=0,this.height=0,this.contentWidth=0,this.contentHeight=0,this.outerWidth=0,this.outerHeight=0,this.lines=[]}return r}();function kP(r,e){var t=new EP;if(r!=null&&(r+=""),!r)return t;for(var a=e.width,n=e.height,i=e.overflow,o=(i==="break"||i==="breakAll")&&a!=null?{width:a,accumWidth:0,breakAll:i==="breakAll"}:null,s=Qh.lastIndex=0,l;(l=Qh.exec(r))!=null;){var u=l.index;u>s&&Jh(t,r.substring(s,u),e,o),Jh(t,l[2],e,o,l[1]),s=Qh.lastIndex}s<r.length&&Jh(t,r.substring(s,r.length),e,o);var f=[],h=0,v=0,c=e.padding,p=i==="truncate",d=e.lineOverflow==="truncate";function g(O,B,F){O.width=B,O.lineHeight=F,h+=F,v=Math.max(v,B)}t:for(var y=0;y<t.lines.length;y++){for(var m=t.lines[y],_=0,S=0,w=0;w<m.tokens.length;w++){var x=m.tokens[w],b=x.styleName&&e.rich[x.styleName]||{},T=x.textPadding=b.padding,A=T?T[1]+T[3]:0,D=x.font=b.font||e.font;x.contentHeight=Xf(D);var M=it(b.height,x.contentHeight);if(x.innerHeight=M,T&&(M+=T[0]+T[2]),x.height=M,x.lineHeight=Br(b.lineHeight,e.lineHeight,M),x.align=b&&b.align||e.align,x.verticalAlign=b&&b.verticalAlign||"middle",d&&n!=null&&h+x.lineHeight>n){w>0?(m.tokens=m.tokens.slice(0,w),g(m,S,_),t.lines=t.lines.slice(0,y+1)):t.lines=t.lines.slice(0,y);break t}var I=b.width,L=I==null||I==="auto";if(typeof I=="string"&&I.charAt(I.length-1)==="%")x.percentWidth=I,f.push(x),x.contentWidth=We(x.text,D);else{if(L){var P=b.backgroundColor,R=P&&P.image;R&&(R=MP(R),Kf(R)&&(x.width=Math.max(x.width,R.width*M/R.height)))}var E=p&&a!=null?a-S:null;E!=null&&E<x.width?!L||E<A?(x.text="",x.width=x.contentWidth=0):(x.text=IP(x.text,E-A,D,e.ellipsis,{minChar:e.truncateMinChar}),x.width=x.contentWidth=We(x.text,D)):x.contentWidth=We(x.text,D)}x.width+=A,S+=x.width,b&&(_=Math.max(_,x.lineHeight))}g(m,S,_)}t.outerWidth=t.width=it(a,v),t.outerHeight=t.height=it(n,h),t.contentHeight=h,t.contentWidth=v,c&&(t.outerWidth+=c[1]+c[3],t.outerHeight+=c[0]+c[2]);for(var y=0;y<f.length;y++){var x=f[y],N=x.percentWidth;x.width=parseInt(N,10)/100*t.width}return t}function Jh(r,e,t,a,n){var i=e==="",o=n&&t.rich[n]||{},s=r.lines,l=o.font||t.font,u=!1,f,h;if(a){var v=o.padding,c=v?v[1]+v[3]:0;if(o.width!=null&&o.width!=="auto"){var p=_r(o.width,a.width)+c;s.length>0&&p+a.accumWidth>a.width&&(f=e.split(`
`),u=!0),a.accumWidth=p}else{var d=oT(e,l,a.width,a.breakAll,a.accumWidth);a.accumWidth=d.accumWidth+c,h=d.linesWidths,f=d.lines}}else f=e.split(`
`);for(var g=0;g<f.length;g++){var y=f[g],m=new RP;if(m.styleName=n,m.text=y,m.isLineHolder=!y&&!i,typeof o.width=="number"?m.width=o.width:m.width=h?h[g]:We(y,l),!g&&!u){var _=(s[s.length-1]||(s[0]=new Bm)).tokens,S=_.length;S===1&&_[0].isLineHolder?_[0]=m:(y||!S||i)&&_.push(m)}else s.push(new Bm([m]))}}function OP(r){var e=r.charCodeAt(0);return e>=32&&e<=591||e>=880&&e<=4351||e>=4608&&e<=5119||e>=7680&&e<=8303}var NP=zr(",&?/;] ".split(""),function(r,e){return r[e]=!0,r},{});function BP(r){return OP(r)?!!NP[r]:!0}function oT(r,e,t,a,n){for(var i=[],o=[],s="",l="",u=0,f=0,h=0;h<r.length;h++){var v=r.charAt(h);if(v===`
`){l&&(s+=l,f+=u),i.push(s),o.push(f),s="",l="",u=0,f=0;continue}var c=We(v,e),p=a?!1:!BP(v);if(i.length?f+c>t:n+f+c>t){f?(s||l)&&(p?(s||(s=l,l="",u=0,f=u),i.push(s),o.push(f-u),l+=v,u+=c,s="",f=u):(l&&(s+=l,l="",u=0),i.push(s),o.push(f),s=v,f=c)):p?(i.push(l),o.push(u),l=v,u=c):(i.push(v),o.push(c));continue}f+=c,p?(l+=v,u+=c):(l&&(s+=l,l="",u=0),s+=v)}return!i.length&&!s&&(s=r,l="",u=0),l&&(s+=l),s&&(i.push(s),o.push(f)),i.length===1&&(f+=n),{accumWidth:f,lines:i,linesWidths:o}}var Cp="__zr_style_"+Math.round(Math.random()*10),Un={shadowBlur:0,shadowOffsetX:0,shadowOffsetY:0,shadowColor:"#000",opacity:1,blend:"source-over"},Qf={style:{shadowBlur:!0,shadowOffsetX:!0,shadowOffsetY:!0,shadowColor:!0,opacity:!0}};Un[Cp]=!0;var Vm=["z","z2","invisible"],VP=["invisible"],ir=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype._init=function(t){for(var a=_t(t),n=0;n<a.length;n++){var i=a[n];i==="style"?this.useStyle(t[i]):r.prototype.attrKV.call(this,i,t[i])}this.style||this.useStyle({})},e.prototype.beforeBrush=function(){},e.prototype.afterBrush=function(){},e.prototype.innerBeforeBrush=function(){},e.prototype.innerAfterBrush=function(){},e.prototype.shouldBePainted=function(t,a,n,i){var o=this.transform;if(this.ignore||this.invisible||this.style.opacity===0||this.culling&&zP(this,t,a)||o&&!o[0]&&!o[3])return!1;if(n&&this.__clipPaths){for(var s=0;s<this.__clipPaths.length;++s)if(this.__clipPaths[s].isZeroArea())return!1}if(i&&this.parent)for(var l=this.parent;l;){if(l.ignore)return!1;l=l.parent}return!0},e.prototype.contain=function(t,a){return this.rectContain(t,a)},e.prototype.traverse=function(t,a){t.call(a,this)},e.prototype.rectContain=function(t,a){var n=this.transformCoordToLocal(t,a),i=this.getBoundingRect();return i.contain(n[0],n[1])},e.prototype.getPaintRect=function(){var t=this._paintRect;if(!this._paintRect||this.__dirty){var a=this.transform,n=this.getBoundingRect(),i=this.style,o=i.shadowBlur||0,s=i.shadowOffsetX||0,l=i.shadowOffsetY||0;t=this._paintRect||(this._paintRect=new ht(0,0,0,0)),a?ht.applyTransform(t,n,a):t.copy(n),(o||s||l)&&(t.width+=o*2+Math.abs(s),t.height+=o*2+Math.abs(l),t.x=Math.min(t.x,t.x+s-o),t.y=Math.min(t.y,t.y+l-o));var u=this.dirtyRectTolerance;t.isZero()||(t.x=Math.floor(t.x-u),t.y=Math.floor(t.y-u),t.width=Math.ceil(t.width+1+u*2),t.height=Math.ceil(t.height+1+u*2))}return t},e.prototype.setPrevPaintRect=function(t){t?(this._prevPaintRect=this._prevPaintRect||new ht(0,0,0,0),this._prevPaintRect.copy(t)):this._prevPaintRect=null},e.prototype.getPrevPaintRect=function(){return this._prevPaintRect},e.prototype.animateStyle=function(t){return this.animate("style",t)},e.prototype.updateDuringAnimation=function(t){t==="style"?this.dirtyStyle():this.markRedraw()},e.prototype.attrKV=function(t,a){t!=="style"?r.prototype.attrKV.call(this,t,a):this.style?this.setStyle(a):this.useStyle(a)},e.prototype.setStyle=function(t,a){return typeof t=="string"?this.style[t]=a:V(this.style,t),this.dirtyStyle(),this},e.prototype.dirtyStyle=function(t){t||this.markRedraw(),this.__dirty|=ts,this._rect&&(this._rect=null)},e.prototype.dirty=function(){this.dirtyStyle()},e.prototype.styleChanged=function(){return!!(this.__dirty&ts)},e.prototype.styleUpdated=function(){this.__dirty&=~ts},e.prototype.createStyle=function(t){return Uf(Un,t)},e.prototype.useStyle=function(t){t[Cp]||(t=this.createStyle(t)),this.__inHover?this.__hoverStyle=t:this.style=t,this.dirtyStyle()},e.prototype.isStyleObject=function(t){return t[Cp]},e.prototype._innerSaveToNormal=function(t){r.prototype._innerSaveToNormal.call(this,t);var a=this._normalState;t.style&&!a.style&&(a.style=this._mergeStyle(this.createStyle(),this.style)),this._savePrimaryToNormal(t,a,Vm)},e.prototype._applyStateObj=function(t,a,n,i,o,s){r.prototype._applyStateObj.call(this,t,a,n,i,o,s);var l=!(a&&i),u;if(a&&a.style?o?i?u=a.style:(u=this._mergeStyle(this.createStyle(),n.style),this._mergeStyle(u,a.style)):(u=this._mergeStyle(this.createStyle(),i?this.style:n.style),this._mergeStyle(u,a.style)):l&&(u=n.style),u)if(o){var f=this.style;if(this.style=this.createStyle(l?{}:f),l)for(var h=_t(f),v=0;v<h.length;v++){var c=h[v];c in u&&(u[c]=u[c],this.style[c]=f[c])}for(var p=_t(u),v=0;v<p.length;v++){var c=p[v];this.style[c]=this.style[c]}this._transitionState(t,{style:u},s,this.getAnimationStyleProps())}else this.useStyle(u);for(var d=this.__inHover?VP:Vm,v=0;v<d.length;v++){var c=d[v];a&&a[c]!=null?this[c]=a[c]:l&&n[c]!=null&&(this[c]=n[c])}},e.prototype._mergeStates=function(t){for(var a=r.prototype._mergeStates.call(this,t),n,i=0;i<t.length;i++){var o=t[i];o.style&&(n=n||{},this._mergeStyle(n,o.style))}return n&&(a.style=n),a},e.prototype._mergeStyle=function(t,a){return V(t,a),t},e.prototype.getAnimationStyleProps=function(){return Qf},e.initDefaultProps=function(){var t=e.prototype;t.type="displayable",t.invisible=!1,t.z=0,t.z2=0,t.zlevel=0,t.culling=!1,t.cursor="pointer",t.rectHover=!1,t.incremental=!1,t._rect=null,t.dirtyRectTolerance=0,t.__dirty=ze|ts}(),e}(Fb),jh=new ht(0,0,0,0),tv=new ht(0,0,0,0);function zP(r,e,t){return jh.copy(r.getBoundingRect()),r.transform&&jh.applyTransform(r.transform),tv.width=e,tv.height=t,!jh.intersect(tv)}var Ee=Math.min,ke=Math.max,ev=Math.sin,rv=Math.cos,ln=Math.PI*2,Ol=ii(),Nl=ii(),Bl=ii();function Jf(r,e,t){if(r.length!==0){for(var a=r[0],n=a[0],i=a[0],o=a[1],s=a[1],l=1;l<r.length;l++)a=r[l],n=Ee(n,a[0]),i=ke(i,a[0]),o=Ee(o,a[1]),s=ke(s,a[1]);e[0]=n,e[1]=o,t[0]=i,t[1]=s}}function zm(r,e,t,a,n,i){n[0]=Ee(r,t),n[1]=Ee(e,a),i[0]=ke(r,t),i[1]=ke(e,a)}var Gm=[],Fm=[];function GP(r,e,t,a,n,i,o,s,l,u){var f=Tb,h=jt,v=f(r,t,n,o,Gm);l[0]=1/0,l[1]=1/0,u[0]=-1/0,u[1]=-1/0;for(var c=0;c<v;c++){var p=h(r,t,n,o,Gm[c]);l[0]=Ee(p,l[0]),u[0]=ke(p,u[0])}v=f(e,a,i,s,Fm);for(var c=0;c<v;c++){var d=h(e,a,i,s,Fm[c]);l[1]=Ee(d,l[1]),u[1]=ke(d,u[1])}l[0]=Ee(r,l[0]),u[0]=ke(r,u[0]),l[0]=Ee(o,l[0]),u[0]=ke(o,u[0]),l[1]=Ee(e,l[1]),u[1]=ke(e,u[1]),l[1]=Ee(s,l[1]),u[1]=ke(s,u[1])}function FP(r,e,t,a,n,i,o,s){var l=Cb,u=ne,f=ke(Ee(l(r,t,n),1),0),h=ke(Ee(l(e,a,i),1),0),v=u(r,t,n,f),c=u(e,a,i,h);o[0]=Ee(r,n,v),o[1]=Ee(e,i,c),s[0]=ke(r,n,v),s[1]=ke(e,i,c)}function HP(r,e,t,a,n,i,o,s,l){var u=Ia,f=La,h=Math.abs(n-i);if(h%ln<1e-4&&h>1e-4){s[0]=r-t,s[1]=e-a,l[0]=r+t,l[1]=e+a;return}if(Ol[0]=rv(n)*t+r,Ol[1]=ev(n)*a+e,Nl[0]=rv(i)*t+r,Nl[1]=ev(i)*a+e,u(s,Ol,Nl),f(l,Ol,Nl),n=n%ln,n<0&&(n=n+ln),i=i%ln,i<0&&(i=i+ln),n>i&&!o?i+=ln:n<i&&o&&(n+=ln),o){var v=i;i=n,n=v}for(var c=0;c<i;c+=Math.PI/2)c>n&&(Bl[0]=rv(c)*t+r,Bl[1]=ev(c)*a+e,u(s,Bl,s),f(l,Bl,l))}var Rt={M:1,L:2,C:3,Q:4,A:5,Z:6,R:7},un=[],fn=[],br=[],da=[],Tr=[],Ar=[],av=Math.min,nv=Math.max,hn=Math.cos,vn=Math.sin,Zr=Math.abs,Dp=Math.PI,Ta=Dp*2,iv=typeof Float32Array<"u",Lo=[];function ov(r){var e=Math.round(r/Dp*1e8)/1e8;return e%2*Dp}function og(r,e){var t=ov(r[0]);t<0&&(t+=Ta);var a=t-r[0],n=r[1];n+=a,!e&&n-t>=Ta?n=t+Ta:e&&t-n>=Ta?n=t-Ta:!e&&t>n?n=t+(Ta-ov(t-n)):e&&t<n&&(n=t-(Ta-ov(n-t))),r[0]=t,r[1]=n}var Wr=function(){function r(e){this.dpr=1,this._xi=0,this._yi=0,this._x0=0,this._y0=0,this._len=0,e&&(this._saveData=!1),this._saveData&&(this.data=[])}return r.prototype.increaseVersion=function(){this._version++},r.prototype.getVersion=function(){return this._version},r.prototype.setScale=function(e,t,a){a=a||0,a>0&&(this._ux=Zr(a/ef/e)||0,this._uy=Zr(a/ef/t)||0)},r.prototype.setDPR=function(e){this.dpr=e},r.prototype.setContext=function(e){this._ctx=e},r.prototype.getContext=function(){return this._ctx},r.prototype.beginPath=function(){return this._ctx&&this._ctx.beginPath(),this.reset(),this},r.prototype.reset=function(){this._saveData&&(this._len=0),this._pathSegLen&&(this._pathSegLen=null,this._pathLen=0),this._version++},r.prototype.moveTo=function(e,t){return this._drawPendingPt(),this.addData(Rt.M,e,t),this._ctx&&this._ctx.moveTo(e,t),this._x0=e,this._y0=t,this._xi=e,this._yi=t,this},r.prototype.lineTo=function(e,t){var a=Zr(e-this._xi),n=Zr(t-this._yi),i=a>this._ux||n>this._uy;if(this.addData(Rt.L,e,t),this._ctx&&i&&this._ctx.lineTo(e,t),i)this._xi=e,this._yi=t,this._pendingPtDist=0;else{var o=a*a+n*n;o>this._pendingPtDist&&(this._pendingPtX=e,this._pendingPtY=t,this._pendingPtDist=o)}return this},r.prototype.bezierCurveTo=function(e,t,a,n,i,o){return this._drawPendingPt(),this.addData(Rt.C,e,t,a,n,i,o),this._ctx&&this._ctx.bezierCurveTo(e,t,a,n,i,o),this._xi=i,this._yi=o,this},r.prototype.quadraticCurveTo=function(e,t,a,n){return this._drawPendingPt(),this.addData(Rt.Q,e,t,a,n),this._ctx&&this._ctx.quadraticCurveTo(e,t,a,n),this._xi=a,this._yi=n,this},r.prototype.arc=function(e,t,a,n,i,o){this._drawPendingPt(),Lo[0]=n,Lo[1]=i,og(Lo,o),n=Lo[0],i=Lo[1];var s=i-n;return this.addData(Rt.A,e,t,a,a,n,s,0,o?0:1),this._ctx&&this._ctx.arc(e,t,a,n,i,o),this._xi=hn(i)*a+e,this._yi=vn(i)*a+t,this},r.prototype.arcTo=function(e,t,a,n,i){return this._drawPendingPt(),this._ctx&&this._ctx.arcTo(e,t,a,n,i),this},r.prototype.rect=function(e,t,a,n){return this._drawPendingPt(),this._ctx&&this._ctx.rect(e,t,a,n),this.addData(Rt.R,e,t,a,n),this},r.prototype.closePath=function(){this._drawPendingPt(),this.addData(Rt.Z);var e=this._ctx,t=this._x0,a=this._y0;return e&&e.closePath(),this._xi=t,this._yi=a,this},r.prototype.fill=function(e){e&&e.fill(),this.toStatic()},r.prototype.stroke=function(e){e&&e.stroke(),this.toStatic()},r.prototype.len=function(){return this._len},r.prototype.setData=function(e){var t=e.length;!(this.data&&this.data.length===t)&&iv&&(this.data=new Float32Array(t));for(var a=0;a<t;a++)this.data[a]=e[a];this._len=t},r.prototype.appendPath=function(e){e instanceof Array||(e=[e]);for(var t=e.length,a=0,n=this._len,i=0;i<t;i++)a+=e[i].len();iv&&this.data instanceof Float32Array&&(this.data=new Float32Array(n+a));for(var i=0;i<t;i++)for(var o=e[i].data,s=0;s<o.length;s++)this.data[n++]=o[s];this._len=n},r.prototype.addData=function(e,t,a,n,i,o,s,l,u){if(this._saveData){var f=this.data;this._len+arguments.length>f.length&&(this._expandData(),f=this.data);for(var h=0;h<arguments.length;h++)f[this._len++]=arguments[h]}},r.prototype._drawPendingPt=function(){this._pendingPtDist>0&&(this._ctx&&this._ctx.lineTo(this._pendingPtX,this._pendingPtY),this._pendingPtDist=0)},r.prototype._expandData=function(){if(!(this.data instanceof Array)){for(var e=[],t=0;t<this._len;t++)e[t]=this.data[t];this.data=e}},r.prototype.toStatic=function(){if(this._saveData){this._drawPendingPt();var e=this.data;e instanceof Array&&(e.length=this._len,iv&&this._len>11&&(this.data=new Float32Array(e)))}},r.prototype.getBoundingRect=function(){br[0]=br[1]=Tr[0]=Tr[1]=Number.MAX_VALUE,da[0]=da[1]=Ar[0]=Ar[1]=-Number.MAX_VALUE;var e=this.data,t=0,a=0,n=0,i=0,o;for(o=0;o<this._len;){var s=e[o++],l=o===1;switch(l&&(t=e[o],a=e[o+1],n=t,i=a),s){case Rt.M:t=n=e[o++],a=i=e[o++],Tr[0]=n,Tr[1]=i,Ar[0]=n,Ar[1]=i;break;case Rt.L:zm(t,a,e[o],e[o+1],Tr,Ar),t=e[o++],a=e[o++];break;case Rt.C:GP(t,a,e[o++],e[o++],e[o++],e[o++],e[o],e[o+1],Tr,Ar),t=e[o++],a=e[o++];break;case Rt.Q:FP(t,a,e[o++],e[o++],e[o],e[o+1],Tr,Ar),t=e[o++],a=e[o++];break;case Rt.A:var u=e[o++],f=e[o++],h=e[o++],v=e[o++],c=e[o++],p=e[o++]+c;o+=1;var d=!e[o++];l&&(n=hn(c)*h+u,i=vn(c)*v+f),HP(u,f,h,v,c,p,d,Tr,Ar),t=hn(p)*h+u,a=vn(p)*v+f;break;case Rt.R:n=t=e[o++],i=a=e[o++];var g=e[o++],y=e[o++];zm(n,i,n+g,i+y,Tr,Ar);break;case Rt.Z:t=n,a=i;break}Ia(br,br,Tr),La(da,da,Ar)}return o===0&&(br[0]=br[1]=da[0]=da[1]=0),new ht(br[0],br[1],da[0]-br[0],da[1]-br[1])},r.prototype._calculateLength=function(){var e=this.data,t=this._len,a=this._ux,n=this._uy,i=0,o=0,s=0,l=0;this._pathSegLen||(this._pathSegLen=[]);for(var u=this._pathSegLen,f=0,h=0,v=0;v<t;){var c=e[v++],p=v===1;p&&(i=e[v],o=e[v+1],s=i,l=o);var d=-1;switch(c){case Rt.M:i=s=e[v++],o=l=e[v++];break;case Rt.L:{var g=e[v++],y=e[v++],m=g-i,_=y-o;(Zr(m)>a||Zr(_)>n||v===t-1)&&(d=Math.sqrt(m*m+_*_),i=g,o=y);break}case Rt.C:{var S=e[v++],w=e[v++],g=e[v++],y=e[v++],x=e[v++],b=e[v++];d=o2(i,o,S,w,g,y,x,b,10),i=x,o=b;break}case Rt.Q:{var S=e[v++],w=e[v++],g=e[v++],y=e[v++];d=l2(i,o,S,w,g,y,10),i=g,o=y;break}case Rt.A:var T=e[v++],A=e[v++],D=e[v++],M=e[v++],I=e[v++],L=e[v++],P=L+I;v+=1,p&&(s=hn(I)*D+T,l=vn(I)*M+A),d=nv(D,M)*av(Ta,Math.abs(L)),i=hn(P)*D+T,o=vn(P)*M+A;break;case Rt.R:{s=i=e[v++],l=o=e[v++];var R=e[v++],E=e[v++];d=R*2+E*2;break}case Rt.Z:{var m=s-i,_=l-o;d=Math.sqrt(m*m+_*_),i=s,o=l;break}}d>=0&&(u[h++]=d,f+=d)}return this._pathLen=f,f},r.prototype.rebuildPath=function(e,t){var a=this.data,n=this._ux,i=this._uy,o=this._len,s,l,u,f,h,v,c=t<1,p,d,g=0,y=0,m,_=0,S,w;if(!(c&&(this._pathSegLen||this._calculateLength(),p=this._pathSegLen,d=this._pathLen,m=t*d,!m)))t:for(var x=0;x<o;){var b=a[x++],T=x===1;switch(T&&(u=a[x],f=a[x+1],s=u,l=f),b!==Rt.L&&_>0&&(e.lineTo(S,w),_=0),b){case Rt.M:s=u=a[x++],l=f=a[x++],e.moveTo(u,f);break;case Rt.L:{h=a[x++],v=a[x++];var A=Zr(h-u),D=Zr(v-f);if(A>n||D>i){if(c){var M=p[y++];if(g+M>m){var I=(m-g)/M;e.lineTo(u*(1-I)+h*I,f*(1-I)+v*I);break t}g+=M}e.lineTo(h,v),u=h,f=v,_=0}else{var L=A*A+D*D;L>_&&(S=h,w=v,_=L)}break}case Rt.C:{var P=a[x++],R=a[x++],E=a[x++],N=a[x++],O=a[x++],B=a[x++];if(c){var M=p[y++];if(g+M>m){var I=(m-g)/M;Wa(u,P,E,O,I,un),Wa(f,R,N,B,I,fn),e.bezierCurveTo(un[1],fn[1],un[2],fn[2],un[3],fn[3]);break t}g+=M}e.bezierCurveTo(P,R,E,N,O,B),u=O,f=B;break}case Rt.Q:{var P=a[x++],R=a[x++],E=a[x++],N=a[x++];if(c){var M=p[y++];if(g+M>m){var I=(m-g)/M;Ls(u,P,E,I,un),Ls(f,R,N,I,fn),e.quadraticCurveTo(un[1],fn[1],un[2],fn[2]);break t}g+=M}e.quadraticCurveTo(P,R,E,N),u=E,f=N;break}case Rt.A:var F=a[x++],H=a[x++],X=a[x++],Q=a[x++],J=a[x++],ct=a[x++],St=a[x++],pt=!a[x++],et=X>Q?X:Q,dt=Zr(X-Q)>.001,st=J+ct,q=!1;if(c){var M=p[y++];g+M>m&&(st=J+ct*(m-g)/M,q=!0),g+=M}if(dt&&e.ellipse?e.ellipse(F,H,X,Q,St,J,st,pt):e.arc(F,H,et,J,st,pt),q)break t;T&&(s=hn(J)*X+F,l=vn(J)*Q+H),u=hn(st)*X+F,f=vn(st)*Q+H;break;case Rt.R:s=u=a[x],l=f=a[x+1],h=a[x++],v=a[x++];var lt=a[x++],Vt=a[x++];if(c){var M=p[y++];if(g+M>m){var xt=m-g;e.moveTo(h,v),e.lineTo(h+av(xt,lt),v),xt-=lt,xt>0&&e.lineTo(h+lt,v+av(xt,Vt)),xt-=Vt,xt>0&&e.lineTo(h+nv(lt-xt,0),v+Vt),xt-=lt,xt>0&&e.lineTo(h,v+nv(Vt-xt,0));break t}g+=M}e.rect(h,v,lt,Vt);break;case Rt.Z:if(c){var M=p[y++];if(g+M>m){var I=(m-g)/M;e.lineTo(u*(1-I)+s*I,f*(1-I)+l*I);break t}g+=M}e.closePath(),u=s,f=l}}},r.prototype.clone=function(){var e=new r,t=this.data;return e.data=t.slice?t.slice():Array.prototype.slice.call(t),e._len=this._len,e},r.CMD=Rt,r.initDefaultProps=function(){var e=r.prototype;e._saveData=!0,e._ux=0,e._uy=0,e._pendingPtDist=0,e._version=0}(),r}();function Ca(r,e,t,a,n,i,o){if(n===0)return!1;var s=n,l=0,u=r;if(o>e+s&&o>a+s||o<e-s&&o<a-s||i>r+s&&i>t+s||i<r-s&&i<t-s)return!1;if(r!==t)l=(e-a)/(r-t),u=(r*a-t*e)/(r-t);else return Math.abs(i-r)<=s/2;var f=l*i-o+u,h=f*f/(l*l+1);return h<=s/2*s/2}function WP(r,e,t,a,n,i,o,s,l,u,f){if(l===0)return!1;var h=l;if(f>e+h&&f>a+h&&f>i+h&&f>s+h||f<e-h&&f<a-h&&f<i-h&&f<s-h||u>r+h&&u>t+h&&u>n+h&&u>o+h||u<r-h&&u<t-h&&u<n-h&&u<o-h)return!1;var v=Ab(r,e,t,a,n,i,o,s,u,f,null);return v<=h/2}function sT(r,e,t,a,n,i,o,s,l){if(o===0)return!1;var u=o;if(l>e+u&&l>a+u&&l>i+u||l<e-u&&l<a-u&&l<i-u||s>r+u&&s>t+u&&s>n+u||s<r-u&&s<t-u&&s<n-u)return!1;var f=Db(r,e,t,a,n,i,s,l,null);return f<=u/2}var Hm=Math.PI*2;function Ge(r){return r%=Hm,r<0&&(r+=Hm),r}var Po=Math.PI*2;function $P(r,e,t,a,n,i,o,s,l){if(o===0)return!1;var u=o;s-=r,l-=e;var f=Math.sqrt(s*s+l*l);if(f-u>t||f+u<t)return!1;if(Math.abs(a-n)%Po<1e-4)return!0;if(i){var h=a;a=Ge(n),n=Ge(h)}else a=Ge(a),n=Ge(n);a>n&&(n+=Po);var v=Math.atan2(l,s);return v<0&&(v+=Po),v>=a&&v<=n||v+Po>=a&&v+Po<=n}function Qr(r,e,t,a,n,i){if(i>e&&i>a||i<e&&i<a||a===e)return 0;var o=(i-e)/(a-e),s=a<e?1:-1;(o===1||o===0)&&(s=a<e?.5:-.5);var l=o*(t-r)+r;return l===n?1/0:l>n?s:0}var ga=Wr.CMD,cn=Math.PI*2,UP=1e-4;function YP(r,e){return Math.abs(r-e)<UP}var xe=[-1,-1,-1],Qe=[-1,-1];function ZP(){var r=Qe[0];Qe[0]=Qe[1],Qe[1]=r}function XP(r,e,t,a,n,i,o,s,l,u){if(u>e&&u>a&&u>i&&u>s||u<e&&u<a&&u<i&&u<s)return 0;var f=Qu(e,a,i,s,u,xe);if(f===0)return 0;for(var h=0,v=-1,c=void 0,p=void 0,d=0;d<f;d++){var g=xe[d],y=g===0||g===1?.5:1,m=jt(r,t,n,o,g);m<l||(v<0&&(v=Tb(e,a,i,s,Qe),Qe[1]<Qe[0]&&v>1&&ZP(),c=jt(e,a,i,s,Qe[0]),v>1&&(p=jt(e,a,i,s,Qe[1]))),v===2?g<Qe[0]?h+=c<e?y:-y:g<Qe[1]?h+=p<c?y:-y:h+=s<p?y:-y:g<Qe[0]?h+=c<e?y:-y:h+=s<c?y:-y)}return h}function qP(r,e,t,a,n,i,o,s){if(s>e&&s>a&&s>i||s<e&&s<a&&s<i)return 0;var l=s2(e,a,i,s,xe);if(l===0)return 0;var u=Cb(e,a,i);if(u>=0&&u<=1){for(var f=0,h=ne(e,a,i,u),v=0;v<l;v++){var c=xe[v]===0||xe[v]===1?.5:1,p=ne(r,t,n,xe[v]);p<o||(xe[v]<u?f+=h<e?c:-c:f+=i<h?c:-c)}return f}else{var c=xe[0]===0||xe[0]===1?.5:1,p=ne(r,t,n,xe[0]);return p<o?0:i<e?c:-c}}function KP(r,e,t,a,n,i,o,s){if(s-=e,s>t||s<-t)return 0;var l=Math.sqrt(t*t-s*s);xe[0]=-l,xe[1]=l;var u=Math.abs(a-n);if(u<1e-4)return 0;if(u>=cn-1e-4){a=0,n=cn;var f=i?1:-1;return o>=xe[0]+r&&o<=xe[1]+r?f:0}if(a>n){var h=a;a=n,n=h}a<0&&(a+=cn,n+=cn);for(var v=0,c=0;c<2;c++){var p=xe[c];if(p+r>o){var d=Math.atan2(s,p),f=i?1:-1;d<0&&(d=cn+d),(d>=a&&d<=n||d+cn>=a&&d+cn<=n)&&(d>Math.PI/2&&d<Math.PI*1.5&&(f=-f),v+=f)}}return v}function lT(r,e,t,a,n){for(var i=r.data,o=r.len(),s=0,l=0,u=0,f=0,h=0,v,c,p=0;p<o;){var d=i[p++],g=p===1;switch(d===ga.M&&p>1&&(t||(s+=Qr(l,u,f,h,a,n))),g&&(l=i[p],u=i[p+1],f=l,h=u),d){case ga.M:f=i[p++],h=i[p++],l=f,u=h;break;case ga.L:if(t){if(Ca(l,u,i[p],i[p+1],e,a,n))return!0}else s+=Qr(l,u,i[p],i[p+1],a,n)||0;l=i[p++],u=i[p++];break;case ga.C:if(t){if(WP(l,u,i[p++],i[p++],i[p++],i[p++],i[p],i[p+1],e,a,n))return!0}else s+=XP(l,u,i[p++],i[p++],i[p++],i[p++],i[p],i[p+1],a,n)||0;l=i[p++],u=i[p++];break;case ga.Q:if(t){if(sT(l,u,i[p++],i[p++],i[p],i[p+1],e,a,n))return!0}else s+=qP(l,u,i[p++],i[p++],i[p],i[p+1],a,n)||0;l=i[p++],u=i[p++];break;case ga.A:var y=i[p++],m=i[p++],_=i[p++],S=i[p++],w=i[p++],x=i[p++];p+=1;var b=!!(1-i[p++]);v=Math.cos(w)*_+y,c=Math.sin(w)*S+m,g?(f=v,h=c):s+=Qr(l,u,v,c,a,n);var T=(a-y)*S/_+y;if(t){if($P(y,m,S,w,w+x,b,e,T,n))return!0}else s+=KP(y,m,S,w,w+x,b,T,n);l=Math.cos(w+x)*_+y,u=Math.sin(w+x)*S+m;break;case ga.R:f=l=i[p++],h=u=i[p++];var A=i[p++],D=i[p++];if(v=f+A,c=h+D,t){if(Ca(f,h,v,h,e,a,n)||Ca(v,h,v,c,e,a,n)||Ca(v,c,f,c,e,a,n)||Ca(f,c,f,h,e,a,n))return!0}else s+=Qr(v,h,v,c,a,n),s+=Qr(f,c,f,h,a,n);break;case ga.Z:if(t){if(Ca(l,u,f,h,e,a,n))return!0}else s+=Qr(l,u,f,h,a,n);l=f,u=h;break}}return!t&&!YP(u,h)&&(s+=Qr(l,u,f,h,a,n)||0),s!==0}function QP(r,e,t){return lT(r,0,!1,e,t)}function JP(r,e,t,a){return lT(r,e,!0,t,a)}var af=j({fill:"#000",stroke:null,strokePercent:1,fillOpacity:1,strokeOpacity:1,lineDashOffset:0,lineWidth:1,lineCap:"butt",miterLimit:10,strokeNoScale:!1,strokeFirst:!1},Un),jP={style:j({fill:!0,stroke:!0,strokePercent:!0,fillOpacity:!0,strokeOpacity:!0,lineDashOffset:!0,lineWidth:!0,miterLimit:!0},Qf.style)},sv=Fr.concat(["invisible","culling","z","z2","zlevel","parent"]),tR=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.update=function(){var t=this;r.prototype.update.call(this);var a=this.style;if(a.decal){var n=this._decalEl=this._decalEl||new e;n.buildPath===e.prototype.buildPath&&(n.buildPath=function(l){t.buildPath(l,t.shape)}),n.silent=!0;var i=n.style;for(var o in a)i[o]!==a[o]&&(i[o]=a[o]);i.fill=a.fill?a.decal:null,i.decal=null,i.shadowColor=null,a.strokeFirst&&(i.stroke=null);for(var s=0;s<sv.length;++s)n[sv[s]]=this[sv[s]];n.__dirty|=ze}else this._decalEl&&(this._decalEl=null)},e.prototype.getDecalElement=function(){return this._decalEl},e.prototype._init=function(t){var a=_t(t);this.shape=this.getDefaultShape();var n=this.getDefaultStyle();n&&this.useStyle(n);for(var i=0;i<a.length;i++){var o=a[i],s=t[o];o==="style"?this.style?V(this.style,s):this.useStyle(s):o==="shape"?V(this.shape,s):r.prototype.attrKV.call(this,o,s)}this.style||this.useStyle({})},e.prototype.getDefaultStyle=function(){return null},e.prototype.getDefaultShape=function(){return{}},e.prototype.canBeInsideText=function(){return this.hasFill()},e.prototype.getInsideTextFill=function(){var t=this.style.fill;if(t!=="none"){if($(t)){var a=ju(t,0);return a>.5?xp:a>.2?B2:wp}else if(t)return wp}return xp},e.prototype.getInsideTextStroke=function(t){var a=this.style.fill;if($(a)){var n=this.__zr,i=!!(n&&n.isDarkMode()),o=ju(t,0)<Sp;if(i===o)return a}},e.prototype.buildPath=function(t,a,n){},e.prototype.pathUpdated=function(){this.__dirty&=~Oi},e.prototype.getUpdatedPathProxy=function(t){return!this.path&&this.createPathProxy(),this.path.beginPath(),this.buildPath(this.path,this.shape,t),this.path},e.prototype.createPathProxy=function(){this.path=new Wr(!1)},e.prototype.hasStroke=function(){var t=this.style,a=t.stroke;return!(a==null||a==="none"||!(t.lineWidth>0))},e.prototype.hasFill=function(){var t=this.style,a=t.fill;return a!=null&&a!=="none"},e.prototype.getBoundingRect=function(){var t=this._rect,a=this.style,n=!t;if(n){var i=!1;this.path||(i=!0,this.createPathProxy());var o=this.path;(i||this.__dirty&Oi)&&(o.beginPath(),this.buildPath(o,this.shape,!1),this.pathUpdated()),t=o.getBoundingRect()}if(this._rect=t,this.hasStroke()&&this.path&&this.path.len()>0){var s=this._rectStroke||(this._rectStroke=t.clone());if(this.__dirty||n){s.copy(t);var l=a.strokeNoScale?this.getLineScale():1,u=a.lineWidth;if(!this.hasFill()){var f=this.strokeContainThreshold;u=Math.max(u,f??4)}l>1e-10&&(s.width+=u/l,s.height+=u/l,s.x-=u/l/2,s.y-=u/l/2)}return s}return t},e.prototype.contain=function(t,a){var n=this.transformCoordToLocal(t,a),i=this.getBoundingRect(),o=this.style;if(t=n[0],a=n[1],i.contain(t,a)){var s=this.path;if(this.hasStroke()){var l=o.lineWidth,u=o.strokeNoScale?this.getLineScale():1;if(u>1e-10&&(this.hasFill()||(l=Math.max(l,this.strokeContainThreshold)),JP(s,l/u,t,a)))return!0}if(this.hasFill())return QP(s,t,a)}return!1},e.prototype.dirtyShape=function(){this.__dirty|=Oi,this._rect&&(this._rect=null),this._decalEl&&this._decalEl.dirtyShape(),this.markRedraw()},e.prototype.dirty=function(){this.dirtyStyle(),this.dirtyShape()},e.prototype.animateShape=function(t){return this.animate("shape",t)},e.prototype.updateDuringAnimation=function(t){t==="style"?this.dirtyStyle():t==="shape"?this.dirtyShape():this.markRedraw()},e.prototype.attrKV=function(t,a){t==="shape"?this.setShape(a):r.prototype.attrKV.call(this,t,a)},e.prototype.setShape=function(t,a){var n=this.shape;return n||(n=this.shape={}),typeof t=="string"?n[t]=a:V(n,t),this.dirtyShape(),this},e.prototype.shapeChanged=function(){return!!(this.__dirty&Oi)},e.prototype.createStyle=function(t){return Uf(af,t)},e.prototype._innerSaveToNormal=function(t){r.prototype._innerSaveToNormal.call(this,t);var a=this._normalState;t.shape&&!a.shape&&(a.shape=V({},this.shape))},e.prototype._applyStateObj=function(t,a,n,i,o,s){r.prototype._applyStateObj.call(this,t,a,n,i,o,s);var l=!(a&&i),u;if(a&&a.shape?o?i?u=a.shape:(u=V({},n.shape),V(u,a.shape)):(u=V({},i?this.shape:n.shape),V(u,a.shape)):l&&(u=n.shape),u)if(o){this.shape=V({},this.shape);for(var f={},h=_t(u),v=0;v<h.length;v++){var c=h[v];typeof u[c]=="object"?this.shape[c]=u[c]:f[c]=u[c]}this._transitionState(t,{shape:f},s)}else this.shape=u,this.dirtyShape()},e.prototype._mergeStates=function(t){for(var a=r.prototype._mergeStates.call(this,t),n,i=0;i<t.length;i++){var o=t[i];o.shape&&(n=n||{},this._mergeStyle(n,o.shape))}return n&&(a.shape=n),a},e.prototype.getAnimationStyleProps=function(){return jP},e.prototype.isZeroArea=function(){return!1},e.extend=function(t){var a=function(i){k(o,i);function o(s){var l=i.call(this,s)||this;return t.init&&t.init.call(l,s),l}return o.prototype.getDefaultStyle=function(){return rt(t.style)},o.prototype.getDefaultShape=function(){return rt(t.shape)},o}(e);for(var n in t)typeof t[n]=="function"&&(a.prototype[n]=t[n]);return a},e.initDefaultProps=function(){var t=e.prototype;t.type="path",t.strokeContainThreshold=5,t.segmentIgnoreThreshold=0,t.subPixelOptimize=!1,t.autoBatch=!1,t.__dirty=ze|ts|Oi}(),e}(ir);const yt=tR;var eR=j({strokeFirst:!0,font:Fa,x:0,y:0,textAlign:"left",textBaseline:"top",miterLimit:2},af),uT=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.hasStroke=function(){var t=this.style,a=t.stroke;return a!=null&&a!=="none"&&t.lineWidth>0},e.prototype.hasFill=function(){var t=this.style,a=t.fill;return a!=null&&a!=="none"},e.prototype.createStyle=function(t){return Uf(eR,t)},e.prototype.setBoundingRect=function(t){this._rect=t},e.prototype.getBoundingRect=function(){var t=this.style;if(!this._rect){var a=t.text;a!=null?a+="":a="";var n=il(a,t.font,t.textAlign,t.textBaseline);if(n.x+=t.x||0,n.y+=t.y||0,this.hasStroke()){var i=t.lineWidth;n.x-=i/2,n.y-=i/2,n.width+=i,n.height+=i}this._rect=n}return this._rect},e.initDefaultProps=function(){var t=e.prototype;t.dirtyRectTolerance=10}(),e}(ir);uT.prototype.type="tspan";const Os=uT;var rR=j({x:0,y:0},Un),aR={style:j({x:!0,y:!0,width:!0,height:!0,sx:!0,sy:!0,sWidth:!0,sHeight:!0},Qf.style)};function nR(r){return!!(r&&typeof r!="string"&&r.width&&r.height)}var fT=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.createStyle=function(t){return Uf(rR,t)},e.prototype._getSize=function(t){var a=this.style,n=a[t];if(n!=null)return n;var i=nR(a.image)?a.image:this.__image;if(!i)return 0;var o=t==="width"?"height":"width",s=a[o];return s==null?i[t]:i[t]/i[o]*s},e.prototype.getWidth=function(){return this._getSize("width")},e.prototype.getHeight=function(){return this._getSize("height")},e.prototype.getAnimationStyleProps=function(){return aR},e.prototype.getBoundingRect=function(){var t=this.style;return this._rect||(this._rect=new ht(t.x||0,t.y||0,this.getWidth(),this.getHeight())),this._rect},e}(ir);fT.prototype.type="image";const he=fT;function iR(r,e){var t=e.x,a=e.y,n=e.width,i=e.height,o=e.r,s,l,u,f;n<0&&(t=t+n,n=-n),i<0&&(a=a+i,i=-i),typeof o=="number"?s=l=u=f=o:o instanceof Array?o.length===1?s=l=u=f=o[0]:o.length===2?(s=u=o[0],l=f=o[1]):o.length===3?(s=o[0],l=f=o[1],u=o[2]):(s=o[0],l=o[1],u=o[2],f=o[3]):s=l=u=f=0;var h;s+l>n&&(h=s+l,s*=n/h,l*=n/h),u+f>n&&(h=u+f,u*=n/h,f*=n/h),l+u>i&&(h=l+u,l*=i/h,u*=i/h),s+f>i&&(h=s+f,s*=i/h,f*=i/h),r.moveTo(t+s,a),r.lineTo(t+n-l,a),l!==0&&r.arc(t+n-l,a+l,l,-Math.PI/2,0),r.lineTo(t+n,a+i-u),u!==0&&r.arc(t+n-u,a+i-u,u,0,Math.PI/2),r.lineTo(t+f,a+i),f!==0&&r.arc(t+f,a+i-f,f,Math.PI/2,Math.PI),r.lineTo(t,a+s),s!==0&&r.arc(t+s,a+s,s,Math.PI,Math.PI*1.5)}var Fi=Math.round;function hT(r,e,t){if(e){var a=e.x1,n=e.x2,i=e.y1,o=e.y2;r.x1=a,r.x2=n,r.y1=i,r.y2=o;var s=t&&t.lineWidth;return s&&(Fi(a*2)===Fi(n*2)&&(r.x1=r.x2=Nn(a,s,!0)),Fi(i*2)===Fi(o*2)&&(r.y1=r.y2=Nn(i,s,!0))),r}}function vT(r,e,t){if(e){var a=e.x,n=e.y,i=e.width,o=e.height;r.x=a,r.y=n,r.width=i,r.height=o;var s=t&&t.lineWidth;return s&&(r.x=Nn(a,s,!0),r.y=Nn(n,s,!0),r.width=Math.max(Nn(a+i,s,!1)-r.x,i===0?0:1),r.height=Math.max(Nn(n+o,s,!1)-r.y,o===0?0:1)),r}}function Nn(r,e,t){if(!e)return r;var a=Fi(r*2);return(a+Fi(e))%2===0?a/2:(a+(t?1:-1))/2}var oR=function(){function r(){this.x=0,this.y=0,this.width=0,this.height=0}return r}(),sR={},cT=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new oR},e.prototype.buildPath=function(t,a){var n,i,o,s;if(this.subPixelOptimize){var l=vT(sR,a,this.style);n=l.x,i=l.y,o=l.width,s=l.height,l.r=a.r,a=l}else n=a.x,i=a.y,o=a.width,s=a.height;a.r?iR(t,a):t.rect(n,i,o,s)},e.prototype.isZeroArea=function(){return!this.shape.width||!this.shape.height},e}(yt);cT.prototype.type="rect";const wt=cT;var Wm={fill:"#000"},$m=2,lR={style:j({fill:!0,stroke:!0,fillOpacity:!0,strokeOpacity:!0,lineWidth:!0,fontSize:!0,lineHeight:!0,width:!0,height:!0,textShadowColor:!0,textShadowBlur:!0,textShadowOffsetX:!0,textShadowOffsetY:!0,backgroundColor:!0,padding:!0,borderColor:!0,borderWidth:!0,borderRadius:!0},Qf.style)},pT=function(r){k(e,r);function e(t){var a=r.call(this)||this;return a.type="text",a._children=[],a._defaultStyle=Wm,a.attr(t),a}return e.prototype.childrenRef=function(){return this._children},e.prototype.update=function(){r.prototype.update.call(this),this.styleChanged()&&this._updateSubTexts();for(var t=0;t<this._children.length;t++){var a=this._children[t];a.zlevel=this.zlevel,a.z=this.z,a.z2=this.z2,a.culling=this.culling,a.cursor=this.cursor,a.invisible=this.invisible}},e.prototype.updateTransform=function(){var t=this.innerTransformable;t?(t.updateTransform(),t.transform&&(this.transform=t.transform)):r.prototype.updateTransform.call(this)},e.prototype.getLocalTransform=function(t){var a=this.innerTransformable;return a?a.getLocalTransform(t):r.prototype.getLocalTransform.call(this,t)},e.prototype.getComputedTransform=function(){return this.__hostTarget&&(this.__hostTarget.getComputedTransform(),this.__hostTarget.updateInnerText(!0)),r.prototype.getComputedTransform.call(this)},e.prototype._updateSubTexts=function(){this._childCursor=0,hR(this.style),this.style.rich?this._updateRichTexts():this._updatePlainTexts(),this._children.length=this._childCursor,this.styleUpdated()},e.prototype.addSelfToZr=function(t){r.prototype.addSelfToZr.call(this,t);for(var a=0;a<this._children.length;a++)this._children[a].__zr=t},e.prototype.removeSelfFromZr=function(t){r.prototype.removeSelfFromZr.call(this,t);for(var a=0;a<this._children.length;a++)this._children[a].__zr=null},e.prototype.getBoundingRect=function(){if(this.styleChanged()&&this._updateSubTexts(),!this._rect){for(var t=new ht(0,0,0,0),a=this._children,n=[],i=null,o=0;o<a.length;o++){var s=a[o],l=s.getBoundingRect(),u=s.getLocalTransform(n);u?(t.copy(l),t.applyTransform(u),i=i||t.clone(),i.union(t)):(i=i||l.clone(),i.union(l))}this._rect=i||t}return this._rect},e.prototype.setDefaultTextStyle=function(t){this._defaultStyle=t||Wm},e.prototype.setTextContent=function(t){},e.prototype._mergeStyle=function(t,a){if(!a)return t;var n=a.rich,i=t.rich||n&&{};return V(t,a),n&&i?(this._mergeRich(i,n),t.rich=i):i&&(t.rich=i),t},e.prototype._mergeRich=function(t,a){for(var n=_t(a),i=0;i<n.length;i++){var o=n[i];t[o]=t[o]||{},V(t[o],a[o])}},e.prototype.getAnimationStyleProps=function(){return lR},e.prototype._getOrCreateChild=function(t){var a=this._children[this._childCursor];return(!a||!(a instanceof t))&&(a=new t),this._children[this._childCursor++]=a,a.__zr=this.__zr,a.parent=this,a},e.prototype._updatePlainTexts=function(){var t=this.style,a=t.font||Fa,n=t.padding,i=Qm(t),o=PP(i,t),s=lv(t),l=!!t.backgroundColor,u=o.outerHeight,f=o.outerWidth,h=o.contentWidth,v=o.lines,c=o.lineHeight,p=this._defaultStyle,d=t.x||0,g=t.y||0,y=t.align||p.align||"left",m=t.verticalAlign||p.verticalAlign||"top",_=d,S=Ni(g,o.contentHeight,m);if(s||n){var w=rs(d,f,y),x=Ni(g,u,m);s&&this._renderBackground(t,t,w,x,f,u)}S+=c/2,n&&(_=Km(d,y,n),m==="top"?S+=n[0]:m==="bottom"&&(S-=n[2]));for(var b=0,T=!1,A=qm("fill"in t?t.fill:(T=!0,p.fill)),D=Xm("stroke"in t?t.stroke:!l&&(!p.autoStroke||T)?(b=$m,p.stroke):null),M=t.textShadowBlur>0,I=t.width!=null&&(t.overflow==="truncate"||t.overflow==="break"||t.overflow==="breakAll"),L=o.calculatedLineHeight,P=0;P<v.length;P++){var R=this._getOrCreateChild(Os),E=R.createStyle();R.useStyle(E),E.text=v[P],E.x=_,E.y=S,y&&(E.textAlign=y),E.textBaseline="middle",E.opacity=t.opacity,E.strokeFirst=!0,M&&(E.shadowBlur=t.textShadowBlur||0,E.shadowColor=t.textShadowColor||"transparent",E.shadowOffsetX=t.textShadowOffsetX||0,E.shadowOffsetY=t.textShadowOffsetY||0),E.stroke=D,E.fill=A,D&&(E.lineWidth=t.lineWidth||b,E.lineDash=t.lineDash,E.lineDashOffset=t.lineDashOffset||0),E.font=a,Ym(E,t),S+=c,I&&R.setBoundingRect(new ht(rs(E.x,t.width,E.textAlign),Ni(E.y,L,E.textBaseline),h,L))}},e.prototype._updateRichTexts=function(){var t=this.style,a=Qm(t),n=kP(a,t),i=n.width,o=n.outerWidth,s=n.outerHeight,l=t.padding,u=t.x||0,f=t.y||0,h=this._defaultStyle,v=t.align||h.align,c=t.verticalAlign||h.verticalAlign,p=rs(u,o,v),d=Ni(f,s,c),g=p,y=d;l&&(g+=l[3],y+=l[0]);var m=g+i;lv(t)&&this._renderBackground(t,t,p,d,o,s);for(var _=!!t.backgroundColor,S=0;S<n.lines.length;S++){for(var w=n.lines[S],x=w.tokens,b=x.length,T=w.lineHeight,A=w.width,D=0,M=g,I=m,L=b-1,P=void 0;D<b&&(P=x[D],!P.align||P.align==="left");)this._placeToken(P,t,T,y,M,"left",_),A-=P.width,M+=P.width,D++;for(;L>=0&&(P=x[L],P.align==="right");)this._placeToken(P,t,T,y,I,"right",_),A-=P.width,I-=P.width,L--;for(M+=(i-(M-g)-(m-I)-A)/2;D<=L;)P=x[D],this._placeToken(P,t,T,y,M+P.width/2,"center",_),M+=P.width,D++;y+=T}},e.prototype._placeToken=function(t,a,n,i,o,s,l){var u=a.rich[t.styleName]||{};u.text=t.text;var f=t.verticalAlign,h=i+n/2;f==="top"?h=i+t.height/2:f==="bottom"&&(h=i+n-t.height/2);var v=!t.isLineHolder&&lv(u);v&&this._renderBackground(u,a,s==="right"?o-t.width:s==="center"?o-t.width/2:o,h-t.height/2,t.width,t.height);var c=!!u.backgroundColor,p=t.textPadding;p&&(o=Km(o,s,p),h-=t.height/2-p[0]-t.innerHeight/2);var d=this._getOrCreateChild(Os),g=d.createStyle();d.useStyle(g);var y=this._defaultStyle,m=!1,_=0,S=qm("fill"in u?u.fill:"fill"in a?a.fill:(m=!0,y.fill)),w=Xm("stroke"in u?u.stroke:"stroke"in a?a.stroke:!c&&!l&&(!y.autoStroke||m)?(_=$m,y.stroke):null),x=u.textShadowBlur>0||a.textShadowBlur>0;g.text=t.text,g.x=o,g.y=h,x&&(g.shadowBlur=u.textShadowBlur||a.textShadowBlur||0,g.shadowColor=u.textShadowColor||a.textShadowColor||"transparent",g.shadowOffsetX=u.textShadowOffsetX||a.textShadowOffsetX||0,g.shadowOffsetY=u.textShadowOffsetY||a.textShadowOffsetY||0),g.textAlign=s,g.textBaseline="middle",g.font=t.font||Fa,g.opacity=Br(u.opacity,a.opacity,1),Ym(g,u),w&&(g.lineWidth=Br(u.lineWidth,a.lineWidth,_),g.lineDash=it(u.lineDash,a.lineDash),g.lineDashOffset=a.lineDashOffset||0,g.stroke=w),S&&(g.fill=S);var b=t.contentWidth,T=t.contentHeight;d.setBoundingRect(new ht(rs(g.x,b,g.textAlign),Ni(g.y,T,g.textBaseline),b,T))},e.prototype._renderBackground=function(t,a,n,i,o,s){var l=t.backgroundColor,u=t.borderWidth,f=t.borderColor,h=l&&l.image,v=l&&!h,c=t.borderRadius,p=this,d,g;if(v||t.lineHeight||u&&f){d=this._getOrCreateChild(wt),d.useStyle(d.createStyle()),d.style.fill=null;var y=d.shape;y.x=n,y.y=i,y.width=o,y.height=s,y.r=c,d.dirtyShape()}if(v){var m=d.style;m.fill=l||null,m.fillOpacity=it(t.fillOpacity,1)}else if(h){g=this._getOrCreateChild(he),g.onload=function(){p.dirtyStyle()};var _=g.style;_.image=l.image,_.x=n,_.y=i,_.width=o,_.height=s}if(u&&f){var m=d.style;m.lineWidth=u,m.stroke=f,m.strokeOpacity=it(t.strokeOpacity,1),m.lineDash=t.borderDash,m.lineDashOffset=t.borderDashOffset||0,d.strokeContainThreshold=0,d.hasFill()&&d.hasStroke()&&(m.strokeFirst=!0,m.lineWidth*=2)}var S=(d||g).style;S.shadowBlur=t.shadowBlur||0,S.shadowColor=t.shadowColor||"transparent",S.shadowOffsetX=t.shadowOffsetX||0,S.shadowOffsetY=t.shadowOffsetY||0,S.opacity=Br(t.opacity,a.opacity,1)},e.makeFont=function(t){var a="";return gT(t)&&(a=[t.fontStyle,t.fontWeight,dT(t.fontSize),t.fontFamily||"sans-serif"].join(" ")),a&&dr(a)||t.textFont||t.font},e}(ir),uR={left:!0,right:1,center:1},fR={top:1,bottom:1,middle:1},Um=["fontStyle","fontWeight","fontSize","fontFamily"];function dT(r){return typeof r=="string"&&(r.indexOf("px")!==-1||r.indexOf("rem")!==-1||r.indexOf("em")!==-1)?r:isNaN(+r)?Fd+"px":r+"px"}function Ym(r,e){for(var t=0;t<Um.length;t++){var a=Um[t],n=e[a];n!=null&&(r[a]=n)}}function gT(r){return r.fontSize!=null||r.fontFamily||r.fontWeight}function hR(r){return Zm(r),C(r.rich,Zm),r}function Zm(r){if(r){r.font=pT.makeFont(r);var e=r.align;e==="middle"&&(e="center"),r.align=e==null||uR[e]?e:"left";var t=r.verticalAlign;t==="center"&&(t="middle"),r.verticalAlign=t==null||fR[t]?t:"top";var a=r.padding;a&&(r.padding=Zd(r.padding))}}function Xm(r,e){return r==null||e<=0||r==="transparent"||r==="none"?null:r.image||r.colorStops?"#000":r}function qm(r){return r==null||r==="none"?null:r.image||r.colorStops?"#000":r}function Km(r,e,t){return e==="right"?r-t[1]:e==="center"?r+t[3]/2-t[1]/2:r+t[3]}function Qm(r){var e=r.text;return e!=null&&(e+=""),e}function lv(r){return!!(r.backgroundColor||r.lineHeight||r.borderWidth&&r.borderColor)}const At=pT;var nt=bt(),Mp=function(r,e,t,a){if(a){var n=nt(a);n.dataIndex=t,n.dataType=e,n.seriesIndex=r,n.ssrType="chart",a.type==="group"&&a.traverse(function(i){var o=nt(i);o.seriesIndex=r,o.dataIndex=t,o.dataType=e,o.ssrType="chart"})}},Jm=1,jm={},yT=bt(),sg=bt(),lg=0,sl=1,jf=2,Ce=["emphasis","blur","select"],Ns=["normal","emphasis","blur","select"],fo=10,vR=9,Yn="highlight",Nu="downplay",ms="select",Bu="unselect",_s="toggleSelect";function mi(r){return r!=null&&r!=="none"}function th(r,e,t){r.onHoverStateChange&&(r.hoverState||0)!==t&&r.onHoverStateChange(e),r.hoverState=t}function mT(r){th(r,"emphasis",jf)}function _T(r){r.hoverState===jf&&th(r,"normal",lg)}function ug(r){th(r,"blur",sl)}function ST(r){r.hoverState===sl&&th(r,"normal",lg)}function cR(r){r.selected=!0}function pR(r){r.selected=!1}function t0(r,e,t){e(r,t)}function ha(r,e,t){t0(r,e,t),r.isGroup&&r.traverse(function(a){t0(a,e,t)})}function nf(r,e){switch(e){case"emphasis":r.hoverState=jf;break;case"normal":r.hoverState=lg;break;case"blur":r.hoverState=sl;break;case"select":r.selected=!0}}function dR(r,e,t,a){for(var n=r.style,i={},o=0;o<e.length;o++){var s=e[o],l=n[s];i[s]=l??(a&&a[s])}for(var o=0;o<r.animators.length;o++){var u=r.animators[o];u.__fromStateTransition&&u.__fromStateTransition.indexOf(t)<0&&u.targetName==="style"&&u.saveTo(i,e)}return i}function gR(r,e,t,a){var n=t&&vt(t,"select")>=0,i=!1;if(r instanceof yt){var o=yT(r),s=n&&o.selectFill||o.normalFill,l=n&&o.selectStroke||o.normalStroke;if(mi(s)||mi(l)){a=a||{};var u=a.style||{};u.fill==="inherit"?(i=!0,a=V({},a),u=V({},u),u.fill=s):!mi(u.fill)&&mi(s)?(i=!0,a=V({},a),u=V({},u),u.fill=cp(s)):!mi(u.stroke)&&mi(l)&&(i||(a=V({},a),u=V({},u)),u.stroke=cp(l)),a.style=u}}if(a&&a.z2==null){i||(a=V({},a));var f=r.z2EmphasisLift;a.z2=r.z2+(f??fo)}return a}function yR(r,e,t){if(t&&t.z2==null){t=V({},t);var a=r.z2SelectLift;t.z2=r.z2+(a??vR)}return t}function mR(r,e,t){var a=vt(r.currentStates,e)>=0,n=r.style.opacity,i=a?null:dR(r,["opacity"],e,{opacity:1});t=t||{};var o=t.style||{};return o.opacity==null&&(t=V({},t),o=V({opacity:a?n:i.opacity*.1},o),t.style=o),t}function uv(r,e){var t=this.states[r];if(this.style){if(r==="emphasis")return gR(this,r,e,t);if(r==="blur")return mR(this,r,t);if(r==="select")return yR(this,r,t)}return t}function ei(r){r.stateProxy=uv;var e=r.getTextContent(),t=r.getTextGuideLine();e&&(e.stateProxy=uv),t&&(t.stateProxy=uv)}function e0(r,e){!TT(r,e)&&!r.__highByOuter&&ha(r,mT)}function r0(r,e){!TT(r,e)&&!r.__highByOuter&&ha(r,_T)}function sa(r,e){r.__highByOuter|=1<<(e||0),ha(r,mT)}function la(r,e){!(r.__highByOuter&=~(1<<(e||0)))&&ha(r,_T)}function xT(r){ha(r,ug)}function fg(r){ha(r,ST)}function wT(r){ha(r,cR)}function bT(r){ha(r,pR)}function TT(r,e){return r.__highDownSilentOnTouch&&e.zrByTouch}function AT(r){var e=r.getModel(),t=[],a=[];e.eachComponent(function(n,i){var o=sg(i),s=n==="series",l=s?r.getViewOfSeriesModel(i):r.getViewOfComponentModel(i);!s&&a.push(l),o.isBlured&&(l.group.traverse(function(u){ST(u)}),s&&t.push(i)),o.isBlured=!1}),C(a,function(n){n&&n.toggleBlurSeries&&n.toggleBlurSeries(t,!1,e)})}function Ip(r,e,t,a){var n=a.getModel();t=t||"coordinateSystem";function i(u,f){for(var h=0;h<f.length;h++){var v=u.getItemGraphicEl(f[h]);v&&fg(v)}}if(r!=null&&!(!e||e==="none")){var o=n.getSeriesByIndex(r),s=o.coordinateSystem;s&&s.master&&(s=s.master);var l=[];n.eachSeries(function(u){var f=o===u,h=u.coordinateSystem;h&&h.master&&(h=h.master);var v=h&&s?h===s:f;if(!(t==="series"&&!f||t==="coordinateSystem"&&!v||e==="series"&&f)){var c=a.getViewOfSeriesModel(u);if(c.group.traverse(function(g){g.__highByOuter&&f&&e==="self"||ug(g)}),ge(e))i(u.getData(),e);else if(tt(e))for(var p=_t(e),d=0;d<p.length;d++)i(u.getData(p[d]),e[p[d]]);l.push(u),sg(u).isBlured=!0}}),n.eachComponent(function(u,f){if(u!=="series"){var h=a.getViewOfComponentModel(f);h&&h.toggleBlurSeries&&h.toggleBlurSeries(l,!0,n)}})}}function Lp(r,e,t){if(!(r==null||e==null)){var a=t.getModel().getComponent(r,e);if(a){sg(a).isBlured=!0;var n=t.getViewOfComponentModel(a);!n||!n.focusBlurEnabled||n.group.traverse(function(i){ug(i)})}}}function _R(r,e,t){var a=r.seriesIndex,n=r.getData(e.dataType);if(n){var i=jn(n,e);i=(z(i)?i[0]:i)||0;var o=n.getItemGraphicEl(i);if(!o)for(var s=n.count(),l=0;!o&&l<s;)o=n.getItemGraphicEl(l++);if(o){var u=nt(o);Ip(a,u.focus,u.blurScope,t)}else{var f=r.get(["emphasis","focus"]),h=r.get(["emphasis","blurScope"]);f!=null&&Ip(a,f,h,t)}}}function hg(r,e,t,a){var n={focusSelf:!1,dispatchers:null};if(r==null||r==="series"||e==null||t==null)return n;var i=a.getModel().getComponent(r,e);if(!i)return n;var o=a.getViewOfComponentModel(i);if(!o||!o.findHighDownDispatchers)return n;for(var s=o.findHighDownDispatchers(t),l,u=0;u<s.length;u++)if(nt(s[u]).focus==="self"){l=!0;break}return{focusSelf:l,dispatchers:s}}function SR(r,e,t){var a=nt(r),n=hg(a.componentMainType,a.componentIndex,a.componentHighDownName,t),i=n.dispatchers,o=n.focusSelf;i?(o&&Lp(a.componentMainType,a.componentIndex,t),C(i,function(s){return e0(s,e)})):(Ip(a.seriesIndex,a.focus,a.blurScope,t),a.focus==="self"&&Lp(a.componentMainType,a.componentIndex,t),e0(r,e))}function xR(r,e,t){AT(t);var a=nt(r),n=hg(a.componentMainType,a.componentIndex,a.componentHighDownName,t).dispatchers;n?C(n,function(i){return r0(i,e)}):r0(r,e)}function wR(r,e,t){if(Rp(e)){var a=e.dataType,n=r.getData(a),i=jn(n,e);z(i)||(i=[i]),r[e.type===_s?"toggleSelect":e.type===ms?"select":"unselect"](i,a)}}function a0(r){var e=r.getAllData();C(e,function(t){var a=t.data,n=t.type;a.eachItemGraphicEl(function(i,o){r.isSelected(o,n)?wT(i):bT(i)})})}function bR(r){var e=[];return r.eachSeries(function(t){var a=t.getAllData();C(a,function(n){n.data;var i=n.type,o=t.getSelectedDataIndices();if(o.length>0){var s={dataIndex:o,seriesIndex:t.seriesIndex};i!=null&&(s.dataType=i),e.push(s)}})}),e}function Zn(r,e,t){Bn(r,!0),ha(r,ei),Pp(r,e,t)}function TR(r){Bn(r,!1)}function Ft(r,e,t,a){a?TR(r):Zn(r,e,t)}function Pp(r,e,t){var a=nt(r);e!=null?(a.focus=e,a.blurScope=t):a.focus&&(a.focus=null)}var n0=["emphasis","blur","select"],AR={itemStyle:"getItemStyle",lineStyle:"getLineStyle",areaStyle:"getAreaStyle"};function ue(r,e,t,a){t=t||"itemStyle";for(var n=0;n<n0.length;n++){var i=n0[n],o=e.getModel([i,t]),s=r.ensureState(i);s.style=a?a(o):o[AR[t]]()}}function Bn(r,e){var t=e===!1,a=r;r.highDownSilentOnTouch&&(a.__highDownSilentOnTouch=r.highDownSilentOnTouch),(!t||a.__highDownDispatcher)&&(a.__highByOuter=a.__highByOuter||0,a.__highDownDispatcher=!t)}function Bs(r){return!!(r&&r.__highDownDispatcher)}function CR(r,e,t){var a=nt(r);a.componentMainType=e.mainType,a.componentIndex=e.componentIndex,a.componentHighDownName=t}function DR(r){var e=jm[r];return e==null&&Jm<=32&&(e=jm[r]=Jm++),e}function Rp(r){var e=r.type;return e===ms||e===Bu||e===_s}function i0(r){var e=r.type;return e===Yn||e===Nu}function MR(r){var e=yT(r);e.normalFill=r.style.fill,e.normalStroke=r.style.stroke;var t=r.states.select||{};e.selectFill=t.style&&t.style.fill||null,e.selectStroke=t.style&&t.style.stroke||null}var _i=Wr.CMD,IR=[[],[],[]],o0=Math.sqrt,LR=Math.atan2;function CT(r,e){if(e){var t=r.data,a=r.len(),n,i,o,s,l,u,f=_i.M,h=_i.C,v=_i.L,c=_i.R,p=_i.A,d=_i.Q;for(o=0,s=0;o<a;){switch(n=t[o++],s=o,i=0,n){case f:i=1;break;case v:i=1;break;case h:i=3;break;case d:i=2;break;case p:var g=e[4],y=e[5],m=o0(e[0]*e[0]+e[1]*e[1]),_=o0(e[2]*e[2]+e[3]*e[3]),S=LR(-e[1]/_,e[0]/m);t[o]*=m,t[o++]+=g,t[o]*=_,t[o++]+=y,t[o++]*=m,t[o++]*=_,t[o++]+=S,t[o++]+=S,o+=2,s=o;break;case c:u[0]=t[o++],u[1]=t[o++],se(u,u,e),t[s++]=u[0],t[s++]=u[1],u[0]+=t[o++],u[1]+=t[o++],se(u,u,e),t[s++]=u[0],t[s++]=u[1]}for(l=0;l<i;l++){var w=IR[l];w[0]=t[o++],w[1]=t[o++],se(w,w,e),t[s++]=w[0],t[s++]=w[1]}}r.increaseVersion()}}var fv=Math.sqrt,Vl=Math.sin,zl=Math.cos,Ro=Math.PI;function s0(r){return Math.sqrt(r[0]*r[0]+r[1]*r[1])}function Ep(r,e){return(r[0]*e[0]+r[1]*e[1])/(s0(r)*s0(e))}function l0(r,e){return(r[0]*e[1]<r[1]*e[0]?-1:1)*Math.acos(Ep(r,e))}function u0(r,e,t,a,n,i,o,s,l,u,f){var h=l*(Ro/180),v=zl(h)*(r-t)/2+Vl(h)*(e-a)/2,c=-1*Vl(h)*(r-t)/2+zl(h)*(e-a)/2,p=v*v/(o*o)+c*c/(s*s);p>1&&(o*=fv(p),s*=fv(p));var d=(n===i?-1:1)*fv((o*o*(s*s)-o*o*(c*c)-s*s*(v*v))/(o*o*(c*c)+s*s*(v*v)))||0,g=d*o*c/s,y=d*-s*v/o,m=(r+t)/2+zl(h)*g-Vl(h)*y,_=(e+a)/2+Vl(h)*g+zl(h)*y,S=l0([1,0],[(v-g)/o,(c-y)/s]),w=[(v-g)/o,(c-y)/s],x=[(-1*v-g)/o,(-1*c-y)/s],b=l0(w,x);if(Ep(w,x)<=-1&&(b=Ro),Ep(w,x)>=1&&(b=0),b<0){var T=Math.round(b/Ro*1e6)/1e6;b=Ro*2+T%2*Ro}f.addData(u,m,_,o,s,S,b,h,i)}var PR=/([mlvhzcqtsa])([^mlvhzcqtsa]*)/ig,RR=/-?([0-9]*\.)?[0-9]+([eE]-?[0-9]+)?/g;function ER(r){var e=new Wr;if(!r)return e;var t=0,a=0,n=t,i=a,o,s=Wr.CMD,l=r.match(PR);if(!l)return e;for(var u=0;u<l.length;u++){for(var f=l[u],h=f.charAt(0),v=void 0,c=f.match(RR)||[],p=c.length,d=0;d<p;d++)c[d]=parseFloat(c[d]);for(var g=0;g<p;){var y=void 0,m=void 0,_=void 0,S=void 0,w=void 0,x=void 0,b=void 0,T=t,A=a,D=void 0,M=void 0;switch(h){case"l":t+=c[g++],a+=c[g++],v=s.L,e.addData(v,t,a);break;case"L":t=c[g++],a=c[g++],v=s.L,e.addData(v,t,a);break;case"m":t+=c[g++],a+=c[g++],v=s.M,e.addData(v,t,a),n=t,i=a,h="l";break;case"M":t=c[g++],a=c[g++],v=s.M,e.addData(v,t,a),n=t,i=a,h="L";break;case"h":t+=c[g++],v=s.L,e.addData(v,t,a);break;case"H":t=c[g++],v=s.L,e.addData(v,t,a);break;case"v":a+=c[g++],v=s.L,e.addData(v,t,a);break;case"V":a=c[g++],v=s.L,e.addData(v,t,a);break;case"C":v=s.C,e.addData(v,c[g++],c[g++],c[g++],c[g++],c[g++],c[g++]),t=c[g-2],a=c[g-1];break;case"c":v=s.C,e.addData(v,c[g++]+t,c[g++]+a,c[g++]+t,c[g++]+a,c[g++]+t,c[g++]+a),t+=c[g-2],a+=c[g-1];break;case"S":y=t,m=a,D=e.len(),M=e.data,o===s.C&&(y+=t-M[D-4],m+=a-M[D-3]),v=s.C,T=c[g++],A=c[g++],t=c[g++],a=c[g++],e.addData(v,y,m,T,A,t,a);break;case"s":y=t,m=a,D=e.len(),M=e.data,o===s.C&&(y+=t-M[D-4],m+=a-M[D-3]),v=s.C,T=t+c[g++],A=a+c[g++],t+=c[g++],a+=c[g++],e.addData(v,y,m,T,A,t,a);break;case"Q":T=c[g++],A=c[g++],t=c[g++],a=c[g++],v=s.Q,e.addData(v,T,A,t,a);break;case"q":T=c[g++]+t,A=c[g++]+a,t+=c[g++],a+=c[g++],v=s.Q,e.addData(v,T,A,t,a);break;case"T":y=t,m=a,D=e.len(),M=e.data,o===s.Q&&(y+=t-M[D-4],m+=a-M[D-3]),t=c[g++],a=c[g++],v=s.Q,e.addData(v,y,m,t,a);break;case"t":y=t,m=a,D=e.len(),M=e.data,o===s.Q&&(y+=t-M[D-4],m+=a-M[D-3]),t+=c[g++],a+=c[g++],v=s.Q,e.addData(v,y,m,t,a);break;case"A":_=c[g++],S=c[g++],w=c[g++],x=c[g++],b=c[g++],T=t,A=a,t=c[g++],a=c[g++],v=s.A,u0(T,A,t,a,x,b,_,S,w,v,e);break;case"a":_=c[g++],S=c[g++],w=c[g++],x=c[g++],b=c[g++],T=t,A=a,t+=c[g++],a+=c[g++],v=s.A,u0(T,A,t,a,x,b,_,S,w,v,e);break}}(h==="z"||h==="Z")&&(v=s.Z,e.addData(v),t=n,a=i),o=v}return e.toStatic(),e}var DT=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.applyTransform=function(t){},e}(yt);function MT(r){return r.setData!=null}function IT(r,e){var t=ER(r),a=V({},e);return a.buildPath=function(n){if(MT(n)){n.setData(t.data);var i=n.getContext();i&&n.rebuildPath(i,1)}else{var i=n;t.rebuildPath(i,1)}},a.applyTransform=function(n){CT(t,n),this.dirtyShape()},a}function LT(r,e){return new DT(IT(r,e))}function kR(r,e){var t=IT(r,e),a=function(n){k(i,n);function i(o){var s=n.call(this,o)||this;return s.applyTransform=t.applyTransform,s.buildPath=t.buildPath,s}return i}(DT);return a}function OR(r,e){for(var t=[],a=r.length,n=0;n<a;n++){var i=r[n];t.push(i.getUpdatedPathProxy(!0))}var o=new yt(e);return o.createPathProxy(),o.buildPath=function(s){if(MT(s)){s.appendPath(t);var l=s.getContext();l&&s.rebuildPath(l,1)}},o}function vg(r,e){e=e||{};var t=new yt;return r.shape&&t.setShape(r.shape),t.setStyle(r.style),e.bakeTransform?CT(t.path,r.getComputedTransform()):e.toLocal?t.setLocalTransform(r.getComputedTransform()):t.copyTransform(r),t.buildPath=r.buildPath,t.applyTransform=t.applyTransform,t.z=r.z,t.z2=r.z2,t.zlevel=r.zlevel,t}var NR=function(){function r(){this.cx=0,this.cy=0,this.r=0}return r}(),PT=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new NR},e.prototype.buildPath=function(t,a){t.moveTo(a.cx+a.r,a.cy),t.arc(a.cx,a.cy,a.r,0,Math.PI*2)},e}(yt);PT.prototype.type="circle";const Qa=PT;var BR=function(){function r(){this.cx=0,this.cy=0,this.rx=0,this.ry=0}return r}(),RT=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new BR},e.prototype.buildPath=function(t,a){var n=.5522848,i=a.cx,o=a.cy,s=a.rx,l=a.ry,u=s*n,f=l*n;t.moveTo(i-s,o),t.bezierCurveTo(i-s,o-f,i-u,o-l,i,o-l),t.bezierCurveTo(i+u,o-l,i+s,o-f,i+s,o),t.bezierCurveTo(i+s,o+f,i+u,o+l,i,o+l),t.bezierCurveTo(i-u,o+l,i-s,o+f,i-s,o),t.closePath()},e}(yt);RT.prototype.type="ellipse";const cg=RT;var ET=Math.PI,hv=ET*2,pn=Math.sin,Si=Math.cos,VR=Math.acos,ce=Math.atan2,f0=Math.abs,Ss=Math.sqrt,as=Math.max,Cr=Math.min,hr=1e-4;function zR(r,e,t,a,n,i,o,s){var l=t-r,u=a-e,f=o-n,h=s-i,v=h*l-f*u;if(!(v*v<hr))return v=(f*(e-i)-h*(r-n))/v,[r+v*l,e+v*u]}function Gl(r,e,t,a,n,i,o){var s=r-t,l=e-a,u=(o?i:-i)/Ss(s*s+l*l),f=u*l,h=-u*s,v=r+f,c=e+h,p=t+f,d=a+h,g=(v+p)/2,y=(c+d)/2,m=p-v,_=d-c,S=m*m+_*_,w=n-i,x=v*d-p*c,b=(_<0?-1:1)*Ss(as(0,w*w*S-x*x)),T=(x*_-m*b)/S,A=(-x*m-_*b)/S,D=(x*_+m*b)/S,M=(-x*m+_*b)/S,I=T-g,L=A-y,P=D-g,R=M-y;return I*I+L*L>P*P+R*R&&(T=D,A=M),{cx:T,cy:A,x0:-f,y0:-h,x1:T*(n/w-1),y1:A*(n/w-1)}}function GR(r){var e;if(z(r)){var t=r.length;if(!t)return r;t===1?e=[r[0],r[0],0,0]:t===2?e=[r[0],r[0],r[1],r[1]]:t===3?e=r.concat(r[2]):e=r}else e=[r,r,r,r];return e}function FR(r,e){var t,a=as(e.r,0),n=as(e.r0||0,0),i=a>0,o=n>0;if(!(!i&&!o)){if(i||(a=n,n=0),n>a){var s=a;a=n,n=s}var l=e.startAngle,u=e.endAngle;if(!(isNaN(l)||isNaN(u))){var f=e.cx,h=e.cy,v=!!e.clockwise,c=f0(u-l),p=c>hv&&c%hv;if(p>hr&&(c=p),!(a>hr))r.moveTo(f,h);else if(c>hv-hr)r.moveTo(f+a*Si(l),h+a*pn(l)),r.arc(f,h,a,l,u,!v),n>hr&&(r.moveTo(f+n*Si(u),h+n*pn(u)),r.arc(f,h,n,u,l,v));else{var d=void 0,g=void 0,y=void 0,m=void 0,_=void 0,S=void 0,w=void 0,x=void 0,b=void 0,T=void 0,A=void 0,D=void 0,M=void 0,I=void 0,L=void 0,P=void 0,R=a*Si(l),E=a*pn(l),N=n*Si(u),O=n*pn(u),B=c>hr;if(B){var F=e.cornerRadius;F&&(t=GR(F),d=t[0],g=t[1],y=t[2],m=t[3]);var H=f0(a-n)/2;if(_=Cr(H,y),S=Cr(H,m),w=Cr(H,d),x=Cr(H,g),A=b=as(_,S),D=T=as(w,x),(b>hr||T>hr)&&(M=a*Si(u),I=a*pn(u),L=n*Si(l),P=n*pn(l),c<ET)){var X=zR(R,E,L,P,M,I,N,O);if(X){var Q=R-X[0],J=E-X[1],ct=M-X[0],St=I-X[1],pt=1/pn(VR((Q*ct+J*St)/(Ss(Q*Q+J*J)*Ss(ct*ct+St*St)))/2),et=Ss(X[0]*X[0]+X[1]*X[1]);A=Cr(b,(a-et)/(pt+1)),D=Cr(T,(n-et)/(pt-1))}}}if(!B)r.moveTo(f+R,h+E);else if(A>hr){var dt=Cr(y,A),st=Cr(m,A),q=Gl(L,P,R,E,a,dt,v),lt=Gl(M,I,N,O,a,st,v);r.moveTo(f+q.cx+q.x0,h+q.cy+q.y0),A<b&&dt===st?r.arc(f+q.cx,h+q.cy,A,ce(q.y0,q.x0),ce(lt.y0,lt.x0),!v):(dt>0&&r.arc(f+q.cx,h+q.cy,dt,ce(q.y0,q.x0),ce(q.y1,q.x1),!v),r.arc(f,h,a,ce(q.cy+q.y1,q.cx+q.x1),ce(lt.cy+lt.y1,lt.cx+lt.x1),!v),st>0&&r.arc(f+lt.cx,h+lt.cy,st,ce(lt.y1,lt.x1),ce(lt.y0,lt.x0),!v))}else r.moveTo(f+R,h+E),r.arc(f,h,a,l,u,!v);if(!(n>hr)||!B)r.lineTo(f+N,h+O);else if(D>hr){var dt=Cr(d,D),st=Cr(g,D),q=Gl(N,O,M,I,n,-st,v),lt=Gl(R,E,L,P,n,-dt,v);r.lineTo(f+q.cx+q.x0,h+q.cy+q.y0),D<T&&dt===st?r.arc(f+q.cx,h+q.cy,D,ce(q.y0,q.x0),ce(lt.y0,lt.x0),!v):(st>0&&r.arc(f+q.cx,h+q.cy,st,ce(q.y0,q.x0),ce(q.y1,q.x1),!v),r.arc(f,h,n,ce(q.cy+q.y1,q.cx+q.x1),ce(lt.cy+lt.y1,lt.cx+lt.x1),v),dt>0&&r.arc(f+lt.cx,h+lt.cy,dt,ce(lt.y1,lt.x1),ce(lt.y0,lt.x0),!v))}else r.lineTo(f+N,h+O),r.arc(f,h,n,u,l,v)}r.closePath()}}}var HR=function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0,this.cornerRadius=0}return r}(),kT=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new HR},e.prototype.buildPath=function(t,a){FR(t,a)},e.prototype.isZeroArea=function(){return this.shape.startAngle===this.shape.endAngle||this.shape.r===this.shape.r0},e}(yt);kT.prototype.type="sector";const Be=kT;var WR=function(){function r(){this.cx=0,this.cy=0,this.r=0,this.r0=0}return r}(),OT=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new WR},e.prototype.buildPath=function(t,a){var n=a.cx,i=a.cy,o=Math.PI*2;t.moveTo(n+a.r,i),t.arc(n,i,a.r,0,o,!1),t.moveTo(n+a.r0,i),t.arc(n,i,a.r0,0,o,!0)},e}(yt);OT.prototype.type="ring";const eh=OT;function $R(r,e,t,a){var n=[],i=[],o=[],s=[],l,u,f,h;if(a){f=[1/0,1/0],h=[-1/0,-1/0];for(var v=0,c=r.length;v<c;v++)Ia(f,f,r[v]),La(h,h,r[v]);Ia(f,f,a[0]),La(h,h,a[1])}for(var v=0,c=r.length;v<c;v++){var p=r[v];if(t)l=r[v?v-1:c-1],u=r[(v+1)%c];else if(v===0||v===c-1){n.push(ta(r[v]));continue}else l=r[v-1],u=r[v+1];On(i,u,l),Iu(i,i,e);var d=ap(p,l),g=ap(p,u),y=d+g;y!==0&&(d/=y,g/=y),Iu(o,i,-d),Iu(s,i,g);var m=am([],p,o),_=am([],p,s);a&&(La(m,m,f),Ia(m,m,h),La(_,_,f),Ia(_,_,h)),n.push(m),n.push(_)}return t&&n.push(n.shift()),n}function NT(r,e,t){var a=e.smooth,n=e.points;if(n&&n.length>=2){if(a){var i=$R(n,a,t,e.smoothConstraint);r.moveTo(n[0][0],n[0][1]);for(var o=n.length,s=0;s<(t?o:o-1);s++){var l=i[s*2],u=i[s*2+1],f=n[(s+1)%o];r.bezierCurveTo(l[0],l[1],u[0],u[1],f[0],f[1])}}else{r.moveTo(n[0][0],n[0][1]);for(var s=1,h=n.length;s<h;s++)r.lineTo(n[s][0],n[s][1])}t&&r.closePath()}}var UR=function(){function r(){this.points=null,this.smooth=0,this.smoothConstraint=null}return r}(),De=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new UR},e.prototype.buildPath=function(t,a){NT(t,a,!0)},e}(yt);De.prototype.type="polygon";var YR=function(){function r(){this.points=null,this.percent=1,this.smooth=0,this.smoothConstraint=null}return r}(),Me=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new YR},e.prototype.buildPath=function(t,a){NT(t,a,!1)},e}(yt);Me.prototype.type="polyline";var ZR={},XR=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.percent=1}return r}(),te=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new XR},e.prototype.buildPath=function(t,a){var n,i,o,s;if(this.subPixelOptimize){var l=hT(ZR,a,this.style);n=l.x1,i=l.y1,o=l.x2,s=l.y2}else n=a.x1,i=a.y1,o=a.x2,s=a.y2;var u=a.percent;u!==0&&(t.moveTo(n,i),u<1&&(o=n*(1-u)+o*u,s=i*(1-u)+s*u),t.lineTo(o,s))},e.prototype.pointAt=function(t){var a=this.shape;return[a.x1*(1-t)+a.x2*t,a.y1*(1-t)+a.y2*t]},e}(yt);te.prototype.type="line";var Le=[],qR=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.cpx1=0,this.cpy1=0,this.percent=1}return r}();function h0(r,e,t){var a=r.cpx2,n=r.cpy2;return a!=null||n!=null?[(t?dm:jt)(r.x1,r.cpx1,r.cpx2,r.x2,e),(t?dm:jt)(r.y1,r.cpy1,r.cpy2,r.y2,e)]:[(t?up:ne)(r.x1,r.cpx1,r.x2,e),(t?up:ne)(r.y1,r.cpy1,r.y2,e)]}var BT=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new qR},e.prototype.buildPath=function(t,a){var n=a.x1,i=a.y1,o=a.x2,s=a.y2,l=a.cpx1,u=a.cpy1,f=a.cpx2,h=a.cpy2,v=a.percent;v!==0&&(t.moveTo(n,i),f==null||h==null?(v<1&&(Ls(n,l,o,v,Le),l=Le[1],o=Le[2],Ls(i,u,s,v,Le),u=Le[1],s=Le[2]),t.quadraticCurveTo(l,u,o,s)):(v<1&&(Wa(n,l,f,o,v,Le),l=Le[1],f=Le[2],o=Le[3],Wa(i,u,h,s,v,Le),u=Le[1],h=Le[2],s=Le[3]),t.bezierCurveTo(l,u,f,h,o,s)))},e.prototype.pointAt=function(t){return h0(this.shape,t,!1)},e.prototype.tangentAt=function(t){var a=h0(this.shape,t,!0);return so(a,a)},e}(yt);BT.prototype.type="bezier-curve";const rh=BT;var KR=function(){function r(){this.cx=0,this.cy=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r}(),VT=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new KR},e.prototype.buildPath=function(t,a){var n=a.cx,i=a.cy,o=Math.max(a.r,0),s=a.startAngle,l=a.endAngle,u=a.clockwise,f=Math.cos(s),h=Math.sin(s);t.moveTo(f*o+n,h*o+i),t.arc(n,i,o,s,l,!u)},e}(yt);VT.prototype.type="arc";const pg=VT;var QR=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="compound",t}return e.prototype._updatePathDirty=function(){for(var t=this.shape.paths,a=this.shapeChanged(),n=0;n<t.length;n++)a=a||t[n].shapeChanged();a&&this.dirtyShape()},e.prototype.beforeBrush=function(){this._updatePathDirty();for(var t=this.shape.paths||[],a=this.getGlobalScale(),n=0;n<t.length;n++)t[n].path||t[n].createPathProxy(),t[n].path.setScale(a[0],a[1],t[n].segmentIgnoreThreshold)},e.prototype.buildPath=function(t,a){for(var n=a.paths||[],i=0;i<n.length;i++)n[i].buildPath(t,n[i].shape,!0)},e.prototype.afterBrush=function(){for(var t=this.shape.paths||[],a=0;a<t.length;a++)t[a].pathUpdated()},e.prototype.getBoundingRect=function(){return this._updatePathDirty.call(this),yt.prototype.getBoundingRect.call(this)},e}(yt);const dg=QR;var JR=function(){function r(e){this.colorStops=e||[]}return r.prototype.addColorStop=function(e,t){this.colorStops.push({offset:e,color:t})},r}();const zT=JR;var ho=function(r){k(e,r);function e(t,a,n,i,o,s){var l=r.call(this,o)||this;return l.x=t??0,l.y=a??0,l.x2=n??1,l.y2=i??0,l.type="linear",l.global=s||!1,l}return e}(zT),jR=function(r){k(e,r);function e(t,a,n,i,o){var s=r.call(this,i)||this;return s.x=t??.5,s.y=a??.5,s.r=n??.5,s.type="radial",s.global=o||!1,s}return e}(zT);const GT=jR;var dn=[0,0],gn=[0,0],Fl=new ut,Hl=new ut,tE=function(){function r(e,t){this._corners=[],this._axes=[],this._origin=[0,0];for(var a=0;a<4;a++)this._corners[a]=new ut;for(var a=0;a<2;a++)this._axes[a]=new ut;e&&this.fromBoundingRect(e,t)}return r.prototype.fromBoundingRect=function(e,t){var a=this._corners,n=this._axes,i=e.x,o=e.y,s=i+e.width,l=o+e.height;if(a[0].set(i,o),a[1].set(s,o),a[2].set(s,l),a[3].set(i,l),t)for(var u=0;u<4;u++)a[u].transform(t);ut.sub(n[0],a[1],a[0]),ut.sub(n[1],a[3],a[0]),n[0].normalize(),n[1].normalize();for(var u=0;u<2;u++)this._origin[u]=n[u].dot(a[0])},r.prototype.intersect=function(e,t){var a=!0,n=!t;return Fl.set(1/0,1/0),Hl.set(0,0),!this._intersectCheckOneSide(this,e,Fl,Hl,n,1)&&(a=!1,n)||!this._intersectCheckOneSide(e,this,Fl,Hl,n,-1)&&(a=!1,n)||n||ut.copy(t,a?Fl:Hl),a},r.prototype._intersectCheckOneSide=function(e,t,a,n,i,o){for(var s=!0,l=0;l<2;l++){var u=this._axes[l];if(this._getProjMinMaxOnAxis(l,e._corners,dn),this._getProjMinMaxOnAxis(l,t._corners,gn),dn[1]<gn[0]||dn[0]>gn[1]){if(s=!1,i)return s;var f=Math.abs(gn[0]-dn[1]),h=Math.abs(dn[0]-gn[1]);Math.min(f,h)>n.len()&&(f<h?ut.scale(n,u,-f*o):ut.scale(n,u,h*o))}else if(a){var f=Math.abs(gn[0]-dn[1]),h=Math.abs(dn[0]-gn[1]);Math.min(f,h)<a.len()&&(f<h?ut.scale(a,u,f*o):ut.scale(a,u,-h*o))}}return s},r.prototype._getProjMinMaxOnAxis=function(e,t,a){for(var n=this._axes[e],i=this._origin,o=t[0].dot(n)+i[e],s=o,l=o,u=1;u<t.length;u++){var f=t[u].dot(n)+i[e];s=Math.min(f,s),l=Math.max(f,l)}a[0]=s,a[1]=l},r}();const of=tE;var eE=[],rE=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.notClear=!0,t.incremental=!0,t._displayables=[],t._temporaryDisplayables=[],t._cursor=0,t}return e.prototype.traverse=function(t,a){t.call(a,this)},e.prototype.useStyle=function(){this.style={}},e.prototype.getCursor=function(){return this._cursor},e.prototype.innerAfterBrush=function(){this._cursor=this._displayables.length},e.prototype.clearDisplaybles=function(){this._displayables=[],this._temporaryDisplayables=[],this._cursor=0,this.markRedraw(),this.notClear=!1},e.prototype.clearTemporalDisplayables=function(){this._temporaryDisplayables=[]},e.prototype.addDisplayable=function(t,a){a?this._temporaryDisplayables.push(t):this._displayables.push(t),this.markRedraw()},e.prototype.addDisplayables=function(t,a){a=a||!1;for(var n=0;n<t.length;n++)this.addDisplayable(t[n],a)},e.prototype.getDisplayables=function(){return this._displayables},e.prototype.getTemporalDisplayables=function(){return this._temporaryDisplayables},e.prototype.eachPendingDisplayable=function(t){for(var a=this._cursor;a<this._displayables.length;a++)t&&t(this._displayables[a]);for(var a=0;a<this._temporaryDisplayables.length;a++)t&&t(this._temporaryDisplayables[a])},e.prototype.update=function(){this.updateTransform();for(var t=this._cursor;t<this._displayables.length;t++){var a=this._displayables[t];a.parent=this,a.update(),a.parent=null}for(var t=0;t<this._temporaryDisplayables.length;t++){var a=this._temporaryDisplayables[t];a.parent=this,a.update(),a.parent=null}},e.prototype.getBoundingRect=function(){if(!this._rect){for(var t=new ht(1/0,1/0,-1/0,-1/0),a=0;a<this._displayables.length;a++){var n=this._displayables[a],i=n.getBoundingRect().clone();n.needLocalTransform()&&i.applyTransform(n.getLocalTransform(eE)),t.union(i)}this._rect=t}return this._rect},e.prototype.contain=function(t,a){var n=this.transformCoordToLocal(t,a),i=this.getBoundingRect();if(i.contain(n[0],n[1]))for(var o=0;o<this._displayables.length;o++){var s=this._displayables[o];if(s.contain(t,a))return!0}return!1},e}(ir);const aE=rE;var FT=bt();function vo(r,e,t,a,n){var i;if(e&&e.ecModel){var o=e.ecModel.getUpdatePayload();i=o&&o.animation}var s=e&&e.isAnimationEnabled(),l=r==="update";if(s){var u=void 0,f=void 0,h=void 0;a?(u=it(a.duration,200),f=it(a.easing,"cubicOut"),h=0):(u=e.getShallow(l?"animationDurationUpdate":"animationDuration"),f=e.getShallow(l?"animationEasingUpdate":"animationEasing"),h=e.getShallow(l?"animationDelayUpdate":"animationDelay")),i&&(i.duration!=null&&(u=i.duration),i.easing!=null&&(f=i.easing),i.delay!=null&&(h=i.delay)),K(h)&&(h=h(t,n)),K(u)&&(u=u(t));var v={duration:u||0,delay:h,easing:f};return v}else return null}function gg(r,e,t,a,n,i,o){var s=!1,l;K(n)?(o=i,i=n,n=null):tt(n)&&(i=n.cb,o=n.during,s=n.isFrom,l=n.removeOpt,n=n.dataIndex);var u=r==="leave";u||e.stopAnimation("leave");var f=vo(r,a,n,u?l||{}:null,a&&a.getAnimationDelayParams?a.getAnimationDelayParams(e,n):null);if(f&&f.duration>0){var h=f.duration,v=f.delay,c=f.easing,p={duration:h,delay:v||0,easing:c,done:i,force:!!i||!!o,setToFinal:!u,scope:r,during:o};s?e.animateFrom(t,p):e.animateTo(t,p)}else e.stopAnimation(),!s&&e.attr(t),o&&o(1),i&&i()}function Dt(r,e,t,a,n,i){gg("update",r,e,t,a,n,i)}function Bt(r,e,t,a,n,i){gg("enter",r,e,t,a,n,i)}function Ui(r){if(!r.__zr)return!0;for(var e=0;e<r.animators.length;e++){var t=r.animators[e];if(t.scope==="leave")return!0}return!1}function $a(r,e,t,a,n,i){Ui(r)||gg("leave",r,e,t,a,n,i)}function v0(r,e,t,a){r.removeTextContent(),r.removeTextGuideLine(),$a(r,{style:{opacity:0}},e,t,a)}function Vs(r,e,t){function a(){r.parent&&r.parent.remove(r)}r.isGroup?r.traverse(function(n){n.isGroup||v0(n,e,t,a)}):v0(r,e,t,a)}function Sr(r){FT(r).oldStyle=r.style}function nE(r){return FT(r).oldStyle}var sf=Math.max,lf=Math.min,kp={};function iE(r){return yt.extend(r)}var oE=kR;function sE(r,e){return oE(r,e)}function xr(r,e){kp[r]=e}function yg(r){if(kp.hasOwnProperty(r))return kp[r]}function ah(r,e,t,a){var n=LT(r,e);return t&&(a==="center"&&(t=WT(t,n.getBoundingRect())),$T(n,t)),n}function HT(r,e,t){var a=new he({style:{image:r,x:e.x,y:e.y,width:e.width,height:e.height},onload:function(n){if(t==="center"){var i={width:n.width,height:n.height};a.setStyle(WT(e,i))}}});return a}function WT(r,e){var t=e.width/e.height,a=r.height*t,n;a<=r.width?n=r.height:(a=r.width,n=a/t);var i=r.x+r.width/2,o=r.y+r.height/2;return{x:i-a/2,y:o-n/2,width:a,height:n}}var er=OR;function $T(r,e){if(r.applyTransform){var t=r.getBoundingRect(),a=t.calculateTransform(e);r.applyTransform(a)}}function Qi(r,e){return hT(r,r,{lineWidth:e}),r}function lE(r){return vT(r.shape,r.shape,r.style),r}var Vu=Nn;function Xn(r,e){for(var t=Yf([]);r&&r!==e;)ea(t,r.getLocalTransform(),t),r=r.parent;return t}function mr(r,e,t){return e&&!ge(e)&&(e=Jr.getLocalTransform(e)),t&&(e=lo([],e)),se([],r,e)}function nh(r,e,t){var a=e[4]===0||e[5]===0||e[0]===0?1:Math.abs(2*e[4]/e[0]),n=e[4]===0||e[5]===0||e[2]===0?1:Math.abs(2*e[4]/e[2]),i=[r==="left"?-a:r==="right"?a:0,r==="top"?-n:r==="bottom"?n:0];return i=mr(i,e,t),Math.abs(i[0])>Math.abs(i[1])?i[0]>0?"right":"left":i[1]>0?"bottom":"top"}function c0(r){return!r.isGroup}function uE(r){return r.shape!=null}function ll(r,e,t){if(!r||!e)return;function a(o){var s={};return o.traverse(function(l){c0(l)&&l.anid&&(s[l.anid]=l)}),s}function n(o){var s={x:o.x,y:o.y,rotation:o.rotation};return uE(o)&&(s.shape=V({},o.shape)),s}var i=a(r);e.traverse(function(o){if(c0(o)&&o.anid){var s=i[o.anid];if(s){var l=n(o);o.attr(n(s)),Dt(o,l,t,nt(o).dataIndex)}}})}function UT(r,e){return G(r,function(t){var a=t[0];a=sf(a,e.x),a=lf(a,e.x+e.width);var n=t[1];return n=sf(n,e.y),n=lf(n,e.y+e.height),[a,n]})}function fE(r,e){var t=sf(r.x,e.x),a=lf(r.x+r.width,e.x+e.width),n=sf(r.y,e.y),i=lf(r.y+r.height,e.y+e.height);if(a>=t&&i>=n)return{x:t,y:n,width:a-t,height:i-n}}function ul(r,e,t){var a=V({rectHover:!0},e),n=a.style={strokeNoScale:!0};if(t=t||{x:-1,y:-1,width:2,height:2},r)return r.indexOf("image://")===0?(n.image=r.slice(8),j(n,t),new he(a)):ah(r.replace("path://",""),a,t,"center")}function ns(r,e,t,a,n){for(var i=0,o=n[n.length-1];i<n.length;i++){var s=n[i];if(YT(r,e,t,a,s[0],s[1],o[0],o[1]))return!0;o=s}}function YT(r,e,t,a,n,i,o,s){var l=t-r,u=a-e,f=o-n,h=s-i,v=vv(f,h,l,u);if(hE(v))return!1;var c=r-n,p=e-i,d=vv(c,p,l,u)/v;if(d<0||d>1)return!1;var g=vv(c,p,f,h)/v;return!(g<0||g>1)}function vv(r,e,t,a){return r*a-t*e}function hE(r){return r<=1e-6&&r>=-1e-6}function co(r){var e=r.itemTooltipOption,t=r.componentModel,a=r.itemName,n=$(e)?{formatter:e}:e,i=t.mainType,o=t.componentIndex,s={componentType:i,name:a,$vars:["name"]};s[i+"Index"]=o;var l=r.formatterParamsExtra;l&&C(_t(l),function(f){Y(s,f)||(s[f]=l[f],s.$vars.push(f))});var u=nt(r.el);u.componentMainType=i,u.componentIndex=o,u.tooltipConfig={name:a,option:j({content:a,formatterParams:s},n)}}function p0(r,e){var t;r.isGroup&&(t=e(r)),t||r.traverse(e)}function Ja(r,e){if(r)if(z(r))for(var t=0;t<r.length;t++)p0(r[t],e);else p0(r,e)}xr("circle",Qa);xr("ellipse",cg);xr("sector",Be);xr("ring",eh);xr("polygon",De);xr("polyline",Me);xr("rect",wt);xr("line",te);xr("bezierCurve",rh);xr("arc",pg);const si=Object.freeze(Object.defineProperty({__proto__:null,Arc:pg,BezierCurve:rh,BoundingRect:ht,Circle:Qa,CompoundPath:dg,Ellipse:cg,Group:at,Image:he,IncrementalDisplayable:aE,Line:te,LinearGradient:ho,OrientedBoundingRect:of,Path:yt,Point:ut,Polygon:De,Polyline:Me,RadialGradient:GT,Rect:wt,Ring:eh,Sector:Be,Text:At,applyTransform:mr,clipPointsByRect:UT,clipRectByRect:fE,createIcon:ul,extendPath:sE,extendShape:iE,getShapeClass:yg,getTransform:Xn,groupTransition:ll,initProps:Bt,isElementRemoved:Ui,lineLineIntersect:YT,linePolygonIntersect:ns,makeImage:HT,makePath:ah,mergePath:er,registerShape:xr,removeElement:$a,removeElementWithFadeOut:Vs,resizePath:$T,setTooltipConfig:co,subPixelOptimize:Vu,subPixelOptimizeLine:Qi,subPixelOptimizeRect:lE,transformDirection:nh,traverseElements:Ja,updateProps:Dt},Symbol.toStringTag,{value:"Module"}));var ih={};function ZT(r,e){for(var t=0;t<Ce.length;t++){var a=Ce[t],n=e[a],i=r.ensureState(a);i.style=i.style||{},i.style.text=n}var o=r.currentStates.slice();r.clearStates(!0),r.setStyle({text:e.normal}),r.useStates(o,!0)}function Op(r,e,t){var a=r.labelFetcher,n=r.labelDataIndex,i=r.labelDimIndex,o=e.normal,s;a&&(s=a.getFormattedLabel(n,"normal",null,i,o&&o.get("formatter"),t!=null?{interpolatedValue:t}:null)),s==null&&(s=K(r.defaultText)?r.defaultText(n,r,t):r.defaultText);for(var l={normal:s},u=0;u<Ce.length;u++){var f=Ce[u],h=e[f];l[f]=it(a?a.getFormattedLabel(n,f,null,i,h&&h.get("formatter")):null,s)}return l}function fe(r,e,t,a){t=t||ih;for(var n=r instanceof At,i=!1,o=0;o<Ns.length;o++){var s=e[Ns[o]];if(s&&s.getShallow("show")){i=!0;break}}var l=n?r:r.getTextContent();if(i){n||(l||(l=new At,r.setTextContent(l)),r.stateProxy&&(l.stateProxy=r.stateProxy));var u=Op(t,e),f=e.normal,h=!!f.getShallow("show"),v=kt(f,a&&a.normal,t,!1,!n);v.text=u.normal,n||r.setTextConfig(uf(f,t,!1));for(var o=0;o<Ce.length;o++){var c=Ce[o],s=e[c];if(s){var p=l.ensureState(c),d=!!it(s.getShallow("show"),h);if(d!==h&&(p.ignore=!d),p.style=kt(s,a&&a[c],t,!0,!n),p.style.text=u[c],!n){var g=r.ensureState(c);g.textConfig=uf(s,t,!0)}}}l.silent=!!f.getShallow("silent"),l.style.x!=null&&(v.x=l.style.x),l.style.y!=null&&(v.y=l.style.y),l.ignore=!h,l.useStyle(v),l.dirty(),t.enableTextSetter&&(po(l).setLabelText=function(y){var m=Op(t,e,y);ZT(l,m)})}else l&&(l.ignore=!0);r.dirty()}function re(r,e){e=e||"label";for(var t={normal:r.getModel(e)},a=0;a<Ce.length;a++){var n=Ce[a];t[n]=r.getModel([n,e])}return t}function kt(r,e,t,a,n){var i={};return vE(i,r,t,a,n),e&&V(i,e),i}function uf(r,e,t){e=e||{};var a={},n,i=r.getShallow("rotate"),o=it(r.getShallow("distance"),t?null:5),s=r.getShallow("offset");return n=r.getShallow("position")||(t?null:"inside"),n==="outside"&&(n=e.defaultOutsidePosition||"top"),n!=null&&(a.position=n),s!=null&&(a.offset=s),i!=null&&(i*=Math.PI/180,a.rotation=i),o!=null&&(a.distance=o),a.outsideFill=r.get("color")==="inherit"?e.inheritColor||null:"auto",a}function vE(r,e,t,a,n){t=t||ih;var i=e.ecModel,o=i&&i.option.textStyle,s=cE(e),l;if(s){l={};for(var u in s)if(s.hasOwnProperty(u)){var f=e.getModel(["rich",u]);m0(l[u]={},f,o,t,a,n,!1,!0)}}l&&(r.rich=l);var h=e.get("overflow");h&&(r.overflow=h);var v=e.get("minMargin");v!=null&&(r.margin=v),m0(r,e,o,t,a,n,!0,!1)}function cE(r){for(var e;r&&r!==r.ecModel;){var t=(r.option||ih).rich;if(t){e=e||{};for(var a=_t(t),n=0;n<a.length;n++){var i=a[n];e[i]=1}}r=r.parentModel}return e}var d0=["fontStyle","fontWeight","fontSize","fontFamily","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY"],g0=["align","lineHeight","width","height","tag","verticalAlign","ellipsis"],y0=["padding","borderWidth","borderRadius","borderDashOffset","backgroundColor","borderColor","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"];function m0(r,e,t,a,n,i,o,s){t=!n&&t||ih;var l=a&&a.inheritColor,u=e.getShallow("color"),f=e.getShallow("textBorderColor"),h=it(e.getShallow("opacity"),t.opacity);(u==="inherit"||u==="auto")&&(l?u=l:u=null),(f==="inherit"||f==="auto")&&(l?f=l:f=null),i||(u=u||t.color,f=f||t.textBorderColor),u!=null&&(r.fill=u),f!=null&&(r.stroke=f);var v=it(e.getShallow("textBorderWidth"),t.textBorderWidth);v!=null&&(r.lineWidth=v);var c=it(e.getShallow("textBorderType"),t.textBorderType);c!=null&&(r.lineDash=c);var p=it(e.getShallow("textBorderDashOffset"),t.textBorderDashOffset);p!=null&&(r.lineDashOffset=p),!n&&h==null&&!s&&(h=a&&a.defaultOpacity),h!=null&&(r.opacity=h),!n&&!i&&r.fill==null&&a.inheritColor&&(r.fill=a.inheritColor);for(var d=0;d<d0.length;d++){var g=d0[d],y=it(e.getShallow(g),t[g]);y!=null&&(r[g]=y)}for(var d=0;d<g0.length;d++){var g=g0[d],y=e.getShallow(g);y!=null&&(r[g]=y)}if(r.verticalAlign==null){var m=e.getShallow("baseline");m!=null&&(r.verticalAlign=m)}if(!o||!a.disableBox){for(var d=0;d<y0.length;d++){var g=y0[d],y=e.getShallow(g);y!=null&&(r[g]=y)}var _=e.getShallow("borderType");_!=null&&(r.borderDash=_),(r.backgroundColor==="auto"||r.backgroundColor==="inherit")&&l&&(r.backgroundColor=l),(r.borderColor==="auto"||r.borderColor==="inherit")&&l&&(r.borderColor=l)}}function mg(r,e){var t=e&&e.getModel("textStyle");return dr([r.fontStyle||t&&t.getShallow("fontStyle")||"",r.fontWeight||t&&t.getShallow("fontWeight")||"",(r.fontSize||t&&t.getShallow("fontSize")||12)+"px",r.fontFamily||t&&t.getShallow("fontFamily")||"sans-serif"].join(" "))}var po=bt();function XT(r,e,t,a){if(r){var n=po(r);n.prevValue=n.value,n.value=t;var i=e.normal;n.valueAnimation=i.get("valueAnimation"),n.valueAnimation&&(n.precision=i.get("precision"),n.defaultInterpolatedText=a,n.statesModels=e)}}function qT(r,e,t,a,n){var i=po(r);if(!i.valueAnimation||i.prevValue===i.value)return;var o=i.defaultInterpolatedText,s=it(i.interpolatedValue,i.prevValue),l=i.value;function u(f){var h=eT(t,i.precision,s,l,f);i.interpolatedValue=f===1?null:h;var v=Op({labelDataIndex:e,labelFetcher:n,defaultText:o?o(h):h+""},i.statesModels,h);ZT(r,v)}r.percent=0,(i.prevValue==null?Bt:Dt)(r,{percent:1},a,e,null,u)}var pE=["textStyle","color"],cv=["fontStyle","fontWeight","fontSize","fontFamily","padding","lineHeight","rich","width","height","overflow"],pv=new At,dE=function(){function r(){}return r.prototype.getTextColor=function(e){var t=this.ecModel;return this.getShallow("color")||(!e&&t?t.get(pE):null)},r.prototype.getFont=function(){return mg({fontStyle:this.getShallow("fontStyle"),fontWeight:this.getShallow("fontWeight"),fontSize:this.getShallow("fontSize"),fontFamily:this.getShallow("fontFamily")},this.ecModel)},r.prototype.getTextRect=function(e){for(var t={text:e,verticalAlign:this.getShallow("verticalAlign")||this.getShallow("baseline")},a=0;a<cv.length;a++)t[cv[a]]=this.getShallow(cv[a]);return pv.useStyle(t),pv.update(),pv.getBoundingRect()},r}();const gE=dE;var KT=[["lineWidth","width"],["stroke","color"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","type"],["lineDashOffset","dashOffset"],["lineCap","cap"],["lineJoin","join"],["miterLimit"]],yE=ti(KT),mE=function(){function r(){}return r.prototype.getLineStyle=function(e){return yE(this,e)},r}(),QT=[["fill","color"],["stroke","borderColor"],["lineWidth","borderWidth"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","borderType"],["lineDashOffset","borderDashOffset"],["lineCap","borderCap"],["lineJoin","borderJoin"],["miterLimit","borderMiterLimit"]],_E=ti(QT),SE=function(){function r(){}return r.prototype.getItemStyle=function(e,t){return _E(this,e,t)},r}(),li=function(){function r(e,t,a){this.parentModel=t,this.ecModel=a,this.option=e}return r.prototype.init=function(e,t,a){},r.prototype.mergeOption=function(e,t){ft(this.option,e,!0)},r.prototype.get=function(e,t){return e==null?this.option:this._doGet(this.parsePath(e),!t&&this.parentModel)},r.prototype.getShallow=function(e,t){var a=this.option,n=a==null?a:a[e];if(n==null&&!t){var i=this.parentModel;i&&(n=i.getShallow(e))}return n},r.prototype.getModel=function(e,t){var a=e!=null,n=a?this.parsePath(e):null,i=a?this._doGet(n):this.option;return t=t||this.parentModel&&this.parentModel.getModel(this.resolveParentPath(n)),new r(i,t,this.ecModel)},r.prototype.isEmpty=function(){return this.option==null},r.prototype.restoreData=function(){},r.prototype.clone=function(){var e=this.constructor;return new e(rt(this.option))},r.prototype.parsePath=function(e){return typeof e=="string"?e.split("."):e},r.prototype.resolveParentPath=function(e){return e},r.prototype.isAnimationEnabled=function(){if(!mt.node&&this.option){if(this.option.animation!=null)return!!this.option.animation;if(this.parentModel)return this.parentModel.isAnimationEnabled()}},r.prototype._doGet=function(e,t){var a=this.option;if(!e)return a;for(var n=0;n<e.length&&!(e[n]&&(a=a&&typeof a=="object"?a[e[n]]:null,a==null));n++);return a==null&&t&&(a=t._doGet(this.resolveParentPath(e),t.parentModel)),a},r}();ng(li);wP(li);Kt(li,mE);Kt(li,SE);Kt(li,DP);Kt(li,gE);const Ot=li;var xE=Math.round(Math.random()*10);function go(r){return[r||"",xE++].join("_")}function wE(r){var e={};r.registerSubTypeDefaulter=function(t,a){var n=kr(t);e[n.main]=a},r.determineSubType=function(t,a){var n=a.type;if(!n){var i=kr(t).main;r.hasSubTypes(t)&&e[i]&&(n=e[i](a))}return n}}function bE(r,e){r.topologicalTravel=function(i,o,s,l){if(!i.length)return;var u=t(o),f=u.graph,h=u.noEntryList,v={};for(C(i,function(m){v[m]=!0});h.length;){var c=h.pop(),p=f[c],d=!!v[c];d&&(s.call(l,c,p.originalDeps.slice()),delete v[c]),C(p.successor,d?y:g)}C(v,function(){var m="";throw new Error(m)});function g(m){f[m].entryCount--,f[m].entryCount===0&&h.push(m)}function y(m){v[m]=!0,g(m)}};function t(i){var o={},s=[];return C(i,function(l){var u=a(o,l),f=u.originalDeps=e(l),h=n(f,i);u.entryCount=h.length,u.entryCount===0&&s.push(l),C(h,function(v){vt(u.predecessor,v)<0&&u.predecessor.push(v);var c=a(o,v);vt(c.successor,v)<0&&c.successor.push(l)})}),{graph:o,noEntryList:s}}function a(i,o){return i[o]||(i[o]={predecessor:[],successor:[]}),i[o]}function n(i,o){var s=[];return C(i,function(l){vt(o,l)>=0&&s.push(l)}),s}}function ja(r,e){return ft(ft({},r,!0),e,!0)}const TE={time:{month:["January","February","March","April","May","June","July","August","September","October","November","December"],monthAbbr:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayOfWeek:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayOfWeekAbbr:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]},legend:{selector:{all:"All",inverse:"Inv"}},toolbox:{brush:{title:{rect:"Box Select",polygon:"Lasso Select",lineX:"Horizontally Select",lineY:"Vertically Select",keep:"Keep Selections",clear:"Clear Selections"}},dataView:{title:"Data View",lang:["Data View","Close","Refresh"]},dataZoom:{title:{zoom:"Zoom",back:"Zoom Reset"}},magicType:{title:{line:"Switch to Line Chart",bar:"Switch to Bar Chart",stack:"Stack",tiled:"Tile"}},restore:{title:"Restore"},saveAsImage:{title:"Save as Image",lang:["Right Click to Save Image"]}},series:{typeNames:{pie:"Pie chart",bar:"Bar chart",line:"Line chart",scatter:"Scatter plot",effectScatter:"Ripple scatter plot",radar:"Radar chart",tree:"Tree",treemap:"Treemap",boxplot:"Boxplot",candlestick:"Candlestick",k:"K line chart",heatmap:"Heat map",map:"Map",parallel:"Parallel coordinate map",lines:"Line graph",graph:"Relationship graph",sankey:"Sankey diagram",funnel:"Funnel chart",gauge:"Gauge",pictorialBar:"Pictorial bar",themeRiver:"Theme River Map",sunburst:"Sunburst",custom:"Custom chart",chart:"Chart"}},aria:{general:{withTitle:'This is a chart about "{title}"',withoutTitle:"This is a chart"},series:{single:{prefix:"",withName:" with type {seriesType} named {seriesName}.",withoutName:" with type {seriesType}."},multiple:{prefix:". It consists of {seriesCount} series count.",withName:" The {seriesId} series is a {seriesType} representing {seriesName}.",withoutName:" The {seriesId} series is a {seriesType}.",separator:{middle:"",end:""}}},data:{allData:"The data is as follows: ",partialData:"The first {displayCnt} items are: ",withName:"the data for {name} is {value}",withoutName:"{value}",separator:{middle:", ",end:". "}}}},AE={time:{month:["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],monthAbbr:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],dayOfWeek:["星期日","星期一","星期二","星期三","星期四","星期五","星期六"],dayOfWeekAbbr:["日","一","二","三","四","五","六"]},legend:{selector:{all:"全选",inverse:"反选"}},toolbox:{brush:{title:{rect:"矩形选择",polygon:"圈选",lineX:"横向选择",lineY:"纵向选择",keep:"保持选择",clear:"清除选择"}},dataView:{title:"数据视图",lang:["数据视图","关闭","刷新"]},dataZoom:{title:{zoom:"区域缩放",back:"区域缩放还原"}},magicType:{title:{line:"切换为折线图",bar:"切换为柱状图",stack:"切换为堆叠",tiled:"切换为平铺"}},restore:{title:"还原"},saveAsImage:{title:"保存为图片",lang:["右键另存为图片"]}},series:{typeNames:{pie:"饼图",bar:"柱状图",line:"折线图",scatter:"散点图",effectScatter:"涟漪散点图",radar:"雷达图",tree:"树图",treemap:"矩形树图",boxplot:"箱型图",candlestick:"K线图",k:"K线图",heatmap:"热力图",map:"地图",parallel:"平行坐标图",lines:"线图",graph:"关系图",sankey:"桑基图",funnel:"漏斗图",gauge:"仪表盘图",pictorialBar:"象形柱图",themeRiver:"主题河流图",sunburst:"旭日图",custom:"自定义图表",chart:"图表"}},aria:{general:{withTitle:"这是一个关于“{title}”的图表。",withoutTitle:"这是一个图表，"},series:{single:{prefix:"",withName:"图表类型是{seriesType}，表示{seriesName}。",withoutName:"图表类型是{seriesType}。"},multiple:{prefix:"它由{seriesCount}个图表系列组成。",withName:"第{seriesId}个系列是一个表示{seriesName}的{seriesType}，",withoutName:"第{seriesId}个系列是一个{seriesType}，",separator:{middle:"；",end:"。"}}},data:{allData:"其数据是——",partialData:"其中，前{displayCnt}项是——",withName:"{name}的数据是{value}",withoutName:"{value}",separator:{middle:"，",end:""}}}};var ff="ZH",_g="EN",Yi=_g,zu={},Sg={},JT=mt.domSupported?function(){var r=(document.documentElement.lang||navigator.language||navigator.browserLanguage||Yi).toUpperCase();return r.indexOf(ff)>-1?ff:Yi}():Yi;function jT(r,e){r=r.toUpperCase(),Sg[r]=new Ot(e),zu[r]=e}function CE(r){if($(r)){var e=zu[r.toUpperCase()]||{};return r===ff||r===_g?rt(e):ft(rt(e),rt(zu[Yi]),!1)}else return ft(rt(r),rt(zu[Yi]),!1)}function Np(r){return Sg[r]}function DE(){return Sg[Yi]}jT(_g,TE);jT(ff,AE);var xg=1e3,wg=xg*60,xs=wg*60,rr=xs*24,_0=rr*365,is={year:"{yyyy}",month:"{MMM}",day:"{d}",hour:"{HH}:{mm}",minute:"{HH}:{mm}",second:"{HH}:{mm}:{ss}",millisecond:"{HH}:{mm}:{ss} {SSS}",none:"{yyyy}-{MM}-{dd} {HH}:{mm}:{ss} {SSS}"},Wl="{yyyy}-{MM}-{dd}",S0={year:"{yyyy}",month:"{yyyy}-{MM}",day:Wl,hour:Wl+" "+is.hour,minute:Wl+" "+is.minute,second:Wl+" "+is.second,millisecond:is.none},dv=["year","month","day","hour","minute","second","millisecond"],tA=["year","half-year","quarter","month","week","half-week","day","half-day","quarter-day","hour","minute","second","millisecond"];function ya(r,e){return r+="","0000".substr(0,e-r.length)+r}function Zi(r){switch(r){case"half-year":case"quarter":return"month";case"week":case"half-week":return"day";case"half-day":case"quarter-day":return"hour";default:return r}}function ME(r){return r===Zi(r)}function IE(r){switch(r){case"year":case"month":return"day";case"millisecond":return"millisecond";default:return"second"}}function oh(r,e,t,a){var n=Hr(r),i=n[bg(t)](),o=n[Xi(t)]()+1,s=Math.floor((o-1)/3)+1,l=n[sh(t)](),u=n["get"+(t?"UTC":"")+"Day"](),f=n[zs(t)](),h=(f-1)%12+1,v=n[lh(t)](),c=n[uh(t)](),p=n[fh(t)](),d=a instanceof Ot?a:Np(a||JT)||DE(),g=d.getModel("time"),y=g.get("month"),m=g.get("monthAbbr"),_=g.get("dayOfWeek"),S=g.get("dayOfWeekAbbr");return(e||"").replace(/{yyyy}/g,i+"").replace(/{yy}/g,ya(i%100+"",2)).replace(/{Q}/g,s+"").replace(/{MMMM}/g,y[o-1]).replace(/{MMM}/g,m[o-1]).replace(/{MM}/g,ya(o,2)).replace(/{M}/g,o+"").replace(/{dd}/g,ya(l,2)).replace(/{d}/g,l+"").replace(/{eeee}/g,_[u]).replace(/{ee}/g,S[u]).replace(/{e}/g,u+"").replace(/{HH}/g,ya(f,2)).replace(/{H}/g,f+"").replace(/{hh}/g,ya(h+"",2)).replace(/{h}/g,h+"").replace(/{mm}/g,ya(v,2)).replace(/{m}/g,v+"").replace(/{ss}/g,ya(c,2)).replace(/{s}/g,c+"").replace(/{SSS}/g,ya(p,3)).replace(/{S}/g,p+"")}function LE(r,e,t,a,n){var i=null;if($(t))i=t;else if(K(t))i=t(r.value,e,{level:r.level});else{var o=V({},is);if(r.level>0)for(var s=0;s<dv.length;++s)o[dv[s]]="{primary|"+o[dv[s]]+"}";var l=t?t.inherit===!1?t:j(t,o):o,u=eA(r.value,n);if(l[u])i=l[u];else if(l.inherit){for(var f=tA.indexOf(u),s=f-1;s>=0;--s)if(l[u]){i=l[u];break}i=i||o.none}if(z(i)){var h=r.level==null?0:r.level>=0?r.level:i.length+r.level;h=Math.min(h,i.length-1),i=i[h]}}return oh(new Date(r.value),i,n,a)}function eA(r,e){var t=Hr(r),a=t[Xi(e)]()+1,n=t[sh(e)](),i=t[zs(e)](),o=t[lh(e)](),s=t[uh(e)](),l=t[fh(e)](),u=l===0,f=u&&s===0,h=f&&o===0,v=h&&i===0,c=v&&n===1,p=c&&a===1;return p?"year":c?"month":v?"day":h?"hour":f?"minute":u?"second":"millisecond"}function x0(r,e,t){var a=Ct(r)?Hr(r):r;switch(e=e||eA(r,t),e){case"year":return a[bg(t)]();case"half-year":return a[Xi(t)]()>=6?1:0;case"quarter":return Math.floor((a[Xi(t)]()+1)/4);case"month":return a[Xi(t)]();case"day":return a[sh(t)]();case"half-day":return a[zs(t)]()/24;case"hour":return a[zs(t)]();case"minute":return a[lh(t)]();case"second":return a[uh(t)]();case"millisecond":return a[fh(t)]()}}function bg(r){return r?"getUTCFullYear":"getFullYear"}function Xi(r){return r?"getUTCMonth":"getMonth"}function sh(r){return r?"getUTCDate":"getDate"}function zs(r){return r?"getUTCHours":"getHours"}function lh(r){return r?"getUTCMinutes":"getMinutes"}function uh(r){return r?"getUTCSeconds":"getSeconds"}function fh(r){return r?"getUTCMilliseconds":"getMilliseconds"}function PE(r){return r?"setUTCFullYear":"setFullYear"}function rA(r){return r?"setUTCMonth":"setMonth"}function aA(r){return r?"setUTCDate":"setDate"}function nA(r){return r?"setUTCHours":"setHours"}function iA(r){return r?"setUTCMinutes":"setMinutes"}function oA(r){return r?"setUTCSeconds":"setSeconds"}function sA(r){return r?"setUTCMilliseconds":"setMilliseconds"}function lA(r){if(!Zb(r))return $(r)?r:"-";var e=(r+"").split(".");return e[0].replace(/(\d{1,3})(?=(?:\d{3})+(?!\d))/g,"$1,")+(e.length>1?"."+e[1]:"")}function uA(r,e){return r=(r||"").toLowerCase().replace(/-(.)/g,function(t,a){return a.toUpperCase()}),e&&r&&(r=r.charAt(0).toUpperCase()+r.slice(1)),r}var yo=Zd;function Bp(r,e,t){var a="{yyyy}-{MM}-{dd} {HH}:{mm}:{ss}";function n(f){return f&&dr(f)?f:"-"}function i(f){return!!(f!=null&&!isNaN(f)&&isFinite(f))}var o=e==="time",s=r instanceof Date;if(o||s){var l=o?Hr(r):r;if(isNaN(+l)){if(s)return"-"}else return oh(l,a,t)}if(e==="ordinal")return tp(r)?n(r):Ct(r)&&i(r)?r+"":"-";var u=oa(r);return i(u)?lA(u):tp(r)?n(r):typeof r=="boolean"?r+"":"-"}var w0=["a","b","c","d","e","f","g"],gv=function(r,e){return"{"+r+(e??"")+"}"};function fA(r,e,t){z(e)||(e=[e]);var a=e.length;if(!a)return"";for(var n=e[0].$vars||[],i=0;i<n.length;i++){var o=w0[i];r=r.replace(gv(o),gv(o,0))}for(var s=0;s<a;s++)for(var l=0;l<n.length;l++){var u=e[s][n[l]];r=r.replace(gv(w0[l],s),t?Re(u):u)}return r}function RE(r,e,t){return C(e,function(a,n){r=r.replace("{"+n+"}",t?Re(a):a)}),r}function EE(r,e){var t=$(r)?{color:r,extraCssText:e}:r||{},a=t.color,n=t.type;e=t.extraCssText;var i=t.renderMode||"html";if(!a)return"";if(i==="html")return n==="subItem"?'<span style="display:inline-block;vertical-align:middle;margin-right:8px;margin-left:3px;border-radius:4px;width:4px;height:4px;background-color:'+Re(a)+";"+(e||"")+'"></span>':'<span style="display:inline-block;margin-right:4px;border-radius:10px;width:10px;height:10px;background-color:'+Re(a)+";"+(e||"")+'"></span>';var o=t.markerId||"markerX";return{renderMode:i,content:"{"+o+"|}  ",style:n==="subItem"?{width:4,height:4,borderRadius:2,backgroundColor:a}:{width:10,height:10,borderRadius:5,backgroundColor:a}}}function ri(r,e){return e=e||"transparent",$(r)?r:tt(r)&&r.colorStops&&(r.colorStops[0]||{}).color||e}function hf(r,e){if(e==="_blank"||e==="blank"){var t=window.open();t.opener=null,t.location.href=r}else window.open(r,e)}var Gu=C,hA=["left","right","top","bottom","width","height"],Vn=[["width","left","right"],["height","top","bottom"]];function Tg(r,e,t,a,n){var i=0,o=0;a==null&&(a=1/0),n==null&&(n=1/0);var s=0;e.eachChild(function(l,u){var f=l.getBoundingRect(),h=e.childAt(u+1),v=h&&h.getBoundingRect(),c,p;if(r==="horizontal"){var d=f.width+(v?-v.x+f.x:0);c=i+d,c>a||l.newline?(i=0,c=d,o+=s+t,s=f.height):s=Math.max(s,f.height)}else{var g=f.height+(v?-v.y+f.y:0);p=o+g,p>n||l.newline?(i+=s+t,o=0,p=g,s=f.width):s=Math.max(s,f.width)}l.newline||(l.x=i,l.y=o,l.markRedraw(),r==="horizontal"?i=c+t:o=p+t)})}var qn=Tg;ot(Tg,"vertical");ot(Tg,"horizontal");function kE(r,e,t){var a=e.width,n=e.height,i=W(r.left,a),o=W(r.top,n),s=W(r.right,a),l=W(r.bottom,n);return(isNaN(i)||isNaN(parseFloat(r.left)))&&(i=0),(isNaN(s)||isNaN(parseFloat(r.right)))&&(s=a),(isNaN(o)||isNaN(parseFloat(r.top)))&&(o=0),(isNaN(l)||isNaN(parseFloat(r.bottom)))&&(l=n),t=yo(t||0),{width:Math.max(s-i-t[1]-t[3],0),height:Math.max(l-o-t[0]-t[2],0)}}function Jt(r,e,t){t=yo(t||0);var a=e.width,n=e.height,i=W(r.left,a),o=W(r.top,n),s=W(r.right,a),l=W(r.bottom,n),u=W(r.width,a),f=W(r.height,n),h=t[2]+t[0],v=t[1]+t[3],c=r.aspect;switch(isNaN(u)&&(u=a-s-v-i),isNaN(f)&&(f=n-l-h-o),c!=null&&(isNaN(u)&&isNaN(f)&&(c>a/n?u=a*.8:f=n*.8),isNaN(u)&&(u=c*f),isNaN(f)&&(f=u/c)),isNaN(i)&&(i=a-s-u-v),isNaN(o)&&(o=n-l-f-h),r.left||r.right){case"center":i=a/2-u/2-t[3];break;case"right":i=a-u-v;break}switch(r.top||r.bottom){case"middle":case"center":o=n/2-f/2-t[0];break;case"bottom":o=n-f-h;break}i=i||0,o=o||0,isNaN(u)&&(u=a-v-i-(s||0)),isNaN(f)&&(f=n-h-o-(l||0));var p=new ht(i+t[3],o+t[0],u,f);return p.margin=t,p}function hh(r,e,t,a,n,i){var o=!n||!n.hv||n.hv[0],s=!n||!n.hv||n.hv[1],l=n&&n.boundingMode||"all";if(i=i||r,i.x=r.x,i.y=r.y,!o&&!s)return!1;var u;if(l==="raw")u=r.type==="group"?new ht(0,0,+e.width||0,+e.height||0):r.getBoundingRect();else if(u=r.getBoundingRect(),r.needLocalTransform()){var f=r.getLocalTransform();u=u.clone(),u.applyTransform(f)}var h=Jt(j({width:u.width,height:u.height},e),t,a),v=o?h.x-u.x:0,c=s?h.y-u.y:0;return l==="raw"?(i.x=v,i.y=c):(i.x+=v,i.y+=c),i===r&&r.markRedraw(),!0}function OE(r,e){return r[Vn[e][0]]!=null||r[Vn[e][1]]!=null&&r[Vn[e][2]]!=null}function Gs(r){var e=r.layoutMode||r.constructor.layoutMode;return tt(e)?e:e?{type:e}:null}function Ua(r,e,t){var a=t&&t.ignoreSize;!z(a)&&(a=[a,a]);var n=o(Vn[0],0),i=o(Vn[1],1);u(Vn[0],r,n),u(Vn[1],r,i);function o(f,h){var v={},c=0,p={},d=0,g=2;if(Gu(f,function(_){p[_]=r[_]}),Gu(f,function(_){s(e,_)&&(v[_]=p[_]=e[_]),l(v,_)&&c++,l(p,_)&&d++}),a[h])return l(e,f[1])?p[f[2]]=null:l(e,f[2])&&(p[f[1]]=null),p;if(d===g||!c)return p;if(c>=g)return v;for(var y=0;y<f.length;y++){var m=f[y];if(!s(v,m)&&s(r,m)){v[m]=r[m];break}}return v}function s(f,h){return f.hasOwnProperty(h)}function l(f,h){return f[h]!=null&&f[h]!=="auto"}function u(f,h,v){Gu(f,function(c){h[c]=v[c]})}}function mo(r){return vA({},r)}function vA(r,e){return e&&r&&Gu(hA,function(t){e.hasOwnProperty(t)&&(r[t]=e[t])}),r}var NE=bt(),_o=function(r){k(e,r);function e(t,a,n){var i=r.call(this,t,a,n)||this;return i.uid=go("ec_cpt_model"),i}return e.prototype.init=function(t,a,n){this.mergeDefaultAndTheme(t,n)},e.prototype.mergeDefaultAndTheme=function(t,a){var n=Gs(this),i=n?mo(t):{},o=a.getTheme();ft(t,o.get(this.mainType)),ft(t,this.getDefaultOption()),n&&Ua(t,i,n)},e.prototype.mergeOption=function(t,a){ft(this.option,t,!0);var n=Gs(this);n&&Ua(this.option,t,n)},e.prototype.optionUpdated=function(t,a){},e.prototype.getDefaultOption=function(){var t=this.constructor;if(!_P(t))return t.defaultOption;var a=NE(this);if(!a.defaultOption){for(var n=[],i=t;i;){var o=i.prototype.defaultOption;o&&n.push(o),i=i.superClass}for(var s={},l=n.length-1;l>=0;l--)s=ft(s,n[l],!0);a.defaultOption=s}return a.defaultOption},e.prototype.getReferringComponents=function(t,a){var n=t+"Index",i=t+"Id";return ol(this.ecModel,t,{index:this.get(n,!0),id:this.get(i,!0)},a)},e.prototype.getBoxLayoutParams=function(){var t=this;return{left:t.get("left"),top:t.get("top"),right:t.get("right"),bottom:t.get("bottom"),width:t.get("width"),height:t.get("height")}},e.prototype.getZLevelKey=function(){return""},e.prototype.setZLevel=function(t){this.option.zlevel=t},e.protoInitialize=function(){var t=e.prototype;t.type="component",t.id="",t.name="",t.mainType="",t.subType="",t.componentIndex=0}(),e}(Ot);aT(_o,Ot);qf(_o);wE(_o);bE(_o,BE);function BE(r){var e=[];return C(_o.getClassesByMainType(r),function(t){e=e.concat(t.dependencies||t.prototype.dependencies||[])}),e=G(e,function(t){return kr(t).main}),r!=="dataset"&&vt(e,"dataset")<=0&&e.unshift("dataset"),e}const Tt=_o;var cA="";typeof navigator<"u"&&(cA=navigator.platform||"");var xi="rgba(0, 0, 0, 0.2)";const VE={darkMode:"auto",colorBy:"series",color:["#5470c6","#91cc75","#fac858","#ee6666","#73c0de","#3ba272","#fc8452","#9a60b4","#ea7ccc"],gradientColor:["#f6efa6","#d88273","#bf444c"],aria:{decal:{decals:[{color:xi,dashArrayX:[1,0],dashArrayY:[2,5],symbolSize:1,rotation:Math.PI/6},{color:xi,symbol:"circle",dashArrayX:[[8,8],[0,8,8,0]],dashArrayY:[6,0],symbolSize:.8},{color:xi,dashArrayX:[1,0],dashArrayY:[4,3],rotation:-Math.PI/4},{color:xi,dashArrayX:[[6,6],[0,6,6,0]],dashArrayY:[6,0]},{color:xi,dashArrayX:[[1,0],[1,6]],dashArrayY:[1,0,6,0],rotation:Math.PI/4},{color:xi,symbol:"triangle",dashArrayX:[[9,9],[0,9,9,0]],dashArrayY:[7,2],symbolSize:.75}]}},textStyle:{fontFamily:cA.match(/^Win/)?"Microsoft YaHei":"sans-serif",fontSize:12,fontStyle:"normal",fontWeight:"normal"},blendMode:null,stateAnimation:{duration:300,easing:"cubicOut"},animation:"auto",animationDuration:1e3,animationDurationUpdate:500,animationEasing:"cubicInOut",animationEasingUpdate:"cubicInOut",animationThreshold:2e3,progressiveThreshold:3e3,progressive:400,hoverLayerThreshold:3e3,useUTC:!1};var pA=Z(["tooltip","label","itemName","itemId","itemGroupId","itemChildGroupId","seriesName"]),sr="original",ye="arrayRows",lr="objectRows",$r="keyedColumns",Va="typedArray",dA="unknown",Vr="column",So="row",oe={Must:1,Might:2,Not:3},gA=bt();function zE(r){gA(r).datasetMap=Z()}function yA(r,e,t){var a={},n=Cg(e);if(!n||!r)return a;var i=[],o=[],s=e.ecModel,l=gA(s).datasetMap,u=n.uid+"_"+t.seriesLayoutBy,f,h;r=r.slice(),C(r,function(d,g){var y=tt(d)?d:r[g]={name:d};y.type==="ordinal"&&f==null&&(f=g,h=p(y)),a[y.name]=[]});var v=l.get(u)||l.set(u,{categoryWayDim:h,valueWayDim:0});C(r,function(d,g){var y=d.name,m=p(d);if(f==null){var _=v.valueWayDim;c(a[y],_,m),c(o,_,m),v.valueWayDim+=m}else if(f===g)c(a[y],0,m),c(i,0,m);else{var _=v.categoryWayDim;c(a[y],_,m),c(o,_,m),v.categoryWayDim+=m}});function c(d,g,y){for(var m=0;m<y;m++)d.push(g+m)}function p(d){var g=d.dimsDef;return g?g.length:1}return i.length&&(a.itemName=i),o.length&&(a.seriesName=o),a}function Ag(r,e,t){var a={},n=Cg(r);if(!n)return a;var i=e.sourceFormat,o=e.dimensionsDefine,s;(i===lr||i===$r)&&C(o,function(f,h){(tt(f)?f.name:f)==="name"&&(s=h)});var l=function(){for(var f={},h={},v=[],c=0,p=Math.min(5,t);c<p;c++){var d=_A(e.data,i,e.seriesLayoutBy,o,e.startIndex,c);v.push(d);var g=d===oe.Not;if(g&&f.v==null&&c!==s&&(f.v=c),(f.n==null||f.n===f.v||!g&&v[f.n]===oe.Not)&&(f.n=c),y(f)&&v[f.n]!==oe.Not)return f;g||(d===oe.Might&&h.v==null&&c!==s&&(h.v=c),(h.n==null||h.n===h.v)&&(h.n=c))}function y(m){return m.v!=null&&m.n!=null}return y(f)?f:y(h)?h:null}();if(l){a.value=[l.v];var u=s??l.n;a.itemName=[u],a.seriesName=[u]}return a}function Cg(r){var e=r.get("data",!0);if(!e)return ol(r.ecModel,"dataset",{index:r.get("datasetIndex",!0),id:r.get("datasetId",!0)},Xt).models[0]}function GE(r){return!r.get("transform",!0)&&!r.get("fromTransformResult",!0)?[]:ol(r.ecModel,"dataset",{index:r.get("fromDatasetIndex",!0),id:r.get("fromDatasetId",!0)},Xt).models}function mA(r,e){return _A(r.data,r.sourceFormat,r.seriesLayoutBy,r.dimensionsDefine,r.startIndex,e)}function _A(r,e,t,a,n,i){var o,s=5;if(Ne(r))return oe.Not;var l,u;if(a){var f=a[i];tt(f)?(l=f.name,u=f.type):$(f)&&(l=f)}if(u!=null)return u==="ordinal"?oe.Must:oe.Not;if(e===ye){var h=r;if(t===So){for(var v=h[i],c=0;c<(v||[]).length&&c<s;c++)if((o=S(v[n+c]))!=null)return o}else for(var c=0;c<h.length&&c<s;c++){var p=h[n+c];if(p&&(o=S(p[i]))!=null)return o}}else if(e===lr){var d=r;if(!l)return oe.Not;for(var c=0;c<d.length&&c<s;c++){var g=d[c];if(g&&(o=S(g[l]))!=null)return o}}else if(e===$r){var y=r;if(!l)return oe.Not;var v=y[l];if(!v||Ne(v))return oe.Not;for(var c=0;c<v.length&&c<s;c++)if((o=S(v[c]))!=null)return o}else if(e===sr)for(var m=r,c=0;c<m.length&&c<s;c++){var g=m[c],_=uo(g);if(!z(_))return oe.Not;if((o=S(_[i]))!=null)return o}function S(w){var x=$(w);if(w!=null&&isFinite(w)&&w!=="")return x?oe.Might:oe.Not;if(x&&w!=="-")return oe.Must}return oe.Not}var Vp=Z();function FE(r,e){Ae(Vp.get(r)==null&&e),Vp.set(r,e)}function HE(r,e,t){var a=Vp.get(e);if(!a)return t;var n=a(r);return n?t.concat(n):t}var b0=bt(),WE=bt(),Dg=function(){function r(){}return r.prototype.getColorFromPalette=function(e,t,a){var n=Pt(this.get("color",!0)),i=this.get("colorLayer",!0);return SA(this,b0,n,i,e,t,a)},r.prototype.clearColorPalette=function(){UE(this,b0)},r}();function zp(r,e,t,a){var n=Pt(r.get(["aria","decal","decals"]));return SA(r,WE,n,null,e,t,a)}function $E(r,e){for(var t=r.length,a=0;a<t;a++)if(r[a].length>e)return r[a];return r[t-1]}function SA(r,e,t,a,n,i,o){i=i||r;var s=e(i),l=s.paletteIdx||0,u=s.paletteNameMap=s.paletteNameMap||{};if(u.hasOwnProperty(n))return u[n];var f=o==null||!a?t:$E(a,o);if(f=f||t,!(!f||!f.length)){var h=f[l];return n&&(u[n]=h),s.paletteIdx=(l+1)%f.length,h}}function UE(r,e){e(r).paletteIdx=0,e(r).paletteNameMap={}}var $l,Eo,T0,A0="\0_ec_inner",YE=1,Mg=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.init=function(t,a,n,i,o,s){i=i||{},this.option=null,this._theme=new Ot(i),this._locale=new Ot(o),this._optionManager=s},e.prototype.setOption=function(t,a,n){var i=M0(a);this._optionManager.setOption(t,n,i),this._resetOption(null,i)},e.prototype.resetOption=function(t,a){return this._resetOption(t,M0(a))},e.prototype._resetOption=function(t,a){var n=!1,i=this._optionManager;if(!t||t==="recreate"){var o=i.mountOption(t==="recreate");!this.option||t==="recreate"?T0(this,o):(this.restoreData(),this._mergeOption(o,a)),n=!0}if((t==="timeline"||t==="media")&&this.restoreData(),!t||t==="recreate"||t==="timeline"){var s=i.getTimelineOption(this);s&&(n=!0,this._mergeOption(s,a))}if(!t||t==="recreate"||t==="media"){var l=i.getMediaOption(this);l.length&&C(l,function(u){n=!0,this._mergeOption(u,a)},this)}return n},e.prototype.mergeOption=function(t){this._mergeOption(t,null)},e.prototype._mergeOption=function(t,a){var n=this.option,i=this._componentsMap,o=this._componentsCount,s=[],l=Z(),u=a&&a.replaceMergeMainTypeMap;zE(this),C(t,function(h,v){h!=null&&(Tt.hasClass(v)?v&&(s.push(v),l.set(v,!0)):n[v]=n[v]==null?rt(h):ft(n[v],h,!0))}),u&&u.each(function(h,v){Tt.hasClass(v)&&!l.get(v)&&(s.push(v),l.set(v,!0))}),Tt.topologicalTravel(s,Tt.getAllClassMainTypes(),f,this);function f(h){var v=HE(this,h,Pt(t[h])),c=i.get(h),p=c?u&&u.get(h)?"replaceMerge":"normalMerge":"replaceAll",d=Jb(c,v,p);fP(d,h,Tt),n[h]=null,i.set(h,null),o.set(h,0);var g=[],y=[],m=0,_;C(d,function(S,w){var x=S.existing,b=S.newOption;if(!b)x&&(x.mergeOption({},this),x.optionUpdated({},!1));else{var T=h==="series",A=Tt.getClass(h,S.keyInfo.subType,!T);if(!A)return;if(h==="tooltip"){if(_)return;_=!0}if(x&&x.constructor===A)x.name=S.keyInfo.name,x.mergeOption(b,this),x.optionUpdated(b,!1);else{var D=V({componentIndex:w},S.keyInfo);x=new A(b,this,this,D),V(x,D),S.brandNew&&(x.__requireNewView=!0),x.init(b,this,this),x.optionUpdated(null,!0)}}x?(g.push(x.option),y.push(x),m++):(g.push(void 0),y.push(void 0))},this),n[h]=g,i.set(h,y),o.set(h,m),h==="series"&&$l(this)}this._seriesIndices||$l(this)},e.prototype.getOption=function(){var t=rt(this.option);return C(t,function(a,n){if(Tt.hasClass(n)){for(var i=Pt(a),o=i.length,s=!1,l=o-1;l>=0;l--)i[l]&&!ks(i[l])?s=!0:(i[l]=null,!s&&o--);i.length=o,t[n]=i}}),delete t[A0],t},e.prototype.getTheme=function(){return this._theme},e.prototype.getLocaleModel=function(){return this._locale},e.prototype.setUpdatePayload=function(t){this._payload=t},e.prototype.getUpdatePayload=function(){return this._payload},e.prototype.getComponent=function(t,a){var n=this._componentsMap.get(t);if(n){var i=n[a||0];if(i)return i;if(a==null){for(var o=0;o<n.length;o++)if(n[o])return n[o]}}},e.prototype.queryComponents=function(t){var a=t.mainType;if(!a)return[];var n=t.index,i=t.id,o=t.name,s=this._componentsMap.get(a);if(!s||!s.length)return[];var l;return n!=null?(l=[],C(Pt(n),function(u){s[u]&&l.push(s[u])})):i!=null?l=C0("id",i,s):o!=null?l=C0("name",o,s):l=Lt(s,function(u){return!!u}),D0(l,t)},e.prototype.findComponents=function(t){var a=t.query,n=t.mainType,i=s(a),o=i?this.queryComponents(i):Lt(this._componentsMap.get(n),function(u){return!!u});return l(D0(o,t));function s(u){var f=n+"Index",h=n+"Id",v=n+"Name";return u&&(u[f]!=null||u[h]!=null||u[v]!=null)?{mainType:n,index:u[f],id:u[h],name:u[v]}:null}function l(u){return t.filter?Lt(u,t.filter):u}},e.prototype.eachComponent=function(t,a,n){var i=this._componentsMap;if(K(t)){var o=a,s=t;i.each(function(h,v){for(var c=0;h&&c<h.length;c++){var p=h[c];p&&s.call(o,v,p,p.componentIndex)}})}else for(var l=$(t)?i.get(t):tt(t)?this.findComponents(t):null,u=0;l&&u<l.length;u++){var f=l[u];f&&a.call(n,f,f.componentIndex)}},e.prototype.getSeriesByName=function(t){var a=Qt(t,null);return Lt(this._componentsMap.get("series"),function(n){return!!n&&a!=null&&n.name===a})},e.prototype.getSeriesByIndex=function(t){return this._componentsMap.get("series")[t]},e.prototype.getSeriesByType=function(t){return Lt(this._componentsMap.get("series"),function(a){return!!a&&a.subType===t})},e.prototype.getSeries=function(){return Lt(this._componentsMap.get("series"),function(t){return!!t})},e.prototype.getSeriesCount=function(){return this._componentsCount.get("series")},e.prototype.eachSeries=function(t,a){Eo(this),C(this._seriesIndices,function(n){var i=this._componentsMap.get("series")[n];t.call(a,i,n)},this)},e.prototype.eachRawSeries=function(t,a){C(this._componentsMap.get("series"),function(n){n&&t.call(a,n,n.componentIndex)})},e.prototype.eachSeriesByType=function(t,a,n){Eo(this),C(this._seriesIndices,function(i){var o=this._componentsMap.get("series")[i];o.subType===t&&a.call(n,o,i)},this)},e.prototype.eachRawSeriesByType=function(t,a,n){return C(this.getSeriesByType(t),a,n)},e.prototype.isSeriesFiltered=function(t){return Eo(this),this._seriesIndicesMap.get(t.componentIndex)==null},e.prototype.getCurrentSeriesIndices=function(){return(this._seriesIndices||[]).slice()},e.prototype.filterSeries=function(t,a){Eo(this);var n=[];C(this._seriesIndices,function(i){var o=this._componentsMap.get("series")[i];t.call(a,o,i)&&n.push(i)},this),this._seriesIndices=n,this._seriesIndicesMap=Z(n)},e.prototype.restoreData=function(t){$l(this);var a=this._componentsMap,n=[];a.each(function(i,o){Tt.hasClass(o)&&n.push(o)}),Tt.topologicalTravel(n,Tt.getAllClassMainTypes(),function(i){C(a.get(i),function(o){o&&(i!=="series"||!ZE(o,t))&&o.restoreData()})})},e.internalField=function(){$l=function(t){var a=t._seriesIndices=[];C(t._componentsMap.get("series"),function(n){n&&a.push(n.componentIndex)}),t._seriesIndicesMap=Z(a)},Eo=function(t){},T0=function(t,a){t.option={},t.option[A0]=YE,t._componentsMap=Z({series:[]}),t._componentsCount=Z();var n=a.aria;tt(n)&&n.enabled==null&&(n.enabled=!0),XE(a,t._theme.option),ft(a,VE,!1),t._mergeOption(a,null)}}(),e}(Ot);function ZE(r,e){if(e){var t=e.seriesIndex,a=e.seriesId,n=e.seriesName;return t!=null&&r.componentIndex!==t||a!=null&&r.id!==a||n!=null&&r.name!==n}}function XE(r,e){var t=r.color&&!r.colorLayer;C(e,function(a,n){n==="colorLayer"&&t||Tt.hasClass(n)||(typeof a=="object"?r[n]=r[n]?ft(r[n],a,!1):rt(a):r[n]==null&&(r[n]=a))})}function C0(r,e,t){if(z(e)){var a=Z();return C(e,function(i){if(i!=null){var o=Qt(i,null);o!=null&&a.set(i,!0)}}),Lt(t,function(i){return i&&a.get(i[r])})}else{var n=Qt(e,null);return Lt(t,function(i){return i&&n!=null&&i[r]===n})}}function D0(r,e){return e.hasOwnProperty("subType")?Lt(r,function(t){return t&&t.subType===e.subType}):r}function M0(r){var e=Z();return r&&C(Pt(r.replaceMerge),function(t){e.set(t,!0)}),{replaceMergeMainTypeMap:e}}Kt(Mg,Dg);var qE=["getDom","getZr","getWidth","getHeight","getDevicePixelRatio","dispatchAction","isSSR","isDisposed","on","off","getDataURL","getConnectedDataURL","getOption","getId","updateLabelLayout"],KE=function(){function r(e){C(qE,function(t){this[t]=U(e[t],e)},this)}return r}();const xA=KE;var yv={},fl=function(){function r(){this._coordinateSystems=[]}return r.prototype.create=function(e,t){var a=[];C(yv,function(n,i){var o=n.create(e,t);a=a.concat(o||[])}),this._coordinateSystems=a},r.prototype.update=function(e,t){C(this._coordinateSystems,function(a){a.update&&a.update(e,t)})},r.prototype.getCoordinateSystems=function(){return this._coordinateSystems.slice()},r.register=function(e,t){yv[e]=t},r.get=function(e){return yv[e]},r}(),QE=/^(min|max)?(.+)$/,JE=function(){function r(e){this._timelineOptions=[],this._mediaList=[],this._currentMediaIndices=[],this._api=e}return r.prototype.setOption=function(e,t,a){e&&(C(Pt(e.series),function(o){o&&o.data&&Ne(o.data)&&Xu(o.data)}),C(Pt(e.dataset),function(o){o&&o.source&&Ne(o.source)&&Xu(o.source)})),e=rt(e);var n=this._optionBackup,i=jE(e,t,!n);this._newBaseOption=i.baseOption,n?(i.timelineOptions.length&&(n.timelineOptions=i.timelineOptions),i.mediaList.length&&(n.mediaList=i.mediaList),i.mediaDefault&&(n.mediaDefault=i.mediaDefault)):this._optionBackup=i},r.prototype.mountOption=function(e){var t=this._optionBackup;return this._timelineOptions=t.timelineOptions,this._mediaList=t.mediaList,this._mediaDefault=t.mediaDefault,this._currentMediaIndices=[],rt(e?t.baseOption:this._newBaseOption)},r.prototype.getTimelineOption=function(e){var t,a=this._timelineOptions;if(a.length){var n=e.getComponent("timeline");n&&(t=rt(a[n.getCurrentIndex()]))}return t},r.prototype.getMediaOption=function(e){var t=this._api.getWidth(),a=this._api.getHeight(),n=this._mediaList,i=this._mediaDefault,o=[],s=[];if(!n.length&&!i)return s;for(var l=0,u=n.length;l<u;l++)tk(n[l].query,t,a)&&o.push(l);return!o.length&&i&&(o=[-1]),o.length&&!rk(o,this._currentMediaIndices)&&(s=G(o,function(f){return rt(f===-1?i.option:n[f].option)})),this._currentMediaIndices=o,s},r}();function jE(r,e,t){var a=[],n,i,o=r.baseOption,s=r.timeline,l=r.options,u=r.media,f=!!r.media,h=!!(l||s||o&&o.timeline);o?(i=o,i.timeline||(i.timeline=s)):((h||f)&&(r.options=r.media=null),i=r),f&&z(u)&&C(u,function(c){c&&c.option&&(c.query?a.push(c):n||(n=c))}),v(i),C(l,function(c){return v(c)}),C(a,function(c){return v(c.option)});function v(c){C(e,function(p){p(c,t)})}return{baseOption:i,timelineOptions:l||[],mediaDefault:n,mediaList:a}}function tk(r,e,t){var a={width:e,height:t,aspectratio:e/t},n=!0;return C(r,function(i,o){var s=o.match(QE);if(!(!s||!s[1]||!s[2])){var l=s[1],u=s[2].toLowerCase();ek(a[u],i,l)||(n=!1)}}),n}function ek(r,e,t){return t==="min"?r>=e:t==="max"?r<=e:r===e}function rk(r,e){return r.join(",")===e.join(",")}const ak=JE;var ur=C,Fs=tt,I0=["areaStyle","lineStyle","nodeStyle","linkStyle","chordStyle","label","labelLine"];function mv(r){var e=r&&r.itemStyle;if(e)for(var t=0,a=I0.length;t<a;t++){var n=I0[t],i=e.normal,o=e.emphasis;i&&i[n]&&(r[n]=r[n]||{},r[n].normal?ft(r[n].normal,i[n]):r[n].normal=i[n],i[n]=null),o&&o[n]&&(r[n]=r[n]||{},r[n].emphasis?ft(r[n].emphasis,o[n]):r[n].emphasis=o[n],o[n]=null)}}function de(r,e,t){if(r&&r[e]&&(r[e].normal||r[e].emphasis)){var a=r[e].normal,n=r[e].emphasis;a&&(t?(r[e].normal=r[e].emphasis=null,j(r[e],a)):r[e]=a),n&&(r.emphasis=r.emphasis||{},r.emphasis[e]=n,n.focus&&(r.emphasis.focus=n.focus),n.blurScope&&(r.emphasis.blurScope=n.blurScope))}}function os(r){de(r,"itemStyle"),de(r,"lineStyle"),de(r,"areaStyle"),de(r,"label"),de(r,"labelLine"),de(r,"upperLabel"),de(r,"edgeLabel")}function Zt(r,e){var t=Fs(r)&&r[e],a=Fs(t)&&t.textStyle;if(a)for(var n=0,i=Om.length;n<i;n++){var o=Om[n];a.hasOwnProperty(o)&&(t[o]=a[o])}}function Ke(r){r&&(os(r),Zt(r,"label"),r.emphasis&&Zt(r.emphasis,"label"))}function nk(r){if(Fs(r)){mv(r),os(r),Zt(r,"label"),Zt(r,"upperLabel"),Zt(r,"edgeLabel"),r.emphasis&&(Zt(r.emphasis,"label"),Zt(r.emphasis,"upperLabel"),Zt(r.emphasis,"edgeLabel"));var e=r.markPoint;e&&(mv(e),Ke(e));var t=r.markLine;t&&(mv(t),Ke(t));var a=r.markArea;a&&Ke(a);var n=r.data;if(r.type==="graph"){n=n||r.nodes;var i=r.links||r.edges;if(i&&!Ne(i))for(var o=0;o<i.length;o++)Ke(i[o]);C(r.categories,function(u){os(u)})}if(n&&!Ne(n))for(var o=0;o<n.length;o++)Ke(n[o]);if(e=r.markPoint,e&&e.data)for(var s=e.data,o=0;o<s.length;o++)Ke(s[o]);if(t=r.markLine,t&&t.data)for(var l=t.data,o=0;o<l.length;o++)z(l[o])?(Ke(l[o][0]),Ke(l[o][1])):Ke(l[o]);r.type==="gauge"?(Zt(r,"axisLabel"),Zt(r,"title"),Zt(r,"detail")):r.type==="treemap"?(de(r.breadcrumb,"itemStyle"),C(r.levels,function(u){os(u)})):r.type==="tree"&&os(r.leaves)}}function Xr(r){return z(r)?r:r?[r]:[]}function L0(r){return(z(r)?r[0]:r)||{}}function ik(r,e){ur(Xr(r.series),function(a){Fs(a)&&nk(a)});var t=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","parallelAxis","radar"];e&&t.push("valueAxis","categoryAxis","logAxis","timeAxis"),ur(t,function(a){ur(Xr(r[a]),function(n){n&&(Zt(n,"axisLabel"),Zt(n.axisPointer,"label"))})}),ur(Xr(r.parallel),function(a){var n=a&&a.parallelAxisDefault;Zt(n,"axisLabel"),Zt(n&&n.axisPointer,"label")}),ur(Xr(r.calendar),function(a){de(a,"itemStyle"),Zt(a,"dayLabel"),Zt(a,"monthLabel"),Zt(a,"yearLabel")}),ur(Xr(r.radar),function(a){Zt(a,"name"),a.name&&a.axisName==null&&(a.axisName=a.name,delete a.name),a.nameGap!=null&&a.axisNameGap==null&&(a.axisNameGap=a.nameGap,delete a.nameGap)}),ur(Xr(r.geo),function(a){Fs(a)&&(Ke(a),ur(Xr(a.regions),function(n){Ke(n)}))}),ur(Xr(r.timeline),function(a){Ke(a),de(a,"label"),de(a,"itemStyle"),de(a,"controlStyle",!0);var n=a.data;z(n)&&C(n,function(i){tt(i)&&(de(i,"label"),de(i,"itemStyle"))})}),ur(Xr(r.toolbox),function(a){de(a,"iconStyle"),ur(a.feature,function(n){de(n,"iconStyle")})}),Zt(L0(r.axisPointer),"label"),Zt(L0(r.tooltip).axisPointer,"label")}function ok(r,e){for(var t=e.split(","),a=r,n=0;n<t.length&&(a=a&&a[t[n]],a!=null);n++);return a}function sk(r,e,t,a){for(var n=e.split(","),i=r,o,s=0;s<n.length-1;s++)o=n[s],i[o]==null&&(i[o]={}),i=i[o];(a||i[n[s]]==null)&&(i[n[s]]=t)}function P0(r){r&&C(lk,function(e){e[0]in r&&!(e[1]in r)&&(r[e[1]]=r[e[0]])})}var lk=[["x","left"],["y","top"],["x2","right"],["y2","bottom"]],uk=["grid","geo","parallel","legend","toolbox","title","visualMap","dataZoom","timeline"],_v=[["borderRadius","barBorderRadius"],["borderColor","barBorderColor"],["borderWidth","barBorderWidth"]];function ko(r){var e=r&&r.itemStyle;if(e)for(var t=0;t<_v.length;t++){var a=_v[t][1],n=_v[t][0];e[a]!=null&&(e[n]=e[a])}}function R0(r){r&&r.alignTo==="edge"&&r.margin!=null&&r.edgeDistance==null&&(r.edgeDistance=r.margin)}function E0(r){r&&r.downplay&&!r.blur&&(r.blur=r.downplay)}function fk(r){r&&r.focusNodeAdjacency!=null&&(r.emphasis=r.emphasis||{},r.emphasis.focus==null&&(r.emphasis.focus="adjacency"))}function wA(r,e){if(r)for(var t=0;t<r.length;t++)e(r[t]),r[t]&&wA(r[t].children,e)}function bA(r,e){ik(r,e),r.series=Pt(r.series),C(r.series,function(t){if(tt(t)){var a=t.type;if(a==="line")t.clipOverflow!=null&&(t.clip=t.clipOverflow);else if(a==="pie"||a==="gauge"){t.clockWise!=null&&(t.clockwise=t.clockWise),R0(t.label);var n=t.data;if(n&&!Ne(n))for(var i=0;i<n.length;i++)R0(n[i]);t.hoverOffset!=null&&(t.emphasis=t.emphasis||{},(t.emphasis.scaleSize=null)&&(t.emphasis.scaleSize=t.hoverOffset))}else if(a==="gauge"){var o=ok(t,"pointer.color");o!=null&&sk(t,"itemStyle.color",o)}else if(a==="bar"){ko(t),ko(t.backgroundStyle),ko(t.emphasis);var n=t.data;if(n&&!Ne(n))for(var i=0;i<n.length;i++)typeof n[i]=="object"&&(ko(n[i]),ko(n[i]&&n[i].emphasis))}else if(a==="sunburst"){var s=t.highlightPolicy;s&&(t.emphasis=t.emphasis||{},t.emphasis.focus||(t.emphasis.focus=s)),E0(t),wA(t.data,E0)}else a==="graph"||a==="sankey"?fk(t):a==="map"&&(t.mapType&&!t.map&&(t.map=t.mapType),t.mapLocation&&j(t,t.mapLocation));t.hoverAnimation!=null&&(t.emphasis=t.emphasis||{},t.emphasis&&t.emphasis.scale==null&&(t.emphasis.scale=t.hoverAnimation)),P0(t)}}),r.dataRange&&(r.visualMap=r.dataRange),C(uk,function(t){var a=r[t];a&&(z(a)||(a=[a]),C(a,function(n){P0(n)}))})}function hk(r){var e=Z();r.eachSeries(function(t){var a=t.get("stack");if(a){var n=e.get(a)||e.set(a,[]),i=t.getData(),o={stackResultDimension:i.getCalculationInfo("stackResultDimension"),stackedOverDimension:i.getCalculationInfo("stackedOverDimension"),stackedDimension:i.getCalculationInfo("stackedDimension"),stackedByDimension:i.getCalculationInfo("stackedByDimension"),isStackedByIndex:i.getCalculationInfo("isStackedByIndex"),data:i,seriesModel:t};if(!o.stackedDimension||!(o.isStackedByIndex||o.stackedByDimension))return;n.length&&i.setCalculationInfo("stackedOnSeries",n[n.length-1].seriesModel),n.push(o)}}),e.each(vk)}function vk(r){C(r,function(e,t){var a=[],n=[NaN,NaN],i=[e.stackResultDimension,e.stackedOverDimension],o=e.data,s=e.isStackedByIndex,l=e.seriesModel.get("stackStrategy")||"samesign";o.modify(i,function(u,f,h){var v=o.get(e.stackedDimension,h);if(isNaN(v))return n;var c,p;s?p=o.getRawIndex(h):c=o.get(e.stackedByDimension,h);for(var d=NaN,g=t-1;g>=0;g--){var y=r[g];if(s||(p=y.data.rawIndexOf(y.stackedByDimension,c)),p>=0){var m=y.data.getByRawIndex(y.stackResultDimension,p);if(l==="all"||l==="positive"&&m>0||l==="negative"&&m<0||l==="samesign"&&v>=0&&m>0||l==="samesign"&&v<=0&&m<0){v=j2(v,m),d=m;break}}}return a[0]=v,a[1]=d,a})})}var vh=function(){function r(e){this.data=e.data||(e.sourceFormat===$r?{}:[]),this.sourceFormat=e.sourceFormat||dA,this.seriesLayoutBy=e.seriesLayoutBy||Vr,this.startIndex=e.startIndex||0,this.dimensionsDetectedCount=e.dimensionsDetectedCount,this.metaRawOption=e.metaRawOption;var t=this.dimensionsDefine=e.dimensionsDefine;if(t)for(var a=0;a<t.length;a++){var n=t[a];n.type==null&&mA(this,a)===oe.Must&&(n.type="ordinal")}}return r}();function Ig(r){return r instanceof vh}function Gp(r,e,t){t=t||TA(r);var a=e.seriesLayoutBy,n=pk(r,t,a,e.sourceHeader,e.dimensions),i=new vh({data:r,sourceFormat:t,seriesLayoutBy:a,dimensionsDefine:n.dimensionsDefine,startIndex:n.startIndex,dimensionsDetectedCount:n.dimensionsDetectedCount,metaRawOption:rt(e)});return i}function Lg(r){return new vh({data:r,sourceFormat:Ne(r)?Va:sr})}function ck(r){return new vh({data:r.data,sourceFormat:r.sourceFormat,seriesLayoutBy:r.seriesLayoutBy,dimensionsDefine:rt(r.dimensionsDefine),startIndex:r.startIndex,dimensionsDetectedCount:r.dimensionsDetectedCount})}function TA(r){var e=dA;if(Ne(r))e=Va;else if(z(r)){r.length===0&&(e=ye);for(var t=0,a=r.length;t<a;t++){var n=r[t];if(n!=null){if(z(n)||Ne(n)){e=ye;break}else if(tt(n)){e=lr;break}}}}else if(tt(r)){for(var i in r)if(Y(r,i)&&ge(r[i])){e=$r;break}}return e}function pk(r,e,t,a,n){var i,o;if(!r)return{dimensionsDefine:k0(n),startIndex:o,dimensionsDetectedCount:i};if(e===ye){var s=r;a==="auto"||a==null?O0(function(u){u!=null&&u!=="-"&&($(u)?o==null&&(o=1):o=0)},t,s,10):o=Ct(a)?a:a?1:0,!n&&o===1&&(n=[],O0(function(u,f){n[f]=u!=null?u+"":""},t,s,1/0)),i=n?n.length:t===So?s.length:s[0]?s[0].length:null}else if(e===lr)n||(n=dk(r));else if(e===$r)n||(n=[],C(r,function(u,f){n.push(f)}));else if(e===sr){var l=uo(r[0]);i=z(l)&&l.length||1}return{startIndex:o,dimensionsDefine:k0(n),dimensionsDetectedCount:i}}function dk(r){for(var e=0,t;e<r.length&&!(t=r[e++]););if(t)return _t(t)}function k0(r){if(r){var e=Z();return G(r,function(t,a){t=tt(t)?t:{name:t};var n={name:t.name,displayName:t.displayName,type:t.type};if(n.name==null)return n;n.name+="",n.displayName==null&&(n.displayName=n.name);var i=e.get(n.name);return i?n.name+="-"+i.count++:e.set(n.name,{count:1}),n})}}function O0(r,e,t,a){if(e===So)for(var n=0;n<t.length&&n<a;n++)r(t[n]?t[n][0]:null,n);else for(var i=t[0]||[],n=0;n<i.length&&n<a;n++)r(i[n],n)}function AA(r){var e=r.sourceFormat;return e===lr||e===$r}var yn,mn,_n,N0,B0,CA=function(){function r(e,t){var a=Ig(e)?e:Lg(e);this._source=a;var n=this._data=a.data;a.sourceFormat===Va&&(this._offset=0,this._dimSize=t,this._data=n),B0(this,n,a)}return r.prototype.getSource=function(){return this._source},r.prototype.count=function(){return 0},r.prototype.getItem=function(e,t){},r.prototype.appendData=function(e){},r.prototype.clean=function(){},r.protoInitialize=function(){var e=r.prototype;e.pure=!1,e.persistent=!0}(),r.internalField=function(){var e;B0=function(o,s,l){var u=l.sourceFormat,f=l.seriesLayoutBy,h=l.startIndex,v=l.dimensionsDefine,c=N0[Pg(u,f)];if(V(o,c),u===Va)o.getItem=t,o.count=n,o.fillStorage=a;else{var p=DA(u,f);o.getItem=U(p,null,s,h,v);var d=MA(u,f);o.count=U(d,null,s,h,v)}};var t=function(o,s){o=o-this._offset,s=s||[];for(var l=this._data,u=this._dimSize,f=u*o,h=0;h<u;h++)s[h]=l[f+h];return s},a=function(o,s,l,u){for(var f=this._data,h=this._dimSize,v=0;v<h;v++){for(var c=u[v],p=c[0]==null?1/0:c[0],d=c[1]==null?-1/0:c[1],g=s-o,y=l[v],m=0;m<g;m++){var _=f[m*h+v];y[o+m]=_,_<p&&(p=_),_>d&&(d=_)}c[0]=p,c[1]=d}},n=function(){return this._data?this._data.length/this._dimSize:0};N0=(e={},e[ye+"_"+Vr]={pure:!0,appendData:i},e[ye+"_"+So]={pure:!0,appendData:function(){throw new Error('Do not support appendData when set seriesLayoutBy: "row".')}},e[lr]={pure:!0,appendData:i},e[$r]={pure:!0,appendData:function(o){var s=this._data;C(o,function(l,u){for(var f=s[u]||(s[u]=[]),h=0;h<(l||[]).length;h++)f.push(l[h])})}},e[sr]={appendData:i},e[Va]={persistent:!1,pure:!0,appendData:function(o){this._data=o},clean:function(){this._offset+=this.count(),this._data=null}},e);function i(o){for(var s=0;s<o.length;s++)this._data.push(o[s])}}(),r}(),V0=function(r,e,t,a){return r[a]},gk=(yn={},yn[ye+"_"+Vr]=function(r,e,t,a){return r[a+e]},yn[ye+"_"+So]=function(r,e,t,a,n){a+=e;for(var i=n||[],o=r,s=0;s<o.length;s++){var l=o[s];i[s]=l?l[a]:null}return i},yn[lr]=V0,yn[$r]=function(r,e,t,a,n){for(var i=n||[],o=0;o<t.length;o++){var s=t[o].name,l=r[s];i[o]=l?l[a]:null}return i},yn[sr]=V0,yn);function DA(r,e){var t=gk[Pg(r,e)];return t}var z0=function(r,e,t){return r.length},yk=(mn={},mn[ye+"_"+Vr]=function(r,e,t){return Math.max(0,r.length-e)},mn[ye+"_"+So]=function(r,e,t){var a=r[0];return a?Math.max(0,a.length-e):0},mn[lr]=z0,mn[$r]=function(r,e,t){var a=t[0].name,n=r[a];return n?n.length:0},mn[sr]=z0,mn);function MA(r,e){var t=yk[Pg(r,e)];return t}var Sv=function(r,e,t){return r[e]},mk=(_n={},_n[ye]=Sv,_n[lr]=function(r,e,t){return r[t]},_n[$r]=Sv,_n[sr]=function(r,e,t){var a=uo(r);return a instanceof Array?a[e]:a},_n[Va]=Sv,_n);function IA(r){var e=mk[r];return e}function Pg(r,e){return r===ye?r+"_"+e:r}function Ji(r,e,t){if(r){var a=r.getRawDataItem(e);if(a!=null){var n=r.getStore(),i=n.getSource().sourceFormat;if(t!=null){var o=r.getDimensionIndex(t),s=n.getDimensionProperty(o);return IA(i)(a,o,s)}else{var l=a;return i===sr&&(l=uo(a)),l}}}}var _k=/\{@(.+?)\}/g,Rg=function(){function r(){}return r.prototype.getDataParams=function(e,t){var a=this.getData(t),n=this.getRawValue(e,t),i=a.getRawIndex(e),o=a.getName(e),s=a.getRawDataItem(e),l=a.getItemVisual(e,"style"),u=l&&l[a.getItemVisual(e,"drawType")||"fill"],f=l&&l.stroke,h=this.mainType,v=h==="series",c=a.userOutput&&a.userOutput.get();return{componentType:h,componentSubType:this.subType,componentIndex:this.componentIndex,seriesType:v?this.subType:null,seriesIndex:this.seriesIndex,seriesId:v?this.id:null,seriesName:v?this.name:null,name:o,dataIndex:i,data:s,dataType:t,value:n,color:u,borderColor:f,dimensionNames:c?c.fullDimensions:null,encode:c?c.encode:null,$vars:["seriesName","name","value"]}},r.prototype.getFormattedLabel=function(e,t,a,n,i,o){t=t||"normal";var s=this.getData(a),l=this.getDataParams(e,a);if(o&&(l.value=o.interpolatedValue),n!=null&&z(l.value)&&(l.value=l.value[n]),!i){var u=s.getItemModel(e);i=u.get(t==="normal"?["label","formatter"]:[t,"label","formatter"])}if(K(i))return l.status=t,l.dimensionIndex=n,i(l);if($(i)){var f=fA(i,l);return f.replace(_k,function(h,v){var c=v.length,p=v;p.charAt(0)==="["&&p.charAt(c-1)==="]"&&(p=+p.slice(1,c-1));var d=Ji(s,e,p);if(o&&z(o.interpolatedValue)){var g=s.getDimensionIndex(p);g>=0&&(d=o.interpolatedValue[g])}return d!=null?d+"":""})}},r.prototype.getRawValue=function(e,t){return Ji(this.getData(t),e)},r.prototype.formatTooltip=function(e,t,a){},r}();function G0(r){var e,t;return tt(r)?r.type&&(t=r):e=r,{text:e,frag:t}}function ws(r){return new Sk(r)}var Sk=function(){function r(e){e=e||{},this._reset=e.reset,this._plan=e.plan,this._count=e.count,this._onDirty=e.onDirty,this._dirty=!0}return r.prototype.perform=function(e){var t=this._upstream,a=e&&e.skip;if(this._dirty&&t){var n=this.context;n.data=n.outputData=t.context.outputData}this.__pipeline&&(this.__pipeline.currentTask=this);var i;this._plan&&!a&&(i=this._plan(this.context));var o=f(this._modBy),s=this._modDataCount||0,l=f(e&&e.modBy),u=e&&e.modDataCount||0;(o!==l||s!==u)&&(i="reset");function f(m){return!(m>=1)&&(m=1),m}var h;(this._dirty||i==="reset")&&(this._dirty=!1,h=this._doReset(a)),this._modBy=l,this._modDataCount=u;var v=e&&e.step;if(t?this._dueEnd=t._outputDueEnd:this._dueEnd=this._count?this._count(this.context):1/0,this._progress){var c=this._dueIndex,p=Math.min(v!=null?this._dueIndex+v:1/0,this._dueEnd);if(!a&&(h||c<p)){var d=this._progress;if(z(d))for(var g=0;g<d.length;g++)this._doProgress(d[g],c,p,l,u);else this._doProgress(d,c,p,l,u)}this._dueIndex=p;var y=this._settedOutputEnd!=null?this._settedOutputEnd:p;this._outputDueEnd=y}else this._dueIndex=this._outputDueEnd=this._settedOutputEnd!=null?this._settedOutputEnd:this._dueEnd;return this.unfinished()},r.prototype.dirty=function(){this._dirty=!0,this._onDirty&&this._onDirty(this.context)},r.prototype._doProgress=function(e,t,a,n,i){F0.reset(t,a,n,i),this._callingProgress=e,this._callingProgress({start:t,end:a,count:a-t,next:F0.next},this.context)},r.prototype._doReset=function(e){this._dueIndex=this._outputDueEnd=this._dueEnd=0,this._settedOutputEnd=null;var t,a;!e&&this._reset&&(t=this._reset(this.context),t&&t.progress&&(a=t.forceFirstProgress,t=t.progress),z(t)&&!t.length&&(t=null)),this._progress=t,this._modBy=this._modDataCount=null;var n=this._downstream;return n&&n.dirty(),a},r.prototype.unfinished=function(){return this._progress&&this._dueIndex<this._dueEnd},r.prototype.pipe=function(e){(this._downstream!==e||this._dirty)&&(this._downstream=e,e._upstream=this,e.dirty())},r.prototype.dispose=function(){this._disposed||(this._upstream&&(this._upstream._downstream=null),this._downstream&&(this._downstream._upstream=null),this._dirty=!1,this._disposed=!0)},r.prototype.getUpstream=function(){return this._upstream},r.prototype.getDownstream=function(){return this._downstream},r.prototype.setOutputEnd=function(e){this._outputDueEnd=this._settedOutputEnd=e},r}(),F0=function(){var r,e,t,a,n,i={reset:function(l,u,f,h){e=l,r=u,t=f,a=h,n=Math.ceil(a/t),i.next=t>1&&a>0?s:o}};return i;function o(){return e<r?e++:null}function s(){var l=e%n*t+Math.ceil(e/n),u=e>=r?null:l<a?l:e;return e++,u}}();function za(r,e){var t=e&&e.type;return t==="ordinal"?r:(t==="time"&&!Ct(r)&&r!=null&&r!=="-"&&(r=+Hr(r)),r==null||r===""?NaN:+r)}var xk=Z({number:function(r){return parseFloat(r)},time:function(r){return+Hr(r)},trim:function(r){return $(r)?dr(r):r}});function LA(r){return xk.get(r)}var PA={lt:function(r,e){return r<e},lte:function(r,e){return r<=e},gt:function(r,e){return r>e},gte:function(r,e){return r>=e}},wk=function(){function r(e,t){if(!Ct(t)){var a="";Mt(a)}this._opFn=PA[e],this._rvalFloat=oa(t)}return r.prototype.evaluate=function(e){return Ct(e)?this._opFn(e,this._rvalFloat):this._opFn(oa(e),this._rvalFloat)},r}(),RA=function(){function r(e,t){var a=e==="desc";this._resultLT=a?1:-1,t==null&&(t=a?"min":"max"),this._incomparable=t==="min"?-1/0:1/0}return r.prototype.evaluate=function(e,t){var a=Ct(e)?e:oa(e),n=Ct(t)?t:oa(t),i=isNaN(a),o=isNaN(n);if(i&&(a=this._incomparable),o&&(n=this._incomparable),i&&o){var s=$(e),l=$(t);s&&(a=l?e:0),l&&(n=s?t:0)}return a<n?this._resultLT:a>n?-this._resultLT:0},r}(),bk=function(){function r(e,t){this._rval=t,this._isEQ=e,this._rvalTypeof=typeof t,this._rvalFloat=oa(t)}return r.prototype.evaluate=function(e){var t=e===this._rval;if(!t){var a=typeof e;a!==this._rvalTypeof&&(a==="number"||this._rvalTypeof==="number")&&(t=oa(e)===this._rvalFloat)}return this._isEQ?t:!t},r}();function Tk(r,e){return r==="eq"||r==="ne"?new bk(r==="eq",e):Y(PA,r)?new wk(r,e):null}var Ak=function(){function r(){}return r.prototype.getRawData=function(){throw new Error("not supported")},r.prototype.getRawDataItem=function(e){throw new Error("not supported")},r.prototype.cloneRawData=function(){},r.prototype.getDimensionInfo=function(e){},r.prototype.cloneAllDimensionInfo=function(){},r.prototype.count=function(){},r.prototype.retrieveValue=function(e,t){},r.prototype.retrieveValueFromItem=function(e,t){},r.prototype.convertValue=function(e,t){return za(e,t)},r}();function Ck(r,e){var t=new Ak,a=r.data,n=t.sourceFormat=r.sourceFormat,i=r.startIndex,o="";r.seriesLayoutBy!==Vr&&Mt(o);var s=[],l={},u=r.dimensionsDefine;if(u)C(u,function(d,g){var y=d.name,m={index:g,name:y,displayName:d.displayName};if(s.push(m),y!=null){var _="";Y(l,y)&&Mt(_),l[y]=m}});else for(var f=0;f<r.dimensionsDetectedCount;f++)s.push({index:f});var h=DA(n,Vr);e.__isBuiltIn&&(t.getRawDataItem=function(d){return h(a,i,s,d)},t.getRawData=U(Dk,null,r)),t.cloneRawData=U(Mk,null,r);var v=MA(n,Vr);t.count=U(v,null,a,i,s);var c=IA(n);t.retrieveValue=function(d,g){var y=h(a,i,s,d);return p(y,g)};var p=t.retrieveValueFromItem=function(d,g){if(d!=null){var y=s[g];if(y)return c(d,g,y.name)}};return t.getDimensionInfo=U(Ik,null,s,l),t.cloneAllDimensionInfo=U(Lk,null,s),t}function Dk(r){var e=r.sourceFormat;if(!Eg(e)){var t="";Mt(t)}return r.data}function Mk(r){var e=r.sourceFormat,t=r.data;if(!Eg(e)){var a="";Mt(a)}if(e===ye){for(var n=[],i=0,o=t.length;i<o;i++)n.push(t[i].slice());return n}else if(e===lr){for(var n=[],i=0,o=t.length;i<o;i++)n.push(V({},t[i]));return n}}function Ik(r,e,t){if(t!=null){if(Ct(t)||!isNaN(t)&&!Y(e,t))return r[t];if(Y(e,t))return e[t]}}function Lk(r){return rt(r)}var EA=Z();function Pk(r){r=rt(r);var e=r.type,t="";e||Mt(t);var a=e.split(":");a.length!==2&&Mt(t);var n=!1;a[0]==="echarts"&&(e=a[1],n=!0),r.__isBuiltIn=n,EA.set(e,r)}function Rk(r,e,t){var a=Pt(r),n=a.length,i="";n||Mt(i);for(var o=0,s=n;o<s;o++){var l=a[o];e=Ek(l,e),o!==s-1&&(e.length=Math.max(e.length,1))}return e}function Ek(r,e,t,a){var n="";e.length||Mt(n),tt(r)||Mt(n);var i=r.type,o=EA.get(i);o||Mt(n);var s=G(e,function(u){return Ck(u,o)}),l=Pt(o.transform({upstream:s[0],upstreamList:s,config:rt(r.config)}));return G(l,function(u,f){var h="";tt(u)||Mt(h),u.data||Mt(h);var v=TA(u.data);Eg(v)||Mt(h);var c,p=e[0];if(p&&f===0&&!u.dimensions){var d=p.startIndex;d&&(u.data=p.data.slice(0,d).concat(u.data)),c={seriesLayoutBy:Vr,sourceHeader:d,dimensions:p.metaRawOption.dimensions}}else c={seriesLayoutBy:Vr,sourceHeader:0,dimensions:u.dimensions};return Gp(u.data,c,null)})}function Eg(r){return r===ye||r===lr}var ch="undefined",kk=typeof Uint32Array===ch?Array:Uint32Array,Ok=typeof Uint16Array===ch?Array:Uint16Array,kA=typeof Int32Array===ch?Array:Int32Array,H0=typeof Float64Array===ch?Array:Float64Array,OA={float:H0,int:kA,ordinal:Array,number:Array,time:H0},xv;function Oo(r){return r>65535?kk:Ok}function wi(){return[1/0,-1/0]}function Nk(r){var e=r.constructor;return e===Array?r.slice():new e(r)}function W0(r,e,t,a,n){var i=OA[t||"float"];if(n){var o=r[e],s=o&&o.length;if(s!==a){for(var l=new i(a),u=0;u<s;u++)l[u]=o[u];r[e]=l}}else r[e]=new i(a)}var Fp=function(){function r(){this._chunks=[],this._rawExtent=[],this._extent=[],this._count=0,this._rawCount=0,this._calcDimNameToIdx=Z()}return r.prototype.initData=function(e,t,a){this._provider=e,this._chunks=[],this._indices=null,this.getRawIndex=this._getRawIdxIdentity;var n=e.getSource(),i=this.defaultDimValueGetter=xv[n.sourceFormat];this._dimValueGetter=a||i,this._rawExtent=[],AA(n),this._dimensions=G(t,function(o){return{type:o.type,property:o.property}}),this._initDataFromProvider(0,e.count())},r.prototype.getProvider=function(){return this._provider},r.prototype.getSource=function(){return this._provider.getSource()},r.prototype.ensureCalculationDimension=function(e,t){var a=this._calcDimNameToIdx,n=this._dimensions,i=a.get(e);if(i!=null){if(n[i].type===t)return i}else i=n.length;return n[i]={type:t},a.set(e,i),this._chunks[i]=new OA[t||"float"](this._rawCount),this._rawExtent[i]=wi(),i},r.prototype.collectOrdinalMeta=function(e,t){var a=this._chunks[e],n=this._dimensions[e],i=this._rawExtent,o=n.ordinalOffset||0,s=a.length;o===0&&(i[e]=wi());for(var l=i[e],u=o;u<s;u++){var f=a[u]=t.parseAndCollect(a[u]);isNaN(f)||(l[0]=Math.min(f,l[0]),l[1]=Math.max(f,l[1]))}n.ordinalMeta=t,n.ordinalOffset=s,n.type="ordinal"},r.prototype.getOrdinalMeta=function(e){var t=this._dimensions[e],a=t.ordinalMeta;return a},r.prototype.getDimensionProperty=function(e){var t=this._dimensions[e];return t&&t.property},r.prototype.appendData=function(e){var t=this._provider,a=this.count();t.appendData(e);var n=t.count();return t.persistent||(n+=a),a<n&&this._initDataFromProvider(a,n,!0),[a,n]},r.prototype.appendValues=function(e,t){for(var a=this._chunks,n=this._dimensions,i=n.length,o=this._rawExtent,s=this.count(),l=s+Math.max(e.length,t||0),u=0;u<i;u++){var f=n[u];W0(a,u,f.type,l,!0)}for(var h=[],v=s;v<l;v++)for(var c=v-s,p=0;p<i;p++){var f=n[p],d=xv.arrayRows.call(this,e[c]||h,f.property,c,p);a[p][v]=d;var g=o[p];d<g[0]&&(g[0]=d),d>g[1]&&(g[1]=d)}return this._rawCount=this._count=l,{start:s,end:l}},r.prototype._initDataFromProvider=function(e,t,a){for(var n=this._provider,i=this._chunks,o=this._dimensions,s=o.length,l=this._rawExtent,u=G(o,function(m){return m.property}),f=0;f<s;f++){var h=o[f];l[f]||(l[f]=wi()),W0(i,f,h.type,t,a)}if(n.fillStorage)n.fillStorage(e,t,i,l);else for(var v=[],c=e;c<t;c++){v=n.getItem(c,v);for(var p=0;p<s;p++){var d=i[p],g=this._dimValueGetter(v,u[p],c,p);d[c]=g;var y=l[p];g<y[0]&&(y[0]=g),g>y[1]&&(y[1]=g)}}!n.persistent&&n.clean&&n.clean(),this._rawCount=this._count=t,this._extent=[]},r.prototype.count=function(){return this._count},r.prototype.get=function(e,t){if(!(t>=0&&t<this._count))return NaN;var a=this._chunks[e];return a?a[this.getRawIndex(t)]:NaN},r.prototype.getValues=function(e,t){var a=[],n=[];if(t==null){t=e,e=[];for(var i=0;i<this._dimensions.length;i++)n.push(i)}else n=e;for(var i=0,o=n.length;i<o;i++)a.push(this.get(n[i],t));return a},r.prototype.getByRawIndex=function(e,t){if(!(t>=0&&t<this._rawCount))return NaN;var a=this._chunks[e];return a?a[t]:NaN},r.prototype.getSum=function(e){var t=this._chunks[e],a=0;if(t)for(var n=0,i=this.count();n<i;n++){var o=this.get(e,n);isNaN(o)||(a+=o)}return a},r.prototype.getMedian=function(e){var t=[];this.each([e],function(i){isNaN(i)||t.push(i)});var a=t.sort(function(i,o){return i-o}),n=this.count();return n===0?0:n%2===1?a[(n-1)/2]:(a[n/2]+a[n/2-1])/2},r.prototype.indexOfRawIndex=function(e){if(e>=this._rawCount||e<0)return-1;if(!this._indices)return e;var t=this._indices,a=t[e];if(a!=null&&a<this._count&&a===e)return e;for(var n=0,i=this._count-1;n<=i;){var o=(n+i)/2|0;if(t[o]<e)n=o+1;else if(t[o]>e)i=o-1;else return o}return-1},r.prototype.indicesOfNearest=function(e,t,a){var n=this._chunks,i=n[e],o=[];if(!i)return o;a==null&&(a=1/0);for(var s=1/0,l=-1,u=0,f=0,h=this.count();f<h;f++){var v=this.getRawIndex(f),c=t-i[v],p=Math.abs(c);p<=a&&((p<s||p===s&&c>=0&&l<0)&&(s=p,l=c,u=0),c===l&&(o[u++]=f))}return o.length=u,o},r.prototype.getIndices=function(){var e,t=this._indices;if(t){var a=t.constructor,n=this._count;if(a===Array){e=new a(n);for(var i=0;i<n;i++)e[i]=t[i]}else e=new a(t.buffer,0,n)}else{var a=Oo(this._rawCount);e=new a(this.count());for(var i=0;i<e.length;i++)e[i]=i}return e},r.prototype.filter=function(e,t){if(!this._count)return this;for(var a=this.clone(),n=a.count(),i=Oo(a._rawCount),o=new i(n),s=[],l=e.length,u=0,f=e[0],h=a._chunks,v=0;v<n;v++){var c=void 0,p=a.getRawIndex(v);if(l===0)c=t(v);else if(l===1){var d=h[f][p];c=t(d,v)}else{for(var g=0;g<l;g++)s[g]=h[e[g]][p];s[g]=v,c=t.apply(null,s)}c&&(o[u++]=p)}return u<n&&(a._indices=o),a._count=u,a._extent=[],a._updateGetRawIdx(),a},r.prototype.selectRange=function(e){var t=this.clone(),a=t._count;if(!a)return this;var n=_t(e),i=n.length;if(!i)return this;var o=t.count(),s=Oo(t._rawCount),l=new s(o),u=0,f=n[0],h=e[f][0],v=e[f][1],c=t._chunks,p=!1;if(!t._indices){var d=0;if(i===1){for(var g=c[n[0]],y=0;y<a;y++){var m=g[y];(m>=h&&m<=v||isNaN(m))&&(l[u++]=d),d++}p=!0}else if(i===2){for(var g=c[n[0]],_=c[n[1]],S=e[n[1]][0],w=e[n[1]][1],y=0;y<a;y++){var m=g[y],x=_[y];(m>=h&&m<=v||isNaN(m))&&(x>=S&&x<=w||isNaN(x))&&(l[u++]=d),d++}p=!0}}if(!p)if(i===1)for(var y=0;y<o;y++){var b=t.getRawIndex(y),m=c[n[0]][b];(m>=h&&m<=v||isNaN(m))&&(l[u++]=b)}else for(var y=0;y<o;y++){for(var T=!0,b=t.getRawIndex(y),A=0;A<i;A++){var D=n[A],m=c[D][b];(m<e[D][0]||m>e[D][1])&&(T=!1)}T&&(l[u++]=t.getRawIndex(y))}return u<o&&(t._indices=l),t._count=u,t._extent=[],t._updateGetRawIdx(),t},r.prototype.map=function(e,t){var a=this.clone(e);return this._updateDims(a,e,t),a},r.prototype.modify=function(e,t){this._updateDims(this,e,t)},r.prototype._updateDims=function(e,t,a){for(var n=e._chunks,i=[],o=t.length,s=e.count(),l=[],u=e._rawExtent,f=0;f<t.length;f++)u[t[f]]=wi();for(var h=0;h<s;h++){for(var v=e.getRawIndex(h),c=0;c<o;c++)l[c]=n[t[c]][v];l[o]=h;var p=a&&a.apply(null,l);if(p!=null){typeof p!="object"&&(i[0]=p,p=i);for(var f=0;f<p.length;f++){var d=t[f],g=p[f],y=u[d],m=n[d];m&&(m[v]=g),g<y[0]&&(y[0]=g),g>y[1]&&(y[1]=g)}}}},r.prototype.lttbDownSample=function(e,t){var a=this.clone([e],!0),n=a._chunks,i=n[e],o=this.count(),s=0,l=Math.floor(1/t),u=this.getRawIndex(0),f,h,v,c=new(Oo(this._rawCount))(Math.min((Math.ceil(o/l)+2)*2,o));c[s++]=u;for(var p=1;p<o-1;p+=l){for(var d=Math.min(p+l,o-1),g=Math.min(p+l*2,o),y=(g+d)/2,m=0,_=d;_<g;_++){var S=this.getRawIndex(_),w=i[S];isNaN(w)||(m+=w)}m/=g-d;var x=p,b=Math.min(p+l,o),T=p-1,A=i[u];f=-1,v=x;for(var D=-1,M=0,_=x;_<b;_++){var S=this.getRawIndex(_),w=i[S];if(isNaN(w)){M++,D<0&&(D=S);continue}h=Math.abs((T-y)*(w-A)-(T-_)*(m-A)),h>f&&(f=h,v=S)}M>0&&M<b-x&&(c[s++]=Math.min(D,v),v=Math.max(D,v)),c[s++]=v,u=v}return c[s++]=this.getRawIndex(o-1),a._count=s,a._indices=c,a.getRawIndex=this._getRawIdx,a},r.prototype.downSample=function(e,t,a,n){for(var i=this.clone([e],!0),o=i._chunks,s=[],l=Math.floor(1/t),u=o[e],f=this.count(),h=i._rawExtent[e]=wi(),v=new(Oo(this._rawCount))(Math.ceil(f/l)),c=0,p=0;p<f;p+=l){l>f-p&&(l=f-p,s.length=l);for(var d=0;d<l;d++){var g=this.getRawIndex(p+d);s[d]=u[g]}var y=a(s),m=this.getRawIndex(Math.min(p+n(s,y)||0,f-1));u[m]=y,y<h[0]&&(h[0]=y),y>h[1]&&(h[1]=y),v[c++]=m}return i._count=c,i._indices=v,i._updateGetRawIdx(),i},r.prototype.each=function(e,t){if(this._count)for(var a=e.length,n=this._chunks,i=0,o=this.count();i<o;i++){var s=this.getRawIndex(i);switch(a){case 0:t(i);break;case 1:t(n[e[0]][s],i);break;case 2:t(n[e[0]][s],n[e[1]][s],i);break;default:for(var l=0,u=[];l<a;l++)u[l]=n[e[l]][s];u[l]=i,t.apply(null,u)}}},r.prototype.getDataExtent=function(e){var t=this._chunks[e],a=wi();if(!t)return a;var n=this.count(),i=!this._indices,o;if(i)return this._rawExtent[e].slice();if(o=this._extent[e],o)return o.slice();o=a;for(var s=o[0],l=o[1],u=0;u<n;u++){var f=this.getRawIndex(u),h=t[f];h<s&&(s=h),h>l&&(l=h)}return o=[s,l],this._extent[e]=o,o},r.prototype.getRawDataItem=function(e){var t=this.getRawIndex(e);if(this._provider.persistent)return this._provider.getItem(t);for(var a=[],n=this._chunks,i=0;i<n.length;i++)a.push(n[i][t]);return a},r.prototype.clone=function(e,t){var a=new r,n=this._chunks,i=e&&zr(e,function(s,l){return s[l]=!0,s},{});if(i)for(var o=0;o<n.length;o++)a._chunks[o]=i[o]?Nk(n[o]):n[o];else a._chunks=n;return this._copyCommonProps(a),t||(a._indices=this._cloneIndices()),a._updateGetRawIdx(),a},r.prototype._copyCommonProps=function(e){e._count=this._count,e._rawCount=this._rawCount,e._provider=this._provider,e._dimensions=this._dimensions,e._extent=rt(this._extent),e._rawExtent=rt(this._rawExtent)},r.prototype._cloneIndices=function(){if(this._indices){var e=this._indices.constructor,t=void 0;if(e===Array){var a=this._indices.length;t=new e(a);for(var n=0;n<a;n++)t[n]=this._indices[n]}else t=new e(this._indices);return t}return null},r.prototype._getRawIdxIdentity=function(e){return e},r.prototype._getRawIdx=function(e){return e<this._count&&e>=0?this._indices[e]:-1},r.prototype._updateGetRawIdx=function(){this.getRawIndex=this._indices?this._getRawIdx:this._getRawIdxIdentity},r.internalField=function(){function e(t,a,n,i){return za(t[i],this._dimensions[i])}xv={arrayRows:e,objectRows:function(t,a,n,i){return za(t[a],this._dimensions[i])},keyedColumns:e,original:function(t,a,n,i){var o=t&&(t.value==null?t:t.value);return za(o instanceof Array?o[i]:o,this._dimensions[i])},typedArray:function(t,a,n,i){return t[i]}}}(),r}(),NA=function(){function r(e){this._sourceList=[],this._storeList=[],this._upstreamSignList=[],this._versionSignBase=0,this._dirty=!0,this._sourceHost=e}return r.prototype.dirty=function(){this._setLocalSource([],[]),this._storeList=[],this._dirty=!0},r.prototype._setLocalSource=function(e,t){this._sourceList=e,this._upstreamSignList=t,this._versionSignBase++,this._versionSignBase>9e10&&(this._versionSignBase=0)},r.prototype._getVersionSign=function(){return this._sourceHost.uid+"_"+this._versionSignBase},r.prototype.prepareSource=function(){this._isDirty()&&(this._createSource(),this._dirty=!1)},r.prototype._createSource=function(){this._setLocalSource([],[]);var e=this._sourceHost,t=this._getUpstreamSourceManagers(),a=!!t.length,n,i;if(Ul(e)){var o=e,s=void 0,l=void 0,u=void 0;if(a){var f=t[0];f.prepareSource(),u=f.getSource(),s=u.data,l=u.sourceFormat,i=[f._getVersionSign()]}else s=o.get("data",!0),l=Ne(s)?Va:sr,i=[];var h=this._getSourceMetaRawOption()||{},v=u&&u.metaRawOption||{},c=it(h.seriesLayoutBy,v.seriesLayoutBy)||null,p=it(h.sourceHeader,v.sourceHeader),d=it(h.dimensions,v.dimensions),g=c!==v.seriesLayoutBy||!!p!=!!v.sourceHeader||d;n=g?[Gp(s,{seriesLayoutBy:c,sourceHeader:p,dimensions:d},l)]:[]}else{var y=e;if(a){var m=this._applyTransform(t);n=m.sourceList,i=m.upstreamSignList}else{var _=y.get("source",!0);n=[Gp(_,this._getSourceMetaRawOption(),null)],i=[]}}this._setLocalSource(n,i)},r.prototype._applyTransform=function(e){var t=this._sourceHost,a=t.get("transform",!0),n=t.get("fromTransformResult",!0);if(n!=null){var i="";e.length!==1&&U0(i)}var o,s=[],l=[];return C(e,function(u){u.prepareSource();var f=u.getSource(n||0),h="";n!=null&&!f&&U0(h),s.push(f),l.push(u._getVersionSign())}),a?o=Rk(a,s,{datasetIndex:t.componentIndex}):n!=null&&(o=[ck(s[0])]),{sourceList:o,upstreamSignList:l}},r.prototype._isDirty=function(){if(this._dirty)return!0;for(var e=this._getUpstreamSourceManagers(),t=0;t<e.length;t++){var a=e[t];if(a._isDirty()||this._upstreamSignList[t]!==a._getVersionSign())return!0}},r.prototype.getSource=function(e){e=e||0;var t=this._sourceList[e];if(!t){var a=this._getUpstreamSourceManagers();return a[0]&&a[0].getSource(e)}return t},r.prototype.getSharedDataStore=function(e){var t=e.makeStoreSchema();return this._innerGetDataStore(t.dimensions,e.source,t.hash)},r.prototype._innerGetDataStore=function(e,t,a){var n=0,i=this._storeList,o=i[n];o||(o=i[n]={});var s=o[a];if(!s){var l=this._getUpstreamSourceManagers()[0];Ul(this._sourceHost)&&l?s=l._innerGetDataStore(e,t,a):(s=new Fp,s.initData(new CA(t,e.length),e)),o[a]=s}return s},r.prototype._getUpstreamSourceManagers=function(){var e=this._sourceHost;if(Ul(e)){var t=Cg(e);return t?[t.getSourceManager()]:[]}else return G(GE(e),function(a){return a.getSourceManager()})},r.prototype._getSourceMetaRawOption=function(){var e=this._sourceHost,t,a,n;if(Ul(e))t=e.get("seriesLayoutBy",!0),a=e.get("sourceHeader",!0),n=e.get("dimensions",!0);else if(!this._getUpstreamSourceManagers().length){var i=e;t=i.get("seriesLayoutBy",!0),a=i.get("sourceHeader",!0),n=i.get("dimensions",!0)}return{seriesLayoutBy:t,sourceHeader:a,dimensions:n}},r}();function $0(r){var e=r.option.transform;e&&Xu(r.option.transform)}function Ul(r){return r.mainType==="series"}function U0(r){throw new Error(r)}var BA="line-height:1";function VA(r,e){var t=r.color||"#6e7079",a=r.fontSize||12,n=r.fontWeight||"400",i=r.color||"#464646",o=r.fontSize||14,s=r.fontWeight||"900";return e==="html"?{nameStyle:"font-size:"+Re(a+"")+"px;color:"+Re(t)+";font-weight:"+Re(n+""),valueStyle:"font-size:"+Re(o+"")+"px;color:"+Re(i)+";font-weight:"+Re(s+"")}:{nameStyle:{fontSize:a,fill:t,fontWeight:n},valueStyle:{fontSize:o,fill:i,fontWeight:s}}}var Bk=[0,10,20,30],Vk=["",`
`,`

`,`


`];function ae(r,e){return e.type=r,e}function Hp(r){return r.type==="section"}function zA(r){return Hp(r)?zk:Gk}function GA(r){if(Hp(r)){var e=0,t=r.blocks.length,a=t>1||t>0&&!r.noHeader;return C(r.blocks,function(n){var i=GA(n);i>=e&&(e=i+ +(a&&(!i||Hp(n)&&!n.noHeader)))}),e}return 0}function zk(r,e,t,a){var n=e.noHeader,i=Fk(GA(e)),o=[],s=e.blocks||[];Ae(!s||z(s)),s=s||[];var l=r.orderMode;if(e.sortBlocks&&l){s=s.slice();var u={valueAsc:"asc",valueDesc:"desc"};if(Y(u,l)){var f=new RA(u[l],null);s.sort(function(p,d){return f.evaluate(p.sortParam,d.sortParam)})}else l==="seriesDesc"&&s.reverse()}C(s,function(p,d){var g=e.valueFormatter,y=zA(p)(g?V(V({},r),{valueFormatter:g}):r,p,d>0?i.html:0,a);y!=null&&o.push(y)});var h=r.renderMode==="richText"?o.join(i.richText):Wp(o.join(""),n?t:i.html);if(n)return h;var v=Bp(e.header,"ordinal",r.useUTC),c=VA(a,r.renderMode).nameStyle;return r.renderMode==="richText"?FA(r,v,c)+i.richText+h:Wp('<div style="'+c+";"+BA+';">'+Re(v)+"</div>"+h,t)}function Gk(r,e,t,a){var n=r.renderMode,i=e.noName,o=e.noValue,s=!e.markerType,l=e.name,u=r.useUTC,f=e.valueFormatter||r.valueFormatter||function(S){return S=z(S)?S:[S],G(S,function(w,x){return Bp(w,z(c)?c[x]:c,u)})};if(!(i&&o)){var h=s?"":r.markupStyleCreator.makeTooltipMarker(e.markerType,e.markerColor||"#333",n),v=i?"":Bp(l,"ordinal",u),c=e.valueType,p=o?[]:f(e.value,e.dataIndex),d=!s||!i,g=!s&&i,y=VA(a,n),m=y.nameStyle,_=y.valueStyle;return n==="richText"?(s?"":h)+(i?"":FA(r,v,m))+(o?"":$k(r,p,d,g,_)):Wp((s?"":h)+(i?"":Hk(v,!s,m))+(o?"":Wk(p,d,g,_)),t)}}function Y0(r,e,t,a,n,i){if(r){var o=zA(r),s={useUTC:n,renderMode:t,orderMode:a,markupStyleCreator:e,valueFormatter:r.valueFormatter};return o(s,r,0,i)}}function Fk(r){return{html:Bk[r],richText:Vk[r]}}function Wp(r,e){var t='<div style="clear:both"></div>',a="margin: "+e+"px 0 0";return'<div style="'+a+";"+BA+';">'+r+t+"</div>"}function Hk(r,e,t){var a=e?"margin-left:2px":"";return'<span style="'+t+";"+a+'">'+Re(r)+"</span>"}function Wk(r,e,t,a){var n=t?"10px":"20px",i=e?"float:right;margin-left:"+n:"";return r=z(r)?r:[r],'<span style="'+i+";"+a+'">'+G(r,function(o){return Re(o)}).join("&nbsp;&nbsp;")+"</span>"}function FA(r,e,t){return r.markupStyleCreator.wrapRichTextStyle(e,t)}function $k(r,e,t,a,n){var i=[n],o=a?10:20;return t&&i.push({padding:[0,0,0,o],align:"right"}),r.markupStyleCreator.wrapRichTextStyle(z(e)?e.join("  "):e,i)}function HA(r,e){var t=r.getData().getItemVisual(e,"style"),a=t[r.visualDrawType];return ri(a)}function WA(r,e){var t=r.get("padding");return t??(e==="richText"?[8,10]:10)}var wv=function(){function r(){this.richTextStyles={},this._nextStyleNameId=Xb()}return r.prototype._generateStyleName=function(){return"__EC_aUTo_"+this._nextStyleNameId++},r.prototype.makeTooltipMarker=function(e,t,a){var n=a==="richText"?this._generateStyleName():null,i=EE({color:t,type:e,renderMode:a,markerId:n});return $(i)?i:(this.richTextStyles[n]=i.style,i.content)},r.prototype.wrapRichTextStyle=function(e,t){var a={};z(t)?C(t,function(i){return V(a,i)}):V(a,t);var n=this._generateStyleName();return this.richTextStyles[n]=a,"{"+n+"|"+e+"}"},r}();function $A(r){var e=r.series,t=r.dataIndex,a=r.multipleSeries,n=e.getData(),i=n.mapDimensionsAll("defaultedTooltip"),o=i.length,s=e.getRawValue(t),l=z(s),u=HA(e,t),f,h,v,c;if(o>1||l&&!o){var p=Uk(s,e,t,i,u);f=p.inlineValues,h=p.inlineValueTypes,v=p.blocks,c=p.inlineValues[0]}else if(o){var d=n.getDimensionInfo(i[0]);c=f=Ji(n,t,i[0]),h=d.type}else c=f=l?s[0]:s;var g=rg(e),y=g&&e.name||"",m=n.getName(t),_=a?y:m;return ae("section",{header:y,noHeader:a||!g,sortParam:c,blocks:[ae("nameValue",{markerType:"item",markerColor:u,name:_,noName:!dr(_),value:f,valueType:h,dataIndex:t})].concat(v||[])})}function Uk(r,e,t,a,n){var i=e.getData(),o=zr(r,function(h,v,c){var p=i.getDimensionInfo(c);return h=h||p&&p.tooltip!==!1&&p.displayName!=null},!1),s=[],l=[],u=[];a.length?C(a,function(h){f(Ji(i,t,h),h)}):C(r,f);function f(h,v){var c=i.getDimensionInfo(v);!c||c.otherDims.tooltip===!1||(o?u.push(ae("nameValue",{markerType:"subItem",markerColor:n,name:c.displayName,value:h,valueType:c.type})):(s.push(h),l.push(c.type)))}return{inlineValues:s,inlineValueTypes:l,blocks:u}}var ma=bt();function Yl(r,e){return r.getName(e)||r.getId(e)}var Fu="__universalTransitionEnabled",ph=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t._selectedDataIndicesMap={},t}return e.prototype.init=function(t,a,n){this.seriesIndex=this.componentIndex,this.dataTask=ws({count:Zk,reset:Xk}),this.dataTask.context={model:this},this.mergeDefaultAndTheme(t,n);var i=ma(this).sourceManager=new NA(this);i.prepareSource();var o=this.getInitialData(t,n);X0(o,this),this.dataTask.context.data=o,ma(this).dataBeforeProcessed=o,Z0(this),this._initSelectedMapFromData(o)},e.prototype.mergeDefaultAndTheme=function(t,a){var n=Gs(this),i=n?mo(t):{},o=this.subType;Tt.hasClass(o)&&(o+="Series"),ft(t,a.getTheme().get(this.subType)),ft(t,this.getDefaultOption()),Jn(t,"label",["show"]),this.fillDataTextStyle(t.data),n&&Ua(t,i,n)},e.prototype.mergeOption=function(t,a){t=ft(this.option,t,!0),this.fillDataTextStyle(t.data);var n=Gs(this);n&&Ua(this.option,t,n);var i=ma(this).sourceManager;i.dirty(),i.prepareSource();var o=this.getInitialData(t,a);X0(o,this),this.dataTask.dirty(),this.dataTask.context.data=o,ma(this).dataBeforeProcessed=o,Z0(this),this._initSelectedMapFromData(o)},e.prototype.fillDataTextStyle=function(t){if(t&&!Ne(t))for(var a=["show"],n=0;n<t.length;n++)t[n]&&t[n].label&&Jn(t[n],"label",a)},e.prototype.getInitialData=function(t,a){},e.prototype.appendData=function(t){var a=this.getRawData();a.appendData(t.data)},e.prototype.getData=function(t){var a=$p(this);if(a){var n=a.context.data;return t==null?n:n.getLinkedData(t)}else return ma(this).data},e.prototype.getAllData=function(){var t=this.getData();return t&&t.getLinkedDataAll?t.getLinkedDataAll():[{data:t}]},e.prototype.setData=function(t){var a=$p(this);if(a){var n=a.context;n.outputData=t,a!==this.dataTask&&(n.data=t)}ma(this).data=t},e.prototype.getEncode=function(){var t=this.get("encode",!0);if(t)return Z(t)},e.prototype.getSourceManager=function(){return ma(this).sourceManager},e.prototype.getSource=function(){return this.getSourceManager().getSource()},e.prototype.getRawData=function(){return ma(this).dataBeforeProcessed},e.prototype.getColorBy=function(){var t=this.get("colorBy");return t||"series"},e.prototype.isColorBySeries=function(){return this.getColorBy()==="series"},e.prototype.getBaseAxis=function(){var t=this.coordinateSystem;return t&&t.getBaseAxis&&t.getBaseAxis()},e.prototype.formatTooltip=function(t,a,n){return $A({series:this,dataIndex:t,multipleSeries:a})},e.prototype.isAnimationEnabled=function(){var t=this.ecModel;if(mt.node&&!(t&&t.ssr))return!1;var a=this.getShallow("animation");return a&&this.getData().count()>this.getShallow("animationThreshold")&&(a=!1),!!a},e.prototype.restoreData=function(){this.dataTask.dirty()},e.prototype.getColorFromPalette=function(t,a,n){var i=this.ecModel,o=Dg.prototype.getColorFromPalette.call(this,t,a,n);return o||(o=i.getColorFromPalette(t,a,n)),o},e.prototype.coordDimToDataDim=function(t){return this.getRawData().mapDimensionsAll(t)},e.prototype.getProgressive=function(){return this.get("progressive")},e.prototype.getProgressiveThreshold=function(){return this.get("progressiveThreshold")},e.prototype.select=function(t,a){this._innerSelect(this.getData(a),t)},e.prototype.unselect=function(t,a){var n=this.option.selectedMap;if(n){var i=this.option.selectedMode,o=this.getData(a);if(i==="series"||n==="all"){this.option.selectedMap={},this._selectedDataIndicesMap={};return}for(var s=0;s<t.length;s++){var l=t[s],u=Yl(o,l);n[u]=!1,this._selectedDataIndicesMap[u]=-1}}},e.prototype.toggleSelect=function(t,a){for(var n=[],i=0;i<t.length;i++)n[0]=t[i],this.isSelected(t[i],a)?this.unselect(n,a):this.select(n,a)},e.prototype.getSelectedDataIndices=function(){if(this.option.selectedMap==="all")return[].slice.call(this.getData().getIndices());for(var t=this._selectedDataIndicesMap,a=_t(t),n=[],i=0;i<a.length;i++){var o=t[a[i]];o>=0&&n.push(o)}return n},e.prototype.isSelected=function(t,a){var n=this.option.selectedMap;if(!n)return!1;var i=this.getData(a);return(n==="all"||n[Yl(i,t)])&&!i.getItemModel(t).get(["select","disabled"])},e.prototype.isUniversalTransitionEnabled=function(){if(this[Fu])return!0;var t=this.option.universalTransition;return t?t===!0?!0:t&&t.enabled:!1},e.prototype._innerSelect=function(t,a){var n,i,o=this.option,s=o.selectedMode,l=a.length;if(!(!s||!l)){if(s==="series")o.selectedMap="all";else if(s==="multiple"){tt(o.selectedMap)||(o.selectedMap={});for(var u=o.selectedMap,f=0;f<l;f++){var h=a[f],v=Yl(t,h);u[v]=!0,this._selectedDataIndicesMap[v]=t.getRawIndex(h)}}else if(s==="single"||s===!0){var c=a[l-1],v=Yl(t,c);o.selectedMap=(n={},n[v]=!0,n),this._selectedDataIndicesMap=(i={},i[v]=t.getRawIndex(c),i)}}},e.prototype._initSelectedMapFromData=function(t){if(!this.option.selectedMap){var a=[];t.hasItemOption&&t.each(function(n){var i=t.getRawDataItem(n);i&&i.selected&&a.push(n)}),a.length>0&&this._innerSelect(t,a)}},e.registerClass=function(t){return Tt.registerClass(t)},e.protoInitialize=function(){var t=e.prototype;t.type="series.__base__",t.seriesIndex=0,t.ignoreStyleOnData=!1,t.hasSymbolVisual=!1,t.defaultSymbol="circle",t.visualStyleAccessPath="itemStyle",t.visualDrawType="fill"}(),e}(Tt);Kt(ph,Rg);Kt(ph,Dg);aT(ph,Tt);function Z0(r){var e=r.name;rg(r)||(r.name=Yk(r)||e)}function Yk(r){var e=r.getRawData(),t=e.mapDimensionsAll("seriesName"),a=[];return C(t,function(n){var i=e.getDimensionInfo(n);i.displayName&&a.push(i.displayName)}),a.join(" ")}function Zk(r){return r.model.getRawData().count()}function Xk(r){var e=r.model;return e.setData(e.getRawData().cloneShallow()),qk}function qk(r,e){e.outputData&&r.end>e.outputData.count()&&e.model.getRawData().cloneShallow(e.outputData)}function X0(r,e){C(qu(r.CHANGABLE_METHODS,r.DOWNSAMPLE_METHODS),function(t){r.wrapMethod(t,ot(Kk,e))})}function Kk(r,e){var t=$p(r);return t&&t.setOutputEnd((e||this).count()),e}function $p(r){var e=(r.ecModel||{}).scheduler,t=e&&e.getPipeline(r.uid);if(t){var a=t.currentTask;if(a){var n=a.agentStubMap;n&&(a=n.get(r.uid))}return a}}const zt=ph;var kg=function(){function r(){this.group=new at,this.uid=go("viewComponent")}return r.prototype.init=function(e,t){},r.prototype.render=function(e,t,a,n){},r.prototype.dispose=function(e,t){},r.prototype.updateView=function(e,t,a,n){},r.prototype.updateLayout=function(e,t,a,n){},r.prototype.updateVisual=function(e,t,a,n){},r.prototype.toggleBlurSeries=function(e,t,a){},r.prototype.eachRendered=function(e){var t=this.group;t&&t.traverse(e)},r}();ng(kg);qf(kg);const Ht=kg;function xo(){var r=bt();return function(e){var t=r(e),a=e.pipelineContext,n=!!t.large,i=!!t.progressiveRender,o=t.large=!!(a&&a.large),s=t.progressiveRender=!!(a&&a.progressiveRender);return(n!==o||i!==s)&&"reset"}}var UA=bt(),Qk=xo(),Og=function(){function r(){this.group=new at,this.uid=go("viewChart"),this.renderTask=ws({plan:Jk,reset:jk}),this.renderTask.context={view:this}}return r.prototype.init=function(e,t){},r.prototype.render=function(e,t,a,n){},r.prototype.highlight=function(e,t,a,n){var i=e.getData(n&&n.dataType);i&&K0(i,n,"emphasis")},r.prototype.downplay=function(e,t,a,n){var i=e.getData(n&&n.dataType);i&&K0(i,n,"normal")},r.prototype.remove=function(e,t){this.group.removeAll()},r.prototype.dispose=function(e,t){},r.prototype.updateView=function(e,t,a,n){this.render(e,t,a,n)},r.prototype.updateLayout=function(e,t,a,n){this.render(e,t,a,n)},r.prototype.updateVisual=function(e,t,a,n){this.render(e,t,a,n)},r.prototype.eachRendered=function(e){Ja(this.group,e)},r.markUpdateMethod=function(e,t){UA(e).updateMethod=t},r.protoInitialize=function(){var e=r.prototype;e.type="chart"}(),r}();function q0(r,e,t){r&&Bs(r)&&(e==="emphasis"?sa:la)(r,t)}function K0(r,e,t){var a=jn(r,e),n=e&&e.highlightKey!=null?DR(e.highlightKey):null;a!=null?C(Pt(a),function(i){q0(r.getItemGraphicEl(i),t,n)}):r.eachItemGraphicEl(function(i){q0(i,t,n)})}ng(Og);qf(Og);function Jk(r){return Qk(r.model)}function jk(r){var e=r.model,t=r.ecModel,a=r.api,n=r.payload,i=e.pipelineContext.progressiveRender,o=r.view,s=n&&UA(n).updateMethod,l=i?"incrementalPrepareRender":s&&o[s]?s:"render";return l!=="render"&&o[l](e,t,a,n),tO[l]}var tO={incrementalPrepareRender:{progress:function(r,e){e.view.incrementalRender(r,e.model,e.ecModel,e.api,e.payload)}},render:{forceFirstProgress:!0,progress:function(r,e){e.view.render(e.model,e.ecModel,e.api,e.payload)}}};const Nt=Og;var vf="\0__throttleOriginMethod",Q0="\0__throttleRate",J0="\0__throttleType";function Ng(r,e,t){var a,n=0,i=0,o=null,s,l,u,f;e=e||0;function h(){i=new Date().getTime(),o=null,r.apply(l,u||[])}var v=function(){for(var c=[],p=0;p<arguments.length;p++)c[p]=arguments[p];a=new Date().getTime(),l=this,u=c;var d=f||e,g=f||t;f=null,s=a-(g?n:i)-d,clearTimeout(o),g?o=setTimeout(h,d):s>=0?h():o=setTimeout(h,-s),n=a};return v.clear=function(){o&&(clearTimeout(o),o=null)},v.debounceNextCall=function(c){f=c},v}function wo(r,e,t,a){var n=r[e];if(n){var i=n[vf]||n,o=n[J0],s=n[Q0];if(s!==t||o!==a){if(t==null||!a)return r[e]=i;n=r[e]=Ng(i,t,a==="debounce"),n[vf]=i,n[J0]=a,n[Q0]=t}return n}}function Hs(r,e){var t=r[e];t&&t[vf]&&(t.clear&&t.clear(),r[e]=t[vf])}var j0=bt(),t_={itemStyle:ti(QT,!0),lineStyle:ti(KT,!0)},eO={lineStyle:"stroke",itemStyle:"fill"};function YA(r,e){var t=r.visualStyleMapper||t_[e];return t||(console.warn("Unknown style type '"+e+"'."),t_.itemStyle)}function ZA(r,e){var t=r.visualDrawType||eO[e];return t||(console.warn("Unknown style type '"+e+"'."),"fill")}var rO={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,e){var t=r.getData(),a=r.visualStyleAccessPath||"itemStyle",n=r.getModel(a),i=YA(r,a),o=i(n),s=n.getShallow("decal");s&&(t.setVisual("decal",s),s.dirty=!0);var l=ZA(r,a),u=o[l],f=K(u)?u:null,h=o.fill==="auto"||o.stroke==="auto";if(!o[l]||f||h){var v=r.getColorFromPalette(r.name,null,e.getSeriesCount());o[l]||(o[l]=v,t.setVisual("colorFromPalette",!0)),o.fill=o.fill==="auto"||K(o.fill)?v:o.fill,o.stroke=o.stroke==="auto"||K(o.stroke)?v:o.stroke}if(t.setVisual("style",o),t.setVisual("drawType",l),!e.isSeriesFiltered(r)&&f)return t.setVisual("colorFromPalette",!1),{dataEach:function(c,p){var d=r.getDataParams(p),g=V({},o);g[l]=f(d),c.setItemVisual(p,"style",g)}}}},No=new Ot,aO={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,e){if(!(r.ignoreStyleOnData||e.isSeriesFiltered(r))){var t=r.getData(),a=r.visualStyleAccessPath||"itemStyle",n=YA(r,a),i=t.getVisual("drawType");return{dataEach:t.hasItemOption?function(o,s){var l=o.getRawDataItem(s);if(l&&l[a]){No.option=l[a];var u=n(No),f=o.ensureUniqueItemVisual(s,"style");V(f,u),No.option.decal&&(o.setItemVisual(s,"decal",No.option.decal),No.option.decal.dirty=!0),i in u&&o.setItemVisual(s,"colorFromPalette",!1)}}:null}}}},nO={performRawSeries:!0,overallReset:function(r){var e=Z();r.eachSeries(function(t){var a=t.getColorBy();if(!t.isColorBySeries()){var n=t.type+"-"+a,i=e.get(n);i||(i={},e.set(n,i)),j0(t).scope=i}}),r.eachSeries(function(t){if(!(t.isColorBySeries()||r.isSeriesFiltered(t))){var a=t.getRawData(),n={},i=t.getData(),o=j0(t).scope,s=t.visualStyleAccessPath||"itemStyle",l=ZA(t,s);i.each(function(u){var f=i.getRawIndex(u);n[f]=u}),a.each(function(u){var f=n[u],h=i.getItemVisual(f,"colorFromPalette");if(h){var v=i.ensureUniqueItemVisual(f,"style"),c=a.getName(u)||u+"",p=a.count();v[l]=t.getColorFromPalette(c,o,p)}})}})}},Zl=Math.PI;function iO(r,e){e=e||{},j(e,{text:"loading",textColor:"#000",fontSize:12,fontWeight:"normal",fontStyle:"normal",fontFamily:"sans-serif",maskColor:"rgba(255, 255, 255, 0.8)",showSpinner:!0,color:"#5470c6",spinnerRadius:10,lineWidth:5,zlevel:0});var t=new at,a=new wt({style:{fill:e.maskColor},zlevel:e.zlevel,z:1e4});t.add(a);var n=new At({style:{text:e.text,fill:e.textColor,fontSize:e.fontSize,fontWeight:e.fontWeight,fontStyle:e.fontStyle,fontFamily:e.fontFamily},zlevel:e.zlevel,z:10001}),i=new wt({style:{fill:"none"},textContent:n,textConfig:{position:"right",distance:10},zlevel:e.zlevel,z:10001});t.add(i);var o;return e.showSpinner&&(o=new pg({shape:{startAngle:-Zl/2,endAngle:-Zl/2+.1,r:e.spinnerRadius},style:{stroke:e.color,lineCap:"round",lineWidth:e.lineWidth},zlevel:e.zlevel,z:10001}),o.animateShape(!0).when(1e3,{endAngle:Zl*3/2}).start("circularInOut"),o.animateShape(!0).when(1e3,{startAngle:Zl*3/2}).delay(300).start("circularInOut"),t.add(o)),t.resize=function(){var s=n.getBoundingRect().width,l=e.showSpinner?e.spinnerRadius:0,u=(r.getWidth()-l*2-(e.showSpinner&&s?10:0)-s)/2-(e.showSpinner&&s?0:5+s/2)+(e.showSpinner?0:s/2)+(s?0:l),f=r.getHeight()/2;e.showSpinner&&o.setShape({cx:u,cy:f}),i.setShape({x:u-l,y:f-l,width:l*2,height:l*2}),a.setShape({x:0,y:0,width:r.getWidth(),height:r.getHeight()})},t.resize(),t}var XA=function(){function r(e,t,a,n){this._stageTaskMap=Z(),this.ecInstance=e,this.api=t,a=this._dataProcessorHandlers=a.slice(),n=this._visualHandlers=n.slice(),this._allHandlers=a.concat(n)}return r.prototype.restoreData=function(e,t){e.restoreData(t),this._stageTaskMap.each(function(a){var n=a.overallTask;n&&n.dirty()})},r.prototype.getPerformArgs=function(e,t){if(e.__pipeline){var a=this._pipelineMap.get(e.__pipeline.id),n=a.context,i=!t&&a.progressiveEnabled&&(!n||n.progressiveRender)&&e.__idxInPipeline>a.blockIndex,o=i?a.step:null,s=n&&n.modDataCount,l=s!=null?Math.ceil(s/o):null;return{step:o,modBy:l,modDataCount:s}}},r.prototype.getPipeline=function(e){return this._pipelineMap.get(e)},r.prototype.updateStreamModes=function(e,t){var a=this._pipelineMap.get(e.uid),n=e.getData(),i=n.count(),o=a.progressiveEnabled&&t.incrementalPrepareRender&&i>=a.threshold,s=e.get("large")&&i>=e.get("largeThreshold"),l=e.get("progressiveChunkMode")==="mod"?i:null;e.pipelineContext=a.context={progressiveRender:o,modDataCount:l,large:s}},r.prototype.restorePipelines=function(e){var t=this,a=t._pipelineMap=Z();e.eachSeries(function(n){var i=n.getProgressive(),o=n.uid;a.set(o,{id:o,head:null,tail:null,threshold:n.getProgressiveThreshold(),progressiveEnabled:i&&!(n.preventIncremental&&n.preventIncremental()),blockIndex:-1,step:Math.round(i||700),count:0}),t._pipe(n,n.dataTask)})},r.prototype.prepareStageTasks=function(){var e=this._stageTaskMap,t=this.api.getModel(),a=this.api;C(this._allHandlers,function(n){var i=e.get(n.uid)||e.set(n.uid,{}),o="";Ae(!(n.reset&&n.overallReset),o),n.reset&&this._createSeriesStageTask(n,i,t,a),n.overallReset&&this._createOverallStageTask(n,i,t,a)},this)},r.prototype.prepareView=function(e,t,a,n){var i=e.renderTask,o=i.context;o.model=t,o.ecModel=a,o.api=n,i.__block=!e.incrementalPrepareRender,this._pipe(t,i)},r.prototype.performDataProcessorTasks=function(e,t){this._performStageTasks(this._dataProcessorHandlers,e,t,{block:!0})},r.prototype.performVisualTasks=function(e,t,a){this._performStageTasks(this._visualHandlers,e,t,a)},r.prototype._performStageTasks=function(e,t,a,n){n=n||{};var i=!1,o=this;C(e,function(l,u){if(!(n.visualType&&n.visualType!==l.visualType)){var f=o._stageTaskMap.get(l.uid),h=f.seriesTaskMap,v=f.overallTask;if(v){var c,p=v.agentStubMap;p.each(function(g){s(n,g)&&(g.dirty(),c=!0)}),c&&v.dirty(),o.updatePayload(v,a);var d=o.getPerformArgs(v,n.block);p.each(function(g){g.perform(d)}),v.perform(d)&&(i=!0)}else h&&h.each(function(g,y){s(n,g)&&g.dirty();var m=o.getPerformArgs(g,n.block);m.skip=!l.performRawSeries&&t.isSeriesFiltered(g.context.model),o.updatePayload(g,a),g.perform(m)&&(i=!0)})}});function s(l,u){return l.setDirty&&(!l.dirtyMap||l.dirtyMap.get(u.__pipeline.id))}this.unfinished=i||this.unfinished},r.prototype.performSeriesTasks=function(e){var t;e.eachSeries(function(a){t=a.dataTask.perform()||t}),this.unfinished=t||this.unfinished},r.prototype.plan=function(){this._pipelineMap.each(function(e){var t=e.tail;do{if(t.__block){e.blockIndex=t.__idxInPipeline;break}t=t.getUpstream()}while(t)})},r.prototype.updatePayload=function(e,t){t!=="remain"&&(e.context.payload=t)},r.prototype._createSeriesStageTask=function(e,t,a,n){var i=this,o=t.seriesTaskMap,s=t.seriesTaskMap=Z(),l=e.seriesType,u=e.getTargetSeries;e.createOnAllSeries?a.eachRawSeries(f):l?a.eachRawSeriesByType(l,f):u&&u(a,n).each(f);function f(h){var v=h.uid,c=s.set(v,o&&o.get(v)||ws({plan:fO,reset:hO,count:cO}));c.context={model:h,ecModel:a,api:n,useClearVisual:e.isVisual&&!e.isLayout,plan:e.plan,reset:e.reset,scheduler:i},i._pipe(h,c)}},r.prototype._createOverallStageTask=function(e,t,a,n){var i=this,o=t.overallTask=t.overallTask||ws({reset:oO});o.context={ecModel:a,api:n,overallReset:e.overallReset,scheduler:i};var s=o.agentStubMap,l=o.agentStubMap=Z(),u=e.seriesType,f=e.getTargetSeries,h=!0,v=!1,c="";Ae(!e.createOnAllSeries,c),u?a.eachRawSeriesByType(u,p):f?f(a,n).each(p):(h=!1,C(a.getSeries(),p));function p(d){var g=d.uid,y=l.set(g,s&&s.get(g)||(v=!0,ws({reset:sO,onDirty:uO})));y.context={model:d,overallProgress:h},y.agent=o,y.__block=h,i._pipe(d,y)}v&&o.dirty()},r.prototype._pipe=function(e,t){var a=e.uid,n=this._pipelineMap.get(a);!n.head&&(n.head=t),n.tail&&n.tail.pipe(t),n.tail=t,t.__idxInPipeline=n.count++,t.__pipeline=n},r.wrapStageHandler=function(e,t){return K(e)&&(e={overallReset:e,seriesType:pO(e)}),e.uid=go("stageHandler"),t&&(e.visualType=t),e},r}();function oO(r){r.overallReset(r.ecModel,r.api,r.payload)}function sO(r){return r.overallProgress&&lO}function lO(){this.agent.dirty(),this.getDownstream().dirty()}function uO(){this.agent&&this.agent.dirty()}function fO(r){return r.plan?r.plan(r.model,r.ecModel,r.api,r.payload):null}function hO(r){r.useClearVisual&&r.data.clearAllVisual();var e=r.resetDefines=Pt(r.reset(r.model,r.ecModel,r.api,r.payload));return e.length>1?G(e,function(t,a){return qA(a)}):vO}var vO=qA(0);function qA(r){return function(e,t){var a=t.data,n=t.resetDefines[r];if(n&&n.dataEach)for(var i=e.start;i<e.end;i++)n.dataEach(a,i);else n&&n.progress&&n.progress(e,a)}}function cO(r){return r.data.count()}function pO(r){cf=null;try{r(Ws,KA)}catch{}return cf}var Ws={},KA={},cf;QA(Ws,Mg);QA(KA,xA);Ws.eachSeriesByType=Ws.eachRawSeriesByType=function(r){cf=r};Ws.eachComponent=function(r){r.mainType==="series"&&r.subType&&(cf=r.subType)};function QA(r,e){for(var t in e.prototype)r[t]=Yt}var e_=["#37A2DA","#32C5E9","#67E0E3","#9FE6B8","#FFDB5C","#ff9f7f","#fb7293","#E062AE","#E690D1","#e7bcf3","#9d96f5","#8378EA","#96BFFF"];const dO={color:e_,colorLayer:[["#37A2DA","#ffd85c","#fd7b5f"],["#37A2DA","#67E0E3","#FFDB5C","#ff9f7f","#E062AE","#9d96f5"],["#37A2DA","#32C5E9","#9FE6B8","#FFDB5C","#ff9f7f","#fb7293","#e7bcf3","#8378EA","#96BFFF"],e_]};var _e="#B9B8CE",r_="#100C2A",Xl=function(){return{axisLine:{lineStyle:{color:_e}},splitLine:{lineStyle:{color:"#484753"}},splitArea:{areaStyle:{color:["rgba(255,255,255,0.02)","rgba(255,255,255,0.05)"]}},minorSplitLine:{lineStyle:{color:"#20203B"}}}},a_=["#4992ff","#7cffb2","#fddd60","#ff6e76","#58d9f9","#05c091","#ff8a45","#8d48e3","#dd79ff"],JA={darkMode:!0,color:a_,backgroundColor:r_,axisPointer:{lineStyle:{color:"#817f91"},crossStyle:{color:"#817f91"},label:{color:"#fff"}},legend:{textStyle:{color:_e}},textStyle:{color:_e},title:{textStyle:{color:"#EEF1FA"},subtextStyle:{color:"#B9B8CE"}},toolbox:{iconStyle:{borderColor:_e}},dataZoom:{borderColor:"#71708A",textStyle:{color:_e},brushStyle:{color:"rgba(135,163,206,0.3)"},handleStyle:{color:"#353450",borderColor:"#C5CBE3"},moveHandleStyle:{color:"#B0B6C3",opacity:.3},fillerColor:"rgba(135,163,206,0.2)",emphasis:{handleStyle:{borderColor:"#91B7F2",color:"#4D587D"},moveHandleStyle:{color:"#636D9A",opacity:.7}},dataBackground:{lineStyle:{color:"#71708A",width:1},areaStyle:{color:"#71708A"}},selectedDataBackground:{lineStyle:{color:"#87A3CE"},areaStyle:{color:"#87A3CE"}}},visualMap:{textStyle:{color:_e}},timeline:{lineStyle:{color:_e},label:{color:_e},controlStyle:{color:_e,borderColor:_e}},calendar:{itemStyle:{color:r_},dayLabel:{color:_e},monthLabel:{color:_e},yearLabel:{color:_e}},timeAxis:Xl(),logAxis:Xl(),valueAxis:Xl(),categoryAxis:Xl(),line:{symbol:"circle"},graph:{color:a_},gauge:{title:{color:_e},axisLine:{lineStyle:{color:[[1,"rgba(207,212,219,0.2)"]]}},axisLabel:{color:_e},detail:{color:"#EEF1FA"}},candlestick:{itemStyle:{color:"#f64e56",color0:"#54ea92",borderColor:"#f64e56",borderColor0:"#54ea92"}}};JA.categoryAxis.splitLine.show=!1;const gO=JA;var yO=function(){function r(){}return r.prototype.normalizeQuery=function(e){var t={},a={},n={};if($(e)){var i=kr(e);t.mainType=i.main||null,t.subType=i.sub||null}else{var o=["Index","Name","Id"],s={name:1,dataIndex:1,dataType:1};C(e,function(l,u){for(var f=!1,h=0;h<o.length;h++){var v=o[h],c=u.lastIndexOf(v);if(c>0&&c===u.length-v.length){var p=u.slice(0,c);p!=="data"&&(t.mainType=p,t[v.toLowerCase()]=l,f=!0)}}s.hasOwnProperty(u)&&(a[u]=l,f=!0),f||(n[u]=l)})}return{cptQuery:t,dataQuery:a,otherQuery:n}},r.prototype.filter=function(e,t){var a=this.eventInfo;if(!a)return!0;var n=a.targetEl,i=a.packedEvent,o=a.model,s=a.view;if(!o||!s)return!0;var l=t.cptQuery,u=t.dataQuery;return f(l,o,"mainType")&&f(l,o,"subType")&&f(l,o,"index","componentIndex")&&f(l,o,"name")&&f(l,o,"id")&&f(u,i,"name")&&f(u,i,"dataIndex")&&f(u,i,"dataType")&&(!s.filterForExposedEvent||s.filterForExposedEvent(e,t.otherQuery,n,i));function f(h,v,c,p){return h[c]==null||v[p||c]===h[c]}},r.prototype.afterTrigger=function(){this.eventInfo=null},r}(),Up=["symbol","symbolSize","symbolRotate","symbolOffset"],n_=Up.concat(["symbolKeepAspect"]),mO={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,e){var t=r.getData();if(r.legendIcon&&t.setVisual("legendIcon",r.legendIcon),!r.hasSymbolVisual)return;for(var a={},n={},i=!1,o=0;o<Up.length;o++){var s=Up[o],l=r.get(s);K(l)?(i=!0,n[s]=l):a[s]=l}if(a.symbol=a.symbol||r.defaultSymbol,t.setVisual(V({legendIcon:r.legendIcon||a.symbol,symbolKeepAspect:r.get("symbolKeepAspect")},a)),e.isSeriesFiltered(r))return;var u=_t(n);function f(h,v){for(var c=r.getRawValue(v),p=r.getDataParams(v),d=0;d<u.length;d++){var g=u[d];h.setItemVisual(v,g,n[g](c,p))}}return{dataEach:i?f:null}}},_O={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,e){if(!r.hasSymbolVisual||e.isSeriesFiltered(r))return;var t=r.getData();function a(n,i){for(var o=n.getItemModel(i),s=0;s<n_.length;s++){var l=n_[s],u=o.getShallow(l,!0);u!=null&&n.setItemVisual(i,l,u)}}return{dataEach:t.hasItemOption?a:null}}};function Bg(r,e,t){switch(t){case"color":var a=r.getItemVisual(e,"style");return a[r.getVisual("drawType")];case"opacity":return r.getItemVisual(e,"style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getItemVisual(e,t)}}function hl(r,e){switch(e){case"color":var t=r.getVisual("style");return t[r.getVisual("drawType")];case"opacity":return r.getVisual("style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getVisual(e)}}function jA(r,e,t,a){switch(t){case"color":var n=r.ensureUniqueItemVisual(e,"style");n[r.getVisual("drawType")]=a,r.setItemVisual(e,"colorFromPalette",!1);break;case"opacity":r.ensureUniqueItemVisual(e,"style").opacity=a;break;case"symbol":case"symbolSize":case"liftZ":r.setItemVisual(e,t,a);break}}function tC(r,e){function t(a,n){var i=[];return a.eachComponent({mainType:"series",subType:r,query:n},function(o){i.push(o.seriesIndex)}),i}C([[r+"ToggleSelect","toggleSelect"],[r+"Select","select"],[r+"UnSelect","unselect"]],function(a){e(a[0],function(n,i,o){n=V({},n),o.dispatchAction(V(n,{type:a[1],seriesIndex:t(i,n)}))})})}function bi(r,e,t,a,n){var i=r+e;t.isSilent(i)||a.eachComponent({mainType:"series",subType:"pie"},function(o){for(var s=o.seriesIndex,l=o.option.selectedMap,u=n.selected,f=0;f<u.length;f++)if(u[f].seriesIndex===s){var h=o.getData(),v=jn(h,n.fromActionPayload);t.trigger(i,{type:i,seriesId:o.id,name:z(v)?h.getName(v[0]):h.getName(v),selected:$(l)?l:V({},l)})}})}function SO(r,e,t){r.on("selectchanged",function(a){var n=t.getModel();a.isFromClick?(bi("map","selectchanged",e,n,a),bi("pie","selectchanged",e,n,a)):a.fromAction==="select"?(bi("map","selected",e,n,a),bi("pie","selected",e,n,a)):a.fromAction==="unselect"&&(bi("map","unselected",e,n,a),bi("pie","unselected",e,n,a))})}function zn(r,e,t){for(var a;r&&!(e(r)&&(a=r,t));)r=r.__hostTarget||r.parent;return a}var xO=Math.round(Math.random()*9),wO=typeof Object.defineProperty=="function",bO=function(){function r(){this._id="__ec_inner_"+xO++}return r.prototype.get=function(e){return this._guard(e)[this._id]},r.prototype.set=function(e,t){var a=this._guard(e);return wO?Object.defineProperty(a,this._id,{value:t,enumerable:!1,configurable:!0}):a[this._id]=t,this},r.prototype.delete=function(e){return this.has(e)?(delete this._guard(e)[this._id],!0):!1},r.prototype.has=function(e){return!!this._guard(e)[this._id]},r.prototype._guard=function(e){if(e!==Object(e))throw TypeError("Value of WeakMap is not a non-null object.");return e},r}(),TO=yt.extend({type:"triangle",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,e){var t=e.cx,a=e.cy,n=e.width/2,i=e.height/2;r.moveTo(t,a-i),r.lineTo(t+n,a+i),r.lineTo(t-n,a+i),r.closePath()}}),AO=yt.extend({type:"diamond",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,e){var t=e.cx,a=e.cy,n=e.width/2,i=e.height/2;r.moveTo(t,a-i),r.lineTo(t+n,a),r.lineTo(t,a+i),r.lineTo(t-n,a),r.closePath()}}),CO=yt.extend({type:"pin",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,e){var t=e.x,a=e.y,n=e.width/5*3,i=Math.max(n,e.height),o=n/2,s=o*o/(i-o),l=a-i+o+s,u=Math.asin(s/o),f=Math.cos(u)*o,h=Math.sin(u),v=Math.cos(u),c=o*.6,p=o*.7;r.moveTo(t-f,l+s),r.arc(t,l,o,Math.PI-u,Math.PI*2+u),r.bezierCurveTo(t+f-h*c,l+s+v*c,t,a-p,t,a),r.bezierCurveTo(t,a-p,t-f+h*c,l+s+v*c,t-f,l+s),r.closePath()}}),DO=yt.extend({type:"arrow",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,e){var t=e.height,a=e.width,n=e.x,i=e.y,o=a/3*2;r.moveTo(n,i),r.lineTo(n+o,i+t),r.lineTo(n,i+t/4*3),r.lineTo(n-o,i+t),r.lineTo(n,i),r.closePath()}}),MO={line:te,rect:wt,roundRect:wt,square:wt,circle:Qa,diamond:AO,pin:CO,arrow:DO,triangle:TO},IO={line:function(r,e,t,a,n){n.x1=r,n.y1=e+a/2,n.x2=r+t,n.y2=e+a/2},rect:function(r,e,t,a,n){n.x=r,n.y=e,n.width=t,n.height=a},roundRect:function(r,e,t,a,n){n.x=r,n.y=e,n.width=t,n.height=a,n.r=Math.min(t,a)/4},square:function(r,e,t,a,n){var i=Math.min(t,a);n.x=r,n.y=e,n.width=i,n.height=i},circle:function(r,e,t,a,n){n.cx=r+t/2,n.cy=e+a/2,n.r=Math.min(t,a)/2},diamond:function(r,e,t,a,n){n.cx=r+t/2,n.cy=e+a/2,n.width=t,n.height=a},pin:function(r,e,t,a,n){n.x=r+t/2,n.y=e+a/2,n.width=t,n.height=a},arrow:function(r,e,t,a,n){n.x=r+t/2,n.y=e+a/2,n.width=t,n.height=a},triangle:function(r,e,t,a,n){n.cx=r+t/2,n.cy=e+a/2,n.width=t,n.height=a}},pf={};C(MO,function(r,e){pf[e]=new r});var LO=yt.extend({type:"symbol",shape:{symbolType:"",x:0,y:0,width:0,height:0},calculateTextPosition:function(r,e,t){var a=rf(r,e,t),n=this.shape;return n&&n.symbolType==="pin"&&e.position==="inside"&&(a.y=t.y+t.height*.4),a},buildPath:function(r,e,t){var a=e.symbolType;if(a!=="none"){var n=pf[a];n||(a="rect",n=pf[a]),IO[a](e.x,e.y,e.width,e.height,n.shape),n.buildPath(r,n.shape,t)}}});function PO(r,e){if(this.type!=="image"){var t=this.style;this.__isEmptyBrush?(t.stroke=r,t.fill=e||"#fff",t.lineWidth=2):this.shape.symbolType==="line"?t.stroke=r:t.fill=r,this.markRedraw()}}function qt(r,e,t,a,n,i,o){var s=r.indexOf("empty")===0;s&&(r=r.substr(5,1).toLowerCase()+r.substr(6));var l;return r.indexOf("image://")===0?l=HT(r.slice(8),new ht(e,t,a,n),o?"center":"cover"):r.indexOf("path://")===0?l=ah(r.slice(7),{},new ht(e,t,a,n),o?"center":"cover"):l=new LO({shape:{symbolType:r,x:e,y:t,width:a,height:n}}),l.__isEmptyBrush=s,l.setColor=PO,i&&l.setColor(i),l}function bo(r){return z(r)||(r=[+r,+r]),[r[0]||0,r[1]||0]}function ui(r,e){if(r!=null)return z(r)||(r=[r,r]),[W(r[0],e[0])||0,W(it(r[1],r[0]),e[1])||0]}function Gn(r){return isFinite(r)}function RO(r,e,t){var a=e.x==null?0:e.x,n=e.x2==null?1:e.x2,i=e.y==null?0:e.y,o=e.y2==null?0:e.y2;e.global||(a=a*t.width+t.x,n=n*t.width+t.x,i=i*t.height+t.y,o=o*t.height+t.y),a=Gn(a)?a:0,n=Gn(n)?n:1,i=Gn(i)?i:0,o=Gn(o)?o:0;var s=r.createLinearGradient(a,i,n,o);return s}function EO(r,e,t){var a=t.width,n=t.height,i=Math.min(a,n),o=e.x==null?.5:e.x,s=e.y==null?.5:e.y,l=e.r==null?.5:e.r;e.global||(o=o*a+t.x,s=s*n+t.y,l=l*i),o=Gn(o)?o:.5,s=Gn(s)?s:.5,l=l>=0&&Gn(l)?l:.5;var u=r.createRadialGradient(o,s,0,o,s,l);return u}function Yp(r,e,t){for(var a=e.type==="radial"?EO(r,e,t):RO(r,e,t),n=e.colorStops,i=0;i<n.length;i++)a.addColorStop(n[i].offset,n[i].color);return a}function kO(r,e){if(r===e||!r&&!e)return!1;if(!r||!e||r.length!==e.length)return!0;for(var t=0;t<r.length;t++)if(r[t]!==e[t])return!0;return!1}function ql(r){return parseInt(r,10)}function Hi(r,e,t){var a=["width","height"][e],n=["clientWidth","clientHeight"][e],i=["paddingLeft","paddingTop"][e],o=["paddingRight","paddingBottom"][e];if(t[a]!=null&&t[a]!=="auto")return parseFloat(t[a]);var s=document.defaultView.getComputedStyle(r);return(r[n]||ql(s[a])||ql(r.style[a]))-(ql(s[i])||0)-(ql(s[o])||0)|0}function OO(r,e){return!r||r==="solid"||!(e>0)?null:r==="dashed"?[4*e,2*e]:r==="dotted"?[e]:Ct(r)?[r]:z(r)?r:null}function Vg(r){var e=r.style,t=e.lineDash&&e.lineWidth>0&&OO(e.lineDash,e.lineWidth),a=e.lineDashOffset;if(t){var n=e.strokeNoScale&&r.getLineScale?r.getLineScale():1;n&&n!==1&&(t=G(t,function(i){return i/n}),a/=n)}return[t,a]}var NO=new Wr(!0);function df(r){var e=r.stroke;return!(e==null||e==="none"||!(r.lineWidth>0))}function i_(r){return typeof r=="string"&&r!=="none"}function gf(r){var e=r.fill;return e!=null&&e!=="none"}function o_(r,e){if(e.fillOpacity!=null&&e.fillOpacity!==1){var t=r.globalAlpha;r.globalAlpha=e.fillOpacity*e.opacity,r.fill(),r.globalAlpha=t}else r.fill()}function s_(r,e){if(e.strokeOpacity!=null&&e.strokeOpacity!==1){var t=r.globalAlpha;r.globalAlpha=e.strokeOpacity*e.opacity,r.stroke(),r.globalAlpha=t}else r.stroke()}function Zp(r,e,t){var a=ig(e.image,e.__image,t);if(Kf(a)){var n=r.createPattern(a,e.repeat||"repeat");if(typeof DOMMatrix=="function"&&n&&n.setTransform){var i=new DOMMatrix;i.translateSelf(e.x||0,e.y||0),i.rotateSelf(0,0,(e.rotation||0)*Mu),i.scaleSelf(e.scaleX||1,e.scaleY||1),n.setTransform(i)}return n}}function BO(r,e,t,a){var n,i=df(t),o=gf(t),s=t.strokePercent,l=s<1,u=!e.path;(!e.silent||l)&&u&&e.createPathProxy();var f=e.path||NO,h=e.__dirty;if(!a){var v=t.fill,c=t.stroke,p=o&&!!v.colorStops,d=i&&!!c.colorStops,g=o&&!!v.image,y=i&&!!c.image,m=void 0,_=void 0,S=void 0,w=void 0,x=void 0;(p||d)&&(x=e.getBoundingRect()),p&&(m=h?Yp(r,v,x):e.__canvasFillGradient,e.__canvasFillGradient=m),d&&(_=h?Yp(r,c,x):e.__canvasStrokeGradient,e.__canvasStrokeGradient=_),g&&(S=h||!e.__canvasFillPattern?Zp(r,v,e):e.__canvasFillPattern,e.__canvasFillPattern=S),y&&(w=h||!e.__canvasStrokePattern?Zp(r,c,e):e.__canvasStrokePattern,e.__canvasStrokePattern=S),p?r.fillStyle=m:g&&(S?r.fillStyle=S:o=!1),d?r.strokeStyle=_:y&&(w?r.strokeStyle=w:i=!1)}var b=e.getGlobalScale();f.setScale(b[0],b[1],e.segmentIgnoreThreshold);var T,A;r.setLineDash&&t.lineDash&&(n=Vg(e),T=n[0],A=n[1]);var D=!0;(u||h&Oi)&&(f.setDPR(r.dpr),l?f.setContext(null):(f.setContext(r),D=!1),f.reset(),e.buildPath(f,e.shape,a),f.toStatic(),e.pathUpdated()),D&&f.rebuildPath(r,l?s:1),T&&(r.setLineDash(T),r.lineDashOffset=A),a||(t.strokeFirst?(i&&s_(r,t),o&&o_(r,t)):(o&&o_(r,t),i&&s_(r,t))),T&&r.setLineDash([])}function VO(r,e,t){var a=e.__image=ig(t.image,e.__image,e,e.onload);if(!(!a||!Kf(a))){var n=t.x||0,i=t.y||0,o=e.getWidth(),s=e.getHeight(),l=a.width/a.height;if(o==null&&s!=null?o=s*l:s==null&&o!=null?s=o/l:o==null&&s==null&&(o=a.width,s=a.height),t.sWidth&&t.sHeight){var u=t.sx||0,f=t.sy||0;r.drawImage(a,u,f,t.sWidth,t.sHeight,n,i,o,s)}else if(t.sx&&t.sy){var u=t.sx,f=t.sy,h=o-u,v=s-f;r.drawImage(a,u,f,h,v,n,i,o,s)}else r.drawImage(a,n,i,o,s)}}function zO(r,e,t){var a,n=t.text;if(n!=null&&(n+=""),n){r.font=t.font||Fa,r.textAlign=t.textAlign,r.textBaseline=t.textBaseline;var i=void 0,o=void 0;r.setLineDash&&t.lineDash&&(a=Vg(e),i=a[0],o=a[1]),i&&(r.setLineDash(i),r.lineDashOffset=o),t.strokeFirst?(df(t)&&r.strokeText(n,t.x,t.y),gf(t)&&r.fillText(n,t.x,t.y)):(gf(t)&&r.fillText(n,t.x,t.y),df(t)&&r.strokeText(n,t.x,t.y)),i&&r.setLineDash([])}}var l_=["shadowBlur","shadowOffsetX","shadowOffsetY"],u_=[["lineCap","butt"],["lineJoin","miter"],["miterLimit",10]];function eC(r,e,t,a,n){var i=!1;if(!a&&(t=t||{},e===t))return!1;if(a||e.opacity!==t.opacity){Oe(r,n),i=!0;var o=Math.max(Math.min(e.opacity,1),0);r.globalAlpha=isNaN(o)?Un.opacity:o}(a||e.blend!==t.blend)&&(i||(Oe(r,n),i=!0),r.globalCompositeOperation=e.blend||Un.blend);for(var s=0;s<l_.length;s++){var l=l_[s];(a||e[l]!==t[l])&&(i||(Oe(r,n),i=!0),r[l]=r.dpr*(e[l]||0))}return(a||e.shadowColor!==t.shadowColor)&&(i||(Oe(r,n),i=!0),r.shadowColor=e.shadowColor||Un.shadowColor),i}function f_(r,e,t,a,n){var i=$s(e,n.inHover),o=a?null:t&&$s(t,n.inHover)||{};if(i===o)return!1;var s=eC(r,i,o,a,n);if((a||i.fill!==o.fill)&&(s||(Oe(r,n),s=!0),i_(i.fill)&&(r.fillStyle=i.fill)),(a||i.stroke!==o.stroke)&&(s||(Oe(r,n),s=!0),i_(i.stroke)&&(r.strokeStyle=i.stroke)),(a||i.opacity!==o.opacity)&&(s||(Oe(r,n),s=!0),r.globalAlpha=i.opacity==null?1:i.opacity),e.hasStroke()){var l=i.lineWidth,u=l/(i.strokeNoScale&&e.getLineScale?e.getLineScale():1);r.lineWidth!==u&&(s||(Oe(r,n),s=!0),r.lineWidth=u)}for(var f=0;f<u_.length;f++){var h=u_[f],v=h[0];(a||i[v]!==o[v])&&(s||(Oe(r,n),s=!0),r[v]=i[v]||h[1])}return s}function GO(r,e,t,a,n){return eC(r,$s(e,n.inHover),t&&$s(t,n.inHover),a,n)}function rC(r,e){var t=e.transform,a=r.dpr||1;t?r.setTransform(a*t[0],a*t[1],a*t[2],a*t[3],a*t[4],a*t[5]):r.setTransform(a,0,0,a,0,0)}function FO(r,e,t){for(var a=!1,n=0;n<r.length;n++){var i=r[n];a=a||i.isZeroArea(),rC(e,i),e.beginPath(),i.buildPath(e,i.shape),e.clip()}t.allClipped=a}function HO(r,e){return r&&e?r[0]!==e[0]||r[1]!==e[1]||r[2]!==e[2]||r[3]!==e[3]||r[4]!==e[4]||r[5]!==e[5]:!(!r&&!e)}var h_=1,v_=2,c_=3,p_=4;function WO(r){var e=gf(r),t=df(r);return!(r.lineDash||!(+e^+t)||e&&typeof r.fill!="string"||t&&typeof r.stroke!="string"||r.strokePercent<1||r.strokeOpacity<1||r.fillOpacity<1)}function Oe(r,e){e.batchFill&&r.fill(),e.batchStroke&&r.stroke(),e.batchFill="",e.batchStroke=""}function $s(r,e){return e&&r.__hoverStyle||r.style}function aC(r,e){Fn(r,e,{inHover:!1,viewWidth:0,viewHeight:0},!0)}function Fn(r,e,t,a){var n=e.transform;if(!e.shouldBePainted(t.viewWidth,t.viewHeight,!1,!1)){e.__dirty&=~ze,e.__isRendered=!1;return}var i=e.__clipPaths,o=t.prevElClipPaths,s=!1,l=!1;if((!o||kO(i,o))&&(o&&o.length&&(Oe(r,t),r.restore(),l=s=!0,t.prevElClipPaths=null,t.allClipped=!1,t.prevEl=null),i&&i.length&&(Oe(r,t),r.save(),FO(i,r,t),s=!0),t.prevElClipPaths=i),t.allClipped){e.__isRendered=!1;return}e.beforeBrush&&e.beforeBrush(),e.innerBeforeBrush();var u=t.prevEl;u||(l=s=!0);var f=e instanceof yt&&e.autoBatch&&WO(e.style);s||HO(n,u.transform)?(Oe(r,t),rC(r,e)):f||Oe(r,t);var h=$s(e,t.inHover);e instanceof yt?(t.lastDrawType!==h_&&(l=!0,t.lastDrawType=h_),f_(r,e,u,l,t),(!f||!t.batchFill&&!t.batchStroke)&&r.beginPath(),BO(r,e,h,f),f&&(t.batchFill=h.fill||"",t.batchStroke=h.stroke||"")):e instanceof Os?(t.lastDrawType!==c_&&(l=!0,t.lastDrawType=c_),f_(r,e,u,l,t),zO(r,e,h)):e instanceof he?(t.lastDrawType!==v_&&(l=!0,t.lastDrawType=v_),GO(r,e,u,l,t),VO(r,e,h)):e.getTemporalDisplayables&&(t.lastDrawType!==p_&&(l=!0,t.lastDrawType=p_),$O(r,e,t)),f&&a&&Oe(r,t),e.innerAfterBrush(),e.afterBrush&&e.afterBrush(),t.prevEl=e,e.__dirty=0,e.__isRendered=!0}function $O(r,e,t){var a=e.getDisplayables(),n=e.getTemporalDisplayables();r.save();var i={prevElClipPaths:null,prevEl:null,allClipped:!1,viewWidth:t.viewWidth,viewHeight:t.viewHeight,inHover:t.inHover},o,s;for(o=e.getCursor(),s=a.length;o<s;o++){var l=a[o];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),Fn(r,l,i,o===s-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),i.prevEl=l}for(var u=0,f=n.length;u<f;u++){var l=n[u];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),Fn(r,l,i,u===f-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),i.prevEl=l}e.clearTemporalDisplayables(),e.notClear=!0,r.restore()}var bv=new bO,d_=new nl(100),g_=["symbol","symbolSize","symbolKeepAspect","color","backgroundColor","dashArrayX","dashArrayY","maxTileWidth","maxTileHeight"];function ji(r,e){if(r==="none")return null;var t=e.getDevicePixelRatio(),a=e.getZr(),n=a.painter.type==="svg";r.dirty&&bv.delete(r);var i=bv.get(r);if(i)return i;var o=j(r,{symbol:"rect",symbolSize:1,symbolKeepAspect:!0,color:"rgba(0, 0, 0, 0.2)",backgroundColor:null,dashArrayX:5,dashArrayY:5,rotation:0,maxTileWidth:512,maxTileHeight:512});o.backgroundColor==="none"&&(o.backgroundColor=null);var s={repeat:"repeat"};return l(s),s.rotation=o.rotation,s.scaleX=s.scaleY=n?1:1/t,bv.set(r,s),r.dirty=!1,s;function l(u){for(var f=[t],h=!0,v=0;v<g_.length;++v){var c=o[g_[v]];if(c!=null&&!z(c)&&!$(c)&&!Ct(c)&&typeof c!="boolean"){h=!1;break}f.push(c)}var p;if(h){p=f.join(",")+(n?"-svg":"");var d=d_.get(p);d&&(n?u.svgElement=d:u.image=d)}var g=iC(o.dashArrayX),y=UO(o.dashArrayY),m=nC(o.symbol),_=YO(g),S=oC(y),w=!n&&Ha.createCanvas(),x=n&&{tag:"g",attrs:{},key:"dcl",children:[]},b=A(),T;w&&(w.width=b.width*t,w.height=b.height*t,T=w.getContext("2d")),D(),h&&d_.put(p,w||x),u.image=w,u.svgElement=x,u.svgWidth=b.width,u.svgHeight=b.height;function A(){for(var M=1,I=0,L=_.length;I<L;++I)M=Em(M,_[I]);for(var P=1,I=0,L=m.length;I<L;++I)P=Em(P,m[I].length);M*=P;var R=S*_.length*m.length;return{width:Math.max(1,Math.min(M,o.maxTileWidth)),height:Math.max(1,Math.min(R,o.maxTileHeight))}}function D(){T&&(T.clearRect(0,0,w.width,w.height),o.backgroundColor&&(T.fillStyle=o.backgroundColor,T.fillRect(0,0,w.width,w.height)));for(var M=0,I=0;I<y.length;++I)M+=y[I];if(M<=0)return;for(var L=-S,P=0,R=0,E=0;L<b.height;){if(P%2===0){for(var N=R/2%m.length,O=0,B=0,F=0;O<b.width*2;){for(var H=0,I=0;I<g[E].length;++I)H+=g[E][I];if(H<=0)break;if(B%2===0){var X=(1-o.symbolSize)*.5,Q=O+g[E][B]*X,J=L+y[P]*X,ct=g[E][B]*o.symbolSize,St=y[P]*o.symbolSize,pt=F/2%m[N].length;et(Q,J,ct,St,m[N][pt])}O+=g[E][B],++F,++B,B===g[E].length&&(B=0)}++E,E===g.length&&(E=0)}L+=y[P],++R,++P,P===y.length&&(P=0)}function et(dt,st,q,lt,Vt){var xt=n?1:t,Wt=qt(Vt,dt*xt,st*xt,q*xt,lt*xt,o.color,o.symbolKeepAspect);if(n){var Gt=a.painter.renderOneToVNode(Wt);Gt&&x.children.push(Gt)}else aC(T,Wt)}}}}function nC(r){if(!r||r.length===0)return[["rect"]];if($(r))return[[r]];for(var e=!0,t=0;t<r.length;++t)if(!$(r[t])){e=!1;break}if(e)return nC([r]);for(var a=[],t=0;t<r.length;++t)$(r[t])?a.push([r[t]]):a.push(r[t]);return a}function iC(r){if(!r||r.length===0)return[[0,0]];if(Ct(r)){var e=Math.ceil(r);return[[e,e]]}for(var t=!0,a=0;a<r.length;++a)if(!Ct(r[a])){t=!1;break}if(t)return iC([r]);for(var n=[],a=0;a<r.length;++a)if(Ct(r[a])){var e=Math.ceil(r[a]);n.push([e,e])}else{var e=G(r[a],function(s){return Math.ceil(s)});e.length%2===1?n.push(e.concat(e)):n.push(e)}return n}function UO(r){if(!r||typeof r=="object"&&r.length===0)return[0,0];if(Ct(r)){var e=Math.ceil(r);return[e,e]}var t=G(r,function(a){return Math.ceil(a)});return r.length%2?t.concat(t):t}function YO(r){return G(r,function(e){return oC(e)})}function oC(r){for(var e=0,t=0;t<r.length;++t)e+=r[t];return r.length%2===1?e*2:e}function ZO(r,e){r.eachRawSeries(function(t){if(!r.isSeriesFiltered(t)){var a=t.getData();a.hasItemVisual()&&a.each(function(o){var s=a.getItemVisual(o,"decal");if(s){var l=a.ensureUniqueItemVisual(o,"style");l.decal=ji(s,e)}});var n=a.getVisual("decal");if(n){var i=a.getVisual("style");i.decal=ji(n,e)}}})}var XO=new or;const cr=XO;var sC={};function qO(r,e){sC[r]=e}function KO(r){return sC[r]}var QO=1,JO=800,jO=900,tN=1e3,eN=2e3,rN=5e3,lC=1e3,aN=1100,zg=2e3,uC=3e3,nN=4e3,dh=4500,iN=4600,oN=5e3,sN=6e3,fC=7e3,lN={PROCESSOR:{FILTER:tN,SERIES_FILTER:JO,STATISTIC:rN},VISUAL:{LAYOUT:lC,PROGRESSIVE_LAYOUT:aN,GLOBAL:zg,CHART:uC,POST_CHART_LAYOUT:iN,COMPONENT:nN,BRUSH:oN,CHART_ITEM:dh,ARIA:sN,DECAL:fC}},pe="__flagInMainProcess",Pe="__pendingUpdate",Tv="__needsUpdateStatus",y_=/^[a-zA-Z0-9_]+$/,Av="__connectUpdateStatus",m_=0,uN=1,fN=2;function hC(r){return function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];if(this.isDisposed()){this.id;return}return cC(this,r,e)}}function vC(r){return function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return cC(this,r,e)}}function cC(r,e,t){return t[0]=t[0]&&t[0].toLowerCase(),or.prototype[e].apply(r,t)}var pC=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e}(or),dC=pC.prototype;dC.on=vC("on");dC.off=vC("off");var Ti,Cv,Kl,_a,Dv,Mv,Iv,Bo,Vo,__,S_,Lv,x_,Ql,w_,gC,$e,b_,yC=function(r){k(e,r);function e(t,a,n){var i=r.call(this,new yO)||this;i._chartsViews=[],i._chartsMap={},i._componentsViews=[],i._componentsMap={},i._pendingActions=[],n=n||{},$(a)&&(a=mC[a]),i._dom=t;var o="canvas",s="auto",l=!1;n.ssr&&q2(function(v){var c=nt(v),p=c.dataIndex;if(p!=null){var d=Z();return d.set("series_index",c.seriesIndex),d.set("data_index",p),c.ssrType&&d.set("ssr_type",c.ssrType),d}});var u=i._zr=Im(t,{renderer:n.renderer||o,devicePixelRatio:n.devicePixelRatio,width:n.width,height:n.height,ssr:n.ssr,useDirtyRect:it(n.useDirtyRect,l),useCoarsePointer:it(n.useCoarsePointer,s),pointerSize:n.pointerSize});i._ssr=n.ssr,i._throttledZrFlush=Ng(U(u.flush,u),17),a=rt(a),a&&bA(a,!0),i._theme=a,i._locale=CE(n.locale||JT),i._coordSysMgr=new fl;var f=i._api=w_(i);function h(v,c){return v.__prio-c.__prio}return Pu(mf,h),Pu(Xp,h),i._scheduler=new XA(i,f,Xp,mf),i._messageCenter=new pC,i._initEvents(),i.resize=U(i.resize,i),u.animation.on("frame",i._onframe,i),__(u,i),S_(u,i),Xu(i),i}return e.prototype._onframe=function(){if(!this._disposed){b_(this);var t=this._scheduler;if(this[Pe]){var a=this[Pe].silent;this[pe]=!0;try{Ti(this),_a.update.call(this,null,this[Pe].updateParams)}catch(l){throw this[pe]=!1,this[Pe]=null,l}this._zr.flush(),this[pe]=!1,this[Pe]=null,Bo.call(this,a),Vo.call(this,a)}else if(t.unfinished){var n=QO,i=this._model,o=this._api;t.unfinished=!1;do{var s=+new Date;t.performSeriesTasks(i),t.performDataProcessorTasks(i),Mv(this,i),t.performVisualTasks(i),Ql(this,this._model,o,"remain",{}),n-=+new Date-s}while(n>0&&t.unfinished);t.unfinished||this._zr.flush()}}},e.prototype.getDom=function(){return this._dom},e.prototype.getId=function(){return this.id},e.prototype.getZr=function(){return this._zr},e.prototype.isSSR=function(){return this._ssr},e.prototype.setOption=function(t,a,n){if(!this[pe]){if(this._disposed){this.id;return}var i,o,s;if(tt(a)&&(n=a.lazyUpdate,i=a.silent,o=a.replaceMerge,s=a.transition,a=a.notMerge),this[pe]=!0,!this._model||a){var l=new ak(this._api),u=this._theme,f=this._model=new Mg;f.scheduler=this._scheduler,f.ssr=this._ssr,f.init(null,null,null,u,this._locale,l)}this._model.setOption(t,{replaceMerge:o},qp);var h={seriesTransition:s,optionChanged:!0};if(n)this[Pe]={silent:i,updateParams:h},this[pe]=!1,this.getZr().wakeUp();else{try{Ti(this),_a.update.call(this,null,h)}catch(v){throw this[Pe]=null,this[pe]=!1,v}this._ssr||this._zr.flush(),this[Pe]=null,this[pe]=!1,Bo.call(this,i),Vo.call(this,i)}}},e.prototype.setTheme=function(){},e.prototype.getModel=function(){return this._model},e.prototype.getOption=function(){return this._model&&this._model.getOption()},e.prototype.getWidth=function(){return this._zr.getWidth()},e.prototype.getHeight=function(){return this._zr.getHeight()},e.prototype.getDevicePixelRatio=function(){return this._zr.painter.dpr||mt.hasGlobalWindow&&window.devicePixelRatio||1},e.prototype.getRenderedCanvas=function(t){return this.renderToCanvas(t)},e.prototype.renderToCanvas=function(t){t=t||{};var a=this._zr.painter;return a.getRenderedCanvas({backgroundColor:t.backgroundColor||this._model.get("backgroundColor"),pixelRatio:t.pixelRatio||this.getDevicePixelRatio()})},e.prototype.renderToSVGString=function(t){t=t||{};var a=this._zr.painter;return a.renderToString({useViewBox:t.useViewBox})},e.prototype.getSvgDataURL=function(){if(mt.svgSupported){var t=this._zr,a=t.storage.getDisplayList();return C(a,function(n){n.stopAnimation(null,!0)}),t.painter.toDataURL()}},e.prototype.getDataURL=function(t){if(this._disposed){this.id;return}t=t||{};var a=t.excludeComponents,n=this._model,i=[],o=this;C(a,function(l){n.eachComponent({mainType:l},function(u){var f=o._componentsMap[u.__viewId];f.group.ignore||(i.push(f),f.group.ignore=!0)})});var s=this._zr.painter.getType()==="svg"?this.getSvgDataURL():this.renderToCanvas(t).toDataURL("image/"+(t&&t.type||"png"));return C(i,function(l){l.group.ignore=!1}),s},e.prototype.getConnectedDataURL=function(t){if(this._disposed){this.id;return}var a=t.type==="svg",n=this.group,i=Math.min,o=Math.max,s=1/0;if(T_[n]){var l=s,u=s,f=-s,h=-s,v=[],c=t&&t.pixelRatio||this.getDevicePixelRatio();C(Ts,function(_,S){if(_.group===n){var w=a?_.getZr().painter.getSvgDom().innerHTML:_.renderToCanvas(rt(t)),x=_.getDom().getBoundingClientRect();l=i(x.left,l),u=i(x.top,u),f=o(x.right,f),h=o(x.bottom,h),v.push({dom:w,left:x.left,top:x.top})}}),l*=c,u*=c,f*=c,h*=c;var p=f-l,d=h-u,g=Ha.createCanvas(),y=Im(g,{renderer:a?"svg":"canvas"});if(y.resize({width:p,height:d}),a){var m="";return C(v,function(_){var S=_.left-l,w=_.top-u;m+='<g transform="translate('+S+","+w+')">'+_.dom+"</g>"}),y.painter.getSvgRoot().innerHTML=m,t.connectedBackgroundColor&&y.painter.setBackgroundColor(t.connectedBackgroundColor),y.refreshImmediately(),y.painter.toDataURL()}else return t.connectedBackgroundColor&&y.add(new wt({shape:{x:0,y:0,width:p,height:d},style:{fill:t.connectedBackgroundColor}})),C(v,function(_){var S=new he({style:{x:_.left*c-l,y:_.top*c-u,image:_.dom}});y.add(S)}),y.refreshImmediately(),g.toDataURL("image/"+(t&&t.type||"png"))}else return this.getDataURL(t)},e.prototype.convertToPixel=function(t,a){return Dv(this,"convertToPixel",t,a)},e.prototype.convertFromPixel=function(t,a){return Dv(this,"convertFromPixel",t,a)},e.prototype.containPixel=function(t,a){if(this._disposed){this.id;return}var n=this._model,i,o=ys(n,t);return C(o,function(s,l){l.indexOf("Models")>=0&&C(s,function(u){var f=u.coordinateSystem;if(f&&f.containPoint)i=i||!!f.containPoint(a);else if(l==="seriesModels"){var h=this._chartsMap[u.__viewId];h&&h.containPoint&&(i=i||h.containPoint(a,u))}},this)},this),!!i},e.prototype.getVisual=function(t,a){var n=this._model,i=ys(n,t,{defaultMainType:"series"}),o=i.seriesModel,s=o.getData(),l=i.hasOwnProperty("dataIndexInside")?i.dataIndexInside:i.hasOwnProperty("dataIndex")?s.indexOfRawIndex(i.dataIndex):null;return l!=null?Bg(s,l,a):hl(s,a)},e.prototype.getViewOfComponentModel=function(t){return this._componentsMap[t.__viewId]},e.prototype.getViewOfSeriesModel=function(t){return this._chartsMap[t.__viewId]},e.prototype._initEvents=function(){var t=this;C(hN,function(a){var n=function(i){var o=t.getModel(),s=i.target,l,u=a==="globalout";if(u?l={}:s&&zn(s,function(p){var d=nt(p);if(d&&d.dataIndex!=null){var g=d.dataModel||o.getSeriesByIndex(d.seriesIndex);return l=g&&g.getDataParams(d.dataIndex,d.dataType,s)||{},!0}else if(d.eventData)return l=V({},d.eventData),!0},!0),l){var f=l.componentType,h=l.componentIndex;(f==="markLine"||f==="markPoint"||f==="markArea")&&(f="series",h=l.seriesIndex);var v=f&&h!=null&&o.getComponent(f,h),c=v&&t[v.mainType==="series"?"_chartsMap":"_componentsMap"][v.__viewId];l.event=i,l.type=a,t._$eventProcessor.eventInfo={targetEl:s,packedEvent:l,model:v,view:c},t.trigger(a,l)}};n.zrEventfulCallAtLast=!0,t._zr.on(a,n,t)}),C(bs,function(a,n){t._messageCenter.on(n,function(i){this.trigger(n,i)},t)}),C(["selectchanged"],function(a){t._messageCenter.on(a,function(n){this.trigger(a,n)},t)}),SO(this._messageCenter,this,this._api)},e.prototype.isDisposed=function(){return this._disposed},e.prototype.clear=function(){if(this._disposed){this.id;return}this.setOption({series:[]},!0)},e.prototype.dispose=function(){if(this._disposed){this.id;return}this._disposed=!0;var t=this.getDom();t&&tT(this.getDom(),Fg,"");var a=this,n=a._api,i=a._model;C(a._componentsViews,function(o){o.dispose(i,n)}),C(a._chartsViews,function(o){o.dispose(i,n)}),a._zr.dispose(),a._dom=a._model=a._chartsMap=a._componentsMap=a._chartsViews=a._componentsViews=a._scheduler=a._api=a._zr=a._throttledZrFlush=a._theme=a._coordSysMgr=a._messageCenter=null,delete Ts[a.id]},e.prototype.resize=function(t){if(!this[pe]){if(this._disposed){this.id;return}this._zr.resize(t);var a=this._model;if(this._loadingFX&&this._loadingFX.resize(),!!a){var n=a.resetOption("media"),i=t&&t.silent;this[Pe]&&(i==null&&(i=this[Pe].silent),n=!0,this[Pe]=null),this[pe]=!0;try{n&&Ti(this),_a.update.call(this,{type:"resize",animation:V({duration:0},t&&t.animation)})}catch(o){throw this[pe]=!1,o}this[pe]=!1,Bo.call(this,i),Vo.call(this,i)}}},e.prototype.showLoading=function(t,a){if(this._disposed){this.id;return}if(tt(t)&&(a=t,t=""),t=t||"default",this.hideLoading(),!!Kp[t]){var n=Kp[t](this._api,a),i=this._zr;this._loadingFX=n,i.add(n)}},e.prototype.hideLoading=function(){if(this._disposed){this.id;return}this._loadingFX&&this._zr.remove(this._loadingFX),this._loadingFX=null},e.prototype.makeActionFromEvent=function(t){var a=V({},t);return a.type=bs[t.type],a},e.prototype.dispatchAction=function(t,a){if(this._disposed){this.id;return}if(tt(a)||(a={silent:!!a}),!!yf[t.type]&&this._model){if(this[pe]){this._pendingActions.push(t);return}var n=a.silent;Iv.call(this,t,n);var i=a.flush;i?this._zr.flush():i!==!1&&mt.browser.weChat&&this._throttledZrFlush(),Bo.call(this,n),Vo.call(this,n)}},e.prototype.updateLabelLayout=function(){cr.trigger("series:layoutlabels",this._model,this._api,{updatedSeries:[]})},e.prototype.appendData=function(t){if(this._disposed){this.id;return}var a=t.seriesIndex,n=this.getModel(),i=n.getSeriesByIndex(a);i.appendData(t),this._scheduler.unfinished=!0,this.getZr().wakeUp()},e.internalField=function(){Ti=function(h){var v=h._scheduler;v.restorePipelines(h._model),v.prepareStageTasks(),Cv(h,!0),Cv(h,!1),v.plan()},Cv=function(h,v){for(var c=h._model,p=h._scheduler,d=v?h._componentsViews:h._chartsViews,g=v?h._componentsMap:h._chartsMap,y=h._zr,m=h._api,_=0;_<d.length;_++)d[_].__alive=!1;v?c.eachComponent(function(x,b){x!=="series"&&S(b)}):c.eachSeries(S);function S(x){var b=x.__requireNewView;x.__requireNewView=!1;var T="_ec_"+x.id+"_"+x.type,A=!b&&g[T];if(!A){var D=kr(x.type),M=v?Ht.getClass(D.main,D.sub):Nt.getClass(D.sub);A=new M,A.init(c,m),g[T]=A,d.push(A),y.add(A.group)}x.__viewId=A.__id=T,A.__alive=!0,A.__model=x,A.group.__ecComponentInfo={mainType:x.mainType,index:x.componentIndex},!v&&p.prepareView(A,x,c,m)}for(var _=0;_<d.length;){var w=d[_];w.__alive?_++:(!v&&w.renderTask.dispose(),y.remove(w.group),w.dispose(c,m),d.splice(_,1),g[w.__id]===w&&delete g[w.__id],w.__id=w.group.__ecComponentInfo=null)}},Kl=function(h,v,c,p,d){var g=h._model;if(g.setUpdatePayload(c),!p){C([].concat(h._componentsViews).concat(h._chartsViews),w);return}var y={};y[p+"Id"]=c[p+"Id"],y[p+"Index"]=c[p+"Index"],y[p+"Name"]=c[p+"Name"];var m={mainType:p,query:y};d&&(m.subType=d);var _=c.excludeSeriesId,S;_!=null&&(S=Z(),C(Pt(_),function(x){var b=Qt(x,null);b!=null&&S.set(b,!0)})),g&&g.eachComponent(m,function(x){var b=S&&S.get(x.id)!=null;if(!b)if(i0(c))if(x instanceof zt)c.type===Yn&&!c.notBlur&&!x.get(["emphasis","disabled"])&&_R(x,c,h._api);else{var T=hg(x.mainType,x.componentIndex,c.name,h._api),A=T.focusSelf,D=T.dispatchers;c.type===Yn&&A&&!c.notBlur&&Lp(x.mainType,x.componentIndex,h._api),D&&C(D,function(M){c.type===Yn?sa(M):la(M)})}else Rp(c)&&x instanceof zt&&(wR(x,c,h._api),a0(x),$e(h))},h),g&&g.eachComponent(m,function(x){var b=S&&S.get(x.id)!=null;b||w(h[p==="series"?"_chartsMap":"_componentsMap"][x.__viewId])},h);function w(x){x&&x.__alive&&x[v]&&x[v](x.__model,g,h._api,c)}},_a={prepareAndUpdate:function(h){Ti(this),_a.update.call(this,h,{optionChanged:h.newOption!=null})},update:function(h,v){var c=this._model,p=this._api,d=this._zr,g=this._coordSysMgr,y=this._scheduler;if(c){c.setUpdatePayload(h),y.restoreData(c,h),y.performSeriesTasks(c),g.create(c,p),y.performDataProcessorTasks(c,h),Mv(this,c),g.update(c,p),t(c),y.performVisualTasks(c,h),Lv(this,c,p,h,v);var m=c.get("backgroundColor")||"transparent",_=c.get("darkMode");d.setBackgroundColor(m),_!=null&&_!=="auto"&&d.setDarkMode(_),cr.trigger("afterupdate",c,p)}},updateTransform:function(h){var v=this,c=this._model,p=this._api;if(c){c.setUpdatePayload(h);var d=[];c.eachComponent(function(y,m){if(y!=="series"){var _=v.getViewOfComponentModel(m);if(_&&_.__alive)if(_.updateTransform){var S=_.updateTransform(m,c,p,h);S&&S.update&&d.push(_)}else d.push(_)}});var g=Z();c.eachSeries(function(y){var m=v._chartsMap[y.__viewId];if(m.updateTransform){var _=m.updateTransform(y,c,p,h);_&&_.update&&g.set(y.uid,1)}else g.set(y.uid,1)}),t(c),this._scheduler.performVisualTasks(c,h,{setDirty:!0,dirtyMap:g}),Ql(this,c,p,h,{},g),cr.trigger("afterupdate",c,p)}},updateView:function(h){var v=this._model;v&&(v.setUpdatePayload(h),Nt.markUpdateMethod(h,"updateView"),t(v),this._scheduler.performVisualTasks(v,h,{setDirty:!0}),Lv(this,v,this._api,h,{}),cr.trigger("afterupdate",v,this._api))},updateVisual:function(h){var v=this,c=this._model;c&&(c.setUpdatePayload(h),c.eachSeries(function(p){p.getData().clearAllVisual()}),Nt.markUpdateMethod(h,"updateVisual"),t(c),this._scheduler.performVisualTasks(c,h,{visualType:"visual",setDirty:!0}),c.eachComponent(function(p,d){if(p!=="series"){var g=v.getViewOfComponentModel(d);g&&g.__alive&&g.updateVisual(d,c,v._api,h)}}),c.eachSeries(function(p){var d=v._chartsMap[p.__viewId];d.updateVisual(p,c,v._api,h)}),cr.trigger("afterupdate",c,this._api))},updateLayout:function(h){_a.update.call(this,h)}},Dv=function(h,v,c,p){if(h._disposed){h.id;return}for(var d=h._model,g=h._coordSysMgr.getCoordinateSystems(),y,m=ys(d,c),_=0;_<g.length;_++){var S=g[_];if(S[v]&&(y=S[v](d,m,p))!=null)return y}},Mv=function(h,v){var c=h._chartsMap,p=h._scheduler;v.eachSeries(function(d){p.updateStreamModes(d,c[d.__viewId])})},Iv=function(h,v){var c=this,p=this.getModel(),d=h.type,g=h.escapeConnect,y=yf[d],m=y.actionInfo,_=(m.update||"update").split(":"),S=_.pop(),w=_[0]!=null&&kr(_[0]);this[pe]=!0;var x=[h],b=!1;h.batch&&(b=!0,x=G(h.batch,function(P){return P=j(V({},P),h),P.batch=null,P}));var T=[],A,D=Rp(h),M=i0(h);if(M&&AT(this._api),C(x,function(P){if(A=y.action(P,c._model,c._api),A=A||V({},P),A.type=m.event||A.type,T.push(A),M){var R=ag(h),E=R.queryOptionMap,N=R.mainTypeSpecified,O=N?E.keys()[0]:"series";Kl(c,S,P,O),$e(c)}else D?(Kl(c,S,P,"series"),$e(c)):w&&Kl(c,S,P,w.main,w.sub)}),S!=="none"&&!M&&!D&&!w)try{this[Pe]?(Ti(this),_a.update.call(this,h),this[Pe]=null):_a[S].call(this,h)}catch(P){throw this[pe]=!1,P}if(b?A={type:m.event||d,escapeConnect:g,batch:T}:A=T[0],this[pe]=!1,!v){var I=this._messageCenter;if(I.trigger(A.type,A),D){var L={type:"selectchanged",escapeConnect:g,selected:bR(p),isFromClick:h.isFromClick||!1,fromAction:h.type,fromActionPayload:h};I.trigger(L.type,L)}}},Bo=function(h){for(var v=this._pendingActions;v.length;){var c=v.shift();Iv.call(this,c,h)}},Vo=function(h){!h&&this.trigger("updated")},__=function(h,v){h.on("rendered",function(c){v.trigger("rendered",c),h.animation.isFinished()&&!v[Pe]&&!v._scheduler.unfinished&&!v._pendingActions.length&&v.trigger("finished")})},S_=function(h,v){h.on("mouseover",function(c){var p=c.target,d=zn(p,Bs);d&&(SR(d,c,v._api),$e(v))}).on("mouseout",function(c){var p=c.target,d=zn(p,Bs);d&&(xR(d,c,v._api),$e(v))}).on("click",function(c){var p=c.target,d=zn(p,function(m){return nt(m).dataIndex!=null},!0);if(d){var g=d.selected?"unselect":"select",y=nt(d);v._api.dispatchAction({type:g,dataType:y.dataType,dataIndexInside:y.dataIndex,seriesIndex:y.seriesIndex,isFromClick:!0})}})};function t(h){h.clearColorPalette(),h.eachSeries(function(v){v.clearColorPalette()})}function a(h){var v=[],c=[],p=!1;if(h.eachComponent(function(m,_){var S=_.get("zlevel")||0,w=_.get("z")||0,x=_.getZLevelKey();p=p||!!x,(m==="series"?c:v).push({zlevel:S,z:w,idx:_.componentIndex,type:m,key:x})}),p){var d=v.concat(c),g,y;Pu(d,function(m,_){return m.zlevel===_.zlevel?m.z-_.z:m.zlevel-_.zlevel}),C(d,function(m){var _=h.getComponent(m.type,m.idx),S=m.zlevel,w=m.key;g!=null&&(S=Math.max(g,S)),w?(S===g&&w!==y&&S++,y=w):y&&(S===g&&S++,y=""),g=S,_.setZLevel(S)})}}Lv=function(h,v,c,p,d){a(v),x_(h,v,c,p,d),C(h._chartsViews,function(g){g.__alive=!1}),Ql(h,v,c,p,d),C(h._chartsViews,function(g){g.__alive||g.remove(v,c)})},x_=function(h,v,c,p,d,g){C(g||h._componentsViews,function(y){var m=y.__model;u(m,y),y.render(m,v,c,p),s(m,y),f(m,y)})},Ql=function(h,v,c,p,d,g){var y=h._scheduler;d=V(d||{},{updatedSeries:v.getSeries()}),cr.trigger("series:beforeupdate",v,c,d);var m=!1;v.eachSeries(function(_){var S=h._chartsMap[_.__viewId];S.__alive=!0;var w=S.renderTask;y.updatePayload(w,p),u(_,S),g&&g.get(_.uid)&&w.dirty(),w.perform(y.getPerformArgs(w))&&(m=!0),S.group.silent=!!_.get("silent"),o(_,S),a0(_)}),y.unfinished=m||y.unfinished,cr.trigger("series:layoutlabels",v,c,d),cr.trigger("series:transition",v,c,d),v.eachSeries(function(_){var S=h._chartsMap[_.__viewId];s(_,S),f(_,S)}),i(h,v),cr.trigger("series:afterupdate",v,c,d)},$e=function(h){h[Tv]=!0,h.getZr().wakeUp()},b_=function(h){h[Tv]&&(h.getZr().storage.traverse(function(v){Ui(v)||n(v)}),h[Tv]=!1)};function n(h){for(var v=[],c=h.currentStates,p=0;p<c.length;p++){var d=c[p];d==="emphasis"||d==="blur"||d==="select"||v.push(d)}h.selected&&h.states.select&&v.push("select"),h.hoverState===jf&&h.states.emphasis?v.push("emphasis"):h.hoverState===sl&&h.states.blur&&v.push("blur"),h.useStates(v)}function i(h,v){var c=h._zr,p=c.storage,d=0;p.traverse(function(g){g.isGroup||d++}),d>v.get("hoverLayerThreshold")&&!mt.node&&!mt.worker&&v.eachSeries(function(g){if(!g.preventUsingHoverLayer){var y=h._chartsMap[g.__viewId];y.__alive&&y.eachRendered(function(m){m.states.emphasis&&(m.states.emphasis.hoverLayer=!0)})}})}function o(h,v){var c=h.get("blendMode")||null;v.eachRendered(function(p){p.isGroup||(p.style.blend=c)})}function s(h,v){if(!h.preventAutoZ){var c=h.get("z")||0,p=h.get("zlevel")||0;v.eachRendered(function(d){return l(d,c,p,-1/0),!0})}}function l(h,v,c,p){var d=h.getTextContent(),g=h.getTextGuideLine(),y=h.isGroup;if(y)for(var m=h.childrenRef(),_=0;_<m.length;_++)p=Math.max(l(m[_],v,c,p),p);else h.z=v,h.zlevel=c,p=Math.max(h.z2,p);if(d&&(d.z=v,d.zlevel=c,isFinite(p)&&(d.z2=p+2)),g){var S=h.textGuideLineConfig;g.z=v,g.zlevel=c,isFinite(p)&&(g.z2=p+(S&&S.showAbove?1:-1))}return p}function u(h,v){v.eachRendered(function(c){if(!Ui(c)){var p=c.getTextContent(),d=c.getTextGuideLine();c.stateTransition&&(c.stateTransition=null),p&&p.stateTransition&&(p.stateTransition=null),d&&d.stateTransition&&(d.stateTransition=null),c.hasState()?(c.prevStates=c.currentStates,c.clearStates()):c.prevStates&&(c.prevStates=null)}})}function f(h,v){var c=h.getModel("stateAnimation"),p=h.isAnimationEnabled(),d=c.get("duration"),g=d>0?{duration:d,delay:c.get("delay"),easing:c.get("easing")}:null;v.eachRendered(function(y){if(y.states&&y.states.emphasis){if(Ui(y))return;if(y instanceof yt&&MR(y),y.__dirty){var m=y.prevStates;m&&y.useStates(m)}if(p){y.stateTransition=g;var _=y.getTextContent(),S=y.getTextGuideLine();_&&(_.stateTransition=g),S&&(S.stateTransition=g)}y.__dirty&&n(y)}})}w_=function(h){return new(function(v){k(c,v);function c(){return v!==null&&v.apply(this,arguments)||this}return c.prototype.getCoordinateSystems=function(){return h._coordSysMgr.getCoordinateSystems()},c.prototype.getComponentByElement=function(p){for(;p;){var d=p.__ecComponentInfo;if(d!=null)return h._model.getComponent(d.mainType,d.index);p=p.parent}},c.prototype.enterEmphasis=function(p,d){sa(p,d),$e(h)},c.prototype.leaveEmphasis=function(p,d){la(p,d),$e(h)},c.prototype.enterBlur=function(p){xT(p),$e(h)},c.prototype.leaveBlur=function(p){fg(p),$e(h)},c.prototype.enterSelect=function(p){wT(p),$e(h)},c.prototype.leaveSelect=function(p){bT(p),$e(h)},c.prototype.getModel=function(){return h.getModel()},c.prototype.getViewOfComponentModel=function(p){return h.getViewOfComponentModel(p)},c.prototype.getViewOfSeriesModel=function(p){return h.getViewOfSeriesModel(p)},c}(xA))(h)},gC=function(h){function v(c,p){for(var d=0;d<c.length;d++){var g=c[d];g[Av]=p}}C(bs,function(c,p){h._messageCenter.on(p,function(d){if(T_[h.group]&&h[Av]!==m_){if(d&&d.escapeConnect)return;var g=h.makeActionFromEvent(d),y=[];C(Ts,function(m){m!==h&&m.group===h.group&&y.push(m)}),v(y,m_),C(y,function(m){m[Av]!==uN&&m.dispatchAction(g)}),v(y,fN)}})})}}(),e}(or),Gg=yC.prototype;Gg.on=hC("on");Gg.off=hC("off");Gg.one=function(r,e,t){var a=this;function n(){for(var i=[],o=0;o<arguments.length;o++)i[o]=arguments[o];e&&e.apply&&e.apply(this,i),a.off(r,n)}this.on.call(this,r,n,t)};var hN=["click","dblclick","mouseover","mouseout","mousemove","mousedown","mouseup","globalout","contextmenu"];var yf={},bs={},Xp=[],qp=[],mf=[],mC={},Kp={},Ts={},T_={},vN=+new Date-0,Fg="_echarts_instance_";function cN(r,e,t){var a=!(t&&t.ssr);if(a){var n=pN(r);if(n)return n}var i=new yC(r,e,t);return i.id="ec_"+vN++,Ts[i.id]=i,a&&tT(r,Fg,i.id),gC(i),cr.trigger("afterinit",i),i}function pN(r){return Ts[dP(r,Fg)]}function _C(r,e){mC[r]=e}function SC(r){vt(qp,r)<0&&qp.push(r)}function xC(r,e){Wg(Xp,r,e,eN)}function dN(r){Hg("afterinit",r)}function gN(r){Hg("afterupdate",r)}function Hg(r,e){cr.on(r,e)}function Ur(r,e,t){K(e)&&(t=e,e="");var a=tt(r)?r.type:[r,r={event:e}][0];r.event=(r.event||a).toLowerCase(),e=r.event,!bs[e]&&(Ae(y_.test(a)&&y_.test(e)),yf[a]||(yf[a]={action:t,actionInfo:r}),bs[e]=a)}function yN(r,e){fl.register(r,e)}function mN(r,e){Wg(mf,r,e,lC,"layout")}function fi(r,e){Wg(mf,r,e,uC,"visual")}var A_=[];function Wg(r,e,t,a,n){if((K(e)||tt(e))&&(t=e,e=a),!(vt(A_,t)>=0)){A_.push(t);var i=XA.wrapStageHandler(t,n);i.__prio=e,i.__raw=t,r.push(i)}}function wC(r,e){Kp[r]=e}function _N(r,e,t){var a=KO("registerMap");a&&a(r,e,t)}var SN=Pk;fi(zg,rO);fi(dh,aO);fi(dh,nO);fi(zg,mO);fi(dh,_O);fi(fC,ZO);SC(bA);xC(jO,hk);wC("default",iO);Ur({type:Yn,event:Yn,update:Yn},Yt);Ur({type:Nu,event:Nu,update:Nu},Yt);Ur({type:ms,event:ms,update:ms},Yt);Ur({type:Bu,event:Bu,update:Bu},Yt);Ur({type:_s,event:_s,update:_s},Yt);_C("light",dO);_C("dark",gO);var C_=[],xN={registerPreprocessor:SC,registerProcessor:xC,registerPostInit:dN,registerPostUpdate:gN,registerUpdateLifecycle:Hg,registerAction:Ur,registerCoordinateSystem:yN,registerLayout:mN,registerVisual:fi,registerTransform:SN,registerLoading:wC,registerMap:_N,registerImpl:qO,PRIORITY:lN,ComponentModel:Tt,ComponentView:Ht,SeriesModel:zt,ChartView:Nt,registerComponentModel:function(r){Tt.registerClass(r)},registerComponentView:function(r){Ht.registerClass(r)},registerSeriesModel:function(r){zt.registerClass(r)},registerChartView:function(r){Nt.registerClass(r)},registerSubTypeDefaulter:function(r,e){Tt.registerSubTypeDefaulter(r,e)},registerPainter:function(r,e){Z2(r,e)}};function gt(r){if(z(r)){C(r,function(e){gt(e)});return}vt(C_,r)>=0||(C_.push(r),K(r)&&(r={install:r}),r.install(xN))}function zo(r){return r==null?0:r.length||1}function D_(r){return r}var wN=function(){function r(e,t,a,n,i,o){this._old=e,this._new=t,this._oldKeyGetter=a||D_,this._newKeyGetter=n||D_,this.context=i,this._diffModeMultiple=o==="multiple"}return r.prototype.add=function(e){return this._add=e,this},r.prototype.update=function(e){return this._update=e,this},r.prototype.updateManyToOne=function(e){return this._updateManyToOne=e,this},r.prototype.updateOneToMany=function(e){return this._updateOneToMany=e,this},r.prototype.updateManyToMany=function(e){return this._updateManyToMany=e,this},r.prototype.remove=function(e){return this._remove=e,this},r.prototype.execute=function(){this[this._diffModeMultiple?"_executeMultiple":"_executeOneToOne"]()},r.prototype._executeOneToOne=function(){var e=this._old,t=this._new,a={},n=new Array(e.length),i=new Array(t.length);this._initIndexMap(e,null,n,"_oldKeyGetter"),this._initIndexMap(t,a,i,"_newKeyGetter");for(var o=0;o<e.length;o++){var s=n[o],l=a[s],u=zo(l);if(u>1){var f=l.shift();l.length===1&&(a[s]=l[0]),this._update&&this._update(f,o)}else u===1?(a[s]=null,this._update&&this._update(l,o)):this._remove&&this._remove(o)}this._performRestAdd(i,a)},r.prototype._executeMultiple=function(){var e=this._old,t=this._new,a={},n={},i=[],o=[];this._initIndexMap(e,a,i,"_oldKeyGetter"),this._initIndexMap(t,n,o,"_newKeyGetter");for(var s=0;s<i.length;s++){var l=i[s],u=a[l],f=n[l],h=zo(u),v=zo(f);if(h>1&&v===1)this._updateManyToOne&&this._updateManyToOne(f,u),n[l]=null;else if(h===1&&v>1)this._updateOneToMany&&this._updateOneToMany(f,u),n[l]=null;else if(h===1&&v===1)this._update&&this._update(f,u),n[l]=null;else if(h>1&&v>1)this._updateManyToMany&&this._updateManyToMany(f,u),n[l]=null;else if(h>1)for(var c=0;c<h;c++)this._remove&&this._remove(u[c]);else this._remove&&this._remove(u)}this._performRestAdd(o,n)},r.prototype._performRestAdd=function(e,t){for(var a=0;a<e.length;a++){var n=e[a],i=t[n],o=zo(i);if(o>1)for(var s=0;s<o;s++)this._add&&this._add(i[s]);else o===1&&this._add&&this._add(i);t[n]=null}},r.prototype._initIndexMap=function(e,t,a,n){for(var i=this._diffModeMultiple,o=0;o<e.length;o++){var s="_ec_"+this[n](e[o],o);if(i||(a[o]=s),!!t){var l=t[s],u=zo(l);u===0?(t[s]=o,i&&a.push(s)):u===1?t[s]=[l,o]:l.push(o)}}},r}();const ua=wN;var bN=function(){function r(e,t){this._encode=e,this._schema=t}return r.prototype.get=function(){return{fullDimensions:this._getFullDimensionNames(),encode:this._encode}},r.prototype._getFullDimensionNames=function(){return this._cachedDimNames||(this._cachedDimNames=this._schema?this._schema.makeOutputDimensionNames():[]),this._cachedDimNames},r}();function TN(r,e){var t={},a=t.encode={},n=Z(),i=[],o=[],s={};C(r.dimensions,function(v){var c=r.getDimensionInfo(v),p=c.coordDim;if(p){var d=c.coordDimIndex;Pv(a,p)[d]=v,c.isExtraCoord||(n.set(p,1),AN(c.type)&&(i[0]=v),Pv(s,p)[d]=r.getDimensionIndex(c.name)),c.defaultTooltip&&o.push(v)}pA.each(function(g,y){var m=Pv(a,y),_=c.otherDims[y];_!=null&&_!==!1&&(m[_]=c.name)})});var l=[],u={};n.each(function(v,c){var p=a[c];u[c]=p[0],l=l.concat(p)}),t.dataDimsOnCoord=l,t.dataDimIndicesOnCoord=G(l,function(v){return r.getDimensionInfo(v).storeDimIndex}),t.encodeFirstDimNotExtra=u;var f=a.label;f&&f.length&&(i=f.slice());var h=a.tooltip;return h&&h.length?o=h.slice():o.length||(o=i.slice()),a.defaultedLabel=i,a.defaultedTooltip=o,t.userOutput=new bN(s,e),t}function Pv(r,e){return r.hasOwnProperty(e)||(r[e]=[]),r[e]}function _f(r){return r==="category"?"ordinal":r==="time"?"time":"float"}function AN(r){return!(r==="ordinal"||r==="time")}var Hu=function(){function r(e){this.otherDims={},e!=null&&V(this,e)}return r}(),CN=bt(),DN={float:"f",int:"i",ordinal:"o",number:"n",time:"t"},bC=function(){function r(e){this.dimensions=e.dimensions,this._dimOmitted=e.dimensionOmitted,this.source=e.source,this._fullDimCount=e.fullDimensionCount,this._updateDimOmitted(e.dimensionOmitted)}return r.prototype.isDimensionOmitted=function(){return this._dimOmitted},r.prototype._updateDimOmitted=function(e){this._dimOmitted=e,e&&(this._dimNameMap||(this._dimNameMap=CC(this.source)))},r.prototype.getSourceDimensionIndex=function(e){return it(this._dimNameMap.get(e),-1)},r.prototype.getSourceDimension=function(e){var t=this.source.dimensionsDefine;if(t)return t[e]},r.prototype.makeStoreSchema=function(){for(var e=this._fullDimCount,t=AA(this.source),a=!DC(e),n="",i=[],o=0,s=0;o<e;o++){var l=void 0,u=void 0,f=void 0,h=this.dimensions[s];if(h&&h.storeDimIndex===o)l=t?h.name:null,u=h.type,f=h.ordinalMeta,s++;else{var v=this.getSourceDimension(o);v&&(l=t?v.name:null,u=v.type)}i.push({property:l,type:u,ordinalMeta:f}),t&&l!=null&&(!h||!h.isCalculationCoord)&&(n+=a?l.replace(/\`/g,"`1").replace(/\$/g,"`2"):l),n+="$",n+=DN[u]||"f",f&&(n+=f.uid),n+="$"}var c=this.source,p=[c.seriesLayoutBy,c.startIndex,n].join("$$");return{dimensions:i,hash:p}},r.prototype.makeOutputDimensionNames=function(){for(var e=[],t=0,a=0;t<this._fullDimCount;t++){var n=void 0,i=this.dimensions[a];if(i&&i.storeDimIndex===t)i.isCalculationCoord||(n=i.name),a++;else{var o=this.getSourceDimension(t);o&&(n=o.name)}e.push(n)}return e},r.prototype.appendCalculationDimension=function(e){this.dimensions.push(e),e.isCalculationCoord=!0,this._fullDimCount++,this._updateDimOmitted(!0)},r}();function TC(r){return r instanceof bC}function AC(r){for(var e=Z(),t=0;t<(r||[]).length;t++){var a=r[t],n=tt(a)?a.name:a;n!=null&&e.get(n)==null&&e.set(n,t)}return e}function CC(r){var e=CN(r);return e.dimNameMap||(e.dimNameMap=AC(r.dimensionsDefine))}function DC(r){return r>30}var Go=tt,Sa=G,MN=typeof Int32Array>"u"?Array:Int32Array,IN="e\0\0",M_=-1,LN=["hasItemOption","_nameList","_idList","_invertedIndicesMap","_dimSummary","userOutput","_rawData","_dimValueGetter","_nameDimIdx","_idDimIdx","_nameRepeatCount"],PN=["_approximateExtent"],I_,Jl,Fo,Ho,Rv,jl,Ev,be=function(){function r(e,t){this.type="list",this._dimOmitted=!1,this._nameList=[],this._idList=[],this._visual={},this._layout={},this._itemVisuals=[],this._itemLayouts=[],this._graphicEls=[],this._approximateExtent={},this._calculationInfo={},this.hasItemOption=!1,this.TRANSFERABLE_METHODS=["cloneShallow","downSample","lttbDownSample","map"],this.CHANGABLE_METHODS=["filterSelf","selectRange"],this.DOWNSAMPLE_METHODS=["downSample","lttbDownSample"];var a,n=!1;TC(e)?(a=e.dimensions,this._dimOmitted=e.isDimensionOmitted(),this._schema=e):(n=!0,a=e),a=a||["x","y"];for(var i={},o=[],s={},l=!1,u={},f=0;f<a.length;f++){var h=a[f],v=$(h)?new Hu({name:h}):h instanceof Hu?h:new Hu(h),c=v.name;v.type=v.type||"float",v.coordDim||(v.coordDim=c,v.coordDimIndex=0);var p=v.otherDims=v.otherDims||{};o.push(c),i[c]=v,u[c]!=null&&(l=!0),v.createInvertedIndices&&(s[c]=[]),p.itemName===0&&(this._nameDimIdx=f),p.itemId===0&&(this._idDimIdx=f),n&&(v.storeDimIndex=f)}if(this.dimensions=o,this._dimInfos=i,this._initGetDimensionInfo(l),this.hostModel=t,this._invertedIndicesMap=s,this._dimOmitted){var d=this._dimIdxToName=Z();C(o,function(g){d.set(i[g].storeDimIndex,g)})}}return r.prototype.getDimension=function(e){var t=this._recognizeDimIndex(e);if(t==null)return e;if(t=e,!this._dimOmitted)return this.dimensions[t];var a=this._dimIdxToName.get(t);if(a!=null)return a;var n=this._schema.getSourceDimension(t);if(n)return n.name},r.prototype.getDimensionIndex=function(e){var t=this._recognizeDimIndex(e);if(t!=null)return t;if(e==null)return-1;var a=this._getDimInfo(e);return a?a.storeDimIndex:this._dimOmitted?this._schema.getSourceDimensionIndex(e):-1},r.prototype._recognizeDimIndex=function(e){if(Ct(e)||e!=null&&!isNaN(e)&&!this._getDimInfo(e)&&(!this._dimOmitted||this._schema.getSourceDimensionIndex(e)<0))return+e},r.prototype._getStoreDimIndex=function(e){var t=this.getDimensionIndex(e);return t},r.prototype.getDimensionInfo=function(e){return this._getDimInfo(this.getDimension(e))},r.prototype._initGetDimensionInfo=function(e){var t=this._dimInfos;this._getDimInfo=e?function(a){return t.hasOwnProperty(a)?t[a]:void 0}:function(a){return t[a]}},r.prototype.getDimensionsOnCoord=function(){return this._dimSummary.dataDimsOnCoord.slice()},r.prototype.mapDimension=function(e,t){var a=this._dimSummary;if(t==null)return a.encodeFirstDimNotExtra[e];var n=a.encode[e];return n?n[t]:null},r.prototype.mapDimensionsAll=function(e){var t=this._dimSummary,a=t.encode[e];return(a||[]).slice()},r.prototype.getStore=function(){return this._store},r.prototype.initData=function(e,t,a){var n=this,i;if(e instanceof Fp&&(i=e),!i){var o=this.dimensions,s=Ig(e)||ge(e)?new CA(e,o.length):e;i=new Fp;var l=Sa(o,function(u){return{type:n._dimInfos[u].type,property:u}});i.initData(s,l,a)}this._store=i,this._nameList=(t||[]).slice(),this._idList=[],this._nameRepeatCount={},this._doInit(0,i.count()),this._dimSummary=TN(this,this._schema),this.userOutput=this._dimSummary.userOutput},r.prototype.appendData=function(e){var t=this._store.appendData(e);this._doInit(t[0],t[1])},r.prototype.appendValues=function(e,t){var a=this._store.appendValues(e,t.length),n=a.start,i=a.end,o=this._shouldMakeIdFromName();if(this._updateOrdinalMeta(),t)for(var s=n;s<i;s++){var l=s-n;this._nameList[s]=t[l],o&&Ev(this,s)}},r.prototype._updateOrdinalMeta=function(){for(var e=this._store,t=this.dimensions,a=0;a<t.length;a++){var n=this._dimInfos[t[a]];n.ordinalMeta&&e.collectOrdinalMeta(n.storeDimIndex,n.ordinalMeta)}},r.prototype._shouldMakeIdFromName=function(){var e=this._store.getProvider();return this._idDimIdx==null&&e.getSource().sourceFormat!==Va&&!e.fillStorage},r.prototype._doInit=function(e,t){if(!(e>=t)){var a=this._store,n=a.getProvider();this._updateOrdinalMeta();var i=this._nameList,o=this._idList,s=n.getSource().sourceFormat,l=s===sr;if(l&&!n.pure)for(var u=[],f=e;f<t;f++){var h=n.getItem(f,u);if(!this.hasItemOption&&rP(h)&&(this.hasItemOption=!0),h){var v=h.name;i[f]==null&&v!=null&&(i[f]=Qt(v,null));var c=h.id;o[f]==null&&c!=null&&(o[f]=Qt(c,null))}}if(this._shouldMakeIdFromName())for(var f=e;f<t;f++)Ev(this,f);I_(this)}},r.prototype.getApproximateExtent=function(e){return this._approximateExtent[e]||this._store.getDataExtent(this._getStoreDimIndex(e))},r.prototype.setApproximateExtent=function(e,t){t=this.getDimension(t),this._approximateExtent[t]=e.slice()},r.prototype.getCalculationInfo=function(e){return this._calculationInfo[e]},r.prototype.setCalculationInfo=function(e,t){Go(e)?V(this._calculationInfo,e):this._calculationInfo[e]=t},r.prototype.getName=function(e){var t=this.getRawIndex(e),a=this._nameList[t];return a==null&&this._nameDimIdx!=null&&(a=Fo(this,this._nameDimIdx,t)),a==null&&(a=""),a},r.prototype._getCategory=function(e,t){var a=this._store.get(e,t),n=this._store.getOrdinalMeta(e);return n?n.categories[a]:a},r.prototype.getId=function(e){return Jl(this,this.getRawIndex(e))},r.prototype.count=function(){return this._store.count()},r.prototype.get=function(e,t){var a=this._store,n=this._dimInfos[e];if(n)return a.get(n.storeDimIndex,t)},r.prototype.getByRawIndex=function(e,t){var a=this._store,n=this._dimInfos[e];if(n)return a.getByRawIndex(n.storeDimIndex,t)},r.prototype.getIndices=function(){return this._store.getIndices()},r.prototype.getDataExtent=function(e){return this._store.getDataExtent(this._getStoreDimIndex(e))},r.prototype.getSum=function(e){return this._store.getSum(this._getStoreDimIndex(e))},r.prototype.getMedian=function(e){return this._store.getMedian(this._getStoreDimIndex(e))},r.prototype.getValues=function(e,t){var a=this,n=this._store;return z(e)?n.getValues(Sa(e,function(i){return a._getStoreDimIndex(i)}),t):n.getValues(e)},r.prototype.hasValue=function(e){for(var t=this._dimSummary.dataDimIndicesOnCoord,a=0,n=t.length;a<n;a++)if(isNaN(this._store.get(t[a],e)))return!1;return!0},r.prototype.indexOfName=function(e){for(var t=0,a=this._store.count();t<a;t++)if(this.getName(t)===e)return t;return-1},r.prototype.getRawIndex=function(e){return this._store.getRawIndex(e)},r.prototype.indexOfRawIndex=function(e){return this._store.indexOfRawIndex(e)},r.prototype.rawIndexOf=function(e,t){var a=e&&this._invertedIndicesMap[e],n=a[t];return n==null||isNaN(n)?M_:n},r.prototype.indicesOfNearest=function(e,t,a){return this._store.indicesOfNearest(this._getStoreDimIndex(e),t,a)},r.prototype.each=function(e,t,a){K(e)&&(a=t,t=e,e=[]);var n=a||this,i=Sa(Ho(e),this._getStoreDimIndex,this);this._store.each(i,n?U(t,n):t)},r.prototype.filterSelf=function(e,t,a){K(e)&&(a=t,t=e,e=[]);var n=a||this,i=Sa(Ho(e),this._getStoreDimIndex,this);return this._store=this._store.filter(i,n?U(t,n):t),this},r.prototype.selectRange=function(e){var t=this,a={},n=_t(e);return C(n,function(i){var o=t._getStoreDimIndex(i);a[o]=e[i]}),this._store=this._store.selectRange(a),this},r.prototype.mapArray=function(e,t,a){K(e)&&(a=t,t=e,e=[]),a=a||this;var n=[];return this.each(e,function(){n.push(t&&t.apply(this,arguments))},a),n},r.prototype.map=function(e,t,a,n){var i=a||n||this,o=Sa(Ho(e),this._getStoreDimIndex,this),s=jl(this);return s._store=this._store.map(o,i?U(t,i):t),s},r.prototype.modify=function(e,t,a,n){var i=a||n||this,o=Sa(Ho(e),this._getStoreDimIndex,this);this._store.modify(o,i?U(t,i):t)},r.prototype.downSample=function(e,t,a,n){var i=jl(this);return i._store=this._store.downSample(this._getStoreDimIndex(e),t,a,n),i},r.prototype.lttbDownSample=function(e,t){var a=jl(this);return a._store=this._store.lttbDownSample(this._getStoreDimIndex(e),t),a},r.prototype.getRawDataItem=function(e){return this._store.getRawDataItem(e)},r.prototype.getItemModel=function(e){var t=this.hostModel,a=this.getRawDataItem(e);return new Ot(a,t,t&&t.ecModel)},r.prototype.diff=function(e){var t=this;return new ua(e?e.getStore().getIndices():[],this.getStore().getIndices(),function(a){return Jl(e,a)},function(a){return Jl(t,a)})},r.prototype.getVisual=function(e){var t=this._visual;return t&&t[e]},r.prototype.setVisual=function(e,t){this._visual=this._visual||{},Go(e)?V(this._visual,e):this._visual[e]=t},r.prototype.getItemVisual=function(e,t){var a=this._itemVisuals[e],n=a&&a[t];return n??this.getVisual(t)},r.prototype.hasItemVisual=function(){return this._itemVisuals.length>0},r.prototype.ensureUniqueItemVisual=function(e,t){var a=this._itemVisuals,n=a[e];n||(n=a[e]={});var i=n[t];return i==null&&(i=this.getVisual(t),z(i)?i=i.slice():Go(i)&&(i=V({},i)),n[t]=i),i},r.prototype.setItemVisual=function(e,t,a){var n=this._itemVisuals[e]||{};this._itemVisuals[e]=n,Go(t)?V(n,t):n[t]=a},r.prototype.clearAllVisual=function(){this._visual={},this._itemVisuals=[]},r.prototype.setLayout=function(e,t){Go(e)?V(this._layout,e):this._layout[e]=t},r.prototype.getLayout=function(e){return this._layout[e]},r.prototype.getItemLayout=function(e){return this._itemLayouts[e]},r.prototype.setItemLayout=function(e,t,a){this._itemLayouts[e]=a?V(this._itemLayouts[e]||{},t):t},r.prototype.clearItemLayouts=function(){this._itemLayouts.length=0},r.prototype.setItemGraphicEl=function(e,t){var a=this.hostModel&&this.hostModel.seriesIndex;Mp(a,this.dataType,e,t),this._graphicEls[e]=t},r.prototype.getItemGraphicEl=function(e){return this._graphicEls[e]},r.prototype.eachItemGraphicEl=function(e,t){C(this._graphicEls,function(a,n){a&&e&&e.call(t,a,n)})},r.prototype.cloneShallow=function(e){return e||(e=new r(this._schema?this._schema:Sa(this.dimensions,this._getDimInfo,this),this.hostModel)),Rv(e,this),e._store=this._store,e},r.prototype.wrapMethod=function(e,t){var a=this[e];K(a)&&(this.__wrappedMethods=this.__wrappedMethods||[],this.__wrappedMethods.push(e),this[e]=function(){var n=a.apply(this,arguments);return t.apply(this,[n].concat(Yd(arguments)))})},r.internalField=function(){I_=function(e){var t=e._invertedIndicesMap;C(t,function(a,n){var i=e._dimInfos[n],o=i.ordinalMeta,s=e._store;if(o){a=t[n]=new MN(o.categories.length);for(var l=0;l<a.length;l++)a[l]=M_;for(var l=0;l<s.count();l++)a[s.get(i.storeDimIndex,l)]=l}})},Fo=function(e,t,a){return Qt(e._getCategory(t,a),null)},Jl=function(e,t){var a=e._idList[t];return a==null&&e._idDimIdx!=null&&(a=Fo(e,e._idDimIdx,t)),a==null&&(a=IN+t),a},Ho=function(e){return z(e)||(e=e!=null?[e]:[]),e},jl=function(e){var t=new r(e._schema?e._schema:Sa(e.dimensions,e._getDimInfo,e),e.hostModel);return Rv(t,e),t},Rv=function(e,t){C(LN.concat(t.__wrappedMethods||[]),function(a){t.hasOwnProperty(a)&&(e[a]=t[a])}),e.__wrappedMethods=t.__wrappedMethods,C(PN,function(a){e[a]=rt(t[a])}),e._calculationInfo=V({},t._calculationInfo)},Ev=function(e,t){var a=e._nameList,n=e._idList,i=e._nameDimIdx,o=e._idDimIdx,s=a[t],l=n[t];if(s==null&&i!=null&&(a[t]=s=Fo(e,i,t)),l==null&&o!=null&&(n[t]=l=Fo(e,o,t)),l==null&&s!=null){var u=e._nameRepeatCount,f=u[s]=(u[s]||0)+1;l=s,f>1&&(l+="__ec__"+f),n[t]=l}}}(),r}();function vl(r,e){Ig(r)||(r=Lg(r)),e=e||{};var t=e.coordDimensions||[],a=e.dimensionsDefine||r.dimensionsDefine||[],n=Z(),i=[],o=EN(r,t,a,e.dimensionsCount),s=e.canOmitUnusedDimensions&&DC(o),l=a===r.dimensionsDefine,u=l?CC(r):AC(a),f=e.encodeDefine;!f&&e.encodeDefaulter&&(f=e.encodeDefaulter(r,o));for(var h=Z(f),v=new kA(o),c=0;c<v.length;c++)v[c]=-1;function p(A){var D=v[A];if(D<0){var M=a[A],I=tt(M)?M:{name:M},L=new Hu,P=I.name;P!=null&&u.get(P)!=null&&(L.name=L.displayName=P),I.type!=null&&(L.type=I.type),I.displayName!=null&&(L.displayName=I.displayName);var R=i.length;return v[A]=R,L.storeDimIndex=A,i.push(L),L}return i[D]}if(!s)for(var c=0;c<o;c++)p(c);h.each(function(A,D){var M=Pt(A).slice();if(M.length===1&&!$(M[0])&&M[0]<0){h.set(D,!1);return}var I=h.set(D,[]);C(M,function(L,P){var R=$(L)?u.get(L):L;R!=null&&R<o&&(I[P]=R,g(p(R),D,P))})});var d=0;C(t,function(A){var D,M,I,L;if($(A))D=A,L={};else{L=A,D=L.name;var P=L.ordinalMeta;L.ordinalMeta=null,L=V({},L),L.ordinalMeta=P,M=L.dimsDef,I=L.otherDims,L.name=L.coordDim=L.coordDimIndex=L.dimsDef=L.otherDims=null}var R=h.get(D);if(R!==!1){if(R=Pt(R),!R.length)for(var E=0;E<(M&&M.length||1);E++){for(;d<o&&p(d).coordDim!=null;)d++;d<o&&R.push(d++)}C(R,function(N,O){var B=p(N);if(l&&L.type!=null&&(B.type=L.type),g(j(B,L),D,O),B.name==null&&M){var F=M[O];!tt(F)&&(F={name:F}),B.name=B.displayName=F.name,B.defaultTooltip=F.defaultTooltip}I&&j(B.otherDims,I)})}});function g(A,D,M){pA.get(D)!=null?A.otherDims[D]=M:(A.coordDim=D,A.coordDimIndex=M,n.set(D,!0))}var y=e.generateCoord,m=e.generateCoordCount,_=m!=null;m=y?m||1:0;var S=y||"value";function w(A){A.name==null&&(A.name=A.coordDim)}if(s)C(i,function(A){w(A)}),i.sort(function(A,D){return A.storeDimIndex-D.storeDimIndex});else for(var x=0;x<o;x++){var b=p(x),T=b.coordDim;T==null&&(b.coordDim=kN(S,n,_),b.coordDimIndex=0,(!y||m<=0)&&(b.isExtraCoord=!0),m--),w(b),b.type==null&&(mA(r,x)===oe.Must||b.isExtraCoord&&(b.otherDims.itemName!=null||b.otherDims.seriesName!=null))&&(b.type="ordinal")}return RN(i),new bC({source:r,dimensions:i,fullDimensionCount:o,dimensionOmitted:s})}function RN(r){for(var e=Z(),t=0;t<r.length;t++){var a=r[t],n=a.name,i=e.get(n)||0;i>0&&(a.name=n+(i-1)),i++,e.set(n,i)}}function EN(r,e,t,a){var n=Math.max(r.dimensionsDetectedCount||1,e.length,t.length,a||0);return C(e,function(i){var o;tt(i)&&(o=i.dimsDef)&&(n=Math.max(n,o.length))}),n}function kN(r,e,t){if(t||e.hasKey(r)){for(var a=0;e.hasKey(r+a);)a++;r+=a}return e.set(r,!0),r}var ON=function(){function r(e){this.coordSysDims=[],this.axisMap=Z(),this.categoryAxisMap=Z(),this.coordSysName=e}return r}();function NN(r){var e=r.get("coordinateSystem"),t=new ON(e),a=BN[e];if(a)return a(r,t,t.axisMap,t.categoryAxisMap),t}var BN={cartesian2d:function(r,e,t,a){var n=r.getReferringComponents("xAxis",Xt).models[0],i=r.getReferringComponents("yAxis",Xt).models[0];e.coordSysDims=["x","y"],t.set("x",n),t.set("y",i),Ai(n)&&(a.set("x",n),e.firstCategoryDimIndex=0),Ai(i)&&(a.set("y",i),e.firstCategoryDimIndex==null&&(e.firstCategoryDimIndex=1))},singleAxis:function(r,e,t,a){var n=r.getReferringComponents("singleAxis",Xt).models[0];e.coordSysDims=["single"],t.set("single",n),Ai(n)&&(a.set("single",n),e.firstCategoryDimIndex=0)},polar:function(r,e,t,a){var n=r.getReferringComponents("polar",Xt).models[0],i=n.findAxisModel("radiusAxis"),o=n.findAxisModel("angleAxis");e.coordSysDims=["radius","angle"],t.set("radius",i),t.set("angle",o),Ai(i)&&(a.set("radius",i),e.firstCategoryDimIndex=0),Ai(o)&&(a.set("angle",o),e.firstCategoryDimIndex==null&&(e.firstCategoryDimIndex=1))},geo:function(r,e,t,a){e.coordSysDims=["lng","lat"]},parallel:function(r,e,t,a){var n=r.ecModel,i=n.getComponent("parallel",r.get("parallelIndex")),o=e.coordSysDims=i.dimensions.slice();C(i.parallelAxisIndex,function(s,l){var u=n.getComponent("parallelAxis",s),f=o[l];t.set(f,u),Ai(u)&&(a.set(f,u),e.firstCategoryDimIndex==null&&(e.firstCategoryDimIndex=l))})}};function Ai(r){return r.get("type")==="category"}function VN(r,e,t){t=t||{};var a=t.byIndex,n=t.stackedCoordDimension,i,o,s;zN(e)?i=e:(o=e.schema,i=o.dimensions,s=e.store);var l=!!(r&&r.get("stack")),u,f,h,v;if(C(i,function(m,_){$(m)&&(i[_]=m={name:m}),l&&!m.isExtraCoord&&(!a&&!u&&m.ordinalMeta&&(u=m),!f&&m.type!=="ordinal"&&m.type!=="time"&&(!n||n===m.coordDim)&&(f=m))}),f&&!a&&!u&&(a=!0),f){h="__\0ecstackresult_"+r.id,v="__\0ecstackedover_"+r.id,u&&(u.createInvertedIndices=!0);var c=f.coordDim,p=f.type,d=0;C(i,function(m){m.coordDim===c&&d++});var g={name:h,coordDim:c,coordDimIndex:d,type:p,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:i.length},y={name:v,coordDim:v,coordDimIndex:d+1,type:p,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:i.length+1};o?(s&&(g.storeDimIndex=s.ensureCalculationDimension(v,p),y.storeDimIndex=s.ensureCalculationDimension(h,p)),o.appendCalculationDimension(g),o.appendCalculationDimension(y)):(i.push(g),i.push(y))}return{stackedDimension:f&&f.name,stackedByDimension:u&&u.name,isStackedByIndex:a,stackedOverDimension:v,stackResultDimension:h}}function zN(r){return!TC(r.schema)}function Ya(r,e){return!!e&&e===r.getCalculationInfo("stackedDimension")}function MC(r,e){return Ya(r,e)?r.getCalculationInfo("stackResultDimension"):e}function GN(r,e){var t=r.get("coordinateSystem"),a=fl.get(t),n;return e&&e.coordSysDims&&(n=G(e.coordSysDims,function(i){var o={name:i},s=e.axisMap.get(i);if(s){var l=s.get("type");o.type=_f(l)}return o})),n||(n=a&&(a.getDimensionsInfo?a.getDimensionsInfo():a.dimensions.slice())||["x","y"]),n}function FN(r,e,t){var a,n;return t&&C(r,function(i,o){var s=i.coordDim,l=t.categoryAxisMap.get(s);l&&(a==null&&(a=o),i.ordinalMeta=l.getOrdinalMeta(),e&&(i.createInvertedIndices=!0)),i.otherDims.itemName!=null&&(n=!0)}),!n&&a!=null&&(r[a].otherDims.itemName=0),a}function va(r,e,t){t=t||{};var a=e.getSourceManager(),n,i=!1;r?(i=!0,n=Lg(r)):(n=a.getSource(),i=n.sourceFormat===sr);var o=NN(e),s=GN(e,o),l=t.useEncodeDefaulter,u=K(l)?l:l?ot(yA,s,e):null,f={coordDimensions:s,generateCoord:t.generateCoord,encodeDefine:e.getEncode(),encodeDefaulter:u,canOmitUnusedDimensions:!i},h=vl(n,f),v=FN(h.dimensions,t.createInvertedIndices,o),c=i?null:a.getSharedDataStore(h),p=VN(e,{schema:h,store:c}),d=new be(h,e);d.setCalculationInfo(p);var g=v!=null&&HN(n)?function(y,m,_,S){return S===v?_:this.defaultDimValueGetter(y,m,_,S)}:null;return d.hasItemOption=!1,d.initData(i?n:c,null,g),d}function HN(r){if(r.sourceFormat===sr){var e=WN(r.data||[]);return!z(uo(e))}}function WN(r){for(var e=0;e<r.length&&r[e]==null;)e++;return r[e]}var IC=function(){function r(e){this._setting=e||{},this._extent=[1/0,-1/0]}return r.prototype.getSetting=function(e){return this._setting[e]},r.prototype.unionExtent=function(e){var t=this._extent;e[0]<t[0]&&(t[0]=e[0]),e[1]>t[1]&&(t[1]=e[1])},r.prototype.unionExtentFromData=function(e,t){this.unionExtent(e.getApproximateExtent(t))},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.setExtent=function(e,t){var a=this._extent;isNaN(e)||(a[0]=e),isNaN(t)||(a[1]=t)},r.prototype.isInExtentRange=function(e){return this._extent[0]<=e&&this._extent[1]>=e},r.prototype.isBlank=function(){return this._isBlank},r.prototype.setBlank=function(e){this._isBlank=e},r}();qf(IC);const ca=IC;var $N=0,Qp=function(){function r(e){this.categories=e.categories||[],this._needCollect=e.needCollect,this._deduplication=e.deduplication,this.uid=++$N}return r.createByAxisModel=function(e){var t=e.option,a=t.data,n=a&&G(a,UN);return new r({categories:n,needCollect:!n,deduplication:t.dedplication!==!1})},r.prototype.getOrdinal=function(e){return this._getOrCreateMap().get(e)},r.prototype.parseAndCollect=function(e){var t,a=this._needCollect;if(!$(e)&&!a)return e;if(a&&!this._deduplication)return t=this.categories.length,this.categories[t]=e,t;var n=this._getOrCreateMap();return t=n.get(e),t==null&&(a?(t=this.categories.length,this.categories[t]=e,n.set(e,t)):t=NaN),t},r.prototype._getOrCreateMap=function(){return this._map||(this._map=Z(this.categories))},r}();function UN(r){return tt(r)&&r.value!=null?r.value:r+""}function Jp(r){return r.type==="interval"||r.type==="log"}function YN(r,e,t,a){var n={},i=r[1]-r[0],o=n.interval=Yb(i/e,!0);t!=null&&o<t&&(o=n.interval=t),a!=null&&o>a&&(o=n.interval=a);var s=n.intervalPrecision=LC(o),l=n.niceTickExtent=[$t(Math.ceil(r[0]/o)*o,s),$t(Math.floor(r[1]/o)*o,s)];return ZN(l,r),n}function kv(r){var e=Math.pow(10,eg(r)),t=r/e;return t?t===2?t=3:t===3?t=5:t*=2:t=1,$t(t*e)}function LC(r){return Er(r)+2}function L_(r,e,t){r[e]=Math.max(Math.min(r[e],t[1]),t[0])}function ZN(r,e){!isFinite(r[0])&&(r[0]=e[0]),!isFinite(r[1])&&(r[1]=e[1]),L_(r,0,e),L_(r,1,e),r[0]>r[1]&&(r[0]=r[1])}function gh(r,e){return r>=e[0]&&r<=e[1]}function yh(r,e){return e[1]===e[0]?.5:(r-e[0])/(e[1]-e[0])}function mh(r,e){return r*(e[1]-e[0])+e[0]}var PC=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;a.type="ordinal";var n=a.getSetting("ordinalMeta");return n||(n=new Qp({})),z(n)&&(n=new Qp({categories:G(n,function(i){return tt(i)?i.value:i})})),a._ordinalMeta=n,a._extent=a.getSetting("extent")||[0,n.categories.length-1],a}return e.prototype.parse=function(t){return t==null?NaN:$(t)?this._ordinalMeta.getOrdinal(t):Math.round(t)},e.prototype.contain=function(t){return t=this.parse(t),gh(t,this._extent)&&this._ordinalMeta.categories[t]!=null},e.prototype.normalize=function(t){return t=this._getTickNumber(this.parse(t)),yh(t,this._extent)},e.prototype.scale=function(t){return t=Math.round(mh(t,this._extent)),this.getRawOrdinalNumber(t)},e.prototype.getTicks=function(){for(var t=[],a=this._extent,n=a[0];n<=a[1];)t.push({value:n}),n++;return t},e.prototype.getMinorTicks=function(t){},e.prototype.setSortInfo=function(t){if(t==null){this._ordinalNumbersByTick=this._ticksByOrdinalNumber=null;return}for(var a=t.ordinalNumbers,n=this._ordinalNumbersByTick=[],i=this._ticksByOrdinalNumber=[],o=0,s=this._ordinalMeta.categories.length,l=Math.min(s,a.length);o<l;++o){var u=a[o];n[o]=u,i[u]=o}for(var f=0;o<s;++o){for(;i[f]!=null;)f++;n.push(f),i[f]=o}},e.prototype._getTickNumber=function(t){var a=this._ticksByOrdinalNumber;return a&&t>=0&&t<a.length?a[t]:t},e.prototype.getRawOrdinalNumber=function(t){var a=this._ordinalNumbersByTick;return a&&t>=0&&t<a.length?a[t]:t},e.prototype.getLabel=function(t){if(!this.isBlank()){var a=this.getRawOrdinalNumber(t.value),n=this._ordinalMeta.categories[a];return n==null?"":n+""}},e.prototype.count=function(){return this._extent[1]-this._extent[0]+1},e.prototype.unionExtentFromData=function(t,a){this.unionExtent(t.getApproximateExtent(a))},e.prototype.isInExtentRange=function(t){return t=this._getTickNumber(t),this._extent[0]<=t&&this._extent[1]>=t},e.prototype.getOrdinalMeta=function(){return this._ordinalMeta},e.prototype.calcNiceTicks=function(){},e.prototype.calcNiceExtent=function(){},e.type="ordinal",e}(ca);ca.registerClass(PC);const $g=PC;var Sn=$t,RC=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="interval",t._interval=0,t._intervalPrecision=2,t}return e.prototype.parse=function(t){return t},e.prototype.contain=function(t){return gh(t,this._extent)},e.prototype.normalize=function(t){return yh(t,this._extent)},e.prototype.scale=function(t){return mh(t,this._extent)},e.prototype.setExtent=function(t,a){var n=this._extent;isNaN(t)||(n[0]=parseFloat(t)),isNaN(a)||(n[1]=parseFloat(a))},e.prototype.unionExtent=function(t){var a=this._extent;t[0]<a[0]&&(a[0]=t[0]),t[1]>a[1]&&(a[1]=t[1]),this.setExtent(a[0],a[1])},e.prototype.getInterval=function(){return this._interval},e.prototype.setInterval=function(t){this._interval=t,this._niceExtent=this._extent.slice(),this._intervalPrecision=LC(t)},e.prototype.getTicks=function(t){var a=this._interval,n=this._extent,i=this._niceExtent,o=this._intervalPrecision,s=[];if(!a)return s;var l=1e4;n[0]<i[0]&&(t?s.push({value:Sn(i[0]-a,o)}):s.push({value:n[0]}));for(var u=i[0];u<=i[1]&&(s.push({value:u}),u=Sn(u+a,o),u!==s[s.length-1].value);)if(s.length>l)return[];var f=s.length?s[s.length-1].value:i[1];return n[1]>f&&(t?s.push({value:Sn(f+a,o)}):s.push({value:n[1]})),s},e.prototype.getMinorTicks=function(t){for(var a=this.getTicks(!0),n=[],i=this.getExtent(),o=1;o<a.length;o++){for(var s=a[o],l=a[o-1],u=0,f=[],h=s.value-l.value,v=h/t;u<t-1;){var c=Sn(l.value+(u+1)*v);c>i[0]&&c<i[1]&&f.push(c),u++}n.push(f)}return n},e.prototype.getLabel=function(t,a){if(t==null)return"";var n=a&&a.precision;n==null?n=Er(t.value)||0:n==="auto"&&(n=this._intervalPrecision);var i=Sn(t.value,n,!0);return lA(i)},e.prototype.calcNiceTicks=function(t,a,n){t=t||5;var i=this._extent,o=i[1]-i[0];if(isFinite(o)){o<0&&(o=-o,i.reverse());var s=YN(i,t,a,n);this._intervalPrecision=s.intervalPrecision,this._interval=s.interval,this._niceExtent=s.niceTickExtent}},e.prototype.calcNiceExtent=function(t){var a=this._extent;if(a[0]===a[1])if(a[0]!==0){var n=Math.abs(a[0]);t.fixMax||(a[1]+=n/2),a[0]-=n/2}else a[1]=1;var i=a[1]-a[0];isFinite(i)||(a[0]=0,a[1]=1),this.calcNiceTicks(t.splitNumber,t.minInterval,t.maxInterval);var o=this._interval;t.fixMin||(a[0]=Sn(Math.floor(a[0]/o)*o)),t.fixMax||(a[1]=Sn(Math.ceil(a[1]/o)*o))},e.prototype.setNiceExtent=function(t,a){this._niceExtent=[t,a]},e.type="interval",e}(ca);ca.registerClass(RC);const Za=RC;var EC=typeof Float32Array<"u",XN=EC?Float32Array:Array;function Or(r){return z(r)?EC?new Float32Array(r):r:new XN(r)}var jp="__ec_stack_";function Ug(r){return r.get("stack")||jp+r.seriesIndex}function Yg(r){return r.dim+r.index}function qN(r){var e=[],t=r.axis,a="axis0";if(t.type==="category"){for(var n=t.getBandWidth(),i=0;i<r.count;i++)e.push(j({bandWidth:n,axisKey:a,stackId:jp+i},r));for(var o=NC(e),s=[],i=0;i<r.count;i++){var l=o[a][jp+i];l.offsetCenter=l.offset+l.width/2,s.push(l)}return s}}function kC(r,e){var t=[];return e.eachSeriesByType(r,function(a){zC(a)&&t.push(a)}),t}function KN(r){var e={};C(r,function(l){var u=l.coordinateSystem,f=u.getBaseAxis();if(!(f.type!=="time"&&f.type!=="value"))for(var h=l.getData(),v=f.dim+"_"+f.index,c=h.getDimensionIndex(h.mapDimension(f.dim)),p=h.getStore(),d=0,g=p.count();d<g;++d){var y=p.get(c,d);e[v]?e[v].push(y):e[v]=[y]}});var t={};for(var a in e)if(e.hasOwnProperty(a)){var n=e[a];if(n){n.sort(function(l,u){return l-u});for(var i=null,o=1;o<n.length;++o){var s=n[o]-n[o-1];s>0&&(i=i===null?s:Math.min(i,s))}t[a]=i}}return t}function OC(r){var e=KN(r),t=[];return C(r,function(a){var n=a.coordinateSystem,i=n.getBaseAxis(),o=i.getExtent(),s;if(i.type==="category")s=i.getBandWidth();else if(i.type==="value"||i.type==="time"){var l=i.dim+"_"+i.index,u=e[l],f=Math.abs(o[1]-o[0]),h=i.scale.getExtent(),v=Math.abs(h[1]-h[0]);s=u?f/v*u:f}else{var c=a.getData();s=Math.abs(o[1]-o[0])/c.count()}var p=W(a.get("barWidth"),s),d=W(a.get("barMaxWidth"),s),g=W(a.get("barMinWidth")||(GC(a)?.5:1),s),y=a.get("barGap"),m=a.get("barCategoryGap");t.push({bandWidth:s,barWidth:p,barMaxWidth:d,barMinWidth:g,barGap:y,barCategoryGap:m,axisKey:Yg(i),stackId:Ug(a)})}),NC(t)}function NC(r){var e={};C(r,function(a,n){var i=a.axisKey,o=a.bandWidth,s=e[i]||{bandWidth:o,remainedWidth:o,autoWidthCount:0,categoryGap:null,gap:"20%",stacks:{}},l=s.stacks;e[i]=s;var u=a.stackId;l[u]||s.autoWidthCount++,l[u]=l[u]||{width:0,maxWidth:0};var f=a.barWidth;f&&!l[u].width&&(l[u].width=f,f=Math.min(s.remainedWidth,f),s.remainedWidth-=f);var h=a.barMaxWidth;h&&(l[u].maxWidth=h);var v=a.barMinWidth;v&&(l[u].minWidth=v);var c=a.barGap;c!=null&&(s.gap=c);var p=a.barCategoryGap;p!=null&&(s.categoryGap=p)});var t={};return C(e,function(a,n){t[n]={};var i=a.stacks,o=a.bandWidth,s=a.categoryGap;if(s==null){var l=_t(i).length;s=Math.max(35-l*4,15)+"%"}var u=W(s,o),f=W(a.gap,1),h=a.remainedWidth,v=a.autoWidthCount,c=(h-u)/(v+(v-1)*f);c=Math.max(c,0),C(i,function(y){var m=y.maxWidth,_=y.minWidth;if(y.width){var S=y.width;m&&(S=Math.min(S,m)),_&&(S=Math.max(S,_)),y.width=S,h-=S+f*S,v--}else{var S=c;m&&m<S&&(S=Math.min(m,h)),_&&_>S&&(S=_),S!==c&&(y.width=S,h-=S+f*S,v--)}}),c=(h-u)/(v+(v-1)*f),c=Math.max(c,0);var p=0,d;C(i,function(y,m){y.width||(y.width=c),d=y,p+=y.width*(1+f)}),d&&(p-=d.width*f);var g=-p/2;C(i,function(y,m){t[n][m]=t[n][m]||{bandWidth:o,offset:g,width:y.width},g+=y.width*(1+f)})}),t}function QN(r,e,t){if(r&&e){var a=r[Yg(e)];return a!=null&&t!=null?a[Ug(t)]:a}}function BC(r,e){var t=kC(r,e),a=OC(t);C(t,function(n){var i=n.getData(),o=n.coordinateSystem,s=o.getBaseAxis(),l=Ug(n),u=a[Yg(s)][l],f=u.offset,h=u.width;i.setLayout({bandWidth:u.bandWidth,offset:f,size:h})})}function VC(r){return{seriesType:r,plan:xo(),reset:function(e){if(zC(e)){var t=e.getData(),a=e.coordinateSystem,n=a.getBaseAxis(),i=a.getOtherAxis(n),o=t.getDimensionIndex(t.mapDimension(i.dim)),s=t.getDimensionIndex(t.mapDimension(n.dim)),l=e.get("showBackground",!0),u=t.mapDimension(i.dim),f=t.getCalculationInfo("stackResultDimension"),h=Ya(t,u)&&!!t.getCalculationInfo("stackedOnSeries"),v=i.isHorizontal(),c=JN(n,i),p=GC(e),d=e.get("barMinHeight")||0,g=f&&t.getDimensionIndex(f),y=t.getLayout("size"),m=t.getLayout("offset");return{progress:function(_,S){for(var w=_.count,x=p&&Or(w*3),b=p&&l&&Or(w*3),T=p&&Or(w),A=a.master.getRect(),D=v?A.width:A.height,M,I=S.getStore(),L=0;(M=_.next())!=null;){var P=I.get(h?g:o,M),R=I.get(s,M),E=c,N=void 0;h&&(N=+P-I.get(o,M));var O=void 0,B=void 0,F=void 0,H=void 0;if(v){var X=a.dataToPoint([P,R]);if(h){var Q=a.dataToPoint([N,R]);E=Q[0]}O=E,B=X[1]+m,F=X[0]-E,H=y,Math.abs(F)<d&&(F=(F<0?-1:1)*d)}else{var X=a.dataToPoint([R,P]);if(h){var Q=a.dataToPoint([R,N]);E=Q[1]}O=X[0]+m,B=E,F=y,H=X[1]-E,Math.abs(H)<d&&(H=(H<=0?-1:1)*d)}p?(x[L]=O,x[L+1]=B,x[L+2]=v?F:H,b&&(b[L]=v?A.x:O,b[L+1]=v?B:A.y,b[L+2]=D),T[M]=M):S.setItemLayout(M,{x:O,y:B,width:F,height:H}),L+=3}p&&S.setLayout({largePoints:x,largeDataIndices:T,largeBackgroundPoints:b,valueAxisHorizontal:v})}}}}}}function zC(r){return r.coordinateSystem&&r.coordinateSystem.type==="cartesian2d"}function GC(r){return r.pipelineContext&&r.pipelineContext.large}function JN(r,e){return e.toGlobalCoord(e.dataToCoord(e.type==="log"?1:0))}var jN=function(r,e,t,a){for(;t<a;){var n=t+a>>>1;r[n][1]<e?t=n+1:a=n}return t},FC=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a.type="time",a}return e.prototype.getLabel=function(t){var a=this.getSetting("useUTC");return oh(t.value,S0[IE(Zi(this._minLevelUnit))]||S0.second,a,this.getSetting("locale"))},e.prototype.getFormattedLabel=function(t,a,n){var i=this.getSetting("useUTC"),o=this.getSetting("locale");return LE(t,a,n,o,i)},e.prototype.getTicks=function(){var t=this._interval,a=this._extent,n=[];if(!t)return n;n.push({value:a[0],level:0});var i=this.getSetting("useUTC"),o=oB(this._minLevelUnit,this._approxInterval,i,a);return n=n.concat(o),n.push({value:a[1],level:0}),n},e.prototype.calcNiceExtent=function(t){var a=this._extent;if(a[0]===a[1]&&(a[0]-=rr,a[1]+=rr),a[1]===-1/0&&a[0]===1/0){var n=new Date;a[1]=+new Date(n.getFullYear(),n.getMonth(),n.getDate()),a[0]=a[1]-rr}this.calcNiceTicks(t.splitNumber,t.minInterval,t.maxInterval)},e.prototype.calcNiceTicks=function(t,a,n){t=t||10;var i=this._extent,o=i[1]-i[0];this._approxInterval=o/t,a!=null&&this._approxInterval<a&&(this._approxInterval=a),n!=null&&this._approxInterval>n&&(this._approxInterval=n);var s=tu.length,l=Math.min(jN(tu,this._approxInterval,0,s),s-1);this._interval=tu[l][1],this._minLevelUnit=tu[Math.max(l-1,0)][0]},e.prototype.parse=function(t){return Ct(t)?t:+Hr(t)},e.prototype.contain=function(t){return gh(this.parse(t),this._extent)},e.prototype.normalize=function(t){return yh(this.parse(t),this._extent)},e.prototype.scale=function(t){return mh(t,this._extent)},e.type="time",e}(Za),tu=[["second",xg],["minute",wg],["hour",xs],["quarter-day",xs*6],["half-day",xs*12],["day",rr*1.2],["half-week",rr*3.5],["week",rr*7],["month",rr*31],["quarter",rr*95],["half-year",_0/2],["year",_0]];function tB(r,e,t,a){var n=Hr(e),i=Hr(t),o=function(p){return x0(n,p,a)===x0(i,p,a)},s=function(){return o("year")},l=function(){return s()&&o("month")},u=function(){return l()&&o("day")},f=function(){return u()&&o("hour")},h=function(){return f()&&o("minute")},v=function(){return h()&&o("second")},c=function(){return v()&&o("millisecond")};switch(r){case"year":return s();case"month":return l();case"day":return u();case"hour":return f();case"minute":return h();case"second":return v();case"millisecond":return c()}}function eB(r,e){return r/=rr,r>16?16:r>7.5?7:r>3.5?4:r>1.5?2:1}function rB(r){var e=30*rr;return r/=e,r>6?6:r>3?3:r>2?2:1}function aB(r){return r/=xs,r>12?12:r>6?6:r>3.5?4:r>2?2:1}function P_(r,e){return r/=e?wg:xg,r>30?30:r>20?20:r>15?15:r>10?10:r>5?5:r>2?2:1}function nB(r){return Yb(r,!0)}function iB(r,e,t){var a=new Date(r);switch(Zi(e)){case"year":case"month":a[rA(t)](0);case"day":a[aA(t)](1);case"hour":a[nA(t)](0);case"minute":a[iA(t)](0);case"second":a[oA(t)](0),a[sA(t)](0)}return a.getTime()}function oB(r,e,t,a){var n=1e4,i=tA,o=0;function s(D,M,I,L,P,R,E){for(var N=new Date(M),O=M,B=N[L]();O<I&&O<=a[1];)E.push({value:O}),B+=D,N[P](B),O=N.getTime();E.push({value:O,notAdd:!0})}function l(D,M,I){var L=[],P=!M.length;if(!tB(Zi(D),a[0],a[1],t)){P&&(M=[{value:iB(new Date(a[0]),D,t)},{value:a[1]}]);for(var R=0;R<M.length-1;R++){var E=M[R].value,N=M[R+1].value;if(E!==N){var O=void 0,B=void 0,F=void 0,H=!1;switch(D){case"year":O=Math.max(1,Math.round(e/rr/365)),B=bg(t),F=PE(t);break;case"half-year":case"quarter":case"month":O=rB(e),B=Xi(t),F=rA(t);break;case"week":case"half-week":case"day":O=eB(e),B=sh(t),F=aA(t),H=!0;break;case"half-day":case"quarter-day":case"hour":O=aB(e),B=zs(t),F=nA(t);break;case"minute":O=P_(e,!0),B=lh(t),F=iA(t);break;case"second":O=P_(e,!1),B=uh(t),F=oA(t);break;case"millisecond":O=nB(e),B=fh(t),F=sA(t);break}s(O,E,N,B,F,H,L),D==="year"&&I.length>1&&R===0&&I.unshift({value:I[0].value-O})}}for(var R=0;R<L.length;R++)I.push(L[R]);return L}}for(var u=[],f=[],h=0,v=0,c=0;c<i.length&&o++<n;++c){var p=Zi(i[c]);if(ME(i[c])){l(i[c],u[u.length-1]||[],f);var d=i[c+1]?Zi(i[c+1]):null;if(p!==d){if(f.length){v=h,f.sort(function(D,M){return D.value-M.value});for(var g=[],y=0;y<f.length;++y){var m=f[y].value;(y===0||f[y-1].value!==m)&&(g.push(f[y]),m>=a[0]&&m<=a[1]&&h++)}var _=(a[1]-a[0])/e;if(h>_*1.5&&v>_/1.5||(u.push(g),h>_||r===i[c]))break}f=[]}}}for(var S=Lt(G(u,function(D){return Lt(D,function(M){return M.value>=a[0]&&M.value<=a[1]&&!M.notAdd})}),function(D){return D.length>0}),w=[],x=S.length-1,c=0;c<S.length;++c)for(var b=S[c],T=0;T<b.length;++T)w.push({value:b[T].value,level:x-c});w.sort(function(D,M){return D.value-M.value});for(var A=[],c=0;c<w.length;++c)(c===0||w[c].value!==w[c-1].value)&&A.push(w[c]);return A}ca.registerClass(FC);const HC=FC;var R_=ca.prototype,As=Za.prototype,sB=$t,lB=Math.floor,uB=Math.ceil,eu=Math.pow,fr=Math.log,Zg=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="log",t.base=10,t._originalScale=new Za,t._interval=0,t}return e.prototype.getTicks=function(t){var a=this._originalScale,n=this._extent,i=a.getExtent(),o=As.getTicks.call(this,t);return G(o,function(s){var l=s.value,u=$t(eu(this.base,l));return u=l===n[0]&&this._fixMin?ru(u,i[0]):u,u=l===n[1]&&this._fixMax?ru(u,i[1]):u,{value:u}},this)},e.prototype.setExtent=function(t,a){var n=fr(this.base);t=fr(Math.max(0,t))/n,a=fr(Math.max(0,a))/n,As.setExtent.call(this,t,a)},e.prototype.getExtent=function(){var t=this.base,a=R_.getExtent.call(this);a[0]=eu(t,a[0]),a[1]=eu(t,a[1]);var n=this._originalScale,i=n.getExtent();return this._fixMin&&(a[0]=ru(a[0],i[0])),this._fixMax&&(a[1]=ru(a[1],i[1])),a},e.prototype.unionExtent=function(t){this._originalScale.unionExtent(t);var a=this.base;t[0]=fr(t[0])/fr(a),t[1]=fr(t[1])/fr(a),R_.unionExtent.call(this,t)},e.prototype.unionExtentFromData=function(t,a){this.unionExtent(t.getApproximateExtent(a))},e.prototype.calcNiceTicks=function(t){t=t||10;var a=this._extent,n=a[1]-a[0];if(!(n===1/0||n<=0)){var i=eP(n),o=t/n*i;for(o<=.5&&(i*=10);!isNaN(i)&&Math.abs(i)<1&&Math.abs(i)>0;)i*=10;var s=[$t(uB(a[0]/i)*i),$t(lB(a[1]/i)*i)];this._interval=i,this._niceExtent=s}},e.prototype.calcNiceExtent=function(t){As.calcNiceExtent.call(this,t),this._fixMin=t.fixMin,this._fixMax=t.fixMax},e.prototype.parse=function(t){return t},e.prototype.contain=function(t){return t=fr(t)/fr(this.base),gh(t,this._extent)},e.prototype.normalize=function(t){return t=fr(t)/fr(this.base),yh(t,this._extent)},e.prototype.scale=function(t){return t=mh(t,this._extent),eu(this.base,t)},e.type="log",e}(ca),WC=Zg.prototype;WC.getMinorTicks=As.getMinorTicks;WC.getLabel=As.getLabel;function ru(r,e){return sB(r,Er(e))}ca.registerClass(Zg);const fB=Zg;var hB=function(){function r(e,t,a){this._prepareParams(e,t,a)}return r.prototype._prepareParams=function(e,t,a){a[1]<a[0]&&(a=[NaN,NaN]),this._dataMin=a[0],this._dataMax=a[1];var n=this._isOrdinal=e.type==="ordinal";this._needCrossZero=e.type==="interval"&&t.getNeedCrossZero&&t.getNeedCrossZero();var i=this._modelMinRaw=t.get("min",!0);K(i)?this._modelMinNum=au(e,i({min:a[0],max:a[1]})):i!=="dataMin"&&(this._modelMinNum=au(e,i));var o=this._modelMaxRaw=t.get("max",!0);if(K(o)?this._modelMaxNum=au(e,o({min:a[0],max:a[1]})):o!=="dataMax"&&(this._modelMaxNum=au(e,o)),n)this._axisDataLen=t.getCategories().length;else{var s=t.get("boundaryGap"),l=z(s)?s:[s||0,s||0];typeof l[0]=="boolean"||typeof l[1]=="boolean"?this._boundaryGapInner=[0,0]:this._boundaryGapInner=[_r(l[0],1),_r(l[1],1)]}},r.prototype.calculate=function(){var e=this._isOrdinal,t=this._dataMin,a=this._dataMax,n=this._axisDataLen,i=this._boundaryGapInner,o=e?null:a-t||Math.abs(t),s=this._modelMinRaw==="dataMin"?t:this._modelMinNum,l=this._modelMaxRaw==="dataMax"?a:this._modelMaxNum,u=s!=null,f=l!=null;s==null&&(s=e?n?0:NaN:t-i[0]*o),l==null&&(l=e?n?n-1:NaN:a+i[1]*o),(s==null||!isFinite(s))&&(s=NaN),(l==null||!isFinite(l))&&(l=NaN);var h=Is(s)||Is(l)||e&&!n;this._needCrossZero&&(s>0&&l>0&&!u&&(s=0),s<0&&l<0&&!f&&(l=0));var v=this._determinedMin,c=this._determinedMax;return v!=null&&(s=v,u=!0),c!=null&&(l=c,f=!0),{min:s,max:l,minFixed:u,maxFixed:f,isBlank:h}},r.prototype.modifyDataMinMax=function(e,t){this[cB[e]]=t},r.prototype.setDeterminedMinMax=function(e,t){var a=vB[e];this[a]=t},r.prototype.freeze=function(){this.frozen=!0},r}(),vB={min:"_determinedMin",max:"_determinedMax"},cB={min:"_dataMin",max:"_dataMax"};function $C(r,e,t){var a=r.rawExtentInfo;return a||(a=new hB(r,e,t),r.rawExtentInfo=a,a)}function au(r,e){return e==null?null:Is(e)?NaN:r.parse(e)}function UC(r,e){var t=r.type,a=$C(r,e,r.getExtent()).calculate();r.setBlank(a.isBlank);var n=a.min,i=a.max,o=e.ecModel;if(o&&t==="time"){var s=kC("bar",o),l=!1;if(C(s,function(h){l=l||h.getBaseAxis()===e.axis}),l){var u=OC(s),f=pB(n,i,e,u);n=f.min,i=f.max}}return{extent:[n,i],fixMin:a.minFixed,fixMax:a.maxFixed}}function pB(r,e,t,a){var n=t.axis.getExtent(),i=n[1]-n[0],o=QN(a,t.axis);if(o===void 0)return{min:r,max:e};var s=1/0;C(o,function(c){s=Math.min(c.offset,s)});var l=-1/0;C(o,function(c){l=Math.max(c.offset+c.width,l)}),s=Math.abs(s),l=Math.abs(l);var u=s+l,f=e-r,h=1-(s+l)/i,v=f/h-f;return e+=v*(l/u),r-=v*(s/u),{min:r,max:e}}function to(r,e){var t=e,a=UC(r,t),n=a.extent,i=t.get("splitNumber");r instanceof fB&&(r.base=t.get("logBase"));var o=r.type,s=t.get("interval"),l=o==="interval"||o==="time";r.setExtent(n[0],n[1]),r.calcNiceExtent({splitNumber:i,fixMin:a.fixMin,fixMax:a.fixMax,minInterval:l?t.get("minInterval"):null,maxInterval:l?t.get("maxInterval"):null}),s!=null&&r.setInterval&&r.setInterval(s)}function _h(r,e){if(e=e||r.get("type"),e)switch(e){case"category":return new $g({ordinalMeta:r.getOrdinalMeta?r.getOrdinalMeta():r.getCategories(),extent:[1/0,-1/0]});case"time":return new HC({locale:r.ecModel.getLocaleModel(),useUTC:r.ecModel.get("useUTC")});default:return new(ca.getClass(e)||Za)}}function dB(r){var e=r.scale.getExtent(),t=e[0],a=e[1];return!(t>0&&a>0||t<0&&a<0)}function cl(r){var e=r.getLabelModel().get("formatter"),t=r.type==="category"?r.scale.getExtent()[0]:null;return r.scale.type==="time"?function(a){return function(n,i){return r.scale.getFormattedLabel(n,i,a)}}(e):$(e)?function(a){return function(n){var i=r.scale.getLabel(n),o=a.replace("{value}",i??"");return o}}(e):K(e)?function(a){return function(n,i){return t!=null&&(i=n.value-t),a(Xg(r,n),i,n.level!=null?{level:n.level}:null)}}(e):function(a){return r.scale.getLabel(a)}}function Xg(r,e){return r.type==="category"?r.scale.getLabel(e):e.value}function gB(r){var e=r.model,t=r.scale;if(!(!e.get(["axisLabel","show"])||t.isBlank())){var a,n,i=t.getExtent();t instanceof $g?n=t.count():(a=t.getTicks(),n=a.length);var o=r.getLabelModel(),s=cl(r),l,u=1;n>40&&(u=Math.ceil(n/40));for(var f=0;f<n;f+=u){var h=a?a[f]:{value:i[0]+f},v=s(h,f),c=o.getTextRect(v),p=yB(c,o.get("rotate")||0);l?l.union(p):l=p}return l}}function yB(r,e){var t=e*Math.PI/180,a=r.width,n=r.height,i=a*Math.abs(Math.cos(t))+Math.abs(n*Math.sin(t)),o=a*Math.abs(Math.sin(t))+Math.abs(n*Math.cos(t)),s=new ht(r.x,r.y,i,o);return s}function qg(r){var e=r.get("interval");return e??"auto"}function YC(r){return r.type==="category"&&qg(r.getLabelModel())===0}function Sf(r,e){var t={};return C(r.mapDimensionsAll(e),function(a){t[MC(r,a)]=!0}),_t(t)}function mB(r,e,t){e&&C(Sf(e,t),function(a){var n=e.getApproximateExtent(a);n[0]<r[0]&&(r[0]=n[0]),n[1]>r[1]&&(r[1]=n[1])})}var pl=function(){function r(){}return r.prototype.getNeedCrossZero=function(){var e=this.option;return!e.scale},r.prototype.getCoordSysModel=function(){},r}(),_B=1e-8;function E_(r,e){return Math.abs(r-e)<_B}function Pn(r,e,t){var a=0,n=r[0];if(!n)return!1;for(var i=1;i<r.length;i++){var o=r[i];a+=Qr(n[0],n[1],o[0],o[1],e,t),n=o}var s=r[0];return(!E_(n[0],s[0])||!E_(n[1],s[1]))&&(a+=Qr(n[0],n[1],s[0],s[1],e,t)),a!==0}var SB=[];function Ov(r,e){for(var t=0;t<r.length;t++)se(r[t],r[t],e)}function k_(r,e,t,a){for(var n=0;n<r.length;n++){var i=r[n];a&&(i=a.project(i)),i&&isFinite(i[0])&&isFinite(i[1])&&(Ia(e,e,i),La(t,t,i))}}function xB(r){for(var e=0,t=0,a=0,n=r.length,i=r[n-1][0],o=r[n-1][1],s=0;s<n;s++){var l=r[s][0],u=r[s][1],f=i*u-l*o;e+=f,t+=(i+l)*f,a+=(o+u)*f,i=l,o=u}return e?[t/e/3,a/e/3,e]:[r[0][0]||0,r[0][1]||0]}var ZC=function(){function r(e){this.name=e}return r.prototype.setCenter=function(e){this._center=e},r.prototype.getCenter=function(){var e=this._center;return e||(e=this._center=this.calcCenter()),e},r}(),O_=function(){function r(e,t){this.type="polygon",this.exterior=e,this.interiors=t}return r}(),N_=function(){function r(e){this.type="linestring",this.points=e}return r}(),XC=function(r){k(e,r);function e(t,a,n){var i=r.call(this,t)||this;return i.type="geoJSON",i.geometries=a,i._center=n&&[n[0],n[1]],i}return e.prototype.calcCenter=function(){for(var t=this.geometries,a,n=0,i=0;i<t.length;i++){var o=t[i],s=o.exterior,l=s&&s.length;l>n&&(a=o,n=l)}if(a)return xB(a.exterior);var u=this.getBoundingRect();return[u.x+u.width/2,u.y+u.height/2]},e.prototype.getBoundingRect=function(t){var a=this._rect;if(a&&!t)return a;var n=[1/0,1/0],i=[-1/0,-1/0],o=this.geometries;return C(o,function(s){s.type==="polygon"?k_(s.exterior,n,i,t):C(s.points,function(l){k_(l,n,i,t)})}),isFinite(n[0])&&isFinite(n[1])&&isFinite(i[0])&&isFinite(i[1])||(n[0]=n[1]=i[0]=i[1]=0),a=new ht(n[0],n[1],i[0]-n[0],i[1]-n[1]),t||(this._rect=a),a},e.prototype.contain=function(t){var a=this.getBoundingRect(),n=this.geometries;if(!a.contain(t[0],t[1]))return!1;t:for(var i=0,o=n.length;i<o;i++){var s=n[i];if(s.type==="polygon"){var l=s.exterior,u=s.interiors;if(Pn(l,t[0],t[1])){for(var f=0;f<(u?u.length:0);f++)if(Pn(u[f],t[0],t[1]))continue t;return!0}}}return!1},e.prototype.transformTo=function(t,a,n,i){var o=this.getBoundingRect(),s=o.width/o.height;n?i||(i=n/s):n=s*i;for(var l=new ht(t,a,n,i),u=o.calculateTransform(l),f=this.geometries,h=0;h<f.length;h++){var v=f[h];v.type==="polygon"?(Ov(v.exterior,u),C(v.interiors,function(c){Ov(c,u)})):C(v.points,function(c){Ov(c,u)})}o=this._rect,o.copy(l),this._center=[o.x+o.width/2,o.y+o.height/2]},e.prototype.cloneShallow=function(t){t==null&&(t=this.name);var a=new e(t,this.geometries,this._center);return a._rect=this._rect,a.transformTo=null,a},e}(ZC),wB=function(r){k(e,r);function e(t,a){var n=r.call(this,t)||this;return n.type="geoSVG",n._elOnlyForCalculate=a,n}return e.prototype.calcCenter=function(){for(var t=this._elOnlyForCalculate,a=t.getBoundingRect(),n=[a.x+a.width/2,a.y+a.height/2],i=Yf(SB),o=t;o&&!o.isGeoSVGGraphicRoot;)ea(i,o.getLocalTransform(),i),o=o.parent;return lo(i,i),se(n,n,i),n},e}(ZC);function bB(r){if(!r.UTF8Encoding)return r;var e=r,t=e.UTF8Scale;t==null&&(t=1024);var a=e.features;return C(a,function(n){var i=n.geometry,o=i.encodeOffsets,s=i.coordinates;if(o)switch(i.type){case"LineString":i.coordinates=qC(s,o,t);break;case"Polygon":Nv(s,o,t);break;case"MultiLineString":Nv(s,o,t);break;case"MultiPolygon":C(s,function(l,u){return Nv(l,o[u],t)})}}),e.UTF8Encoding=!1,e}function Nv(r,e,t){for(var a=0;a<r.length;a++)r[a]=qC(r[a],e[a],t)}function qC(r,e,t){for(var a=[],n=e[0],i=e[1],o=0;o<r.length;o+=2){var s=r.charCodeAt(o)-64,l=r.charCodeAt(o+1)-64;s=s>>1^-(s&1),l=l>>1^-(l&1),s+=n,l+=i,n=s,i=l,a.push([s/t,l/t])}return a}function TB(r,e){return r=bB(r),G(Lt(r.features,function(t){return t.geometry&&t.properties&&t.geometry.coordinates.length>0}),function(t){var a=t.properties,n=t.geometry,i=[];switch(n.type){case"Polygon":var o=n.coordinates;i.push(new O_(o[0],o.slice(1)));break;case"MultiPolygon":C(n.coordinates,function(l){l[0]&&i.push(new O_(l[0],l.slice(1)))});break;case"LineString":i.push(new N_([n.coordinates]));break;case"MultiLineString":i.push(new N_(n.coordinates))}var s=new XC(a[e||"name"],i,a.cp);return s.properties=a,s})}var Us=bt();function AB(r){return r.type==="category"?DB(r):IB(r)}function CB(r,e){return r.type==="category"?MB(r,e):{ticks:G(r.scale.getTicks(),function(t){return t.value})}}function DB(r){var e=r.getLabelModel(),t=KC(r,e);return!e.get("show")||r.scale.isBlank()?{labels:[],labelCategoryInterval:t.labelCategoryInterval}:t}function KC(r,e){var t=QC(r,"labels"),a=qg(e),n=JC(t,a);if(n)return n;var i,o;return K(a)?i=eD(r,a):(o=a==="auto"?LB(r):a,i=tD(r,o)),jC(t,a,{labels:i,labelCategoryInterval:o})}function MB(r,e){var t=QC(r,"ticks"),a=qg(e),n=JC(t,a);if(n)return n;var i,o;if((!e.get("show")||r.scale.isBlank())&&(i=[]),K(a))i=eD(r,a,!0);else if(a==="auto"){var s=KC(r,r.getLabelModel());o=s.labelCategoryInterval,i=G(s.labels,function(l){return l.tickValue})}else o=a,i=tD(r,o,!0);return jC(t,a,{ticks:i,tickCategoryInterval:o})}function IB(r){var e=r.scale.getTicks(),t=cl(r);return{labels:G(e,function(a,n){return{level:a.level,formattedLabel:t(a,n),rawLabel:r.scale.getLabel(a),tickValue:a.value}})}}function QC(r,e){return Us(r)[e]||(Us(r)[e]=[])}function JC(r,e){for(var t=0;t<r.length;t++)if(r[t].key===e)return r[t].value}function jC(r,e,t){return r.push({key:e,value:t}),t}function LB(r){var e=Us(r).autoInterval;return e??(Us(r).autoInterval=r.calculateCategoryInterval())}function PB(r){var e=RB(r),t=cl(r),a=(e.axisRotate-e.labelRotate)/180*Math.PI,n=r.scale,i=n.getExtent(),o=n.count();if(i[1]-i[0]<1)return 0;var s=1;o>40&&(s=Math.max(1,Math.floor(o/40)));for(var l=i[0],u=r.dataToCoord(l+1)-r.dataToCoord(l),f=Math.abs(u*Math.cos(a)),h=Math.abs(u*Math.sin(a)),v=0,c=0;l<=i[1];l+=s){var p=0,d=0,g=il(t({value:l}),e.font,"center","top");p=g.width*1.3,d=g.height*1.3,v=Math.max(v,p,7),c=Math.max(c,d,7)}var y=v/f,m=c/h;isNaN(y)&&(y=1/0),isNaN(m)&&(m=1/0);var _=Math.max(0,Math.floor(Math.min(y,m))),S=Us(r.model),w=r.getExtent(),x=S.lastAutoInterval,b=S.lastTickCount;return x!=null&&b!=null&&Math.abs(x-_)<=1&&Math.abs(b-o)<=1&&x>_&&S.axisExtent0===w[0]&&S.axisExtent1===w[1]?_=x:(S.lastTickCount=o,S.lastAutoInterval=_,S.axisExtent0=w[0],S.axisExtent1=w[1]),_}function RB(r){var e=r.getLabelModel();return{axisRotate:r.getRotate?r.getRotate():r.isHorizontal&&!r.isHorizontal()?90:0,labelRotate:e.get("rotate")||0,font:e.getFont()}}function tD(r,e,t){var a=cl(r),n=r.scale,i=n.getExtent(),o=r.getLabelModel(),s=[],l=Math.max((e||0)+1,1),u=i[0],f=n.count();u!==0&&l>1&&f/l>2&&(u=Math.round(Math.ceil(u/l)*l));var h=YC(r),v=o.get("showMinLabel")||h,c=o.get("showMaxLabel")||h;v&&u!==i[0]&&d(i[0]);for(var p=u;p<=i[1];p+=l)d(p);c&&p-l!==i[1]&&d(i[1]);function d(g){var y={value:g};s.push(t?g:{formattedLabel:a(y),rawLabel:n.getLabel(y),tickValue:g})}return s}function eD(r,e,t){var a=r.scale,n=cl(r),i=[];return C(a.getTicks(),function(o){var s=a.getLabel(o),l=o.value;e(o.value,s)&&i.push(t?l:{formattedLabel:n(o),rawLabel:s,tickValue:l})}),i}var B_=[0,1],EB=function(){function r(e,t,a){this.onBand=!1,this.inverse=!1,this.dim=e,this.scale=t,this._extent=a||[0,0]}return r.prototype.contain=function(e){var t=this._extent,a=Math.min(t[0],t[1]),n=Math.max(t[0],t[1]);return e>=a&&e<=n},r.prototype.containData=function(e){return this.scale.contain(e)},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.getPixelPrecision=function(e){return $b(e||this.scale.getExtent(),this._extent)},r.prototype.setExtent=function(e,t){var a=this._extent;a[0]=e,a[1]=t},r.prototype.dataToCoord=function(e,t){var a=this._extent,n=this.scale;return e=n.normalize(e),this.onBand&&n.type==="ordinal"&&(a=a.slice(),V_(a,n.count())),It(e,B_,a,t)},r.prototype.coordToData=function(e,t){var a=this._extent,n=this.scale;this.onBand&&n.type==="ordinal"&&(a=a.slice(),V_(a,n.count()));var i=It(e,a,B_,t);return this.scale.scale(i)},r.prototype.pointToData=function(e,t){},r.prototype.getTicksCoords=function(e){e=e||{};var t=e.tickModel||this.getTickModel(),a=CB(this,t),n=a.ticks,i=G(n,function(s){return{coord:this.dataToCoord(this.scale.type==="ordinal"?this.scale.getRawOrdinalNumber(s):s),tickValue:s}},this),o=t.get("alignWithLabel");return kB(this,i,o,e.clamp),i},r.prototype.getMinorTicksCoords=function(){if(this.scale.type==="ordinal")return[];var e=this.model.getModel("minorTick"),t=e.get("splitNumber");t>0&&t<100||(t=5);var a=this.scale.getMinorTicks(t),n=G(a,function(i){return G(i,function(o){return{coord:this.dataToCoord(o),tickValue:o}},this)},this);return n},r.prototype.getViewLabels=function(){return AB(this).labels},r.prototype.getLabelModel=function(){return this.model.getModel("axisLabel")},r.prototype.getTickModel=function(){return this.model.getModel("axisTick")},r.prototype.getBandWidth=function(){var e=this._extent,t=this.scale.getExtent(),a=t[1]-t[0]+(this.onBand?1:0);a===0&&(a=1);var n=Math.abs(e[1]-e[0]);return Math.abs(n)/a},r.prototype.calculateCategoryInterval=function(){return PB(this)},r}();function V_(r,e){var t=r[1]-r[0],a=e,n=t/a/2;r[0]+=n,r[1]-=n}function kB(r,e,t,a){var n=e.length;if(!r.onBand||t||!n)return;var i=r.getExtent(),o,s;if(n===1)e[0].coord=i[0],o=e[1]={coord:i[1]};else{var l=e[n-1].tickValue-e[0].tickValue,u=(e[n-1].coord-e[0].coord)/l;C(e,function(c){c.coord-=u/2});var f=r.scale.getExtent();s=1+f[1]-e[n-1].tickValue,o={coord:e[n-1].coord+u*s},e.push(o)}var h=i[0]>i[1];v(e[0].coord,i[0])&&(a?e[0].coord=i[0]:e.shift()),a&&v(i[0],e[0].coord)&&e.unshift({coord:i[0]}),v(i[1],o.coord)&&(a?o.coord=i[1]:e.pop()),a&&v(o.coord,i[1])&&e.push({coord:i[1]});function v(c,p){return c=$t(c),p=$t(p),h?c>p:c<p}}const wr=EB;var Wo=Math.PI*2,xn=Wr.CMD,OB=["top","right","bottom","left"];function NB(r,e,t,a,n){var i=t.width,o=t.height;switch(r){case"top":a.set(t.x+i/2,t.y-e),n.set(0,-1);break;case"bottom":a.set(t.x+i/2,t.y+o+e),n.set(0,1);break;case"left":a.set(t.x-e,t.y+o/2),n.set(-1,0);break;case"right":a.set(t.x+i+e,t.y+o/2),n.set(1,0);break}}function BB(r,e,t,a,n,i,o,s,l){o-=r,s-=e;var u=Math.sqrt(o*o+s*s);o/=u,s/=u;var f=o*t+r,h=s*t+e;if(Math.abs(a-n)%Wo<1e-4)return l[0]=f,l[1]=h,u-t;if(i){var v=a;a=Ge(n),n=Ge(v)}else a=Ge(a),n=Ge(n);a>n&&(n+=Wo);var c=Math.atan2(s,o);if(c<0&&(c+=Wo),c>=a&&c<=n||c+Wo>=a&&c+Wo<=n)return l[0]=f,l[1]=h,u-t;var p=t*Math.cos(a)+r,d=t*Math.sin(a)+e,g=t*Math.cos(n)+r,y=t*Math.sin(n)+e,m=(p-o)*(p-o)+(d-s)*(d-s),_=(g-o)*(g-o)+(y-s)*(y-s);return m<_?(l[0]=p,l[1]=d,Math.sqrt(m)):(l[0]=g,l[1]=y,Math.sqrt(_))}function xf(r,e,t,a,n,i,o,s){var l=n-r,u=i-e,f=t-r,h=a-e,v=Math.sqrt(f*f+h*h);f/=v,h/=v;var c=l*f+u*h,p=c/v;s&&(p=Math.min(Math.max(p,0),1)),p*=v;var d=o[0]=r+p*f,g=o[1]=e+p*h;return Math.sqrt((d-n)*(d-n)+(g-i)*(g-i))}function rD(r,e,t,a,n,i,o){t<0&&(r=r+t,t=-t),a<0&&(e=e+a,a=-a);var s=r+t,l=e+a,u=o[0]=Math.min(Math.max(n,r),s),f=o[1]=Math.min(Math.max(i,e),l);return Math.sqrt((u-n)*(u-n)+(f-i)*(f-i))}var pr=[];function VB(r,e,t){var a=rD(e.x,e.y,e.width,e.height,r.x,r.y,pr);return t.set(pr[0],pr[1]),a}function zB(r,e,t){for(var a=0,n=0,i=0,o=0,s,l,u=1/0,f=e.data,h=r.x,v=r.y,c=0;c<f.length;){var p=f[c++];c===1&&(a=f[c],n=f[c+1],i=a,o=n);var d=u;switch(p){case xn.M:i=f[c++],o=f[c++],a=i,n=o;break;case xn.L:d=xf(a,n,f[c],f[c+1],h,v,pr,!0),a=f[c++],n=f[c++];break;case xn.C:d=Ab(a,n,f[c++],f[c++],f[c++],f[c++],f[c],f[c+1],h,v,pr),a=f[c++],n=f[c++];break;case xn.Q:d=Db(a,n,f[c++],f[c++],f[c],f[c+1],h,v,pr),a=f[c++],n=f[c++];break;case xn.A:var g=f[c++],y=f[c++],m=f[c++],_=f[c++],S=f[c++],w=f[c++];c+=1;var x=!!(1-f[c++]);s=Math.cos(S)*m+g,l=Math.sin(S)*_+y,c<=1&&(i=s,o=l);var b=(h-g)*_/m+g;d=BB(g,y,_,S,S+w,x,b,v,pr),a=Math.cos(S+w)*m+g,n=Math.sin(S+w)*_+y;break;case xn.R:i=a=f[c++],o=n=f[c++];var T=f[c++],A=f[c++];d=rD(i,o,T,A,h,v,pr);break;case xn.Z:d=xf(a,n,i,o,h,v,pr,!0),a=i,n=o;break}d<u&&(u=d,t.set(pr[0],pr[1]))}return u}var gr=new ut,Et=new ut,Ut=new ut,Nr=new ut,Rr=new ut;function z_(r,e){if(r){var t=r.getTextGuideLine(),a=r.getTextContent();if(a&&t){var n=r.textGuideLineConfig||{},i=[[0,0],[0,0],[0,0]],o=n.candidates||OB,s=a.getBoundingRect().clone();s.applyTransform(a.getComputedTransform());var l=1/0,u=n.anchor,f=r.getComputedTransform(),h=f&&lo([],f),v=e.get("length2")||0;u&&Ut.copy(u);for(var c=0;c<o.length;c++){var p=o[c];NB(p,0,s,gr,Nr),ut.scaleAndAdd(Et,gr,Nr,v),Et.transform(h);var d=r.getBoundingRect(),g=u?u.distance(Et):r instanceof yt?zB(Et,r.path,Ut):VB(Et,d,Ut);g<l&&(l=g,Et.transform(f),Ut.transform(f),Ut.toArray(i[0]),Et.toArray(i[1]),gr.toArray(i[2]))}aD(i,e.get("minTurnAngle")),t.setShape({points:i})}}}var wf=[],we=new ut;function aD(r,e){if(e<=180&&e>0){e=e/180*Math.PI,gr.fromArray(r[0]),Et.fromArray(r[1]),Ut.fromArray(r[2]),ut.sub(Nr,gr,Et),ut.sub(Rr,Ut,Et);var t=Nr.len(),a=Rr.len();if(!(t<.001||a<.001)){Nr.scale(1/t),Rr.scale(1/a);var n=Nr.dot(Rr),i=Math.cos(e);if(i<n){var o=xf(Et.x,Et.y,Ut.x,Ut.y,gr.x,gr.y,wf,!1);we.fromArray(wf),we.scaleAndAdd(Rr,o/Math.tan(Math.PI-e));var s=Ut.x!==Et.x?(we.x-Et.x)/(Ut.x-Et.x):(we.y-Et.y)/(Ut.y-Et.y);if(isNaN(s))return;s<0?ut.copy(we,Et):s>1&&ut.copy(we,Ut),we.toArray(r[1])}}}}function GB(r,e,t){if(t<=180&&t>0){t=t/180*Math.PI,gr.fromArray(r[0]),Et.fromArray(r[1]),Ut.fromArray(r[2]),ut.sub(Nr,Et,gr),ut.sub(Rr,Ut,Et);var a=Nr.len(),n=Rr.len();if(!(a<.001||n<.001)){Nr.scale(1/a),Rr.scale(1/n);var i=Nr.dot(e),o=Math.cos(t);if(i<o){var s=xf(Et.x,Et.y,Ut.x,Ut.y,gr.x,gr.y,wf,!1);we.fromArray(wf);var l=Math.PI/2,u=Math.acos(Rr.dot(e)),f=l+u-t;if(f>=l)ut.copy(we,Ut);else{we.scaleAndAdd(Rr,s/Math.tan(Math.PI/2-f));var h=Ut.x!==Et.x?(we.x-Et.x)/(Ut.x-Et.x):(we.y-Et.y)/(Ut.y-Et.y);if(isNaN(h))return;h<0?ut.copy(we,Et):h>1&&ut.copy(we,Ut)}we.toArray(r[1])}}}}function Bv(r,e,t,a){var n=t==="normal",i=n?r:r.ensureState(t);i.ignore=e;var o=a.get("smooth");o&&o===!0&&(o=.3),i.shape=i.shape||{},o>0&&(i.shape.smooth=o);var s=a.getModel("lineStyle").getLineStyle();n?r.useStyle(s):i.style=s}function FB(r,e){var t=e.smooth,a=e.points;if(a)if(r.moveTo(a[0][0],a[0][1]),t>0&&a.length>=3){var n=Ma(a[0],a[1]),i=Ma(a[1],a[2]);if(!n||!i){r.lineTo(a[1][0],a[1][1]),r.lineTo(a[2][0],a[2][1]);return}var o=Math.min(n,i)*t,s=Lu([],a[1],a[0],o/n),l=Lu([],a[1],a[2],o/i),u=Lu([],s,l,.5);r.bezierCurveTo(s[0],s[1],s[0],s[1],u[0],u[1]),r.bezierCurveTo(l[0],l[1],l[0],l[1],a[2][0],a[2][1])}else for(var f=1;f<a.length;f++)r.lineTo(a[f][0],a[f][1])}function Kg(r,e,t){var a=r.getTextGuideLine(),n=r.getTextContent();if(!n){a&&r.removeTextGuideLine();return}for(var i=e.normal,o=i.get("show"),s=n.ignore,l=0;l<Ns.length;l++){var u=Ns[l],f=e[u],h=u==="normal";if(f){var v=f.get("show"),c=h?s:it(n.states[u]&&n.states[u].ignore,s);if(c||!it(v,o)){var p=h?a:a&&a.states[u];p&&(p.ignore=!0),a&&Bv(a,!0,u,f);continue}a||(a=new Me,r.setTextGuideLine(a),!h&&(s||!o)&&Bv(a,!0,"normal",e.normal),r.stateProxy&&(a.stateProxy=r.stateProxy)),Bv(a,!1,u,f)}}if(a){j(a.style,t),a.style.fill=null;var d=i.get("showAbove"),g=r.textGuideLineConfig=r.textGuideLineConfig||{};g.showAbove=d||!1,a.buildPath=FB}}function Qg(r,e){e=e||"labelLine";for(var t={normal:r.getModel(e)},a=0;a<Ce.length;a++){var n=Ce[a];t[n]=r.getModel([n,e])}return t}function nD(r){for(var e=[],t=0;t<r.length;t++){var a=r[t];if(!a.defaultAttr.ignore){var n=a.label,i=n.getComputedTransform(),o=n.getBoundingRect(),s=!i||i[1]<1e-5&&i[2]<1e-5,l=n.style.margin||0,u=o.clone();u.applyTransform(i),u.x-=l/2,u.y-=l/2,u.width+=l,u.height+=l;var f=s?new of(o,i):null;e.push({label:n,labelLine:a.labelLine,rect:u,localRect:o,obb:f,priority:a.priority,defaultAttr:a.defaultAttr,layoutOption:a.computedLayoutOption,axisAligned:s,transform:i})}}return e}function iD(r,e,t,a,n,i){var o=r.length;if(o<2)return;r.sort(function(T,A){return T.rect[e]-A.rect[e]});for(var s=0,l,u=!1,f=0,h=0;h<o;h++){var v=r[h],c=v.rect;l=c[e]-s,l<0&&(c[e]-=l,v.label[e]-=l,u=!0);var p=Math.max(-l,0);f+=p,s=c[e]+c[t]}f>0&&i&&w(-f/o,0,o);var d=r[0],g=r[o-1],y,m;_(),y<0&&x(-y,.8),m<0&&x(m,.8),_(),S(y,m,1),S(m,y,-1),_(),y<0&&b(-y),m<0&&b(m);function _(){y=d.rect[e]-a,m=n-g.rect[e]-g.rect[t]}function S(T,A,D){if(T<0){var M=Math.min(A,-T);if(M>0){w(M*D,0,o);var I=M+T;I<0&&x(-I*D,1)}else x(-T*D,1)}}function w(T,A,D){T!==0&&(u=!0);for(var M=A;M<D;M++){var I=r[M],L=I.rect;L[e]+=T,I.label[e]+=T}}function x(T,A){for(var D=[],M=0,I=1;I<o;I++){var L=r[I-1].rect,P=Math.max(r[I].rect[e]-L[e]-L[t],0);D.push(P),M+=P}if(M){var R=Math.min(Math.abs(T)/M,A);if(T>0)for(var I=0;I<o-1;I++){var E=D[I]*R;w(E,0,I+1)}else for(var I=o-1;I>0;I--){var E=D[I-1]*R;w(-E,I,o)}}}function b(T){var A=T<0?-1:1;T=Math.abs(T);for(var D=Math.ceil(T/(o-1)),M=0;M<o-1;M++)if(A>0?w(D,0,M+1):w(-D,o-M-1,o),T-=D,T<=0)return}return u}function HB(r,e,t,a){return iD(r,"x","width",e,t,a)}function oD(r,e,t,a){return iD(r,"y","height",e,t,a)}function sD(r){var e=[];r.sort(function(d,g){return g.priority-d.priority});var t=new ht(0,0,0,0);function a(d){if(!d.ignore){var g=d.ensureState("emphasis");g.ignore==null&&(g.ignore=!1)}d.ignore=!0}for(var n=0;n<r.length;n++){var i=r[n],o=i.axisAligned,s=i.localRect,l=i.transform,u=i.label,f=i.labelLine;t.copy(i.rect),t.width-=.1,t.height-=.1,t.x+=.05,t.y+=.05;for(var h=i.obb,v=!1,c=0;c<e.length;c++){var p=e[c];if(t.intersect(p.rect)){if(o&&p.axisAligned){v=!0;break}if(p.obb||(p.obb=new of(p.localRect,p.transform)),h||(h=new of(s,l)),h.intersect(p.obb)){v=!0;break}}}v?(a(u),f&&a(f)):(u.attr("ignore",i.defaultAttr.ignore),f&&f.attr("ignore",i.defaultAttr.labelGuideIgnore),e.push(i))}}function WB(r){if(r){for(var e=[],t=0;t<r.length;t++)e.push(r[t].slice());return e}}function $B(r,e){var t=r.label,a=e&&e.getTextGuideLine();return{dataIndex:r.dataIndex,dataType:r.dataType,seriesIndex:r.seriesModel.seriesIndex,text:r.label.style.text,rect:r.hostRect,labelRect:r.rect,align:t.style.align,verticalAlign:t.style.verticalAlign,labelLinePoints:WB(a&&a.shape.points)}}var G_=["align","verticalAlign","width","height","fontSize"],me=new Jr,Vv=bt(),UB=bt();function nu(r,e,t){for(var a=0;a<t.length;a++){var n=t[a];e[n]!=null&&(r[n]=e[n])}}var iu=["x","y","rotation"],YB=function(){function r(){this._labelList=[],this._chartViewList=[]}return r.prototype.clearLabels=function(){this._labelList=[],this._chartViewList=[]},r.prototype._addLabel=function(e,t,a,n,i){var o=n.style,s=n.__hostTarget,l=s.textConfig||{},u=n.getComputedTransform(),f=n.getBoundingRect().plain();ht.applyTransform(f,f,u),u?me.setLocalTransform(u):(me.x=me.y=me.rotation=me.originX=me.originY=0,me.scaleX=me.scaleY=1),me.rotation=Ge(me.rotation);var h=n.__hostTarget,v;if(h){v=h.getBoundingRect().plain();var c=h.getComputedTransform();ht.applyTransform(v,v,c)}var p=v&&h.getTextGuideLine();this._labelList.push({label:n,labelLine:p,seriesModel:a,dataIndex:e,dataType:t,layoutOption:i,computedLayoutOption:null,rect:f,hostRect:v,priority:v?v.width*v.height:0,defaultAttr:{ignore:n.ignore,labelGuideIgnore:p&&p.ignore,x:me.x,y:me.y,scaleX:me.scaleX,scaleY:me.scaleY,rotation:me.rotation,style:{x:o.x,y:o.y,align:o.align,verticalAlign:o.verticalAlign,width:o.width,height:o.height,fontSize:o.fontSize},cursor:n.cursor,attachedPos:l.position,attachedRot:l.rotation}})},r.prototype.addLabelsOfSeries=function(e){var t=this;this._chartViewList.push(e);var a=e.__model,n=a.get("labelLayout");(K(n)||_t(n).length)&&e.group.traverse(function(i){if(i.ignore)return!0;var o=i.getTextContent(),s=nt(i);o&&!o.disableLabelLayout&&t._addLabel(s.dataIndex,s.dataType,a,o,n)})},r.prototype.updateLayoutConfig=function(e){var t=e.getWidth(),a=e.getHeight();function n(_,S){return function(){z_(_,S)}}for(var i=0;i<this._labelList.length;i++){var o=this._labelList[i],s=o.label,l=s.__hostTarget,u=o.defaultAttr,f=void 0;K(o.layoutOption)?f=o.layoutOption($B(o,l)):f=o.layoutOption,f=f||{},o.computedLayoutOption=f;var h=Math.PI/180;l&&l.setTextConfig({local:!1,position:f.x!=null||f.y!=null?null:u.attachedPos,rotation:f.rotate!=null?f.rotate*h:u.attachedRot,offset:[f.dx||0,f.dy||0]});var v=!1;if(f.x!=null?(s.x=W(f.x,t),s.setStyle("x",0),v=!0):(s.x=u.x,s.setStyle("x",u.style.x)),f.y!=null?(s.y=W(f.y,a),s.setStyle("y",0),v=!0):(s.y=u.y,s.setStyle("y",u.style.y)),f.labelLinePoints){var c=l.getTextGuideLine();c&&(c.setShape({points:f.labelLinePoints}),v=!1)}var p=Vv(s);p.needsUpdateLabelLine=v,s.rotation=f.rotate!=null?f.rotate*h:u.rotation,s.scaleX=u.scaleX,s.scaleY=u.scaleY;for(var d=0;d<G_.length;d++){var g=G_[d];s.setStyle(g,f[g]!=null?f[g]:u.style[g])}if(f.draggable){if(s.draggable=!0,s.cursor="move",l){var y=o.seriesModel;if(o.dataIndex!=null){var m=o.seriesModel.getData(o.dataType);y=m.getItemModel(o.dataIndex)}s.on("drag",n(l,y.getModel("labelLine")))}}else s.off("drag"),s.cursor=u.cursor}},r.prototype.layout=function(e){var t=e.getWidth(),a=e.getHeight(),n=nD(this._labelList),i=Lt(n,function(l){return l.layoutOption.moveOverlap==="shiftX"}),o=Lt(n,function(l){return l.layoutOption.moveOverlap==="shiftY"});HB(i,0,t),oD(o,0,a);var s=Lt(n,function(l){return l.layoutOption.hideOverlap});sD(s)},r.prototype.processLabelsOverall=function(){var e=this;C(this._chartViewList,function(t){var a=t.__model,n=t.ignoreLabelLineUpdate,i=a.isAnimationEnabled();t.group.traverse(function(o){if(o.ignore&&!o.forceLabelAnimation)return!0;var s=!n,l=o.getTextContent();!s&&l&&(s=Vv(l).needsUpdateLabelLine),s&&e._updateLabelLine(o,a),i&&e._animateLabels(o,a)})})},r.prototype._updateLabelLine=function(e,t){var a=e.getTextContent(),n=nt(e),i=n.dataIndex;if(a&&i!=null){var o=t.getData(n.dataType),s=o.getItemModel(i),l={},u=o.getItemVisual(i,"style");if(u){var f=o.getVisual("drawType");l.stroke=u[f]}var h=s.getModel("labelLine");Kg(e,Qg(s),l),z_(e,h)}},r.prototype._animateLabels=function(e,t){var a=e.getTextContent(),n=e.getTextGuideLine();if(a&&(e.forceLabelAnimation||!a.ignore&&!a.invisible&&!e.disableLabelAnimation&&!Ui(e))){var i=Vv(a),o=i.oldLayout,s=nt(e),l=s.dataIndex,u={x:a.x,y:a.y,rotation:a.rotation},f=t.getData(s.dataType);if(o){a.attr(o);var v=e.prevStates;v&&(vt(v,"select")>=0&&a.attr(i.oldLayoutSelect),vt(v,"emphasis")>=0&&a.attr(i.oldLayoutEmphasis)),Dt(a,u,t,l)}else if(a.attr(u),!po(a).valueAnimation){var h=it(a.style.opacity,1);a.style.opacity=0,Bt(a,{style:{opacity:h}},t,l)}if(i.oldLayout=u,a.states.select){var c=i.oldLayoutSelect={};nu(c,u,iu),nu(c,a.states.select,iu)}if(a.states.emphasis){var p=i.oldLayoutEmphasis={};nu(p,u,iu),nu(p,a.states.emphasis,iu)}qT(a,l,f,t,t)}if(n&&!n.ignore&&!n.invisible){var i=UB(n),o=i.oldLayout,d={points:n.shape.points};o?(n.attr({shape:o}),Dt(n,{shape:d},t)):(n.setShape(d),n.style.strokePercent=0,Bt(n,{style:{strokePercent:1}},t)),i.oldLayout=d}},r}(),zv=bt();function ZB(r){r.registerUpdateLifecycle("series:beforeupdate",function(e,t,a){var n=zv(t).labelManager;n||(n=zv(t).labelManager=new YB),n.clearLabels()}),r.registerUpdateLifecycle("series:layoutlabels",function(e,t,a){var n=zv(t).labelManager;a.updatedSeries.forEach(function(i){n.addLabelsOfSeries(t.getViewOfSeriesModel(i))}),n.updateLayoutConfig(t),n.layout(t),n.processLabelsOverall()})}var Gv=Math.sin,Fv=Math.cos,lD=Math.PI,wn=Math.PI*2,XB=180/lD,uD=function(){function r(){}return r.prototype.reset=function(e){this._start=!0,this._d=[],this._str="",this._p=Math.pow(10,e||4)},r.prototype.moveTo=function(e,t){this._add("M",e,t)},r.prototype.lineTo=function(e,t){this._add("L",e,t)},r.prototype.bezierCurveTo=function(e,t,a,n,i,o){this._add("C",e,t,a,n,i,o)},r.prototype.quadraticCurveTo=function(e,t,a,n){this._add("Q",e,t,a,n)},r.prototype.arc=function(e,t,a,n,i,o){this.ellipse(e,t,a,a,0,n,i,o)},r.prototype.ellipse=function(e,t,a,n,i,o,s,l){var u=s-o,f=!l,h=Math.abs(u),v=Ea(h-wn)||(f?u>=wn:-u>=wn),c=u>0?u%wn:u%wn+wn,p=!1;v?p=!0:Ea(h)?p=!1:p=c>=lD==!!f;var d=e+a*Fv(o),g=t+n*Gv(o);this._start&&this._add("M",d,g);var y=Math.round(i*XB);if(v){var m=1/this._p,_=(f?1:-1)*(wn-m);this._add("A",a,n,y,1,+f,e+a*Fv(o+_),t+n*Gv(o+_)),m>.01&&this._add("A",a,n,y,0,+f,d,g)}else{var S=e+a*Fv(s),w=t+n*Gv(s);this._add("A",a,n,y,+p,+f,S,w)}},r.prototype.rect=function(e,t,a,n){this._add("M",e,t),this._add("l",a,0),this._add("l",0,n),this._add("l",-a,0),this._add("Z")},r.prototype.closePath=function(){this._d.length>0&&this._add("Z")},r.prototype._add=function(e,t,a,n,i,o,s,l,u){for(var f=[],h=this._p,v=1;v<arguments.length;v++){var c=arguments[v];if(isNaN(c)){this._invalid=!0;return}f.push(Math.round(c*h)/h)}this._d.push(e+f.join(" ")),this._start=e==="Z"},r.prototype.generateStr=function(){this._str=this._invalid?"":this._d.join(""),this._d=[]},r.prototype.getStr=function(){return this._str},r}(),Cs="none",qB=Math.round;function KB(r){var e=r.fill;return e!=null&&e!==Cs}function QB(r){var e=r.stroke;return e!=null&&e!==Cs}var td=["lineCap","miterLimit","lineJoin"],JB=G(td,function(r){return"stroke-"+r.toLowerCase()});function jB(r,e,t,a){var n=e.opacity==null?1:e.opacity;if(t instanceof he){r("opacity",n);return}if(KB(e)){var i=Rs(e.fill);r("fill",i.color);var o=e.fillOpacity!=null?e.fillOpacity*i.opacity*n:i.opacity*n;(a||o<1)&&r("fill-opacity",o)}else r("fill",Cs);if(QB(e)){var s=Rs(e.stroke);r("stroke",s.color);var l=e.strokeNoScale?t.getLineScale():1,u=l?(e.lineWidth||0)/l:0,f=e.strokeOpacity!=null?e.strokeOpacity*s.opacity*n:s.opacity*n,h=e.strokeFirst;if((a||u!==1)&&r("stroke-width",u),(a||h)&&r("paint-order",h?"stroke":"fill"),(a||f<1)&&r("stroke-opacity",f),e.lineDash){var v=Vg(t),c=v[0],p=v[1];c&&(p=qB(p||0),r("stroke-dasharray",c.join(",")),(p||a)&&r("stroke-dashoffset",p))}else a&&r("stroke-dasharray",Cs);for(var d=0;d<td.length;d++){var g=td[d];if(a||e[g]!==af[g]){var y=e[g]||af[g];y&&r(JB[d],y)}}}else a&&r("stroke",Cs)}var fD="http://www.w3.org/2000/svg",hD="http://www.w3.org/1999/xlink",tV="http://www.w3.org/2000/xmlns/",eV="http://www.w3.org/XML/1998/namespace",F_="ecmeta_";function vD(r){return document.createElementNS(fD,r)}function ee(r,e,t,a,n){return{tag:r,attrs:t||{},children:a,text:n,key:e}}function rV(r,e){var t=[];if(e)for(var a in e){var n=e[a],i=a;n!==!1&&(n!==!0&&n!=null&&(i+='="'+n+'"'),t.push(i))}return"<"+r+" "+t.join(" ")+">"}function aV(r){return"</"+r+">"}function Jg(r,e){e=e||{};var t=e.newline?`
`:"";function a(n){var i=n.children,o=n.tag,s=n.attrs,l=n.text;return rV(o,s)+(o!=="style"?Re(l):l||"")+(i?""+t+G(i,function(u){return a(u)}).join(t)+t:"")+aV(o)}return a(r)}function nV(r,e,t){t=t||{};var a=t.newline?`
`:"",n=" {"+a,i=a+"}",o=G(_t(r),function(l){return l+n+G(_t(r[l]),function(u){return u+":"+r[l][u]+";"}).join(a)+i}).join(a),s=G(_t(e),function(l){return"@keyframes "+l+n+G(_t(e[l]),function(u){return u+n+G(_t(e[l][u]),function(f){var h=e[l][u][f];return f==="d"&&(h='path("'+h+'")'),f+":"+h+";"}).join(a)+i}).join(a)+i}).join(a);return!o&&!s?"":["<![CDATA[",o,s,"]]>"].join(a)}function ed(r){return{zrId:r,shadowCache:{},patternCache:{},gradientCache:{},clipPathCache:{},defs:{},cssNodes:{},cssAnims:{},cssStyleCache:{},cssAnimIdx:0,shadowIdx:0,gradientIdx:0,patternIdx:0,clipPathIdx:0}}function H_(r,e,t,a){return ee("svg","root",{width:r,height:e,xmlns:fD,"xmlns:xlink":hD,version:"1.1",baseProfile:"full",viewBox:a?"0 0 "+r+" "+e:!1},t)}var iV=0;function cD(){return iV++}var W_={cubicIn:"0.32,0,0.67,0",cubicOut:"0.33,1,0.68,1",cubicInOut:"0.65,0,0.35,1",quadraticIn:"0.11,0,0.5,0",quadraticOut:"0.5,1,0.89,1",quadraticInOut:"0.45,0,0.55,1",quarticIn:"0.5,0,0.75,0",quarticOut:"0.25,1,0.5,1",quarticInOut:"0.76,0,0.24,1",quinticIn:"0.64,0,0.78,0",quinticOut:"0.22,1,0.36,1",quinticInOut:"0.83,0,0.17,1",sinusoidalIn:"0.12,0,0.39,0",sinusoidalOut:"0.61,1,0.88,1",sinusoidalInOut:"0.37,0,0.63,1",exponentialIn:"0.7,0,0.84,0",exponentialOut:"0.16,1,0.3,1",exponentialInOut:"0.87,0,0.13,1",circularIn:"0.55,0,1,0.45",circularOut:"0,0.55,0.45,1",circularInOut:"0.85,0,0.15,1"},An="transform-origin";function oV(r,e,t){var a=V({},r.shape);V(a,e),r.buildPath(t,a);var n=new uD;return n.reset(kb(r)),t.rebuildPath(n,1),n.generateStr(),n.getStr()}function sV(r,e){var t=e.originX,a=e.originY;(t||a)&&(r[An]=t+"px "+a+"px")}var lV={fill:"fill",opacity:"opacity",lineWidth:"stroke-width",lineDashOffset:"stroke-dashoffset"};function pD(r,e){var t=e.zrId+"-ani-"+e.cssAnimIdx++;return e.cssAnims[t]=r,t}function uV(r,e,t){var a=r.shape.paths,n={},i,o;if(C(a,function(l){var u=ed(t.zrId);u.animation=!0,Sh(l,{},u,!0);var f=u.cssAnims,h=u.cssNodes,v=_t(f),c=v.length;if(c){o=v[c-1];var p=f[o];for(var d in p){var g=p[d];n[d]=n[d]||{d:""},n[d].d+=g.d||""}for(var y in h){var m=h[y].animation;m.indexOf(o)>=0&&(i=m)}}}),!!i){e.d=!1;var s=pD(n,t);return i.replace(o,s)}}function $_(r){return $(r)?W_[r]?"cubic-bezier("+W_[r]+")":Qd(r)?r:"":""}function Sh(r,e,t,a){var n=r.animators,i=n.length,o=[];if(r instanceof dg){var s=uV(r,e,t);if(s)o.push(s);else if(!i)return}else if(!i)return;for(var l={},u=0;u<i;u++){var f=n[u],h=[f.getMaxTime()/1e3+"s"],v=$_(f.getClip().easing),c=f.getDelay();v?h.push(v):h.push("linear"),c&&h.push(c/1e3+"s"),f.getLoop()&&h.push("infinite");var p=h.join(" ");l[p]=l[p]||[p,[]],l[p][1].push(f)}function d(m){var _=m[1],S=_.length,w={},x={},b={},T="animation-timing-function";function A(et,dt,st){for(var q=et.getTracks(),lt=et.getMaxTime(),Vt=0;Vt<q.length;Vt++){var xt=q[Vt];if(xt.needsAnimate()){var Wt=xt.keyframes,Gt=xt.propName;if(st&&(Gt=st(Gt)),Gt)for(var ve=0;ve<Wt.length;ve++){var Yr=Wt[ve],Ie=Math.round(Yr.time/lt*100)+"%",Tl=$_(Yr.easing),pa=Yr.rawValue;($(pa)||Ct(pa))&&(dt[Ie]=dt[Ie]||{},dt[Ie][Gt]=Yr.rawValue,Tl&&(dt[Ie][T]=Tl))}}}}for(var D=0;D<S;D++){var M=_[D],I=M.targetName;I?I==="shape"&&A(M,x):!a&&A(M,w)}for(var L in w){var P={};zb(P,r),V(P,w[L]);var R=Ob(P),E=w[L][T];b[L]=R?{transform:R}:{},sV(b[L],P),E&&(b[L][T]=E)}var N,O=!0;for(var L in x){b[L]=b[L]||{};var B=!N,E=x[L][T];B&&(N=new Wr);var F=N.len();N.reset(),b[L].d=oV(r,x[L],N);var H=N.len();if(!B&&F!==H){O=!1;break}E&&(b[L][T]=E)}if(!O)for(var L in b)delete b[L].d;if(!a)for(var D=0;D<S;D++){var M=_[D],I=M.targetName;I==="style"&&A(M,b,function(q){return lV[q]})}for(var X=_t(b),Q=!0,J,D=1;D<X.length;D++){var ct=X[D-1],St=X[D];if(b[ct][An]!==b[St][An]){Q=!1;break}J=b[ct][An]}if(Q&&J){for(var L in b)b[L][An]&&delete b[L][An];e[An]=J}if(Lt(X,function(et){return _t(b[et]).length>0}).length){var pt=pD(b,t);return pt+" "+m[0]+" both"}}for(var g in l){var s=d(l[g]);s&&o.push(s)}if(o.length){var y=t.zrId+"-cls-"+cD();t.cssNodes["."+y]={animation:o.join(",")},e.class=y}}function fV(r,e,t){if(!r.ignore)if(r.isSilent()){var a={"pointer-events":"none"};U_(a,e,t,!0)}else{var n=r.states.emphasis&&r.states.emphasis.style?r.states.emphasis.style:{},i=n.fill;if(!i){var o=r.style&&r.style.fill,s=r.states.select&&r.states.select.style&&r.states.select.style.fill,l=r.currentStates.indexOf("select")>=0&&s||o;l&&(i=cp(l))}var u=n.lineWidth;if(u){var f=!n.strokeNoScale&&r.transform?r.transform[0]:1;u=u/f}var a={cursor:"pointer"};i&&(a.fill=i),n.stroke&&(a.stroke=n.stroke),u&&(a["stroke-width"]=u),U_(a,e,t,!0)}}function U_(r,e,t,a){var n=JSON.stringify(r),i=t.cssStyleCache[n];i||(i=t.zrId+"-cls-"+cD(),t.cssStyleCache[n]=i,t.cssNodes["."+i+(a?":hover":"")]=r),e.class=e.class?e.class+" "+i:i}var Ys=Math.round;function dD(r){return r&&$(r.src)}function gD(r){return r&&K(r.toDataURL)}function jg(r,e,t,a){jB(function(n,i){var o=n==="fill"||n==="stroke";o&&Eb(i)?mD(e,r,n,a):o&&Jd(i)?_D(t,r,n,a):o&&i==="none"?r[n]="transparent":r[n]=i},e,t,!1),yV(t,r,a)}function ty(r,e){var t=X2(e);t&&(t.each(function(a,n){a!=null&&(r[(F_+n).toLowerCase()]=a+"")}),e.isSilent()&&(r[F_+"silent"]="true"))}function Y_(r){return Ea(r[0]-1)&&Ea(r[1])&&Ea(r[2])&&Ea(r[3]-1)}function hV(r){return Ea(r[4])&&Ea(r[5])}function ey(r,e,t){if(e&&!(hV(e)&&Y_(e))){var a=t?10:1e4;r.transform=Y_(e)?"translate("+Ys(e[4]*a)/a+" "+Ys(e[5]*a)/a+")":g2(e)}}function Z_(r,e,t){for(var a=r.points,n=[],i=0;i<a.length;i++)n.push(Ys(a[i][0]*t)/t),n.push(Ys(a[i][1]*t)/t);e.points=n.join(" ")}function X_(r){return!r.smooth}function vV(r){var e=G(r,function(t){return typeof t=="string"?[t,t]:t});return function(t,a,n){for(var i=0;i<e.length;i++){var o=e[i],s=t[o[0]];s!=null&&(a[o[1]]=Ys(s*n)/n)}}}var cV={circle:[vV(["cx","cy","r"])],polyline:[Z_,X_],polygon:[Z_,X_]};function pV(r){for(var e=r.animators,t=0;t<e.length;t++)if(e[t].targetName==="shape")return!0;return!1}function yD(r,e){var t=r.style,a=r.shape,n=cV[r.type],i={},o=e.animation,s="path",l=r.style.strokePercent,u=e.compress&&kb(r)||4;if(n&&!e.willUpdate&&!(n[1]&&!n[1](a))&&!(o&&pV(r))&&!(l<1)){s=r.type;var f=Math.pow(10,u);n[0](a,i,f)}else{var h=!r.path||r.shapeChanged();r.path||r.createPathProxy();var v=r.path;h&&(v.beginPath(),r.buildPath(v,r.shape),r.pathUpdated());var c=v.getVersion(),p=r,d=p.__svgPathBuilder;(p.__svgPathVersion!==c||!d||l!==p.__svgPathStrokePercent)&&(d||(d=p.__svgPathBuilder=new uD),d.reset(u),v.rebuildPath(d,l),d.generateStr(),p.__svgPathVersion=c,p.__svgPathStrokePercent=l),i.d=d.getStr()}return ey(i,r.transform),jg(i,t,r,e),ty(i,r),e.animation&&Sh(r,i,e),e.emphasis&&fV(r,i,e),ee(s,r.id+"",i)}function dV(r,e){var t=r.style,a=t.image;if(a&&!$(a)&&(dD(a)?a=a.src:gD(a)&&(a=a.toDataURL())),!!a){var n=t.x||0,i=t.y||0,o=t.width,s=t.height,l={href:a,width:o,height:s};return n&&(l.x=n),i&&(l.y=i),ey(l,r.transform),jg(l,t,r,e),ty(l,r),e.animation&&Sh(r,l,e),ee("image",r.id+"",l)}}function gV(r,e){var t=r.style,a=t.text;if(a!=null&&(a+=""),!(!a||isNaN(t.x)||isNaN(t.y))){var n=t.font||Fa,i=t.x||0,o=m2(t.y||0,Xf(n),t.textBaseline),s=y2[t.textAlign]||t.textAlign,l={"dominant-baseline":"central","text-anchor":s};if(gT(t)){var u="",f=t.fontStyle,h=dT(t.fontSize);if(!parseFloat(h))return;var v=t.fontFamily||ub,c=t.fontWeight;u+="font-size:"+h+";font-family:"+v+";",f&&f!=="normal"&&(u+="font-style:"+f+";"),c&&c!=="normal"&&(u+="font-weight:"+c+";"),l.style=u}else l.style="font: "+n;return a.match(/\s/)&&(l["xml:space"]="preserve"),i&&(l.x=i),o&&(l.y=o),ey(l,r.transform),jg(l,t,r,e),ty(l,r),e.animation&&Sh(r,l,e),ee("text",r.id+"",l,void 0,a)}}function q_(r,e){if(r instanceof yt)return yD(r,e);if(r instanceof he)return dV(r,e);if(r instanceof Os)return gV(r,e)}function yV(r,e,t){var a=r.style;if(_2(a)){var n=S2(r),i=t.shadowCache,o=i[n];if(!o){var s=r.getGlobalScale(),l=s[0],u=s[1];if(!l||!u)return;var f=a.shadowOffsetX||0,h=a.shadowOffsetY||0,v=a.shadowBlur,c=Rs(a.shadowColor),p=c.opacity,d=c.color,g=v/2/l,y=v/2/u,m=g+" "+y;o=t.zrId+"-s"+t.shadowIdx++,t.defs[o]=ee("filter",o,{id:o,x:"-100%",y:"-100%",width:"300%",height:"300%"},[ee("feDropShadow","",{dx:f/l,dy:h/u,stdDeviation:m,"flood-color":d,"flood-opacity":p})]),i[n]=o}e.filter=Zf(o)}}function mD(r,e,t,a){var n=r[t],i,o={gradientUnits:n.global?"userSpaceOnUse":"objectBoundingBox"};if(Pb(n))i="linearGradient",o.x1=n.x,o.y1=n.y,o.x2=n.x2,o.y2=n.y2;else if(Rb(n))i="radialGradient",o.cx=it(n.x,.5),o.cy=it(n.y,.5),o.r=it(n.r,.5);else return;for(var s=n.colorStops,l=[],u=0,f=s.length;u<f;++u){var h=pp(s[u].offset)*100+"%",v=s[u].color,c=Rs(v),p=c.color,d=c.opacity,g={offset:h};g["stop-color"]=p,d<1&&(g["stop-opacity"]=d),l.push(ee("stop",u+"",g))}var y=ee(i,"",o,l),m=Jg(y),_=a.gradientCache,S=_[m];S||(S=a.zrId+"-g"+a.gradientIdx++,_[m]=S,o.id=S,a.defs[S]=ee(i,S,o,l)),e[t]=Zf(S)}function _D(r,e,t,a){var n=r.style[t],i=r.getBoundingRect(),o={},s=n.repeat,l=s==="no-repeat",u=s==="repeat-x",f=s==="repeat-y",h;if(Lb(n)){var v=n.imageWidth,c=n.imageHeight,p=void 0,d=n.image;if($(d)?p=d:dD(d)?p=d.src:gD(d)&&(p=d.toDataURL()),typeof Image>"u"){var g="Image width/height must been given explictly in svg-ssr renderer.";Ae(v,g),Ae(c,g)}else if(v==null||c==null){var y=function(D,M){if(D){var I=D.elm,L=v||M.width,P=c||M.height;D.tag==="pattern"&&(u?(P=1,L/=i.width):f&&(L=1,P/=i.height)),D.attrs.width=L,D.attrs.height=P,I&&(I.setAttribute("width",L),I.setAttribute("height",P))}},m=ig(p,null,r,function(D){l||y(x,D),y(h,D)});m&&m.width&&m.height&&(v=v||m.width,c=c||m.height)}h=ee("image","img",{href:p,width:v,height:c}),o.width=v,o.height=c}else n.svgElement&&(h=rt(n.svgElement),o.width=n.svgWidth,o.height=n.svgHeight);if(h){var _,S;l?_=S=1:u?(S=1,_=o.width/i.width):f?(_=1,S=o.height/i.height):o.patternUnits="userSpaceOnUse",_!=null&&!isNaN(_)&&(o.width=_),S!=null&&!isNaN(S)&&(o.height=S);var w=Ob(n);w&&(o.patternTransform=w);var x=ee("pattern","",o,[h]),b=Jg(x),T=a.patternCache,A=T[b];A||(A=a.zrId+"-p"+a.patternIdx++,T[b]=A,o.id=A,x=a.defs[A]=ee("pattern",A,o,[h])),e[t]=Zf(A)}}function mV(r,e,t){var a=t.clipPathCache,n=t.defs,i=a[r.id];if(!i){i=t.zrId+"-c"+t.clipPathIdx++;var o={id:i};a[r.id]=i,n[i]=ee("clipPath",i,o,[yD(r,t)])}e["clip-path"]=Zf(i)}function K_(r){return document.createTextNode(r)}function Rn(r,e,t){r.insertBefore(e,t)}function Q_(r,e){r.removeChild(e)}function J_(r,e){r.appendChild(e)}function SD(r){return r.parentNode}function xD(r){return r.nextSibling}function Hv(r,e){r.textContent=e}var j_=58,_V=120,SV=ee("","");function rd(r){return r===void 0}function Lr(r){return r!==void 0}function xV(r,e,t){for(var a={},n=e;n<=t;++n){var i=r[n].key;i!==void 0&&(a[i]=n)}return a}function ss(r,e){var t=r.key===e.key,a=r.tag===e.tag;return a&&t}function Zs(r){var e,t=r.children,a=r.tag;if(Lr(a)){var n=r.elm=vD(a);if(ry(SV,r),z(t))for(e=0;e<t.length;++e){var i=t[e];i!=null&&J_(n,Zs(i))}else Lr(r.text)&&!tt(r.text)&&J_(n,K_(r.text))}else r.elm=K_(r.text);return r.elm}function wD(r,e,t,a,n){for(;a<=n;++a){var i=t[a];i!=null&&Rn(r,Zs(i),e)}}function bf(r,e,t,a){for(;t<=a;++t){var n=e[t];if(n!=null)if(Lr(n.tag)){var i=SD(n.elm);Q_(i,n.elm)}else Q_(r,n.elm)}}function ry(r,e){var t,a=e.elm,n=r&&r.attrs||{},i=e.attrs||{};if(n!==i){for(t in i){var o=i[t],s=n[t];s!==o&&(o===!0?a.setAttribute(t,""):o===!1?a.removeAttribute(t):t==="style"?a.style.cssText=o:t.charCodeAt(0)!==_V?a.setAttribute(t,o):t==="xmlns:xlink"||t==="xmlns"?a.setAttributeNS(tV,t,o):t.charCodeAt(3)===j_?a.setAttributeNS(eV,t,o):t.charCodeAt(5)===j_?a.setAttributeNS(hD,t,o):a.setAttribute(t,o))}for(t in n)t in i||a.removeAttribute(t)}}function wV(r,e,t){for(var a=0,n=0,i=e.length-1,o=e[0],s=e[i],l=t.length-1,u=t[0],f=t[l],h,v,c,p;a<=i&&n<=l;)o==null?o=e[++a]:s==null?s=e[--i]:u==null?u=t[++n]:f==null?f=t[--l]:ss(o,u)?(Bi(o,u),o=e[++a],u=t[++n]):ss(s,f)?(Bi(s,f),s=e[--i],f=t[--l]):ss(o,f)?(Bi(o,f),Rn(r,o.elm,xD(s.elm)),o=e[++a],f=t[--l]):ss(s,u)?(Bi(s,u),Rn(r,s.elm,o.elm),s=e[--i],u=t[++n]):(rd(h)&&(h=xV(e,a,i)),v=h[u.key],rd(v)?Rn(r,Zs(u),o.elm):(c=e[v],c.tag!==u.tag?Rn(r,Zs(u),o.elm):(Bi(c,u),e[v]=void 0,Rn(r,c.elm,o.elm))),u=t[++n]);(a<=i||n<=l)&&(a>i?(p=t[l+1]==null?null:t[l+1].elm,wD(r,p,t,n,l)):bf(r,e,a,i))}function Bi(r,e){var t=e.elm=r.elm,a=r.children,n=e.children;r!==e&&(ry(r,e),rd(e.text)?Lr(a)&&Lr(n)?a!==n&&wV(t,a,n):Lr(n)?(Lr(r.text)&&Hv(t,""),wD(t,null,n,0,n.length-1)):Lr(a)?bf(t,a,0,a.length-1):Lr(r.text)&&Hv(t,""):r.text!==e.text&&(Lr(a)&&bf(t,a,0,a.length-1),Hv(t,e.text)))}function bV(r,e){if(ss(r,e))Bi(r,e);else{var t=r.elm,a=SD(t);Zs(e),a!==null&&(Rn(a,e.elm,xD(t)),bf(a,[r],0,0))}return e}var TV=0,AV=function(){function r(e,t,a){if(this.type="svg",this.refreshHover=t1(),this.configLayer=t1(),this.storage=t,this._opts=a=V({},a),this.root=e,this._id="zr"+TV++,this._oldVNode=H_(a.width,a.height),e&&!a.ssr){var n=this._viewport=document.createElement("div");n.style.cssText="position:relative;overflow:hidden";var i=this._svgDom=this._oldVNode.elm=vD("svg");ry(null,this._oldVNode),n.appendChild(i),e.appendChild(n)}this.resize(a.width,a.height)}return r.prototype.getType=function(){return this.type},r.prototype.getViewportRoot=function(){return this._viewport},r.prototype.getViewportRootOffset=function(){var e=this.getViewportRoot();if(e)return{offsetLeft:e.offsetLeft||0,offsetTop:e.offsetTop||0}},r.prototype.getSvgDom=function(){return this._svgDom},r.prototype.refresh=function(){if(this.root){var e=this.renderToVNode({willUpdate:!0});e.attrs.style="position:absolute;left:0;top:0;user-select:none",bV(this._oldVNode,e),this._oldVNode=e}},r.prototype.renderOneToVNode=function(e){return q_(e,ed(this._id))},r.prototype.renderToVNode=function(e){e=e||{};var t=this.storage.getDisplayList(!0),a=this._width,n=this._height,i=ed(this._id);i.animation=e.animation,i.willUpdate=e.willUpdate,i.compress=e.compress,i.emphasis=e.emphasis;var o=[],s=this._bgVNode=CV(a,n,this._backgroundColor,i);s&&o.push(s);var l=e.compress?null:this._mainVNode=ee("g","main",{},[]);this._paintList(t,i,l?l.children:o),l&&o.push(l);var u=G(_t(i.defs),function(v){return i.defs[v]});if(u.length&&o.push(ee("defs","defs",{},u)),e.animation){var f=nV(i.cssNodes,i.cssAnims,{newline:!0});if(f){var h=ee("style","stl",{},[],f);o.push(h)}}return H_(a,n,o,e.useViewBox)},r.prototype.renderToString=function(e){return e=e||{},Jg(this.renderToVNode({animation:it(e.cssAnimation,!0),emphasis:it(e.cssEmphasis,!0),willUpdate:!1,compress:!0,useViewBox:it(e.useViewBox,!0)}),{newline:!0})},r.prototype.setBackgroundColor=function(e){this._backgroundColor=e},r.prototype.getSvgRoot=function(){return this._mainVNode&&this._mainVNode.elm},r.prototype._paintList=function(e,t,a){for(var n=e.length,i=[],o=0,s,l,u=0,f=0;f<n;f++){var h=e[f];if(!h.invisible){var v=h.__clipPaths,c=v&&v.length||0,p=l&&l.length||0,d=void 0;for(d=Math.max(c-1,p-1);d>=0&&!(v&&l&&v[d]===l[d]);d--);for(var g=p-1;g>d;g--)o--,s=i[o-1];for(var y=d+1;y<c;y++){var m={};mV(v[y],m,t);var _=ee("g","clip-g-"+u++,m,[]);(s?s.children:a).push(_),i[o++]=_,s=_}l=v;var S=q_(h,t);S&&(s?s.children:a).push(S)}}},r.prototype.resize=function(e,t){var a=this._opts,n=this.root,i=this._viewport;if(e!=null&&(a.width=e),t!=null&&(a.height=t),n&&i&&(i.style.display="none",e=Hi(n,0,a),t=Hi(n,1,a),i.style.display=""),this._width!==e||this._height!==t){if(this._width=e,this._height=t,i){var o=i.style;o.width=e+"px",o.height=t+"px"}if(Jd(this._backgroundColor))this.refresh();else{var s=this._svgDom;s&&(s.setAttribute("width",e),s.setAttribute("height",t));var l=this._bgVNode&&this._bgVNode.elm;l&&(l.setAttribute("width",e),l.setAttribute("height",t))}}},r.prototype.getWidth=function(){return this._width},r.prototype.getHeight=function(){return this._height},r.prototype.dispose=function(){this.root&&(this.root.innerHTML=""),this._svgDom=this._viewport=this.storage=this._oldVNode=this._bgVNode=this._mainVNode=null},r.prototype.clear=function(){this._svgDom&&(this._svgDom.innerHTML=null),this._oldVNode=null},r.prototype.toDataURL=function(e){var t=this.renderToString(),a="data:image/svg+xml;";return e?(t=w2(t),t&&a+"base64,"+t):a+"charset=UTF-8,"+encodeURIComponent(t)},r}();function t1(r){return function(){}}function CV(r,e,t,a){var n;if(t&&t!=="none")if(n=ee("rect","bg",{width:r,height:e,x:"0",y:"0"}),Eb(t))mD({fill:t},n.attrs,"fill",a);else if(Jd(t))_D({style:{fill:t},dirty:Yt,getBoundingRect:function(){return{width:r,height:e}}},n.attrs,"fill",a);else{var i=Rs(t),o=i.color,s=i.opacity;n.attrs.fill=o,s<1&&(n.attrs["fill-opacity"]=s)}return n}const DV=AV;function MV(r){r.registerPainter("svg",DV)}function e1(r,e,t){var a=Ha.createCanvas(),n=e.getWidth(),i=e.getHeight(),o=a.style;return o&&(o.position="absolute",o.left="0",o.top="0",o.width=n+"px",o.height=i+"px",a.setAttribute("data-zr-dom-id",r)),a.width=n*t,a.height=i*t,a}var IV=function(r){k(e,r);function e(t,a,n){var i=r.call(this)||this;i.motionBlur=!1,i.lastFrameAlpha=.7,i.dpr=1,i.virtual=!1,i.config={},i.incremental=!1,i.zlevel=0,i.maxRepaintRectCount=5,i.__dirty=!0,i.__firstTimePaint=!0,i.__used=!1,i.__drawIndex=0,i.__startIndex=0,i.__endIndex=0,i.__prevStartIndex=null,i.__prevEndIndex=null;var o;n=n||ef,typeof t=="string"?o=e1(t,a,n):tt(t)&&(o=t,t=o.id),i.id=t,i.dom=o;var s=o.style;return s&&(db(o),o.onselectstart=function(){return!1},s.padding="0",s.margin="0",s.borderWidth="0"),i.painter=a,i.dpr=n,i}return e.prototype.getElementCount=function(){return this.__endIndex-this.__startIndex},e.prototype.afterBrush=function(){this.__prevStartIndex=this.__startIndex,this.__prevEndIndex=this.__endIndex},e.prototype.initContext=function(){this.ctx=this.dom.getContext("2d"),this.ctx.dpr=this.dpr},e.prototype.setUnpainted=function(){this.__firstTimePaint=!0},e.prototype.createBackBuffer=function(){var t=this.dpr;this.domBack=e1("back-"+this.id,this.painter,t),this.ctxBack=this.domBack.getContext("2d"),t!==1&&this.ctxBack.scale(t,t)},e.prototype.createRepaintRects=function(t,a,n,i){if(this.__firstTimePaint)return this.__firstTimePaint=!1,null;var o=[],s=this.maxRepaintRectCount,l=!1,u=new ht(0,0,0,0);function f(m){if(!(!m.isFinite()||m.isZero()))if(o.length===0){var _=new ht(0,0,0,0);_.copy(m),o.push(_)}else{for(var S=!1,w=1/0,x=0,b=0;b<o.length;++b){var T=o[b];if(T.intersect(m)){var A=new ht(0,0,0,0);A.copy(T),A.union(m),o[b]=A,S=!0;break}else if(l){u.copy(m),u.union(T);var D=m.width*m.height,M=T.width*T.height,I=u.width*u.height,L=I-D-M;L<w&&(w=L,x=b)}}if(l&&(o[x].union(m),S=!0),!S){var _=new ht(0,0,0,0);_.copy(m),o.push(_)}l||(l=o.length>=s)}}for(var h=this.__startIndex;h<this.__endIndex;++h){var v=t[h];if(v){var c=v.shouldBePainted(n,i,!0,!0),p=v.__isRendered&&(v.__dirty&ze||!c)?v.getPrevPaintRect():null;p&&f(p);var d=c&&(v.__dirty&ze||!v.__isRendered)?v.getPaintRect():null;d&&f(d)}}for(var h=this.__prevStartIndex;h<this.__prevEndIndex;++h){var v=a[h],c=v&&v.shouldBePainted(n,i,!0,!0);if(v&&(!c||!v.__zr)&&v.__isRendered){var p=v.getPrevPaintRect();p&&f(p)}}var g;do{g=!1;for(var h=0;h<o.length;){if(o[h].isZero()){o.splice(h,1);continue}for(var y=h+1;y<o.length;)o[h].intersect(o[y])?(g=!0,o[h].union(o[y]),o.splice(y,1)):y++;h++}}while(g);return this._paintRects=o,o},e.prototype.debugGetPaintRects=function(){return(this._paintRects||[]).slice()},e.prototype.resize=function(t,a){var n=this.dpr,i=this.dom,o=i.style,s=this.domBack;o&&(o.width=t+"px",o.height=a+"px"),i.width=t*n,i.height=a*n,s&&(s.width=t*n,s.height=a*n,n!==1&&this.ctxBack.scale(n,n))},e.prototype.clear=function(t,a,n){var i=this.dom,o=this.ctx,s=i.width,l=i.height;a=a||this.clearColor;var u=this.motionBlur&&!t,f=this.lastFrameAlpha,h=this.dpr,v=this;u&&(this.domBack||this.createBackBuffer(),this.ctxBack.globalCompositeOperation="copy",this.ctxBack.drawImage(i,0,0,s/h,l/h));var c=this.domBack;function p(d,g,y,m){if(o.clearRect(d,g,y,m),a&&a!=="transparent"){var _=void 0;if($f(a)){var S=a.global||a.__width===y&&a.__height===m;_=S&&a.__canvasGradient||Yp(o,a,{x:0,y:0,width:y,height:m}),a.__canvasGradient=_,a.__width=y,a.__height=m}else CL(a)&&(a.scaleX=a.scaleX||h,a.scaleY=a.scaleY||h,_=Zp(o,a,{dirty:function(){v.setUnpainted(),v.painter.refresh()}}));o.save(),o.fillStyle=_||a,o.fillRect(d,g,y,m),o.restore()}u&&(o.save(),o.globalAlpha=f,o.drawImage(c,d,g,y,m),o.restore())}!n||u?p(0,0,s,l):n.length&&C(n,function(d){p(d.x*h,d.y*h,d.width*h,d.height*h)})},e}(or);const Wv=IV;var r1=1e5,bn=314159,ou=.01,LV=.001;function PV(r){return r?r.__builtin__?!0:!(typeof r.resize!="function"||typeof r.refresh!="function"):!1}function RV(r,e){var t=document.createElement("div");return t.style.cssText=["position:relative","width:"+r+"px","height:"+e+"px","padding:0","margin:0","border-width:0"].join(";")+";",t}var EV=function(){function r(e,t,a,n){this.type="canvas",this._zlevelList=[],this._prevDisplayList=[],this._layers={},this._layerConfig={},this._needsManuallyCompositing=!1,this.type="canvas";var i=!e.nodeName||e.nodeName.toUpperCase()==="CANVAS";this._opts=a=V({},a||{}),this.dpr=a.devicePixelRatio||ef,this._singleCanvas=i,this.root=e;var o=e.style;o&&(db(e),e.innerHTML=""),this.storage=t;var s=this._zlevelList;this._prevDisplayList=[];var l=this._layers;if(i){var f=e,h=f.width,v=f.height;a.width!=null&&(h=a.width),a.height!=null&&(v=a.height),this.dpr=a.devicePixelRatio||1,f.width=h*this.dpr,f.height=v*this.dpr,this._width=h,this._height=v;var c=new Wv(f,this,this.dpr);c.__builtin__=!0,c.initContext(),l[bn]=c,c.zlevel=bn,s.push(bn),this._domRoot=e}else{this._width=Hi(e,0,a),this._height=Hi(e,1,a);var u=this._domRoot=RV(this._width,this._height);e.appendChild(u)}}return r.prototype.getType=function(){return"canvas"},r.prototype.isSingleCanvas=function(){return this._singleCanvas},r.prototype.getViewportRoot=function(){return this._domRoot},r.prototype.getViewportRootOffset=function(){var e=this.getViewportRoot();if(e)return{offsetLeft:e.offsetLeft||0,offsetTop:e.offsetTop||0}},r.prototype.refresh=function(e){var t=this.storage.getDisplayList(!0),a=this._prevDisplayList,n=this._zlevelList;this._redrawId=Math.random(),this._paintList(t,a,e,this._redrawId);for(var i=0;i<n.length;i++){var o=n[i],s=this._layers[o];if(!s.__builtin__&&s.refresh){var l=i===0?this._backgroundColor:null;s.refresh(l)}}return this._opts.useDirtyRect&&(this._prevDisplayList=t.slice()),this},r.prototype.refreshHover=function(){this._paintHoverList(this.storage.getDisplayList(!1))},r.prototype._paintHoverList=function(e){var t=e.length,a=this._hoverlayer;if(a&&a.clear(),!!t){for(var n={inHover:!0,viewWidth:this._width,viewHeight:this._height},i,o=0;o<t;o++){var s=e[o];s.__inHover&&(a||(a=this._hoverlayer=this.getLayer(r1)),i||(i=a.ctx,i.save()),Fn(i,s,n,o===t-1))}i&&i.restore()}},r.prototype.getHoverLayer=function(){return this.getLayer(r1)},r.prototype.paintOne=function(e,t){aC(e,t)},r.prototype._paintList=function(e,t,a,n){if(this._redrawId===n){a=a||!1,this._updateLayerStatus(e);var i=this._doPaintList(e,t,a),o=i.finished,s=i.needsRefreshHover;if(this._needsManuallyCompositing&&this._compositeManually(),s&&this._paintHoverList(e),o)this.eachLayer(function(u){u.afterBrush&&u.afterBrush()});else{var l=this;lp(function(){l._paintList(e,t,a,n)})}}},r.prototype._compositeManually=function(){var e=this.getLayer(bn).ctx,t=this._domRoot.width,a=this._domRoot.height;e.clearRect(0,0,t,a),this.eachBuiltinLayer(function(n){n.virtual&&e.drawImage(n.dom,0,0,t,a)})},r.prototype._doPaintList=function(e,t,a){for(var n=this,i=[],o=this._opts.useDirtyRect,s=0;s<this._zlevelList.length;s++){var l=this._zlevelList[s],u=this._layers[l];u.__builtin__&&u!==this._hoverlayer&&(u.__dirty||a)&&i.push(u)}for(var f=!0,h=!1,v=function(d){var g=i[d],y=g.ctx,m=o&&g.createRepaintRects(e,t,c._width,c._height),_=a?g.__startIndex:g.__drawIndex,S=!a&&g.incremental&&Date.now,w=S&&Date.now(),x=g.zlevel===c._zlevelList[0]?c._backgroundColor:null;if(g.__startIndex===g.__endIndex)g.clear(!1,x,m);else if(_===g.__startIndex){var b=e[_];(!b.incremental||!b.notClear||a)&&g.clear(!1,x,m)}_===-1&&(console.error("For some unknown reason. drawIndex is -1"),_=g.__startIndex);var T,A=function(L){var P={inHover:!1,allClipped:!1,prevEl:null,viewWidth:n._width,viewHeight:n._height};for(T=_;T<g.__endIndex;T++){var R=e[T];if(R.__inHover&&(h=!0),n._doPaintEl(R,g,o,L,P,T===g.__endIndex-1),S){var E=Date.now()-w;if(E>15)break}}P.prevElClipPaths&&y.restore()};if(m)if(m.length===0)T=g.__endIndex;else for(var D=c.dpr,M=0;M<m.length;++M){var I=m[M];y.save(),y.beginPath(),y.rect(I.x*D,I.y*D,I.width*D,I.height*D),y.clip(),A(I),y.restore()}else y.save(),A(),y.restore();g.__drawIndex=T,g.__drawIndex<g.__endIndex&&(f=!1)},c=this,p=0;p<i.length;p++)v(p);return mt.wxa&&C(this._layers,function(d){d&&d.ctx&&d.ctx.draw&&d.ctx.draw()}),{finished:f,needsRefreshHover:h}},r.prototype._doPaintEl=function(e,t,a,n,i,o){var s=t.ctx;if(a){var l=e.getPaintRect();(!n||l&&l.intersect(n))&&(Fn(s,e,i,o),e.setPrevPaintRect(l))}else Fn(s,e,i,o)},r.prototype.getLayer=function(e,t){this._singleCanvas&&!this._needsManuallyCompositing&&(e=bn);var a=this._layers[e];return a||(a=new Wv("zr_"+e,this,this.dpr),a.zlevel=e,a.__builtin__=!0,this._layerConfig[e]?ft(a,this._layerConfig[e],!0):this._layerConfig[e-ou]&&ft(a,this._layerConfig[e-ou],!0),t&&(a.virtual=t),this.insertLayer(e,a),a.initContext()),a},r.prototype.insertLayer=function(e,t){var a=this._layers,n=this._zlevelList,i=n.length,o=this._domRoot,s=null,l=-1;if(!a[e]&&PV(t)){if(i>0&&e>n[0]){for(l=0;l<i-1&&!(n[l]<e&&n[l+1]>e);l++);s=a[n[l]]}if(n.splice(l+1,0,e),a[e]=t,!t.virtual)if(s){var u=s.dom;u.nextSibling?o.insertBefore(t.dom,u.nextSibling):o.appendChild(t.dom)}else o.firstChild?o.insertBefore(t.dom,o.firstChild):o.appendChild(t.dom);t.painter||(t.painter=this)}},r.prototype.eachLayer=function(e,t){for(var a=this._zlevelList,n=0;n<a.length;n++){var i=a[n];e.call(t,this._layers[i],i)}},r.prototype.eachBuiltinLayer=function(e,t){for(var a=this._zlevelList,n=0;n<a.length;n++){var i=a[n],o=this._layers[i];o.__builtin__&&e.call(t,o,i)}},r.prototype.eachOtherLayer=function(e,t){for(var a=this._zlevelList,n=0;n<a.length;n++){var i=a[n],o=this._layers[i];o.__builtin__||e.call(t,o,i)}},r.prototype.getLayers=function(){return this._layers},r.prototype._updateLayerStatus=function(e){this.eachBuiltinLayer(function(h,v){h.__dirty=h.__used=!1});function t(h){i&&(i.__endIndex!==h&&(i.__dirty=!0),i.__endIndex=h)}if(this._singleCanvas)for(var a=1;a<e.length;a++){var n=e[a];if(n.zlevel!==e[a-1].zlevel||n.incremental){this._needsManuallyCompositing=!0;break}}var i=null,o=0,s,l;for(l=0;l<e.length;l++){var n=e[l],u=n.zlevel,f=void 0;s!==u&&(s=u,o=0),n.incremental?(f=this.getLayer(u+LV,this._needsManuallyCompositing),f.incremental=!0,o=1):f=this.getLayer(u+(o>0?ou:0),this._needsManuallyCompositing),f.__builtin__||$d("ZLevel "+u+" has been used by unkown layer "+f.id),f!==i&&(f.__used=!0,f.__startIndex!==l&&(f.__dirty=!0),f.__startIndex=l,f.incremental?f.__drawIndex=-1:f.__drawIndex=l,t(l),i=f),n.__dirty&ze&&!n.__inHover&&(f.__dirty=!0,f.incremental&&f.__drawIndex<0&&(f.__drawIndex=l))}t(l),this.eachBuiltinLayer(function(h,v){!h.__used&&h.getElementCount()>0&&(h.__dirty=!0,h.__startIndex=h.__endIndex=h.__drawIndex=0),h.__dirty&&h.__drawIndex<0&&(h.__drawIndex=h.__startIndex)})},r.prototype.clear=function(){return this.eachBuiltinLayer(this._clearLayer),this},r.prototype._clearLayer=function(e){e.clear()},r.prototype.setBackgroundColor=function(e){this._backgroundColor=e,C(this._layers,function(t){t.setUnpainted()})},r.prototype.configLayer=function(e,t){if(t){var a=this._layerConfig;a[e]?ft(a[e],t,!0):a[e]=t;for(var n=0;n<this._zlevelList.length;n++){var i=this._zlevelList[n];if(i===e||i===e+ou){var o=this._layers[i];ft(o,a[e],!0)}}}},r.prototype.delLayer=function(e){var t=this._layers,a=this._zlevelList,n=t[e];n&&(n.dom.parentNode.removeChild(n.dom),delete t[e],a.splice(vt(a,e),1))},r.prototype.resize=function(e,t){if(this._domRoot.style){var a=this._domRoot;a.style.display="none";var n=this._opts,i=this.root;if(e!=null&&(n.width=e),t!=null&&(n.height=t),e=Hi(i,0,n),t=Hi(i,1,n),a.style.display="",this._width!==e||t!==this._height){a.style.width=e+"px",a.style.height=t+"px";for(var o in this._layers)this._layers.hasOwnProperty(o)&&this._layers[o].resize(e,t);this.refresh(!0)}this._width=e,this._height=t}else{if(e==null||t==null)return;this._width=e,this._height=t,this.getLayer(bn).resize(e,t)}return this},r.prototype.clearLayer=function(e){var t=this._layers[e];t&&t.clear()},r.prototype.dispose=function(){this.root.innerHTML="",this.root=this.storage=this._domRoot=this._layers=null},r.prototype.getRenderedCanvas=function(e){if(e=e||{},this._singleCanvas&&!this._compositeManually)return this._layers[bn].dom;var t=new Wv("image",this,e.pixelRatio||this.dpr);t.initContext(),t.clear(!1,e.backgroundColor||this._backgroundColor);var a=t.ctx;if(e.pixelRatio<=this.dpr){this.refresh();var n=t.dom.width,i=t.dom.height;this.eachLayer(function(h){h.__builtin__?a.drawImage(h.dom,0,0,n,i):h.renderToCanvas&&(a.save(),h.renderToCanvas(a),a.restore())})}else for(var o={inHover:!1,viewWidth:this._width,viewHeight:this._height},s=this.storage.getDisplayList(!0),l=0,u=s.length;l<u;l++){var f=s[l];Fn(a,f,o,l===u-1)}return t.dom},r.prototype.getWidth=function(){return this._width},r.prototype.getHeight=function(){return this._height},r}();const kV=EV;function OV(r){r.registerPainter("canvas",kV)}var NV=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t}return e.prototype.getInitialData=function(t){return va(null,this,{useEncodeDefaulter:!0})},e.prototype.getLegendIcon=function(t){var a=new at,n=qt("line",0,t.itemHeight/2,t.itemWidth,0,t.lineStyle.stroke,!1);a.add(n),n.setStyle(t.lineStyle);var i=this.getData().getVisual("symbol"),o=this.getData().getVisual("symbolRotate"),s=i==="none"?"circle":i,l=t.itemHeight*.8,u=qt(s,(t.itemWidth-l)/2,(t.itemHeight-l)/2,l,l,t.itemStyle.fill);a.add(u),u.setStyle(t.itemStyle);var f=t.iconRotate==="inherit"?o:t.iconRotate||0;return u.rotation=f*Math.PI/180,u.setOrigin([t.itemWidth/2,t.itemHeight/2]),s.indexOf("empty")>-1&&(u.style.stroke=u.style.fill,u.style.fill="#fff",u.style.lineWidth=2),a},e.type="series.line",e.dependencies=["grid","polar"],e.defaultOption={z:3,coordinateSystem:"cartesian2d",legendHoverLink:!0,clip:!0,label:{position:"top"},endLabel:{show:!1,valueAnimation:!0,distance:8},lineStyle:{width:2,type:"solid"},emphasis:{scale:!0},step:!1,smooth:!1,smoothMonotone:null,symbol:"emptyCircle",symbolSize:4,symbolRotate:null,showSymbol:!0,showAllSymbol:"auto",connectNulls:!1,sampling:"none",animationEasing:"linear",progressive:0,hoverLayerThreshold:1/0,universalTransition:{divideShape:"clone"},triggerLineEvent:!1},e}(zt);const BV=NV;function eo(r,e){var t=r.mapDimensionsAll("defaultedLabel"),a=t.length;if(a===1){var n=Ji(r,e,t[0]);return n!=null?n+"":null}else if(a){for(var i=[],o=0;o<t.length;o++)i.push(Ji(r,e,t[o]));return i.join(" ")}}function bD(r,e){var t=r.mapDimensionsAll("defaultedLabel");if(!z(e))return e+"";for(var a=[],n=0;n<t.length;n++){var i=r.getDimensionIndex(t[n]);i>=0&&a.push(e[i])}return a.join(" ")}var dl=function(r){k(e,r);function e(t,a,n,i){var o=r.call(this)||this;return o.updateData(t,a,n,i),o}return e.prototype._createSymbol=function(t,a,n,i,o){this.removeAll();var s=qt(t,-1,-1,2,2,null,o);s.attr({z2:100,culling:!0,scaleX:i[0]/2,scaleY:i[1]/2}),s.drift=VV,this._symbolType=t,this.add(s)},e.prototype.stopSymbolAnimation=function(t){this.childAt(0).stopAnimation(null,t)},e.prototype.getSymbolType=function(){return this._symbolType},e.prototype.getSymbolPath=function(){return this.childAt(0)},e.prototype.highlight=function(){sa(this.childAt(0))},e.prototype.downplay=function(){la(this.childAt(0))},e.prototype.setZ=function(t,a){var n=this.childAt(0);n.zlevel=t,n.z=a},e.prototype.setDraggable=function(t,a){var n=this.childAt(0);n.draggable=t,n.cursor=!a&&t?"move":n.cursor},e.prototype.updateData=function(t,a,n,i){this.silent=!1;var o=t.getItemVisual(a,"symbol")||"circle",s=t.hostModel,l=e.getSymbolSize(t,a),u=o!==this._symbolType,f=i&&i.disableAnimation;if(u){var h=t.getItemVisual(a,"symbolKeepAspect");this._createSymbol(o,t,a,l,h)}else{var v=this.childAt(0);v.silent=!1;var c={scaleX:l[0]/2,scaleY:l[1]/2};f?v.attr(c):Dt(v,c,s,a),Sr(v)}if(this._updateCommon(t,a,l,n,i),u){var v=this.childAt(0);if(!f){var c={scaleX:this._sizeX,scaleY:this._sizeY,style:{opacity:v.style.opacity}};v.scaleX=v.scaleY=0,v.style.opacity=0,Bt(v,c,s,a)}}f&&this.childAt(0).stopAnimation("leave")},e.prototype._updateCommon=function(t,a,n,i,o){var s=this.childAt(0),l=t.hostModel,u,f,h,v,c,p,d,g,y;if(i&&(u=i.emphasisItemStyle,f=i.blurItemStyle,h=i.selectItemStyle,v=i.focus,c=i.blurScope,d=i.labelStatesModels,g=i.hoverScale,y=i.cursorStyle,p=i.emphasisDisabled),!i||t.hasItemOption){var m=i&&i.itemModel?i.itemModel:t.getItemModel(a),_=m.getModel("emphasis");u=_.getModel("itemStyle").getItemStyle(),h=m.getModel(["select","itemStyle"]).getItemStyle(),f=m.getModel(["blur","itemStyle"]).getItemStyle(),v=_.get("focus"),c=_.get("blurScope"),p=_.get("disabled"),d=re(m),g=_.getShallow("scale"),y=m.getShallow("cursor")}var S=t.getItemVisual(a,"symbolRotate");s.attr("rotation",(S||0)*Math.PI/180||0);var w=ui(t.getItemVisual(a,"symbolOffset"),n);w&&(s.x=w[0],s.y=w[1]),y&&s.attr("cursor",y);var x=t.getItemVisual(a,"style"),b=x.fill;if(s instanceof he){var T=s.style;s.useStyle(V({image:T.image,x:T.x,y:T.y,width:T.width,height:T.height},x))}else s.__isEmptyBrush?s.useStyle(V({},x)):s.useStyle(x),s.style.decal=null,s.setColor(b,o&&o.symbolInnerColor),s.style.strokeNoScale=!0;var A=t.getItemVisual(a,"liftZ"),D=this._z2;A!=null?D==null&&(this._z2=s.z2,s.z2+=A):D!=null&&(s.z2=D,this._z2=null);var M=o&&o.useNameLabel;fe(s,d,{labelFetcher:l,labelDataIndex:a,defaultText:I,inheritColor:b,defaultOpacity:x.opacity});function I(R){return M?t.getName(R):eo(t,R)}this._sizeX=n[0]/2,this._sizeY=n[1]/2;var L=s.ensureState("emphasis");L.style=u,s.ensureState("select").style=h,s.ensureState("blur").style=f;var P=g==null||g===!0?Math.max(1.1,3/this._sizeY):isFinite(g)&&g>0?+g:1;L.scaleX=this._sizeX*P,L.scaleY=this._sizeY*P,this.setSymbolScale(1),Ft(this,v,c,p)},e.prototype.setSymbolScale=function(t){this.scaleX=this.scaleY=t},e.prototype.fadeOut=function(t,a,n){var i=this.childAt(0),o=nt(this).dataIndex,s=n&&n.animation;if(this.silent=i.silent=!0,n&&n.fadeLabel){var l=i.getTextContent();l&&$a(l,{style:{opacity:0}},a,{dataIndex:o,removeOpt:s,cb:function(){i.removeTextContent()}})}else i.removeTextContent();$a(i,{style:{opacity:0},scaleX:0,scaleY:0},a,{dataIndex:o,cb:t,removeOpt:s})},e.getSymbolSize=function(t,a){return bo(t.getItemVisual(a,"symbolSize"))},e}(at);function VV(r,e){this.parent.drift(r,e)}function $v(r,e,t,a){return e&&!isNaN(e[0])&&!isNaN(e[1])&&!(a.isIgnore&&a.isIgnore(t))&&!(a.clipShape&&!a.clipShape.contain(e[0],e[1]))&&r.getItemVisual(t,"symbol")!=="none"}function a1(r){return r!=null&&!tt(r)&&(r={isIgnore:r}),r||{}}function n1(r){var e=r.hostModel,t=e.getModel("emphasis");return{emphasisItemStyle:t.getModel("itemStyle").getItemStyle(),blurItemStyle:e.getModel(["blur","itemStyle"]).getItemStyle(),selectItemStyle:e.getModel(["select","itemStyle"]).getItemStyle(),focus:t.get("focus"),blurScope:t.get("blurScope"),emphasisDisabled:t.get("disabled"),hoverScale:t.get("scale"),labelStatesModels:re(e),cursorStyle:e.get("cursor")}}var gl=function(){function r(e){this.group=new at,this._SymbolCtor=e||dl}return r.prototype.updateData=function(e,t){this._progressiveEls=null,t=a1(t);var a=this.group,n=e.hostModel,i=this._data,o=this._SymbolCtor,s=t.disableAnimation,l=n1(e),u={disableAnimation:s},f=t.getSymbolPoint||function(h){return e.getItemLayout(h)};i||a.removeAll(),e.diff(i).add(function(h){var v=f(h);if($v(e,v,h,t)){var c=new o(e,h,l,u);c.setPosition(v),e.setItemGraphicEl(h,c),a.add(c)}}).update(function(h,v){var c=i.getItemGraphicEl(v),p=f(h);if(!$v(e,p,h,t)){a.remove(c);return}var d=e.getItemVisual(h,"symbol")||"circle",g=c&&c.getSymbolType&&c.getSymbolType();if(!c||g&&g!==d)a.remove(c),c=new o(e,h,l,u),c.setPosition(p);else{c.updateData(e,h,l,u);var y={x:p[0],y:p[1]};s?c.attr(y):Dt(c,y,n)}a.add(c),e.setItemGraphicEl(h,c)}).remove(function(h){var v=i.getItemGraphicEl(h);v&&v.fadeOut(function(){a.remove(v)},n)}).execute(),this._getSymbolPoint=f,this._data=e},r.prototype.updateLayout=function(){var e=this,t=this._data;t&&t.eachItemGraphicEl(function(a,n){var i=e._getSymbolPoint(n);a.setPosition(i),a.markRedraw()})},r.prototype.incrementalPrepareUpdate=function(e){this._seriesScope=n1(e),this._data=null,this.group.removeAll()},r.prototype.incrementalUpdate=function(e,t,a){this._progressiveEls=[],a=a1(a);function n(l){l.isGroup||(l.incremental=!0,l.ensureState("emphasis").hoverLayer=!0)}for(var i=e.start;i<e.end;i++){var o=t.getItemLayout(i);if($v(t,o,i,a)){var s=new this._SymbolCtor(t,i,this._seriesScope);s.traverse(n),s.setPosition(o),this.group.add(s),t.setItemGraphicEl(i,s),this._progressiveEls.push(s)}}},r.prototype.eachRendered=function(e){Ja(this._progressiveEls||this.group,e)},r.prototype.remove=function(e){var t=this.group,a=this._data;a&&e?a.eachItemGraphicEl(function(n){n.fadeOut(function(){t.remove(n)},a.hostModel)}):t.removeAll()},r}();function TD(r,e,t){var a=r.getBaseAxis(),n=r.getOtherAxis(a),i=zV(n,t),o=a.dim,s=n.dim,l=e.mapDimension(s),u=e.mapDimension(o),f=s==="x"||s==="radius"?1:0,h=G(r.dimensions,function(p){return e.mapDimension(p)}),v=!1,c=e.getCalculationInfo("stackResultDimension");return Ya(e,h[0])&&(v=!0,h[0]=c),Ya(e,h[1])&&(v=!0,h[1]=c),{dataDimsForPoint:h,valueStart:i,valueAxisDim:s,baseAxisDim:o,stacked:!!v,valueDim:l,baseDim:u,baseDataOffset:f,stackedOverDimension:e.getCalculationInfo("stackedOverDimension")}}function zV(r,e){var t=0,a=r.scale.getExtent();return e==="start"?t=a[0]:e==="end"?t=a[1]:Ct(e)&&!isNaN(e)?t=e:a[0]>0?t=a[0]:a[1]<0&&(t=a[1]),t}function AD(r,e,t,a){var n=NaN;r.stacked&&(n=t.get(t.getCalculationInfo("stackedOverDimension"),a)),isNaN(n)&&(n=r.valueStart);var i=r.baseDataOffset,o=[];return o[i]=t.get(r.baseDim,a),o[1-i]=n,e.dataToPoint(o)}function GV(r,e){var t=[];return e.diff(r).add(function(a){t.push({cmd:"+",idx:a})}).update(function(a,n){t.push({cmd:"=",idx:n,idx1:a})}).remove(function(a){t.push({cmd:"-",idx:a})}).execute(),t}function FV(r,e,t,a,n,i,o,s){for(var l=GV(r,e),u=[],f=[],h=[],v=[],c=[],p=[],d=[],g=TD(n,e,o),y=r.getLayout("points")||[],m=e.getLayout("points")||[],_=0;_<l.length;_++){var S=l[_],w=!0,x=void 0,b=void 0;switch(S.cmd){case"=":x=S.idx*2,b=S.idx1*2;var T=y[x],A=y[x+1],D=m[b],M=m[b+1];(isNaN(T)||isNaN(A))&&(T=D,A=M),u.push(T,A),f.push(D,M),h.push(t[x],t[x+1]),v.push(a[b],a[b+1]),d.push(e.getRawIndex(S.idx1));break;case"+":var I=S.idx,L=g.dataDimsForPoint,P=n.dataToPoint([e.get(L[0],I),e.get(L[1],I)]);b=I*2,u.push(P[0],P[1]),f.push(m[b],m[b+1]);var R=AD(g,n,e,I);h.push(R[0],R[1]),v.push(a[b],a[b+1]),d.push(e.getRawIndex(I));break;case"-":w=!1}w&&(c.push(S),p.push(p.length))}p.sort(function(ct,St){return d[ct]-d[St]});for(var E=u.length,N=Or(E),O=Or(E),B=Or(E),F=Or(E),H=[],_=0;_<p.length;_++){var X=p[_],Q=_*2,J=X*2;N[Q]=u[J],N[Q+1]=u[J+1],O[Q]=f[J],O[Q+1]=f[J+1],B[Q]=h[J],B[Q+1]=h[J+1],F[Q]=v[J],F[Q+1]=v[J+1],H[_]=c[X]}return{current:N,next:O,stackedOnCurrent:B,stackedOnNext:F,status:H}}var xa=Math.min,wa=Math.max;function Kn(r,e){return isNaN(r)||isNaN(e)}function ad(r,e,t,a,n,i,o,s,l){for(var u,f,h,v,c,p,d=t,g=0;g<a;g++){var y=e[d*2],m=e[d*2+1];if(d>=n||d<0)break;if(Kn(y,m)){if(l){d+=i;continue}break}if(d===t)r[i>0?"moveTo":"lineTo"](y,m),h=y,v=m;else{var _=y-u,S=m-f;if(_*_+S*S<.5){d+=i;continue}if(o>0){for(var w=d+i,x=e[w*2],b=e[w*2+1];x===y&&b===m&&g<a;)g++,w+=i,d+=i,x=e[w*2],b=e[w*2+1],y=e[d*2],m=e[d*2+1],_=y-u,S=m-f;var T=g+1;if(l)for(;Kn(x,b)&&T<a;)T++,w+=i,x=e[w*2],b=e[w*2+1];var A=.5,D=0,M=0,I=void 0,L=void 0;if(T>=a||Kn(x,b))c=y,p=m;else{D=x-u,M=b-f;var P=y-u,R=x-y,E=m-f,N=b-m,O=void 0,B=void 0;if(s==="x"){O=Math.abs(P),B=Math.abs(R);var F=D>0?1:-1;c=y-F*O*o,p=m,I=y+F*B*o,L=m}else if(s==="y"){O=Math.abs(E),B=Math.abs(N);var H=M>0?1:-1;c=y,p=m-H*O*o,I=y,L=m+H*B*o}else O=Math.sqrt(P*P+E*E),B=Math.sqrt(R*R+N*N),A=B/(B+O),c=y-D*o*(1-A),p=m-M*o*(1-A),I=y+D*o*A,L=m+M*o*A,I=xa(I,wa(x,y)),L=xa(L,wa(b,m)),I=wa(I,xa(x,y)),L=wa(L,xa(b,m)),D=I-y,M=L-m,c=y-D*O/B,p=m-M*O/B,c=xa(c,wa(u,y)),p=xa(p,wa(f,m)),c=wa(c,xa(u,y)),p=wa(p,xa(f,m)),D=y-c,M=m-p,I=y+D*B/O,L=m+M*B/O}r.bezierCurveTo(h,v,c,p,y,m),h=I,v=L}else r.lineTo(y,m)}u=y,f=m,d+=i}return g}var CD=function(){function r(){this.smooth=0,this.smoothConstraint=!0}return r}(),HV=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a.type="ec-polyline",a}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new CD},e.prototype.buildPath=function(t,a){var n=a.points,i=0,o=n.length/2;if(a.connectNulls){for(;o>0&&Kn(n[o*2-2],n[o*2-1]);o--);for(;i<o&&Kn(n[i*2],n[i*2+1]);i++);}for(;i<o;)i+=ad(t,n,i,o,o,1,a.smooth,a.smoothMonotone,a.connectNulls)+1},e.prototype.getPointOn=function(t,a){this.path||(this.createPathProxy(),this.buildPath(this.path,this.shape));for(var n=this.path,i=n.data,o=Wr.CMD,s,l,u=a==="x",f=[],h=0;h<i.length;){var v=i[h++],c=void 0,p=void 0,d=void 0,g=void 0,y=void 0,m=void 0,_=void 0;switch(v){case o.M:s=i[h++],l=i[h++];break;case o.L:if(c=i[h++],p=i[h++],_=u?(t-s)/(c-s):(t-l)/(p-l),_<=1&&_>=0){var S=u?(p-l)*_+l:(c-s)*_+s;return u?[t,S]:[S,t]}s=c,l=p;break;case o.C:c=i[h++],p=i[h++],d=i[h++],g=i[h++],y=i[h++],m=i[h++];var w=u?Qu(s,c,d,y,t,f):Qu(l,p,g,m,t,f);if(w>0)for(var x=0;x<w;x++){var b=f[x];if(b<=1&&b>=0){var S=u?jt(l,p,g,m,b):jt(s,c,d,y,b);return u?[t,S]:[S,t]}}s=y,l=m;break}}},e}(yt),WV=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e}(CD),DD=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a.type="ec-polygon",a}return e.prototype.getDefaultShape=function(){return new WV},e.prototype.buildPath=function(t,a){var n=a.points,i=a.stackedOnPoints,o=0,s=n.length/2,l=a.smoothMonotone;if(a.connectNulls){for(;s>0&&Kn(n[s*2-2],n[s*2-1]);s--);for(;o<s&&Kn(n[o*2],n[o*2+1]);o++);}for(;o<s;){var u=ad(t,n,o,s,s,1,a.smooth,l,a.connectNulls);ad(t,i,o+u-1,u,s,-1,a.stackedOnSmooth,l,a.connectNulls),o+=u+1,t.closePath()}},e}(yt);function MD(r,e,t,a,n){var i=r.getArea(),o=i.x,s=i.y,l=i.width,u=i.height,f=t.get(["lineStyle","width"])||2;o-=f/2,s-=f/2,l+=f,u+=f,l=Math.ceil(l),o!==Math.floor(o)&&(o=Math.floor(o),l++);var h=new wt({shape:{x:o,y:s,width:l,height:u}});if(e){var v=r.getBaseAxis(),c=v.isHorizontal(),p=v.inverse;c?(p&&(h.shape.x+=l),h.shape.width=0):(p||(h.shape.y+=u),h.shape.height=0);var d=K(n)?function(g){n(g,h)}:null;Bt(h,{shape:{width:l,height:u,x:o,y:s}},t,null,a,d)}return h}function ID(r,e,t){var a=r.getArea(),n=$t(a.r0,1),i=$t(a.r,1),o=new Be({shape:{cx:$t(r.cx,1),cy:$t(r.cy,1),r0:n,r:i,startAngle:a.startAngle,endAngle:a.endAngle,clockwise:a.clockwise}});if(e){var s=r.getBaseAxis().dim==="angle";s?o.shape.endAngle=a.startAngle:o.shape.r=n,Bt(o,{shape:{endAngle:a.endAngle,r:i}},t)}return o}function yl(r,e,t,a,n){if(r){if(r.type==="polar")return ID(r,e,t);if(r.type==="cartesian2d")return MD(r,e,t,a,n)}else return null;return null}function hi(r,e){return r.type===e}function i1(r,e){if(r.length===e.length){for(var t=0;t<r.length;t++)if(r[t]!==e[t])return;return!0}}function o1(r){for(var e=1/0,t=1/0,a=-1/0,n=-1/0,i=0;i<r.length;){var o=r[i++],s=r[i++];isNaN(o)||(e=Math.min(o,e),a=Math.max(o,a)),isNaN(s)||(t=Math.min(s,t),n=Math.max(s,n))}return[[e,t],[a,n]]}function s1(r,e){var t=o1(r),a=t[0],n=t[1],i=o1(e),o=i[0],s=i[1];return Math.max(Math.abs(a[0]-o[0]),Math.abs(a[1]-o[1]),Math.abs(n[0]-s[0]),Math.abs(n[1]-s[1]))}function l1(r){return Ct(r)?r:r?.5:0}function $V(r,e,t){if(!t.valueDim)return[];for(var a=e.count(),n=Or(a*2),i=0;i<a;i++){var o=AD(t,r,e,i);n[i*2]=o[0],n[i*2+1]=o[1]}return n}function ba(r,e,t,a){var n=e.getBaseAxis(),i=n.dim==="x"||n.dim==="radius"?0:1,o=[],s=0,l=[],u=[],f=[],h=[];if(a){for(s=0;s<r.length;s+=2)!isNaN(r[s])&&!isNaN(r[s+1])&&h.push(r[s],r[s+1]);r=h}for(s=0;s<r.length-2;s+=2)switch(f[0]=r[s+2],f[1]=r[s+3],u[0]=r[s],u[1]=r[s+1],o.push(u[0],u[1]),t){case"end":l[i]=f[i],l[1-i]=u[1-i],o.push(l[0],l[1]);break;case"middle":var v=(u[i]+f[i])/2,c=[];l[i]=c[i]=v,l[1-i]=u[1-i],c[1-i]=f[1-i],o.push(l[0],l[1]),o.push(c[0],c[1]);break;default:l[i]=u[i],l[1-i]=f[1-i],o.push(l[0],l[1])}return o.push(r[s++],r[s++]),o}function UV(r,e){var t=[],a=r.length,n,i;function o(f,h,v){var c=f.coord,p=(v-c)/(h.coord-c),d=d2(p,[f.color,h.color]);return{coord:v,color:d}}for(var s=0;s<a;s++){var l=r[s],u=l.coord;if(u<0)n=l;else if(u>e){i?t.push(o(i,l,e)):n&&t.push(o(n,l,0),o(n,l,e));break}else n&&(t.push(o(n,l,0)),n=null),t.push(l),i=l}return t}function YV(r,e,t){var a=r.getVisual("visualMeta");if(!(!a||!a.length||!r.count())&&e.type==="cartesian2d"){for(var n,i,o=a.length-1;o>=0;o--){var s=r.getDimensionInfo(a[o].dimension);if(n=s&&s.coordDim,n==="x"||n==="y"){i=a[o];break}}if(i){var l=e.getAxis(n),u=G(i.stops,function(_){return{coord:l.toGlobalCoord(l.dataToCoord(_.value)),color:_.color}}),f=u.length,h=i.outerColors.slice();f&&u[0].coord>u[f-1].coord&&(u.reverse(),h.reverse());var v=UV(u,n==="x"?t.getWidth():t.getHeight()),c=v.length;if(!c&&f)return u[0].coord<0?h[1]?h[1]:u[f-1].color:h[0]?h[0]:u[0].color;var p=10,d=v[0].coord-p,g=v[c-1].coord+p,y=g-d;if(y<.001)return"transparent";C(v,function(_){_.offset=(_.coord-d)/y}),v.push({offset:c?v[c-1].offset:.5,color:h[1]||"transparent"}),v.unshift({offset:c?v[0].offset:.5,color:h[0]||"transparent"});var m=new ho(0,0,0,0,v,!0);return m[n]=d,m[n+"2"]=g,m}}}function ZV(r,e,t){var a=r.get("showAllSymbol"),n=a==="auto";if(!(a&&!n)){var i=t.getAxesByScale("ordinal")[0];if(i&&!(n&&XV(i,e))){var o=e.mapDimension(i.dim),s={};return C(i.getViewLabels(),function(l){var u=i.scale.getRawOrdinalNumber(l.tickValue);s[u]=1}),function(l){return!s.hasOwnProperty(e.get(o,l))}}}}function XV(r,e){var t=r.getExtent(),a=Math.abs(t[1]-t[0])/r.scale.count();isNaN(a)&&(a=0);for(var n=e.count(),i=Math.max(1,Math.round(n/5)),o=0;o<n;o+=i)if(dl.getSymbolSize(e,o)[r.isHorizontal()?1:0]*1.5>a)return!1;return!0}function qV(r,e){return isNaN(r)||isNaN(e)}function KV(r){for(var e=r.length/2;e>0&&qV(r[e*2-2],r[e*2-1]);e--);return e-1}function u1(r,e){return[r[e*2],r[e*2+1]]}function QV(r,e,t){for(var a=r.length/2,n=t==="x"?0:1,i,o,s=0,l=-1,u=0;u<a;u++)if(o=r[u*2+n],!(isNaN(o)||isNaN(r[u*2+1-n]))){if(u===0){i=o;continue}if(i<=e&&o>=e||i>=e&&o<=e){l=u;break}s=u,i=o}return{range:[s,l],t:(e-i)/(o-i)}}function LD(r){if(r.get(["endLabel","show"]))return!0;for(var e=0;e<Ce.length;e++)if(r.get([Ce[e],"endLabel","show"]))return!0;return!1}function Uv(r,e,t,a){if(hi(e,"cartesian2d")){var n=a.getModel("endLabel"),i=n.get("valueAnimation"),o=a.getData(),s={lastFrameIndex:0},l=LD(a)?function(c,p){r._endLabelOnDuring(c,p,o,s,i,n,e)}:null,u=e.getBaseAxis().isHorizontal(),f=MD(e,t,a,function(){var c=r._endLabel;c&&t&&s.originalX!=null&&c.attr({x:s.originalX,y:s.originalY})},l);if(!a.get("clip",!0)){var h=f.shape,v=Math.max(h.width,h.height);u?(h.y-=v,h.height+=v*2):(h.x-=v,h.width+=v*2)}return l&&l(1,f),f}else return ID(e,t,a)}function JV(r,e){var t=e.getBaseAxis(),a=t.isHorizontal(),n=t.inverse,i=a?n?"right":"left":"center",o=a?"middle":n?"top":"bottom";return{normal:{align:r.get("align")||i,verticalAlign:r.get("verticalAlign")||o}}}var jV=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.init=function(){var t=new at,a=new gl;this.group.add(a.group),this._symbolDraw=a,this._lineGroup=t},e.prototype.render=function(t,a,n){var i=this,o=t.coordinateSystem,s=this.group,l=t.getData(),u=t.getModel("lineStyle"),f=t.getModel("areaStyle"),h=l.getLayout("points")||[],v=o.type==="polar",c=this._coordSys,p=this._symbolDraw,d=this._polyline,g=this._polygon,y=this._lineGroup,m=!a.ssr&&t.get("animation"),_=!f.isEmpty(),S=f.get("origin"),w=TD(o,l,S),x=_&&$V(o,l,w),b=t.get("showSymbol"),T=t.get("connectNulls"),A=b&&!v&&ZV(t,l,o),D=this._data;D&&D.eachItemGraphicEl(function(St,pt){St.__temp&&(s.remove(St),D.setItemGraphicEl(pt,null))}),b||p.remove(),s.add(y);var M=v?!1:t.get("step"),I;o&&o.getArea&&t.get("clip",!0)&&(I=o.getArea(),I.width!=null?(I.x-=.1,I.y-=.1,I.width+=.2,I.height+=.2):I.r0&&(I.r0-=.5,I.r+=.5)),this._clipShapeForSymbol=I;var L=YV(l,o,n)||l.getVisual("style")[l.getVisual("drawType")];if(!(d&&c.type===o.type&&M===this._step))b&&p.updateData(l,{isIgnore:A,clipShape:I,disableAnimation:!0,getSymbolPoint:function(St){return[h[St*2],h[St*2+1]]}}),m&&this._initSymbolLabelAnimation(l,o,I),M&&(h=ba(h,o,M,T),x&&(x=ba(x,o,M,T))),d=this._newPolyline(h),_?g=this._newPolygon(h,x):g&&(y.remove(g),g=this._polygon=null),v||this._initOrUpdateEndLabel(t,o,ri(L)),y.setClipPath(Uv(this,o,!0,t));else{_&&!g?g=this._newPolygon(h,x):g&&!_&&(y.remove(g),g=this._polygon=null),v||this._initOrUpdateEndLabel(t,o,ri(L));var P=y.getClipPath();if(P){var R=Uv(this,o,!1,t);Bt(P,{shape:R.shape},t)}else y.setClipPath(Uv(this,o,!0,t));b&&p.updateData(l,{isIgnore:A,clipShape:I,disableAnimation:!0,getSymbolPoint:function(St){return[h[St*2],h[St*2+1]]}}),(!i1(this._stackedOnPoints,x)||!i1(this._points,h))&&(m?this._doUpdateAnimation(l,x,o,n,M,S,T):(M&&(h=ba(h,o,M,T),x&&(x=ba(x,o,M,T))),d.setShape({points:h}),g&&g.setShape({points:h,stackedOnPoints:x})))}var E=t.getModel("emphasis"),N=E.get("focus"),O=E.get("blurScope"),B=E.get("disabled");if(d.useStyle(j(u.getLineStyle(),{fill:"none",stroke:L,lineJoin:"bevel"})),ue(d,t,"lineStyle"),d.style.lineWidth>0&&t.get(["emphasis","lineStyle","width"])==="bolder"){var F=d.getState("emphasis").style;F.lineWidth=+d.style.lineWidth+1}nt(d).seriesIndex=t.seriesIndex,Ft(d,N,O,B);var H=l1(t.get("smooth")),X=t.get("smoothMonotone");if(d.setShape({smooth:H,smoothMonotone:X,connectNulls:T}),g){var Q=l.getCalculationInfo("stackedOnSeries"),J=0;g.useStyle(j(f.getAreaStyle(),{fill:L,opacity:.7,lineJoin:"bevel",decal:l.getVisual("style").decal})),Q&&(J=l1(Q.get("smooth"))),g.setShape({smooth:H,stackedOnSmooth:J,smoothMonotone:X,connectNulls:T}),ue(g,t,"areaStyle"),nt(g).seriesIndex=t.seriesIndex,Ft(g,N,O,B)}var ct=function(St){i._changePolyState(St)};l.eachItemGraphicEl(function(St){St&&(St.onHoverStateChange=ct)}),this._polyline.onHoverStateChange=ct,this._data=l,this._coordSys=o,this._stackedOnPoints=x,this._points=h,this._step=M,this._valueOrigin=S,t.get("triggerLineEvent")&&(this.packEventData(t,d),g&&this.packEventData(t,g))},e.prototype.packEventData=function(t,a){nt(a).eventData={componentType:"series",componentSubType:"line",componentIndex:t.componentIndex,seriesIndex:t.seriesIndex,seriesName:t.name,seriesType:"line"}},e.prototype.highlight=function(t,a,n,i){var o=t.getData(),s=jn(o,i);if(this._changePolyState("emphasis"),!(s instanceof Array)&&s!=null&&s>=0){var l=o.getLayout("points"),u=o.getItemGraphicEl(s);if(!u){var f=l[s*2],h=l[s*2+1];if(isNaN(f)||isNaN(h)||this._clipShapeForSymbol&&!this._clipShapeForSymbol.contain(f,h))return;var v=t.get("zlevel")||0,c=t.get("z")||0;u=new dl(o,s),u.x=f,u.y=h,u.setZ(v,c);var p=u.getSymbolPath().getTextContent();p&&(p.zlevel=v,p.z=c,p.z2=this._polyline.z2+1),u.__temp=!0,o.setItemGraphicEl(s,u),u.stopSymbolAnimation(!0),this.group.add(u)}u.highlight()}else Nt.prototype.highlight.call(this,t,a,n,i)},e.prototype.downplay=function(t,a,n,i){var o=t.getData(),s=jn(o,i);if(this._changePolyState("normal"),s!=null&&s>=0){var l=o.getItemGraphicEl(s);l&&(l.__temp?(o.setItemGraphicEl(s,null),this.group.remove(l)):l.downplay())}else Nt.prototype.downplay.call(this,t,a,n,i)},e.prototype._changePolyState=function(t){var a=this._polygon;nf(this._polyline,t),a&&nf(a,t)},e.prototype._newPolyline=function(t){var a=this._polyline;return a&&this._lineGroup.remove(a),a=new HV({shape:{points:t},segmentIgnoreThreshold:2,z2:10}),this._lineGroup.add(a),this._polyline=a,a},e.prototype._newPolygon=function(t,a){var n=this._polygon;return n&&this._lineGroup.remove(n),n=new DD({shape:{points:t,stackedOnPoints:a},segmentIgnoreThreshold:2}),this._lineGroup.add(n),this._polygon=n,n},e.prototype._initSymbolLabelAnimation=function(t,a,n){var i,o,s=a.getBaseAxis(),l=s.inverse;a.type==="cartesian2d"?(i=s.isHorizontal(),o=!1):a.type==="polar"&&(i=s.dim==="angle",o=!0);var u=t.hostModel,f=u.get("animationDuration");K(f)&&(f=f(null));var h=u.get("animationDelay")||0,v=K(h)?h(null):h;t.eachItemGraphicEl(function(c,p){var d=c;if(d){var g=[c.x,c.y],y=void 0,m=void 0,_=void 0;if(n)if(o){var S=n,w=a.pointToCoord(g);i?(y=S.startAngle,m=S.endAngle,_=-w[1]/180*Math.PI):(y=S.r0,m=S.r,_=w[0])}else{var x=n;i?(y=x.x,m=x.x+x.width,_=c.x):(y=x.y+x.height,m=x.y,_=c.y)}var b=m===y?0:(_-y)/(m-y);l&&(b=1-b);var T=K(h)?h(p):f*b+v,A=d.getSymbolPath(),D=A.getTextContent();d.attr({scaleX:0,scaleY:0}),d.animateTo({scaleX:1,scaleY:1},{duration:200,setToFinal:!0,delay:T}),D&&D.animateFrom({style:{opacity:0}},{duration:300,delay:T}),A.disableLabelAnimation=!0}})},e.prototype._initOrUpdateEndLabel=function(t,a,n){var i=t.getModel("endLabel");if(LD(t)){var o=t.getData(),s=this._polyline,l=o.getLayout("points");if(!l){s.removeTextContent(),this._endLabel=null;return}var u=this._endLabel;u||(u=this._endLabel=new At({z2:200}),u.ignoreClip=!0,s.setTextContent(this._endLabel),s.disableLabelAnimation=!0);var f=KV(l);f>=0&&(fe(s,re(t,"endLabel"),{inheritColor:n,labelFetcher:t,labelDataIndex:f,defaultText:function(h,v,c){return c!=null?bD(o,c):eo(o,h)},enableTextSetter:!0},JV(i,a)),s.textConfig.position=null)}else this._endLabel&&(this._polyline.removeTextContent(),this._endLabel=null)},e.prototype._endLabelOnDuring=function(t,a,n,i,o,s,l){var u=this._endLabel,f=this._polyline;if(u){t<1&&i.originalX==null&&(i.originalX=u.x,i.originalY=u.y);var h=n.getLayout("points"),v=n.hostModel,c=v.get("connectNulls"),p=s.get("precision"),d=s.get("distance")||0,g=l.getBaseAxis(),y=g.isHorizontal(),m=g.inverse,_=a.shape,S=m?y?_.x:_.y+_.height:y?_.x+_.width:_.y,w=(y?d:0)*(m?-1:1),x=(y?0:-d)*(m?-1:1),b=y?"x":"y",T=QV(h,S,b),A=T.range,D=A[1]-A[0],M=void 0;if(D>=1){if(D>1&&!c){var I=u1(h,A[0]);u.attr({x:I[0]+w,y:I[1]+x}),o&&(M=v.getRawValue(A[0]))}else{var I=f.getPointOn(S,b);I&&u.attr({x:I[0]+w,y:I[1]+x});var L=v.getRawValue(A[0]),P=v.getRawValue(A[1]);o&&(M=eT(n,p,L,P,T.t))}i.lastFrameIndex=A[0]}else{var R=t===1||i.lastFrameIndex>0?A[0]:0,I=u1(h,R);o&&(M=v.getRawValue(R)),u.attr({x:I[0]+w,y:I[1]+x})}if(o){var E=po(u);typeof E.setLabelText=="function"&&E.setLabelText(M)}}},e.prototype._doUpdateAnimation=function(t,a,n,i,o,s,l){var u=this._polyline,f=this._polygon,h=t.hostModel,v=FV(this._data,t,this._stackedOnPoints,a,this._coordSys,n,this._valueOrigin),c=v.current,p=v.stackedOnCurrent,d=v.next,g=v.stackedOnNext;if(o&&(c=ba(v.current,n,o,l),p=ba(v.stackedOnCurrent,n,o,l),d=ba(v.next,n,o,l),g=ba(v.stackedOnNext,n,o,l)),s1(c,d)>3e3||f&&s1(p,g)>3e3){u.stopAnimation(),u.setShape({points:d}),f&&(f.stopAnimation(),f.setShape({points:d,stackedOnPoints:g}));return}u.shape.__points=v.current,u.shape.points=c;var y={shape:{points:d}};v.current!==c&&(y.shape.__points=v.next),u.stopAnimation(),Dt(u,y,h),f&&(f.setShape({points:c,stackedOnPoints:p}),f.stopAnimation(),Dt(f,{shape:{stackedOnPoints:g}},h),u.shape.points!==f.shape.points&&(f.shape.points=u.shape.points));for(var m=[],_=v.status,S=0;S<_.length;S++){var w=_[S].cmd;if(w==="="){var x=t.getItemGraphicEl(_[S].idx1);x&&m.push({el:x,ptIdx:S})}}u.animators&&u.animators.length&&u.animators[0].during(function(){f&&f.dirtyShape();for(var b=u.shape.__points,T=0;T<m.length;T++){var A=m[T].el,D=m[T].ptIdx*2;A.x=b[D],A.y=b[D+1],A.markRedraw()}})},e.prototype.remove=function(t){var a=this.group,n=this._data;this._lineGroup.removeAll(),this._symbolDraw.remove(!0),n&&n.eachItemGraphicEl(function(i,o){i.__temp&&(a.remove(i),n.setItemGraphicEl(o,null))}),this._polyline=this._polygon=this._coordSys=this._points=this._stackedOnPoints=this._endLabel=this._data=null},e.type="line",e}(Nt);const tz=jV;function ml(r,e){return{seriesType:r,plan:xo(),reset:function(t){var a=t.getData(),n=t.coordinateSystem,i=t.pipelineContext,o=e||i.large;if(n){var s=G(n.dimensions,function(c){return a.mapDimension(c)}).slice(0,2),l=s.length,u=a.getCalculationInfo("stackResultDimension");Ya(a,s[0])&&(s[0]=u),Ya(a,s[1])&&(s[1]=u);var f=a.getStore(),h=a.getDimensionIndex(s[0]),v=a.getDimensionIndex(s[1]);return l&&{progress:function(c,p){for(var d=c.end-c.start,g=o&&Or(d*l),y=[],m=[],_=c.start,S=0;_<c.end;_++){var w=void 0;if(l===1){var x=f.get(h,_);w=n.dataToPoint(x,null,m)}else y[0]=f.get(h,_),y[1]=f.get(v,_),w=n.dataToPoint(y,null,m);o?(g[S++]=w[0],g[S++]=w[1]):p.setItemLayout(_,w.slice())}o&&p.setLayout("points",g)}}}}}}var ez={average:function(r){for(var e=0,t=0,a=0;a<r.length;a++)isNaN(r[a])||(e+=r[a],t++);return t===0?NaN:e/t},sum:function(r){for(var e=0,t=0;t<r.length;t++)e+=r[t]||0;return e},max:function(r){for(var e=-1/0,t=0;t<r.length;t++)r[t]>e&&(e=r[t]);return isFinite(e)?e:NaN},min:function(r){for(var e=1/0,t=0;t<r.length;t++)r[t]<e&&(e=r[t]);return isFinite(e)?e:NaN},minmax:function(r){for(var e=-1/0,t=-1/0,a=0;a<r.length;a++){var n=r[a],i=Math.abs(n);i>e&&(e=i,t=n)}return isFinite(t)?t:NaN},nearest:function(r){return r[0]}},rz=function(r){return Math.round(r.length/2)};function PD(r){return{seriesType:r,reset:function(e,t,a){var n=e.getData(),i=e.get("sampling"),o=e.coordinateSystem,s=n.count();if(s>10&&o.type==="cartesian2d"&&i){var l=o.getBaseAxis(),u=o.getOtherAxis(l),f=l.getExtent(),h=a.getDevicePixelRatio(),v=Math.abs(f[1]-f[0])*(h||1),c=Math.round(s/v);if(isFinite(c)&&c>1){i==="lttb"&&e.setData(n.lttbDownSample(n.mapDimension(u.dim),1/c));var p=void 0;$(i)?p=ez[i]:K(i)&&(p=i),p&&e.setData(n.downSample(n.mapDimension(u.dim),1/c,p,rz))}}}}}function az(r){r.registerChartView(tz),r.registerSeriesModel(BV),r.registerLayout(ml("line",!0)),r.registerVisual({seriesType:"line",reset:function(e){var t=e.getData(),a=e.getModel("lineStyle").getLineStyle();a&&!a.stroke&&(a.stroke=t.getVisual("style").fill),t.setVisual("legendLineStyle",a)}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,PD("line"))}var Xs=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.getInitialData=function(t,a){return va(null,this,{useEncodeDefaulter:!0})},e.prototype.getMarkerPosition=function(t,a,n){var i=this.coordinateSystem;if(i&&i.clampData){var o=i.clampData(t),s=i.dataToPoint(o);if(n)C(i.getAxes(),function(v,c){if(v.type==="category"&&a!=null){var p=v.getTicksCoords(),d=v.getTickModel().get("alignWithLabel"),g=o[c],y=a[c]==="x1"||a[c]==="y1";if(y&&!d&&(g+=1),p.length<2)return;if(p.length===2){s[c]=v.toGlobalCoord(v.getExtent()[y?1:0]);return}for(var m=void 0,_=void 0,S=1,w=0;w<p.length;w++){var x=p[w].coord,b=w===p.length-1?p[w-1].tickValue+S:p[w].tickValue;if(b===g){_=x;break}else if(b<g)m=x;else if(m!=null&&b>g){_=(x+m)/2;break}w===1&&(S=b-p[0].tickValue)}_==null&&(m?m&&(_=p[p.length-1].coord):_=p[0].coord),s[c]=v.toGlobalCoord(_)}});else{var l=this.getData(),u=l.getLayout("offset"),f=l.getLayout("size"),h=i.getBaseAxis().isHorizontal()?0:1;s[h]+=u+f/2}return s}return[NaN,NaN]},e.type="series.__base_bar__",e.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,barMinHeight:0,barMinAngle:0,large:!1,largeThreshold:400,progressive:3e3,progressiveChunkMode:"mod"},e}(zt);zt.registerClass(Xs);var nz=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.getInitialData=function(){return va(null,this,{useEncodeDefaulter:!0,createInvertedIndices:!!this.get("realtimeSort",!0)||null})},e.prototype.getProgressive=function(){return this.get("large")?this.get("progressive"):!1},e.prototype.getProgressiveThreshold=function(){var t=this.get("progressiveThreshold"),a=this.get("largeThreshold");return a>t&&(t=a),t},e.prototype.brushSelector=function(t,a,n){return n.rect(a.getItemLayout(t))},e.type="series.bar",e.dependencies=["grid","polar"],e.defaultOption=ja(Xs.defaultOption,{clip:!0,roundCap:!1,showBackground:!1,backgroundStyle:{color:"rgba(180, 180, 180, 0.2)",borderColor:null,borderWidth:0,borderType:"solid",borderRadius:0,shadowBlur:0,shadowColor:null,shadowOffsetX:0,shadowOffsetY:0,opacity:1},select:{itemStyle:{borderColor:"#212121"}},realtimeSort:!1}),e}(Xs);const iz=nz;var oz=function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r}(),Tf=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a.type="sausage",a}return e.prototype.getDefaultShape=function(){return new oz},e.prototype.buildPath=function(t,a){var n=a.cx,i=a.cy,o=Math.max(a.r0||0,0),s=Math.max(a.r,0),l=(s-o)*.5,u=o+l,f=a.startAngle,h=a.endAngle,v=a.clockwise,c=Math.PI*2,p=v?h-f<c:f-h<c;p||(f=h-(v?c:-c));var d=Math.cos(f),g=Math.sin(f),y=Math.cos(h),m=Math.sin(h);p?(t.moveTo(d*o+n,g*o+i),t.arc(d*u+n,g*u+i,l,-Math.PI+f,f,!v)):t.moveTo(d*s+n,g*s+i),t.arc(n,i,s,f,h,!v),t.arc(y*u+n,m*u+i,l,h-Math.PI*2,h-Math.PI,!v),o!==0&&t.arc(n,i,o,h,f,v)},e}(yt);function sz(r,e){e=e||{};var t=e.isRoundCap;return function(a,n,i){var o=n.position;if(!o||o instanceof Array)return rf(a,n,i);var s=r(o),l=n.distance!=null?n.distance:5,u=this.shape,f=u.cx,h=u.cy,v=u.r,c=u.r0,p=(v+c)/2,d=u.startAngle,g=u.endAngle,y=(d+g)/2,m=t?Math.abs(v-c)/2:0,_=Math.cos,S=Math.sin,w=f+v*_(d),x=h+v*S(d),b="left",T="top";switch(s){case"startArc":w=f+(c-l)*_(y),x=h+(c-l)*S(y),b="center",T="top";break;case"insideStartArc":w=f+(c+l)*_(y),x=h+(c+l)*S(y),b="center",T="bottom";break;case"startAngle":w=f+p*_(d)+su(d,l+m,!1),x=h+p*S(d)+lu(d,l+m,!1),b="right",T="middle";break;case"insideStartAngle":w=f+p*_(d)+su(d,-l+m,!1),x=h+p*S(d)+lu(d,-l+m,!1),b="left",T="middle";break;case"middle":w=f+p*_(y),x=h+p*S(y),b="center",T="middle";break;case"endArc":w=f+(v+l)*_(y),x=h+(v+l)*S(y),b="center",T="bottom";break;case"insideEndArc":w=f+(v-l)*_(y),x=h+(v-l)*S(y),b="center",T="top";break;case"endAngle":w=f+p*_(g)+su(g,l+m,!0),x=h+p*S(g)+lu(g,l+m,!0),b="left",T="middle";break;case"insideEndAngle":w=f+p*_(g)+su(g,-l+m,!0),x=h+p*S(g)+lu(g,-l+m,!0),b="right",T="middle";break;default:return rf(a,n,i)}return a=a||{},a.x=w,a.y=x,a.align=b,a.verticalAlign=T,a}}function lz(r,e,t,a){if(Ct(a)){r.setTextConfig({rotation:a});return}else if(z(e)){r.setTextConfig({rotation:0});return}var n=r.shape,i=n.clockwise?n.startAngle:n.endAngle,o=n.clockwise?n.endAngle:n.startAngle,s=(i+o)/2,l,u=t(e);switch(u){case"startArc":case"insideStartArc":case"middle":case"insideEndArc":case"endArc":l=s;break;case"startAngle":case"insideStartAngle":l=i;break;case"endAngle":case"insideEndAngle":l=o;break;default:r.setTextConfig({rotation:0});return}var f=Math.PI*1.5-l;u==="middle"&&f>Math.PI/2&&f<Math.PI*1.5&&(f-=Math.PI),r.setTextConfig({rotation:f})}function su(r,e,t){return e*Math.sin(r)*(t?-1:1)}function lu(r,e,t){return e*Math.cos(r)*(t?1:-1)}function Hn(r,e,t){var a=r.get("borderRadius");if(a==null)return t?{cornerRadius:0}:null;z(a)||(a=[a,a,a,a]);var n=Math.abs(e.r||0-e.r0||0);return{cornerRadius:G(a,function(i){return _r(i,n)})}}var Yv=Math.max,Zv=Math.min;function uz(r,e){var t=r.getArea&&r.getArea();if(hi(r,"cartesian2d")){var a=r.getBaseAxis();if(a.type!=="category"||!a.onBand){var n=e.getLayout("bandWidth");a.isHorizontal()?(t.x-=n,t.width+=n*2):(t.y-=n,t.height+=n*2)}}return t}var fz=function(r){k(e,r);function e(){var t=r.call(this)||this;return t.type=e.type,t._isFirstFrame=!0,t}return e.prototype.render=function(t,a,n,i){this._model=t,this._removeOnRenderedListener(n),this._updateDrawMode(t);var o=t.get("coordinateSystem");(o==="cartesian2d"||o==="polar")&&(this._progressiveEls=null,this._isLargeDraw?this._renderLarge(t,a,n):this._renderNormal(t,a,n,i))},e.prototype.incrementalPrepareRender=function(t){this._clear(),this._updateDrawMode(t),this._updateLargeClip(t)},e.prototype.incrementalRender=function(t,a){this._progressiveEls=[],this._incrementalRenderLarge(t,a)},e.prototype.eachRendered=function(t){Ja(this._progressiveEls||this.group,t)},e.prototype._updateDrawMode=function(t){var a=t.pipelineContext.large;(this._isLargeDraw==null||a!==this._isLargeDraw)&&(this._isLargeDraw=a,this._clear())},e.prototype._renderNormal=function(t,a,n,i){var o=this.group,s=t.getData(),l=this._data,u=t.coordinateSystem,f=u.getBaseAxis(),h;u.type==="cartesian2d"?h=f.isHorizontal():u.type==="polar"&&(h=f.dim==="angle");var v=t.isAnimationEnabled()?t:null,c=hz(t,u);c&&this._enableRealtimeSort(c,s,n);var p=t.get("clip",!0)||c,d=uz(u,s);o.removeClipPath();var g=t.get("roundCap",!0),y=t.get("showBackground",!0),m=t.getModel("backgroundStyle"),_=m.get("borderRadius")||0,S=[],w=this._backgroundEls,x=i&&i.isInitSort,b=i&&i.type==="changeAxisOrder";function T(M){var I=uu[u.type](s,M),L=mz(u,h,I);return L.useStyle(m.getItemStyle()),u.type==="cartesian2d"?L.setShape("r",_):L.setShape("cornerRadius",_),S[M]=L,L}s.diff(l).add(function(M){var I=s.getItemModel(M),L=uu[u.type](s,M,I);if(y&&T(M),!(!s.hasValue(M)||!p1[u.type](L))){var P=!1;p&&(P=f1[u.type](d,L));var R=h1[u.type](t,s,M,L,h,v,f.model,!1,g);c&&(R.forceLabelAnimation=!0),d1(R,s,M,I,L,t,h,u.type==="polar"),x?R.attr({shape:L}):c?v1(c,v,R,L,M,h,!1,!1):Bt(R,{shape:L},t,M),s.setItemGraphicEl(M,R),o.add(R),R.ignore=P}}).update(function(M,I){var L=s.getItemModel(M),P=uu[u.type](s,M,L);if(y){var R=void 0;w.length===0?R=T(I):(R=w[I],R.useStyle(m.getItemStyle()),u.type==="cartesian2d"?R.setShape("r",_):R.setShape("cornerRadius",_),S[M]=R);var E=uu[u.type](s,M),N=ED(h,E,u);Dt(R,{shape:N},v,M)}var O=l.getItemGraphicEl(I);if(!s.hasValue(M)||!p1[u.type](P)){o.remove(O);return}var B=!1;if(p&&(B=f1[u.type](d,P),B&&o.remove(O)),O?Sr(O):O=h1[u.type](t,s,M,P,h,v,f.model,!!O,g),c&&(O.forceLabelAnimation=!0),b){var F=O.getTextContent();if(F){var H=po(F);H.prevValue!=null&&(H.prevValue=H.value)}}else d1(O,s,M,L,P,t,h,u.type==="polar");x?O.attr({shape:P}):c?v1(c,v,O,P,M,h,!0,b):Dt(O,{shape:P},t,M,null),s.setItemGraphicEl(M,O),O.ignore=B,o.add(O)}).remove(function(M){var I=l.getItemGraphicEl(M);I&&Vs(I,t,M)}).execute();var A=this._backgroundGroup||(this._backgroundGroup=new at);A.removeAll();for(var D=0;D<S.length;++D)A.add(S[D]);o.add(A),this._backgroundEls=S,this._data=s},e.prototype._renderLarge=function(t,a,n){this._clear(),y1(t,this.group),this._updateLargeClip(t)},e.prototype._incrementalRenderLarge=function(t,a){this._removeBackground(),y1(a,this.group,this._progressiveEls,!0)},e.prototype._updateLargeClip=function(t){var a=t.get("clip",!0)&&yl(t.coordinateSystem,!1,t),n=this.group;a?n.setClipPath(a):n.removeClipPath()},e.prototype._enableRealtimeSort=function(t,a,n){var i=this;if(a.count()){var o=t.baseAxis;if(this._isFirstFrame)this._dispatchInitSort(a,t,n),this._isFirstFrame=!1;else{var s=function(l){var u=a.getItemGraphicEl(l),f=u&&u.shape;return f&&Math.abs(o.isHorizontal()?f.height:f.width)||0};this._onRendered=function(){i._updateSortWithinSameData(a,s,o,n)},n.getZr().on("rendered",this._onRendered)}}},e.prototype._dataSort=function(t,a,n){var i=[];return t.each(t.mapDimension(a.dim),function(o,s){var l=n(s);l=l??NaN,i.push({dataIndex:s,mappedValue:l,ordinalNumber:o})}),i.sort(function(o,s){return s.mappedValue-o.mappedValue}),{ordinalNumbers:G(i,function(o){return o.ordinalNumber})}},e.prototype._isOrderChangedWithinSameData=function(t,a,n){for(var i=n.scale,o=t.mapDimension(n.dim),s=Number.MAX_VALUE,l=0,u=i.getOrdinalMeta().categories.length;l<u;++l){var f=t.rawIndexOf(o,i.getRawOrdinalNumber(l)),h=f<0?Number.MIN_VALUE:a(t.indexOfRawIndex(f));if(h>s)return!0;s=h}return!1},e.prototype._isOrderDifferentInView=function(t,a){for(var n=a.scale,i=n.getExtent(),o=Math.max(0,i[0]),s=Math.min(i[1],n.getOrdinalMeta().categories.length-1);o<=s;++o)if(t.ordinalNumbers[o]!==n.getRawOrdinalNumber(o))return!0},e.prototype._updateSortWithinSameData=function(t,a,n,i){if(this._isOrderChangedWithinSameData(t,a,n)){var o=this._dataSort(t,n,a);this._isOrderDifferentInView(o,n)&&(this._removeOnRenderedListener(i),i.dispatchAction({type:"changeAxisOrder",componentType:n.dim+"Axis",axisId:n.index,sortInfo:o}))}},e.prototype._dispatchInitSort=function(t,a,n){var i=a.baseAxis,o=this._dataSort(t,i,function(s){return t.get(t.mapDimension(a.otherAxis.dim),s)});n.dispatchAction({type:"changeAxisOrder",componentType:i.dim+"Axis",isInitSort:!0,axisId:i.index,sortInfo:o})},e.prototype.remove=function(t,a){this._clear(this._model),this._removeOnRenderedListener(a)},e.prototype.dispose=function(t,a){this._removeOnRenderedListener(a)},e.prototype._removeOnRenderedListener=function(t){this._onRendered&&(t.getZr().off("rendered",this._onRendered),this._onRendered=null)},e.prototype._clear=function(t){var a=this.group,n=this._data;t&&t.isAnimationEnabled()&&n&&!this._isLargeDraw?(this._removeBackground(),this._backgroundEls=[],n.eachItemGraphicEl(function(i){Vs(i,t,nt(i).dataIndex)})):a.removeAll(),this._data=null,this._isFirstFrame=!0},e.prototype._removeBackground=function(){this.group.remove(this._backgroundGroup),this._backgroundGroup=null},e.type="bar",e}(Nt),f1={cartesian2d:function(r,e){var t=e.width<0?-1:1,a=e.height<0?-1:1;t<0&&(e.x+=e.width,e.width=-e.width),a<0&&(e.y+=e.height,e.height=-e.height);var n=r.x+r.width,i=r.y+r.height,o=Yv(e.x,r.x),s=Zv(e.x+e.width,n),l=Yv(e.y,r.y),u=Zv(e.y+e.height,i),f=s<o,h=u<l;return e.x=f&&o>n?s:o,e.y=h&&l>i?u:l,e.width=f?0:s-o,e.height=h?0:u-l,t<0&&(e.x+=e.width,e.width=-e.width),a<0&&(e.y+=e.height,e.height=-e.height),f||h},polar:function(r,e){var t=e.r0<=e.r?1:-1;if(t<0){var a=e.r;e.r=e.r0,e.r0=a}var n=Zv(e.r,r.r),i=Yv(e.r0,r.r0);e.r=n,e.r0=i;var o=n-i<0;if(t<0){var a=e.r;e.r=e.r0,e.r0=a}return o}},h1={cartesian2d:function(r,e,t,a,n,i,o,s,l){var u=new wt({shape:V({},a),z2:1});if(u.__dataIndex=t,u.name="item",i){var f=u.shape,h=n?"height":"width";f[h]=0}return u},polar:function(r,e,t,a,n,i,o,s,l){var u=!n&&l?Tf:Be,f=new u({shape:a,z2:1});f.name="item";var h=RD(n);if(f.calculateTextPosition=sz(h,{isRoundCap:u===Tf}),i){var v=f.shape,c=n?"r":"endAngle",p={};v[c]=n?a.r0:a.startAngle,p[c]=a[c],(s?Dt:Bt)(f,{shape:p},i)}return f}};function hz(r,e){var t=r.get("realtimeSort",!0),a=e.getBaseAxis();if(t&&a.type==="category"&&e.type==="cartesian2d")return{baseAxis:a,otherAxis:e.getOtherAxis(a)}}function v1(r,e,t,a,n,i,o,s){var l,u;i?(u={x:a.x,width:a.width},l={y:a.y,height:a.height}):(u={y:a.y,height:a.height},l={x:a.x,width:a.width}),s||(o?Dt:Bt)(t,{shape:l},e,n,null);var f=e?r.baseAxis.model:null;(o?Dt:Bt)(t,{shape:u},f,n)}function c1(r,e){for(var t=0;t<e.length;t++)if(!isFinite(r[e[t]]))return!0;return!1}var vz=["x","y","width","height"],cz=["cx","cy","r","startAngle","endAngle"],p1={cartesian2d:function(r){return!c1(r,vz)},polar:function(r){return!c1(r,cz)}},uu={cartesian2d:function(r,e,t){var a=r.getItemLayout(e),n=t?dz(t,a):0,i=a.width>0?1:-1,o=a.height>0?1:-1;return{x:a.x+i*n/2,y:a.y+o*n/2,width:a.width-i*n,height:a.height-o*n}},polar:function(r,e,t){var a=r.getItemLayout(e);return{cx:a.cx,cy:a.cy,r0:a.r0,r:a.r,startAngle:a.startAngle,endAngle:a.endAngle,clockwise:a.clockwise}}};function pz(r){return r.startAngle!=null&&r.endAngle!=null&&r.startAngle===r.endAngle}function RD(r){return function(e){var t=e?"Arc":"Angle";return function(a){switch(a){case"start":case"insideStart":case"end":case"insideEnd":return a+t;default:return a}}}(r)}function d1(r,e,t,a,n,i,o,s){var l=e.getItemVisual(t,"style");if(s){if(!i.get("roundCap")){var f=r.shape,h=Hn(a.getModel("itemStyle"),f,!0);V(f,h),r.setShape(f)}}else{var u=a.get(["itemStyle","borderRadius"])||0;r.setShape("r",u)}r.useStyle(l);var v=a.getShallow("cursor");v&&r.attr("cursor",v);var c=s?o?n.r>=n.r0?"endArc":"startArc":n.endAngle>=n.startAngle?"endAngle":"startAngle":o?n.height>=0?"bottom":"top":n.width>=0?"right":"left",p=re(a);fe(r,p,{labelFetcher:i,labelDataIndex:t,defaultText:eo(i.getData(),t),inheritColor:l.fill,defaultOpacity:l.opacity,defaultOutsidePosition:c});var d=r.getTextContent();if(s&&d){var g=a.get(["label","position"]);r.textConfig.inside=g==="middle"?!0:null,lz(r,g==="outside"?c:g,RD(o),a.get(["label","rotate"]))}XT(d,p,i.getRawValue(t),function(m){return bD(e,m)});var y=a.getModel(["emphasis"]);Ft(r,y.get("focus"),y.get("blurScope"),y.get("disabled")),ue(r,a),pz(n)&&(r.style.fill="none",r.style.stroke="none",C(r.states,function(m){m.style&&(m.style.fill=m.style.stroke="none")}))}function dz(r,e){var t=r.get(["itemStyle","borderColor"]);if(!t||t==="none")return 0;var a=r.get(["itemStyle","borderWidth"])||0,n=isNaN(e.width)?Number.MAX_VALUE:Math.abs(e.width),i=isNaN(e.height)?Number.MAX_VALUE:Math.abs(e.height);return Math.min(a,n,i)}var gz=function(){function r(){}return r}(),g1=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a.type="largeBar",a}return e.prototype.getDefaultShape=function(){return new gz},e.prototype.buildPath=function(t,a){for(var n=a.points,i=this.baseDimIdx,o=1-this.baseDimIdx,s=[],l=[],u=this.barWidth,f=0;f<n.length;f+=3)l[i]=u,l[o]=n[f+2],s[i]=n[f+i],s[o]=n[f+o],t.rect(s[0],s[1],l[0],l[1])},e}(yt);function y1(r,e,t,a){var n=r.getData(),i=n.getLayout("valueAxisHorizontal")?1:0,o=n.getLayout("largeDataIndices"),s=n.getLayout("size"),l=r.getModel("backgroundStyle"),u=n.getLayout("largeBackgroundPoints");if(u){var f=new g1({shape:{points:u},incremental:!!a,silent:!0,z2:0});f.baseDimIdx=i,f.largeDataIndices=o,f.barWidth=s,f.useStyle(l.getItemStyle()),e.add(f),t&&t.push(f)}var h=new g1({shape:{points:n.getLayout("largePoints")},incremental:!!a,ignoreCoarsePointer:!0,z2:1});h.baseDimIdx=i,h.largeDataIndices=o,h.barWidth=s,e.add(h),h.useStyle(n.getVisual("style")),nt(h).seriesIndex=r.seriesIndex,r.get("silent")||(h.on("mousedown",m1),h.on("mousemove",m1)),t&&t.push(h)}var m1=Ng(function(r){var e=this,t=yz(e,r.offsetX,r.offsetY);nt(e).dataIndex=t>=0?t:null},30,!1);function yz(r,e,t){for(var a=r.baseDimIdx,n=1-a,i=r.shape.points,o=r.largeDataIndices,s=[],l=[],u=r.barWidth,f=0,h=i.length/3;f<h;f++){var v=f*3;if(l[a]=u,l[n]=i[v+2],s[a]=i[v+a],s[n]=i[v+n],l[n]<0&&(s[n]+=l[n],l[n]=-l[n]),e>=s[0]&&e<=s[0]+l[0]&&t>=s[1]&&t<=s[1]+l[1])return o[f]}return-1}function ED(r,e,t){if(hi(t,"cartesian2d")){var a=e,n=t.getArea();return{x:r?a.x:n.x,y:r?n.y:a.y,width:r?a.width:n.width,height:r?n.height:a.height}}else{var n=t.getArea(),i=e;return{cx:n.cx,cy:n.cy,r0:r?n.r0:i.r0,r:r?n.r:i.r,startAngle:r?i.startAngle:0,endAngle:r?i.endAngle:Math.PI*2}}}function mz(r,e,t){var a=r.type==="polar"?Be:wt;return new a({shape:ED(e,t,r),silent:!0,z2:0})}const _z=fz;function Sz(r){r.registerChartView(_z),r.registerSeriesModel(iz),r.registerLayout(r.PRIORITY.VISUAL.LAYOUT,ot(BC,"bar")),r.registerLayout(r.PRIORITY.VISUAL.PROGRESSIVE_LAYOUT,VC("bar")),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,PD("bar")),r.registerAction({type:"changeAxisOrder",event:"changeAxisOrder",update:"update"},function(e,t){var a=e.componentType||"series";t.eachComponent({mainType:a,query:e},function(n){e.sortInfo&&n.axis.setCategorySortInfo(e.sortInfo)})})}var _1=Math.PI*2,fu=Math.PI/180;function kD(r,e){return Jt(r.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()})}function OD(r,e){var t=kD(r,e),a=r.get("center"),n=r.get("radius");z(n)||(n=[0,n]);var i=W(t.width,e.getWidth()),o=W(t.height,e.getHeight()),s=Math.min(i,o),l=W(n[0],s/2),u=W(n[1],s/2),f,h,v=r.coordinateSystem;if(v){var c=v.dataToPoint(a);f=c[0]||0,h=c[1]||0}else z(a)||(a=[a,a]),f=W(a[0],i)+t.x,h=W(a[1],o)+t.y;return{cx:f,cy:h,r0:l,r:u}}function xz(r,e,t){e.eachSeriesByType(r,function(a){var n=a.getData(),i=n.mapDimension("value"),o=kD(a,t),s=OD(a,t),l=s.cx,u=s.cy,f=s.r,h=s.r0,v=-a.get("startAngle")*fu,c=a.get("endAngle"),p=a.get("padAngle")*fu;c=c==="auto"?v-_1:-c*fu;var d=a.get("minAngle")*fu,g=d+p,y=0;n.each(i,function(E){!isNaN(E)&&y++});var m=n.getSum(i),_=Math.PI/(m||y)*2,S=a.get("clockwise"),w=a.get("roseType"),x=a.get("stillShowZeroSum"),b=n.getDataExtent(i);b[0]=0;var T=S?1:-1,A=[v,c],D=T*p/2;og(A,!S),v=A[0],c=A[1];var M=Math.abs(c-v),I=M,L=0,P=v;if(n.setLayout({viewRect:o,r:f}),n.each(i,function(E,N){var O;if(isNaN(E)){n.setItemLayout(N,{angle:NaN,startAngle:NaN,endAngle:NaN,clockwise:S,cx:l,cy:u,r0:h,r:w?NaN:f});return}w!=="area"?O=m===0&&x?_:E*_:O=M/y,O<g?(O=g,I-=g):L+=E;var B=P+T*O,F=0,H=0;p>O?(F=P+T*O/2,H=F):(F=P+D,H=B-D),n.setItemLayout(N,{angle:O,startAngle:F,endAngle:H,clockwise:S,cx:l,cy:u,r0:h,r:w?It(E,b,[h,f]):f}),P=B}),I<_1&&y)if(I<=.001){var R=M/y;n.each(i,function(E,N){if(!isNaN(E)){var O=n.getItemLayout(N);O.angle=R;var B=0,F=0;R<p?(B=v+T*(N+1/2)*R,F=B):(B=v+T*N*R+D,F=v+T*(N+1)*R-D),O.startAngle=B,O.endAngle=F}})}else _=I/L,P=v,n.each(i,function(E,N){if(!isNaN(E)){var O=n.getItemLayout(N),B=O.angle===g?g:E*_,F=0,H=0;B<p?(F=P+T*B/2,H=F):(F=P+D,H=P+T*B-D),O.startAngle=F,O.endAngle=H,P+=T*B}})})}function _l(r){return{seriesType:r,reset:function(e,t){var a=t.findComponents({mainType:"legend"});if(!(!a||!a.length)){var n=e.getData();n.filterSelf(function(i){for(var o=n.getName(i),s=0;s<a.length;s++)if(!a[s].isSelected(o))return!1;return!0})}}}}var wz=Math.PI/180;function S1(r,e,t,a,n,i,o,s,l,u){if(r.length<2)return;function f(d){for(var g=d.rB,y=g*g,m=0;m<d.list.length;m++){var _=d.list[m],S=Math.abs(_.label.y-t),w=a+_.len,x=w*w,b=Math.sqrt((1-Math.abs(S*S/y))*x),T=e+(b+_.len2)*n,A=T-_.label.x,D=_.targetTextWidth-A*n;ND(_,D,!0),_.label.x=T}}function h(d){for(var g={list:[],maxY:0},y={list:[],maxY:0},m=0;m<d.length;m++)if(d[m].labelAlignTo==="none"){var _=d[m],S=_.label.y>t?y:g,w=Math.abs(_.label.y-t);if(w>=S.maxY){var x=_.label.x-e-_.len2*n,b=a+_.len,T=Math.abs(x)<b?Math.sqrt(w*w/(1-x*x/b/b)):b;S.rB=T,S.maxY=w}S.list.push(_)}f(g),f(y)}for(var v=r.length,c=0;c<v;c++)if(r[c].position==="outer"&&r[c].labelAlignTo==="labelLine"){var p=r[c].label.x-u;r[c].linePoints[1][0]+=p,r[c].label.x=u}oD(r,l,l+o)&&h(r)}function bz(r,e,t,a,n,i,o,s){for(var l=[],u=[],f=Number.MAX_VALUE,h=-Number.MAX_VALUE,v=0;v<r.length;v++){var c=r[v].label;Xv(r[v])||(c.x<e?(f=Math.min(f,c.x),l.push(r[v])):(h=Math.max(h,c.x),u.push(r[v])))}for(var v=0;v<r.length;v++){var p=r[v];if(!Xv(p)&&p.linePoints){if(p.labelStyleWidth!=null)continue;var c=p.label,d=p.linePoints,g=void 0;p.labelAlignTo==="edge"?c.x<e?g=d[2][0]-p.labelDistance-o-p.edgeDistance:g=o+n-p.edgeDistance-d[2][0]-p.labelDistance:p.labelAlignTo==="labelLine"?c.x<e?g=f-o-p.bleedMargin:g=o+n-h-p.bleedMargin:c.x<e?g=c.x-o-p.bleedMargin:g=o+n-c.x-p.bleedMargin,p.targetTextWidth=g,ND(p,g)}}S1(u,e,t,a,1,n,i,o,s,h),S1(l,e,t,a,-1,n,i,o,s,f);for(var v=0;v<r.length;v++){var p=r[v];if(!Xv(p)&&p.linePoints){var c=p.label,d=p.linePoints,y=p.labelAlignTo==="edge",m=c.style.padding,_=m?m[1]+m[3]:0,S=c.style.backgroundColor?0:_,w=p.rect.width+S,x=d[1][0]-d[2][0];y?c.x<e?d[2][0]=o+p.edgeDistance+w+p.labelDistance:d[2][0]=o+n-p.edgeDistance-w-p.labelDistance:(c.x<e?d[2][0]=c.x+p.labelDistance:d[2][0]=c.x-p.labelDistance,d[1][0]=d[2][0]+x),d[1][1]=d[2][1]=c.y}}}function ND(r,e,t){if(t===void 0&&(t=!1),r.labelStyleWidth==null){var a=r.label,n=a.style,i=r.rect,o=n.backgroundColor,s=n.padding,l=s?s[1]+s[3]:0,u=n.overflow,f=i.width+(o?0:l);if(e<f||t){var h=i.height;if(u&&u.match("break")){a.setStyle("backgroundColor",null),a.setStyle("width",e-l);var v=a.getBoundingRect();a.setStyle("width",Math.ceil(v.width)),a.setStyle("backgroundColor",o)}else{var c=e-l,p=e<f?c:t?c>r.unconstrainedWidth?null:c:null;a.setStyle("width",p)}var d=a.getBoundingRect();i.width=d.width;var g=(a.style.margin||0)+2.1;i.height=d.height+g,i.y-=(i.height-h)/2}}}function Xv(r){return r.position==="center"}function Tz(r){var e=r.getData(),t=[],a,n,i=!1,o=(r.get("minShowLabelAngle")||0)*wz,s=e.getLayout("viewRect"),l=e.getLayout("r"),u=s.width,f=s.x,h=s.y,v=s.height;function c(x){x.ignore=!0}function p(x){if(!x.ignore)return!0;for(var b in x.states)if(x.states[b].ignore===!1)return!0;return!1}e.each(function(x){var b=e.getItemGraphicEl(x),T=b.shape,A=b.getTextContent(),D=b.getTextGuideLine(),M=e.getItemModel(x),I=M.getModel("label"),L=I.get("position")||M.get(["emphasis","label","position"]),P=I.get("distanceToLabelLine"),R=I.get("alignTo"),E=W(I.get("edgeDistance"),u),N=I.get("bleedMargin"),O=M.getModel("labelLine"),B=O.get("length");B=W(B,u);var F=O.get("length2");if(F=W(F,u),Math.abs(T.endAngle-T.startAngle)<o){C(A.states,c),A.ignore=!0,D&&(C(D.states,c),D.ignore=!0);return}if(p(A)){var H=(T.startAngle+T.endAngle)/2,X=Math.cos(H),Q=Math.sin(H),J,ct,St,pt;a=T.cx,n=T.cy;var et=L==="inside"||L==="inner";if(L==="center")J=T.cx,ct=T.cy,pt="center";else{var dt=(et?(T.r+T.r0)/2*X:T.r*X)+a,st=(et?(T.r+T.r0)/2*Q:T.r*Q)+n;if(J=dt+X*3,ct=st+Q*3,!et){var q=dt+X*(B+l-T.r),lt=st+Q*(B+l-T.r),Vt=q+(X<0?-1:1)*F,xt=lt;R==="edge"?J=X<0?f+E:f+u-E:J=Vt+(X<0?-P:P),ct=xt,St=[[dt,st],[q,lt],[Vt,xt]]}pt=et?"center":R==="edge"?X>0?"right":"left":X>0?"left":"right"}var Wt=Math.PI,Gt=0,ve=I.get("rotate");if(Ct(ve))Gt=ve*(Wt/180);else if(L==="center")Gt=0;else if(ve==="radial"||ve===!0){var Yr=X<0?-H+Wt:-H;Gt=Yr}else if(ve==="tangential"&&L!=="outside"&&L!=="outer"){var Ie=Math.atan2(X,Q);Ie<0&&(Ie=Wt*2+Ie);var Tl=Q>0;Tl&&(Ie=Wt+Ie),Gt=Ie-Wt}if(i=!!Gt,A.x=J,A.y=ct,A.rotation=Gt,A.setStyle({verticalAlign:"middle"}),et){A.setStyle({align:pt});var Mh=A.states.select;Mh&&(Mh.x+=A.x,Mh.y+=A.y)}else{var pa=A.getBoundingRect().clone();pa.applyTransform(A.getComputedTransform());var tm=(A.style.margin||0)+2.1;pa.y-=tm/2,pa.height+=tm,t.push({label:A,labelLine:D,position:L,len:B,len2:F,minTurnAngle:O.get("minTurnAngle"),maxSurfaceAngle:O.get("maxSurfaceAngle"),surfaceNormal:new ut(X,Q),linePoints:St,textAlign:pt,labelDistance:P,labelAlignTo:R,edgeDistance:E,bleedMargin:N,rect:pa,unconstrainedWidth:pa.width,labelStyleWidth:A.style.width})}b.setTextConfig({inside:et})}}),!i&&r.get("avoidLabelOverlap")&&bz(t,a,n,l,u,v,f,h);for(var d=0;d<t.length;d++){var g=t[d],y=g.label,m=g.labelLine,_=isNaN(y.x)||isNaN(y.y);if(y){y.setStyle({align:g.textAlign}),_&&(C(y.states,c),y.ignore=!0);var S=y.states.select;S&&(S.x+=y.x,S.y+=y.y)}if(m){var w=g.linePoints;_||!w?(C(m.states,c),m.ignore=!0):(aD(w,g.minTurnAngle),GB(w,g.surfaceNormal,g.maxSurfaceAngle),m.setShape({points:w}),y.__hostTarget.textGuideLineConfig={anchor:new ut(w[0][0],w[0][1])})}}}var Az=function(r){k(e,r);function e(t,a,n){var i=r.call(this)||this;i.z2=2;var o=new At;return i.setTextContent(o),i.updateData(t,a,n,!0),i}return e.prototype.updateData=function(t,a,n,i){var o=this,s=t.hostModel,l=t.getItemModel(a),u=l.getModel("emphasis"),f=t.getItemLayout(a),h=V(Hn(l.getModel("itemStyle"),f,!0),f);if(isNaN(h.startAngle)){o.setShape(h);return}if(i){o.setShape(h);var v=s.getShallow("animationType");s.ecModel.ssr?(Bt(o,{scaleX:0,scaleY:0},s,{dataIndex:a,isFrom:!0}),o.originX=h.cx,o.originY=h.cy):v==="scale"?(o.shape.r=f.r0,Bt(o,{shape:{r:f.r}},s,a)):n!=null?(o.setShape({startAngle:n,endAngle:n}),Bt(o,{shape:{startAngle:f.startAngle,endAngle:f.endAngle}},s,a)):(o.shape.endAngle=f.startAngle,Dt(o,{shape:{endAngle:f.endAngle}},s,a))}else Sr(o),Dt(o,{shape:h},s,a);o.useStyle(t.getItemVisual(a,"style")),ue(o,l);var c=(f.startAngle+f.endAngle)/2,p=s.get("selectedOffset"),d=Math.cos(c)*p,g=Math.sin(c)*p,y=l.getShallow("cursor");y&&o.attr("cursor",y),this._updateLabel(s,t,a),o.ensureState("emphasis").shape=V({r:f.r+(u.get("scale")&&u.get("scaleSize")||0)},Hn(u.getModel("itemStyle"),f)),V(o.ensureState("select"),{x:d,y:g,shape:Hn(l.getModel(["select","itemStyle"]),f)}),V(o.ensureState("blur"),{shape:Hn(l.getModel(["blur","itemStyle"]),f)});var m=o.getTextGuideLine(),_=o.getTextContent();m&&V(m.ensureState("select"),{x:d,y:g}),V(_.ensureState("select"),{x:d,y:g}),Ft(this,u.get("focus"),u.get("blurScope"),u.get("disabled"))},e.prototype._updateLabel=function(t,a,n){var i=this,o=a.getItemModel(n),s=o.getModel("labelLine"),l=a.getItemVisual(n,"style"),u=l&&l.fill,f=l&&l.opacity;fe(i,re(o),{labelFetcher:a.hostModel,labelDataIndex:n,inheritColor:u,defaultOpacity:f,defaultText:t.getFormattedLabel(n,"normal")||a.getName(n)});var h=i.getTextContent();i.setTextConfig({position:null,rotation:null}),h.attr({z2:10});var v=t.get(["label","position"]);if(v!=="outside"&&v!=="outer")i.removeTextGuideLine();else{var c=this.getTextGuideLine();c||(c=new Me,this.setTextGuideLine(c)),Kg(this,Qg(o),{stroke:u,opacity:Br(s.get(["lineStyle","opacity"]),f,1)})}},e}(Be),Cz=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.ignoreLabelLineUpdate=!0,t}return e.prototype.render=function(t,a,n,i){var o=t.getData(),s=this._data,l=this.group,u;if(!s&&o.count()>0){for(var f=o.getItemLayout(0),h=1;isNaN(f&&f.startAngle)&&h<o.count();++h)f=o.getItemLayout(h);f&&(u=f.startAngle)}if(this._emptyCircleSector&&l.remove(this._emptyCircleSector),o.count()===0&&t.get("showEmptyCircle")){var v=new Be({shape:OD(t,n)});v.useStyle(t.getModel("emptyCircleStyle").getItemStyle()),this._emptyCircleSector=v,l.add(v)}o.diff(s).add(function(c){var p=new Az(o,c,u);o.setItemGraphicEl(c,p),l.add(p)}).update(function(c,p){var d=s.getItemGraphicEl(p);d.updateData(o,c,u),d.off("click"),l.add(d),o.setItemGraphicEl(c,d)}).remove(function(c){var p=s.getItemGraphicEl(c);Vs(p,t,c)}).execute(),Tz(t),t.get("animationTypeUpdate")!=="expansion"&&(this._data=o)},e.prototype.dispose=function(){},e.prototype.containPoint=function(t,a){var n=a.getData(),i=n.getItemLayout(0);if(i){var o=t[0]-i.cx,s=t[1]-i.cy,l=Math.sqrt(o*o+s*s);return l<=i.r&&l>=i.r0}},e.type="pie",e}(Nt);const Dz=Cz;function To(r,e,t){e=z(e)&&{coordDimensions:e}||V({encodeDefine:r.getEncode()},e);var a=r.getSource(),n=vl(a,e).dimensions,i=new be(n,r);return i.initData(a,t),i}var Mz=function(){function r(e,t){this._getDataWithEncodedVisual=e,this._getRawData=t}return r.prototype.getAllNames=function(){var e=this._getRawData();return e.mapArray(e.getName)},r.prototype.containName=function(e){var t=this._getRawData();return t.indexOfName(e)>=0},r.prototype.indexOfName=function(e){var t=this._getDataWithEncodedVisual();return t.indexOfName(e)},r.prototype.getItemVisual=function(e,t){var a=this._getDataWithEncodedVisual();return a.getItemVisual(e,t)},r}();const Sl=Mz;var Iz=bt(),Lz=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.init=function(t){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new Sl(U(this.getData,this),U(this.getRawData,this)),this._defaultLabelLine(t)},e.prototype.mergeOption=function(){r.prototype.mergeOption.apply(this,arguments)},e.prototype.getInitialData=function(){return To(this,{coordDimensions:["value"],encodeDefaulter:ot(Ag,this)})},e.prototype.getDataParams=function(t){var a=this.getData(),n=Iz(a),i=n.seats;if(!i){var o=[];a.each(a.mapDimension("value"),function(l){o.push(l)}),i=n.seats=J2(o,a.hostModel.get("percentPrecision"))}var s=r.prototype.getDataParams.call(this,t);return s.percent=i[t]||0,s.$vars.push("percent"),s},e.prototype._defaultLabelLine=function(t){Jn(t,"labelLine",["show"]);var a=t.labelLine,n=t.emphasis.labelLine;a.show=a.show&&t.label.show,n.show=n.show&&t.emphasis.label.show},e.type="series.pie",e.defaultOption={z:2,legendHoverLink:!0,colorBy:"data",center:["50%","50%"],radius:[0,"75%"],clockwise:!0,startAngle:90,endAngle:"auto",padAngle:0,minAngle:0,minShowLabelAngle:0,selectedOffset:10,percentPrecision:2,stillShowZeroSum:!0,left:0,top:0,right:0,bottom:0,width:null,height:null,label:{rotate:0,show:!0,overflow:"truncate",position:"outer",alignTo:"none",edgeDistance:"25%",bleedMargin:10,distanceToLabelLine:5},labelLine:{show:!0,length:15,length2:15,smooth:!1,minTurnAngle:90,maxSurfaceAngle:90,lineStyle:{width:1,type:"solid"}},itemStyle:{borderWidth:1,borderJoin:"round"},showEmptyCircle:!0,emptyCircleStyle:{color:"lightgray",opacity:1},labelLayout:{hideOverlap:!0},emphasis:{scale:!0,scaleSize:5},avoidLabelOverlap:!0,animationType:"expansion",animationDuration:1e3,animationTypeUpdate:"transition",animationEasingUpdate:"cubicInOut",animationDurationUpdate:500,animationEasing:"cubicInOut"},e}(zt);const Pz=Lz;function Rz(r){return{seriesType:r,reset:function(e,t){var a=e.getData();a.filterSelf(function(n){var i=a.mapDimension("value"),o=a.get(i,n);return!(Ct(o)&&!isNaN(o)&&o<0)})}}}function Ez(r){r.registerChartView(Dz),r.registerSeriesModel(Pz),tC("pie",r.registerAction),r.registerLayout(ot(xz,"pie")),r.registerProcessor(_l("pie")),r.registerProcessor(Rz("pie"))}var kz=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t}return e.prototype.getInitialData=function(t,a){return va(null,this,{useEncodeDefaulter:!0})},e.prototype.getProgressive=function(){var t=this.option.progressive;return t??(this.option.large?5e3:this.get("progressive"))},e.prototype.getProgressiveThreshold=function(){var t=this.option.progressiveThreshold;return t??(this.option.large?1e4:this.get("progressiveThreshold"))},e.prototype.brushSelector=function(t,a,n){return n.point(a.getItemLayout(t))},e.prototype.getZLevelKey=function(){return this.getData().count()>this.getProgressiveThreshold()?this.id:""},e.type="series.scatter",e.dependencies=["grid","polar","geo","singleAxis","calendar"],e.defaultOption={coordinateSystem:"cartesian2d",z:2,legendHoverLink:!0,symbolSize:10,large:!1,largeThreshold:2e3,itemStyle:{opacity:.8},emphasis:{scale:!0},clip:!0,select:{itemStyle:{borderColor:"#212121"}},universalTransition:{divideShape:"clone"}},e}(zt);const Oz=kz;var BD=4,Nz=function(){function r(){}return r}(),Bz=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a._off=0,a.hoverDataIdx=-1,a}return e.prototype.getDefaultShape=function(){return new Nz},e.prototype.reset=function(){this.notClear=!1,this._off=0},e.prototype.buildPath=function(t,a){var n=a.points,i=a.size,o=this.symbolProxy,s=o.shape,l=t.getContext?t.getContext():t,u=l&&i[0]<BD,f=this.softClipShape,h;if(u){this._ctx=l;return}for(this._ctx=null,h=this._off;h<n.length;){var v=n[h++],c=n[h++];isNaN(v)||isNaN(c)||f&&!f.contain(v,c)||(s.x=v-i[0]/2,s.y=c-i[1]/2,s.width=i[0],s.height=i[1],o.buildPath(t,s,!0))}this.incremental&&(this._off=h,this.notClear=!0)},e.prototype.afterBrush=function(){var t=this.shape,a=t.points,n=t.size,i=this._ctx,o=this.softClipShape,s;if(i){for(s=this._off;s<a.length;){var l=a[s++],u=a[s++];isNaN(l)||isNaN(u)||o&&!o.contain(l,u)||i.fillRect(l-n[0]/2,u-n[1]/2,n[0],n[1])}this.incremental&&(this._off=s,this.notClear=!0)}},e.prototype.findDataIndex=function(t,a){for(var n=this.shape,i=n.points,o=n.size,s=Math.max(o[0],4),l=Math.max(o[1],4),u=i.length/2-1;u>=0;u--){var f=u*2,h=i[f]-s/2,v=i[f+1]-l/2;if(t>=h&&a>=v&&t<=h+s&&a<=v+l)return u}return-1},e.prototype.contain=function(t,a){var n=this.transformCoordToLocal(t,a),i=this.getBoundingRect();if(t=n[0],a=n[1],i.contain(t,a)){var o=this.hoverDataIdx=this.findDataIndex(t,a);return o>=0}return this.hoverDataIdx=-1,!1},e.prototype.getBoundingRect=function(){var t=this._rect;if(!t){for(var a=this.shape,n=a.points,i=a.size,o=i[0],s=i[1],l=1/0,u=1/0,f=-1/0,h=-1/0,v=0;v<n.length;){var c=n[v++],p=n[v++];l=Math.min(c,l),f=Math.max(c,f),u=Math.min(p,u),h=Math.max(p,h)}t=this._rect=new ht(l-o/2,u-s/2,f-l+o,h-u+s)}return t},e}(yt),Vz=function(){function r(){this.group=new at}return r.prototype.updateData=function(e,t){this._clear();var a=this._create();a.setShape({points:e.getLayout("points")}),this._setCommon(a,e,t)},r.prototype.updateLayout=function(e){var t=e.getLayout("points");this.group.eachChild(function(a){if(a.startIndex!=null){var n=(a.endIndex-a.startIndex)*2,i=a.startIndex*4*2;t=new Float32Array(t.buffer,i,n)}a.setShape("points",t),a.reset()})},r.prototype.incrementalPrepareUpdate=function(e){this._clear()},r.prototype.incrementalUpdate=function(e,t,a){var n=this._newAdded[0],i=t.getLayout("points"),o=n&&n.shape.points;if(o&&o.length<2e4){var s=o.length,l=new Float32Array(s+i.length);l.set(o),l.set(i,s),n.endIndex=e.end,n.setShape({points:l})}else{this._newAdded=[];var u=this._create();u.startIndex=e.start,u.endIndex=e.end,u.incremental=!0,u.setShape({points:i}),this._setCommon(u,t,a)}},r.prototype.eachRendered=function(e){this._newAdded[0]&&e(this._newAdded[0])},r.prototype._create=function(){var e=new Bz({cursor:"default"});return e.ignoreCoarsePointer=!0,this.group.add(e),this._newAdded.push(e),e},r.prototype._setCommon=function(e,t,a){var n=t.hostModel;a=a||{};var i=t.getVisual("symbolSize");e.setShape("size",i instanceof Array?i:[i,i]),e.softClipShape=a.clipShape||null,e.symbolProxy=qt(t.getVisual("symbol"),0,0,0,0),e.setColor=e.symbolProxy.setColor;var o=e.shape.size[0]<BD;e.useStyle(n.getModel("itemStyle").getItemStyle(o?["color","shadowBlur","shadowColor"]:["color"]));var s=t.getVisual("style"),l=s&&s.fill;l&&e.setColor(l);var u=nt(e);u.seriesIndex=n.seriesIndex,e.on("mousemove",function(f){u.dataIndex=null;var h=e.hoverDataIdx;h>=0&&(u.dataIndex=h+(e.startIndex||0))})},r.prototype.remove=function(){this._clear()},r.prototype._clear=function(){this._newAdded=[],this.group.removeAll()},r}(),zz=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){var i=t.getData(),o=this._updateSymbolDraw(i,t);o.updateData(i,{clipShape:this._getClipShape(t)}),this._finished=!0},e.prototype.incrementalPrepareRender=function(t,a,n){var i=t.getData(),o=this._updateSymbolDraw(i,t);o.incrementalPrepareUpdate(i),this._finished=!1},e.prototype.incrementalRender=function(t,a,n){this._symbolDraw.incrementalUpdate(t,a.getData(),{clipShape:this._getClipShape(a)}),this._finished=t.end===a.getData().count()},e.prototype.updateTransform=function(t,a,n){var i=t.getData();if(this.group.dirty(),!this._finished||i.count()>1e4)return{update:!0};var o=ml("").reset(t,a,n);o.progress&&o.progress({start:0,end:i.count(),count:i.count()},i),this._symbolDraw.updateLayout(i)},e.prototype.eachRendered=function(t){this._symbolDraw&&this._symbolDraw.eachRendered(t)},e.prototype._getClipShape=function(t){if(t.get("clip",!0)){var a=t.coordinateSystem;return a&&a.getArea&&a.getArea(.1)}},e.prototype._updateSymbolDraw=function(t,a){var n=this._symbolDraw,i=a.pipelineContext,o=i.large;return(!n||o!==this._isLargeDraw)&&(n&&n.remove(),n=this._symbolDraw=o?new Vz:new gl,this._isLargeDraw=o,this.group.removeAll()),this.group.add(n.group),n},e.prototype.remove=function(t,a){this._symbolDraw&&this._symbolDraw.remove(!0),this._symbolDraw=null},e.prototype.dispose=function(){},e.type="scatter",e}(Nt);const Gz=zz;var Fz=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.type="grid",e.dependencies=["xAxis","yAxis"],e.layoutMode="box",e.defaultOption={show:!1,z:0,left:"10%",top:60,right:"10%",bottom:70,containLabel:!1,backgroundColor:"rgba(0,0,0,0)",borderWidth:1,borderColor:"#ccc"},e}(Tt);const Hz=Fz;var nd=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.getCoordSysModel=function(){return this.getReferringComponents("grid",Xt).models[0]},e.type="cartesian2dAxis",e}(Tt);Kt(nd,pl);var VD={show:!0,z:0,inverse:!1,name:"",nameLocation:"end",nameRotate:null,nameTruncate:{maxWidth:null,ellipsis:"...",placeholder:"."},nameTextStyle:{},nameGap:15,silent:!1,triggerEvent:!1,tooltip:{show:!1},axisPointer:{},axisLine:{show:!0,onZero:!0,onZeroAxisIndex:null,lineStyle:{color:"#6E7079",width:1,type:"solid"},symbol:["none","none"],symbolSize:[10,15]},axisTick:{show:!0,inside:!1,length:5,lineStyle:{width:1}},axisLabel:{show:!0,inside:!1,rotate:0,showMinLabel:null,showMaxLabel:null,margin:8,fontSize:12},splitLine:{show:!0,lineStyle:{color:["#E0E6F1"],width:1,type:"solid"}},splitArea:{show:!1,areaStyle:{color:["rgba(250,250,250,0.2)","rgba(210,219,238,0.2)"]}}},Wz=ft({boundaryGap:!0,deduplication:null,splitLine:{show:!1},axisTick:{alignWithLabel:!1,interval:"auto"},axisLabel:{interval:"auto"}},VD),ay=ft({boundaryGap:[0,0],axisLine:{show:"auto"},axisTick:{show:"auto"},splitNumber:5,minorTick:{show:!1,splitNumber:5,length:3,lineStyle:{}},minorSplitLine:{show:!1,lineStyle:{color:"#F4F7FD",width:1}}},VD),$z=ft({splitNumber:6,axisLabel:{showMinLabel:!1,showMaxLabel:!1,rich:{primary:{fontWeight:"bold"}}},splitLine:{show:!1}},ay),Uz=j({logBase:10},ay);const zD={category:Wz,value:ay,time:$z,log:Uz};var Yz={value:1,category:1,time:1,log:1};function ro(r,e,t,a){C(Yz,function(n,i){var o=ft(ft({},zD[i],!0),a,!0),s=function(l){k(u,l);function u(){var f=l!==null&&l.apply(this,arguments)||this;return f.type=e+"Axis."+i,f}return u.prototype.mergeDefaultAndTheme=function(f,h){var v=Gs(this),c=v?mo(f):{},p=h.getTheme();ft(f,p.get(i+"Axis")),ft(f,this.getDefaultOption()),f.type=x1(f),v&&Ua(f,c,v)},u.prototype.optionUpdated=function(){var f=this.option;f.type==="category"&&(this.__ordinalMeta=Qp.createByAxisModel(this))},u.prototype.getCategories=function(f){var h=this.option;if(h.type==="category")return f?h.data:this.__ordinalMeta.categories},u.prototype.getOrdinalMeta=function(){return this.__ordinalMeta},u.type=e+"Axis."+i,u.defaultOption=o,u}(t);r.registerComponentModel(s)}),r.registerSubTypeDefaulter(e+"Axis",x1)}function x1(r){return r.type||(r.data?"category":"value")}var Zz=function(){function r(e){this.type="cartesian",this._dimList=[],this._axes={},this.name=e||""}return r.prototype.getAxis=function(e){return this._axes[e]},r.prototype.getAxes=function(){return G(this._dimList,function(e){return this._axes[e]},this)},r.prototype.getAxesByScale=function(e){return e=e.toLowerCase(),Lt(this.getAxes(),function(t){return t.scale.type===e})},r.prototype.addAxis=function(e){var t=e.dim;this._axes[t]=e,this._dimList.push(t)},r}();const Xz=Zz;var id=["x","y"];function w1(r){return r.type==="interval"||r.type==="time"}var qz=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="cartesian2d",t.dimensions=id,t}return e.prototype.calcAffineTransform=function(){this._transform=this._invTransform=null;var t=this.getAxis("x").scale,a=this.getAxis("y").scale;if(!(!w1(t)||!w1(a))){var n=t.getExtent(),i=a.getExtent(),o=this.dataToPoint([n[0],i[0]]),s=this.dataToPoint([n[1],i[1]]),l=n[1]-n[0],u=i[1]-i[0];if(!(!l||!u)){var f=(s[0]-o[0])/l,h=(s[1]-o[1])/u,v=o[0]-n[0]*f,c=o[1]-i[0]*h,p=this._transform=[f,0,0,h,v,c];this._invTransform=lo([],p)}}},e.prototype.getBaseAxis=function(){return this.getAxesByScale("ordinal")[0]||this.getAxesByScale("time")[0]||this.getAxis("x")},e.prototype.containPoint=function(t){var a=this.getAxis("x"),n=this.getAxis("y");return a.contain(a.toLocalCoord(t[0]))&&n.contain(n.toLocalCoord(t[1]))},e.prototype.containData=function(t){return this.getAxis("x").containData(t[0])&&this.getAxis("y").containData(t[1])},e.prototype.containZone=function(t,a){var n=this.dataToPoint(t),i=this.dataToPoint(a),o=this.getArea(),s=new ht(n[0],n[1],i[0]-n[0],i[1]-n[1]);return o.intersect(s)},e.prototype.dataToPoint=function(t,a,n){n=n||[];var i=t[0],o=t[1];if(this._transform&&i!=null&&isFinite(i)&&o!=null&&isFinite(o))return se(n,t,this._transform);var s=this.getAxis("x"),l=this.getAxis("y");return n[0]=s.toGlobalCoord(s.dataToCoord(i,a)),n[1]=l.toGlobalCoord(l.dataToCoord(o,a)),n},e.prototype.clampData=function(t,a){var n=this.getAxis("x").scale,i=this.getAxis("y").scale,o=n.getExtent(),s=i.getExtent(),l=n.parse(t[0]),u=i.parse(t[1]);return a=a||[],a[0]=Math.min(Math.max(Math.min(o[0],o[1]),l),Math.max(o[0],o[1])),a[1]=Math.min(Math.max(Math.min(s[0],s[1]),u),Math.max(s[0],s[1])),a},e.prototype.pointToData=function(t,a){var n=[];if(this._invTransform)return se(n,t,this._invTransform);var i=this.getAxis("x"),o=this.getAxis("y");return n[0]=i.coordToData(i.toLocalCoord(t[0]),a),n[1]=o.coordToData(o.toLocalCoord(t[1]),a),n},e.prototype.getOtherAxis=function(t){return this.getAxis(t.dim==="x"?"y":"x")},e.prototype.getArea=function(t){t=t||0;var a=this.getAxis("x").getGlobalExtent(),n=this.getAxis("y").getGlobalExtent(),i=Math.min(a[0],a[1])-t,o=Math.min(n[0],n[1])-t,s=Math.max(a[0],a[1])-i+t,l=Math.max(n[0],n[1])-o+t;return new ht(i,o,s,l)},e}(Xz),Kz=function(r){k(e,r);function e(t,a,n,i,o){var s=r.call(this,t,a,n)||this;return s.index=0,s.type=i||"value",s.position=o||"bottom",s}return e.prototype.isHorizontal=function(){var t=this.position;return t==="top"||t==="bottom"},e.prototype.getGlobalExtent=function(t){var a=this.getExtent();return a[0]=this.toGlobalCoord(a[0]),a[1]=this.toGlobalCoord(a[1]),t&&a[0]>a[1]&&a.reverse(),a},e.prototype.pointToData=function(t,a){return this.coordToData(this.toLocalCoord(t[this.dim==="x"?0:1]),a)},e.prototype.setCategorySortInfo=function(t){if(this.type!=="category")return!1;this.model.option.categorySortInfo=t,this.scale.setSortInfo(t)},e}(wr);const Qz=Kz;function od(r,e,t){t=t||{};var a=r.coordinateSystem,n=e.axis,i={},o=n.getAxesOnZeroOf()[0],s=n.position,l=o?"onZero":s,u=n.dim,f=a.getRect(),h=[f.x,f.x+f.width,f.y,f.y+f.height],v={left:0,right:1,top:0,bottom:1,onZero:2},c=e.get("offset")||0,p=u==="x"?[h[2]-c,h[3]+c]:[h[0]-c,h[1]+c];if(o){var d=o.toGlobalCoord(o.dataToCoord(0));p[v.onZero]=Math.max(Math.min(d,p[1]),p[0])}i.position=[u==="y"?p[v[l]]:h[0],u==="x"?p[v[l]]:h[3]],i.rotation=Math.PI/2*(u==="x"?0:1);var g={top:-1,bottom:1,left:-1,right:1};i.labelDirection=i.tickDirection=i.nameDirection=g[s],i.labelOffset=o?p[v[s]]-p[v.onZero]:0,e.get(["axisTick","inside"])&&(i.tickDirection=-i.tickDirection),ie(t.labelInside,e.get(["axisLabel","inside"]))&&(i.labelDirection=-i.labelDirection);var y=e.get(["axisLabel","rotate"]);return i.labelRotate=l==="top"?-y:y,i.z2=1,i}function b1(r){return r.get("coordinateSystem")==="cartesian2d"}function T1(r){var e={xAxisModel:null,yAxisModel:null};return C(e,function(t,a){var n=a.replace(/Model$/,""),i=r.getReferringComponents(n,Xt).models[0];e[a]=i}),e}var qv=Math.log;function GD(r,e,t){var a=Za.prototype,n=a.getTicks.call(t),i=a.getTicks.call(t,!0),o=n.length-1,s=a.getInterval.call(t),l=UC(r,e),u=l.extent,f=l.fixMin,h=l.fixMax;if(r.type==="log"){var v=qv(r.base);u=[qv(u[0])/v,qv(u[1])/v]}r.setExtent(u[0],u[1]),r.calcNiceExtent({splitNumber:o,fixMin:f,fixMax:h});var c=a.getExtent.call(r);f&&(u[0]=c[0]),h&&(u[1]=c[1]);var p=a.getInterval.call(r),d=u[0],g=u[1];if(f&&h)p=(g-d)/o;else if(f)for(g=u[0]+p*o;g<u[1]&&isFinite(g)&&isFinite(u[1]);)p=kv(p),g=u[0]+p*o;else if(h)for(d=u[1]-p*o;d>u[0]&&isFinite(d)&&isFinite(u[0]);)p=kv(p),d=u[1]-p*o;else{var y=r.getTicks().length-1;y>o&&(p=kv(p));var m=p*o;g=Math.ceil(u[1]/p)*p,d=$t(g-m),d<0&&u[0]>=0?(d=0,g=$t(m)):g>0&&u[1]<=0&&(g=0,d=-$t(m))}var _=(n[0].value-i[0].value)/s,S=(n[o].value-i[o].value)/s;a.setExtent.call(r,d+p*_,g+p*S),a.setInterval.call(r,p),(_||S)&&a.setNiceExtent.call(r,d+p,g-p)}var Jz=function(){function r(e,t,a){this.type="grid",this._coordsMap={},this._coordsList=[],this._axesMap={},this._axesList=[],this.axisPointerEnabled=!0,this.dimensions=id,this._initCartesian(e,t,a),this.model=e}return r.prototype.getRect=function(){return this._rect},r.prototype.update=function(e,t){var a=this._axesMap;this._updateScale(e,this.model);function n(o){var s,l=_t(o),u=l.length;if(u){for(var f=[],h=u-1;h>=0;h--){var v=+l[h],c=o[v],p=c.model,d=c.scale;Jp(d)&&p.get("alignTicks")&&p.get("interval")==null?f.push(c):(to(d,p),Jp(d)&&(s=c))}f.length&&(s||(s=f.pop(),to(s.scale,s.model)),C(f,function(g){GD(g.scale,g.model,s.scale)}))}}n(a.x),n(a.y);var i={};C(a.x,function(o){A1(a,"y",o,i)}),C(a.y,function(o){A1(a,"x",o,i)}),this.resize(this.model,t)},r.prototype.resize=function(e,t,a){var n=e.getBoxLayoutParams(),i=!a&&e.get("containLabel"),o=Jt(n,{width:t.getWidth(),height:t.getHeight()});this._rect=o;var s=this._axesList;l(),i&&(C(s,function(u){if(!u.model.get(["axisLabel","inside"])){var f=gB(u);if(f){var h=u.isHorizontal()?"height":"width",v=u.model.get(["axisLabel","margin"]);o[h]-=f[h]+v,u.position==="top"?o.y+=f.height+v:u.position==="left"&&(o.x+=f.width+v)}}}),l()),C(this._coordsList,function(u){u.calcAffineTransform()});function l(){C(s,function(u){var f=u.isHorizontal(),h=f?[0,o.width]:[0,o.height],v=u.inverse?1:0;u.setExtent(h[v],h[1-v]),jz(u,f?o.x:o.y)})}},r.prototype.getAxis=function(e,t){var a=this._axesMap[e];if(a!=null)return a[t||0]},r.prototype.getAxes=function(){return this._axesList.slice()},r.prototype.getCartesian=function(e,t){if(e!=null&&t!=null){var a="x"+e+"y"+t;return this._coordsMap[a]}tt(e)&&(t=e.yAxisIndex,e=e.xAxisIndex);for(var n=0,i=this._coordsList;n<i.length;n++)if(i[n].getAxis("x").index===e||i[n].getAxis("y").index===t)return i[n]},r.prototype.getCartesians=function(){return this._coordsList.slice()},r.prototype.convertToPixel=function(e,t,a){var n=this._findConvertTarget(t);return n.cartesian?n.cartesian.dataToPoint(a):n.axis?n.axis.toGlobalCoord(n.axis.dataToCoord(a)):null},r.prototype.convertFromPixel=function(e,t,a){var n=this._findConvertTarget(t);return n.cartesian?n.cartesian.pointToData(a):n.axis?n.axis.coordToData(n.axis.toLocalCoord(a)):null},r.prototype._findConvertTarget=function(e){var t=e.seriesModel,a=e.xAxisModel||t&&t.getReferringComponents("xAxis",Xt).models[0],n=e.yAxisModel||t&&t.getReferringComponents("yAxis",Xt).models[0],i=e.gridModel,o=this._coordsList,s,l;if(t)s=t.coordinateSystem,vt(o,s)<0&&(s=null);else if(a&&n)s=this.getCartesian(a.componentIndex,n.componentIndex);else if(a)l=this.getAxis("x",a.componentIndex);else if(n)l=this.getAxis("y",n.componentIndex);else if(i){var u=i.coordinateSystem;u===this&&(s=this._coordsList[0])}return{cartesian:s,axis:l}},r.prototype.containPoint=function(e){var t=this._coordsList[0];if(t)return t.containPoint(e)},r.prototype._initCartesian=function(e,t,a){var n=this,i=this,o={left:!1,right:!1,top:!1,bottom:!1},s={x:{},y:{}},l={x:0,y:0};if(t.eachComponent("xAxis",u("x"),this),t.eachComponent("yAxis",u("y"),this),!l.x||!l.y){this._axesMap={},this._axesList=[];return}this._axesMap=s,C(s.x,function(f,h){C(s.y,function(v,c){var p="x"+h+"y"+c,d=new qz(p);d.master=n,d.model=e,n._coordsMap[p]=d,n._coordsList.push(d),d.addAxis(f),d.addAxis(v)})});function u(f){return function(h,v){if(Kv(h,e)){var c=h.get("position");f==="x"?c!=="top"&&c!=="bottom"&&(c=o.bottom?"top":"bottom"):c!=="left"&&c!=="right"&&(c=o.left?"right":"left"),o[c]=!0;var p=new Qz(f,_h(h),[0,0],h.get("type"),c),d=p.type==="category";p.onBand=d&&h.get("boundaryGap"),p.inverse=h.get("inverse"),h.axis=p,p.model=h,p.grid=i,p.index=v,i._axesList.push(p),s[f][v]=p,l[f]++}}}},r.prototype._updateScale=function(e,t){C(this._axesList,function(n){if(n.scale.setExtent(1/0,-1/0),n.type==="category"){var i=n.model.get("categorySortInfo");n.scale.setSortInfo(i)}}),e.eachSeries(function(n){if(b1(n)){var i=T1(n),o=i.xAxisModel,s=i.yAxisModel;if(!Kv(o,t)||!Kv(s,t))return;var l=this.getCartesian(o.componentIndex,s.componentIndex),u=n.getData(),f=l.getAxis("x"),h=l.getAxis("y");a(u,f),a(u,h)}},this);function a(n,i){C(Sf(n,i.dim),function(o){i.scale.unionExtentFromData(n,o)})}},r.prototype.getTooltipAxes=function(e){var t=[],a=[];return C(this.getCartesians(),function(n){var i=e!=null&&e!=="auto"?n.getAxis(e):n.getBaseAxis(),o=n.getOtherAxis(i);vt(t,i)<0&&t.push(i),vt(a,o)<0&&a.push(o)}),{baseAxes:t,otherAxes:a}},r.create=function(e,t){var a=[];return e.eachComponent("grid",function(n,i){var o=new r(n,e,t);o.name="grid_"+i,o.resize(n,t,!0),n.coordinateSystem=o,a.push(o)}),e.eachSeries(function(n){if(b1(n)){var i=T1(n),o=i.xAxisModel,s=i.yAxisModel,l=o.getCoordSysModel(),u=l.coordinateSystem;n.coordinateSystem=u.getCartesian(o.componentIndex,s.componentIndex)}}),a},r.dimensions=id,r}();function Kv(r,e){return r.getCoordSysModel()===e}function A1(r,e,t,a){t.getAxesOnZeroOf=function(){return i?[i]:[]};var n=r[e],i,o=t.model,s=o.get(["axisLine","onZero"]),l=o.get(["axisLine","onZeroAxisIndex"]);if(!s)return;if(l!=null)C1(n[l])&&(i=n[l]);else for(var u in n)if(n.hasOwnProperty(u)&&C1(n[u])&&!a[f(n[u])]){i=n[u];break}i&&(a[f(i)]=!0);function f(h){return h.dim+"_"+h.index}}function C1(r){return r&&r.type!=="category"&&r.type!=="time"&&dB(r)}function jz(r,e){var t=r.getExtent(),a=t[0]+t[1];r.toGlobalCoord=r.dim==="x"?function(n){return n+e}:function(n){return a-n+e},r.toLocalCoord=r.dim==="x"?function(n){return n-e}:function(n){return a-n+e}}const t5=Jz;var ka=Math.PI,Te=function(){function r(e,t){this.group=new at,this.opt=t,this.axisModel=e,j(t,{labelOffset:0,nameDirection:1,tickDirection:1,labelDirection:1,silent:!0,handleAutoShown:function(){return!0}});var a=new at({x:t.position[0],y:t.position[1],rotation:t.rotation});a.updateTransform(),this._transformGroup=a}return r.prototype.hasBuilder=function(e){return!!D1[e]},r.prototype.add=function(e){D1[e](this.opt,this.axisModel,this.group,this._transformGroup)},r.prototype.getGroup=function(){return this.group},r.innerTextLayout=function(e,t,a){var n=Ub(t-e),i,o;return Es(n)?(o=a>0?"top":"bottom",i="center"):Es(n-ka)?(o=a>0?"bottom":"top",i="center"):(o="middle",n>0&&n<ka?i=a>0?"right":"left":i=a>0?"left":"right"),{rotation:n,textAlign:i,textVerticalAlign:o}},r.makeAxisEventDataBase=function(e){var t={componentType:e.mainType,componentIndex:e.componentIndex};return t[e.mainType+"Index"]=e.componentIndex,t},r.isLabelSilent=function(e){var t=e.get("tooltip");return e.get("silent")||!(e.get("triggerEvent")||t&&t.show)},r}(),D1={axisLine:function(r,e,t,a){var n=e.get(["axisLine","show"]);if(n==="auto"&&r.handleAutoShown&&(n=r.handleAutoShown("axisLine")),!!n){var i=e.axis.getExtent(),o=a.transform,s=[i[0],0],l=[i[1],0],u=s[0]>l[0];o&&(se(s,s,o),se(l,l,o));var f=V({lineCap:"round"},e.getModel(["axisLine","lineStyle"]).getLineStyle()),h=new te({shape:{x1:s[0],y1:s[1],x2:l[0],y2:l[1]},style:f,strokeContainThreshold:r.strokeContainThreshold||5,silent:!0,z2:1});Qi(h.shape,h.style.lineWidth),h.anid="line",t.add(h);var v=e.get(["axisLine","symbol"]);if(v!=null){var c=e.get(["axisLine","symbolSize"]);$(v)&&(v=[v,v]),($(c)||Ct(c))&&(c=[c,c]);var p=ui(e.get(["axisLine","symbolOffset"])||0,c),d=c[0],g=c[1];C([{rotate:r.rotation+Math.PI/2,offset:p[0],r:0},{rotate:r.rotation-Math.PI/2,offset:p[1],r:Math.sqrt((s[0]-l[0])*(s[0]-l[0])+(s[1]-l[1])*(s[1]-l[1]))}],function(y,m){if(v[m]!=="none"&&v[m]!=null){var _=qt(v[m],-d/2,-g/2,d,g,f.stroke,!0),S=y.r+y.offset,w=u?l:s;_.attr({rotation:y.rotate,x:w[0]+S*Math.cos(r.rotation),y:w[1]-S*Math.sin(r.rotation),silent:!0,z2:11}),t.add(_)}})}}},axisTickLabel:function(r,e,t,a){var n=a5(t,a,e,r),i=i5(t,a,e,r);if(r5(e,i,n),n5(t,a,e,r.tickDirection),e.get(["axisLabel","hideOverlap"])){var o=nD(G(i,function(s){return{label:s,priority:s.z2,defaultAttr:{ignore:s.ignore}}}));sD(o)}},axisName:function(r,e,t,a){var n=ie(r.axisName,e.get("name"));if(n){var i=e.get("nameLocation"),o=r.nameDirection,s=e.getModel("nameTextStyle"),l=e.get("nameGap")||0,u=e.axis.getExtent(),f=u[0]>u[1]?-1:1,h=[i==="start"?u[0]-f*l:i==="end"?u[1]+f*l:(u[0]+u[1])/2,I1(i)?r.labelOffset+o*l:0],v,c=e.get("nameRotate");c!=null&&(c=c*ka/180);var p;I1(i)?v=Te.innerTextLayout(r.rotation,c??r.rotation,o):(v=e5(r.rotation,i,c||0,u),p=r.axisNameAvailableWidth,p!=null&&(p=Math.abs(p/Math.sin(v.rotation)),!isFinite(p)&&(p=null)));var d=s.getFont(),g=e.get("nameTruncate",!0)||{},y=g.ellipsis,m=ie(r.nameTruncateMaxWidth,g.maxWidth,p),_=new At({x:h[0],y:h[1],rotation:v.rotation,silent:Te.isLabelSilent(e),style:kt(s,{text:n,font:d,overflow:"truncate",width:m,ellipsis:y,fill:s.getTextColor()||e.get(["axisLine","lineStyle","color"]),align:s.get("align")||v.textAlign,verticalAlign:s.get("verticalAlign")||v.textVerticalAlign}),z2:1});if(co({el:_,componentModel:e,itemName:n}),_.__fullText=n,_.anid="name",e.get("triggerEvent")){var S=Te.makeAxisEventDataBase(e);S.targetType="axisName",S.name=n,nt(_).eventData=S}a.add(_),_.updateTransform(),t.add(_),_.decomposeTransform()}}};function e5(r,e,t,a){var n=Ub(t-r),i,o,s=a[0]>a[1],l=e==="start"&&!s||e!=="start"&&s;return Es(n-ka/2)?(o=l?"bottom":"top",i="center"):Es(n-ka*1.5)?(o=l?"top":"bottom",i="center"):(o="middle",n<ka*1.5&&n>ka/2?i=l?"left":"right":i=l?"right":"left"),{rotation:n,textAlign:i,textVerticalAlign:o}}function r5(r,e,t){if(!YC(r.axis)){var a=r.get(["axisLabel","showMinLabel"]),n=r.get(["axisLabel","showMaxLabel"]);e=e||[],t=t||[];var i=e[0],o=e[1],s=e[e.length-1],l=e[e.length-2],u=t[0],f=t[1],h=t[t.length-1],v=t[t.length-2];a===!1?(Ue(i),Ue(u)):M1(i,o)&&(a?(Ue(o),Ue(f)):(Ue(i),Ue(u))),n===!1?(Ue(s),Ue(h)):M1(l,s)&&(n?(Ue(l),Ue(v)):(Ue(s),Ue(h)))}}function Ue(r){r&&(r.ignore=!0)}function M1(r,e){var t=r&&r.getBoundingRect().clone(),a=e&&e.getBoundingRect().clone();if(!(!t||!a)){var n=Yf([]);return oi(n,n,-r.rotation),t.applyTransform(ea([],n,r.getLocalTransform())),a.applyTransform(ea([],n,e.getLocalTransform())),t.intersect(a)}}function I1(r){return r==="middle"||r==="center"}function FD(r,e,t,a,n){for(var i=[],o=[],s=[],l=0;l<r.length;l++){var u=r[l].coord;o[0]=u,o[1]=0,s[0]=u,s[1]=t,e&&(se(o,o,e),se(s,s,e));var f=new te({shape:{x1:o[0],y1:o[1],x2:s[0],y2:s[1]},style:a,z2:2,autoBatch:!0,silent:!0});Qi(f.shape,f.style.lineWidth),f.anid=n+"_"+r[l].tickValue,i.push(f)}return i}function a5(r,e,t,a){var n=t.axis,i=t.getModel("axisTick"),o=i.get("show");if(o==="auto"&&a.handleAutoShown&&(o=a.handleAutoShown("axisTick")),!(!o||n.scale.isBlank())){for(var s=i.getModel("lineStyle"),l=a.tickDirection*i.get("length"),u=n.getTicksCoords(),f=FD(u,e.transform,l,j(s.getLineStyle(),{stroke:t.get(["axisLine","lineStyle","color"])}),"ticks"),h=0;h<f.length;h++)r.add(f[h]);return f}}function n5(r,e,t,a){var n=t.axis,i=t.getModel("minorTick");if(!(!i.get("show")||n.scale.isBlank())){var o=n.getMinorTicksCoords();if(o.length)for(var s=i.getModel("lineStyle"),l=a*i.get("length"),u=j(s.getLineStyle(),j(t.getModel("axisTick").getLineStyle(),{stroke:t.get(["axisLine","lineStyle","color"])})),f=0;f<o.length;f++)for(var h=FD(o[f],e.transform,l,u,"minorticks_"+f),v=0;v<h.length;v++)r.add(h[v])}}function i5(r,e,t,a){var n=t.axis,i=ie(a.axisLabelShow,t.get(["axisLabel","show"]));if(!(!i||n.scale.isBlank())){var o=t.getModel("axisLabel"),s=o.get("margin"),l=n.getViewLabels(),u=(ie(a.labelRotate,o.get("rotate"))||0)*ka/180,f=Te.innerTextLayout(a.rotation,u,a.labelDirection),h=t.getCategories&&t.getCategories(!0),v=[],c=Te.isLabelSilent(t),p=t.get("triggerEvent");return C(l,function(d,g){var y=n.scale.type==="ordinal"?n.scale.getRawOrdinalNumber(d.tickValue):d.tickValue,m=d.formattedLabel,_=d.rawLabel,S=o;if(h&&h[y]){var w=h[y];tt(w)&&w.textStyle&&(S=new Ot(w.textStyle,o,t.ecModel))}var x=S.getTextColor()||t.get(["axisLine","lineStyle","color"]),b=n.dataToCoord(y),T=S.getShallow("align",!0)||f.textAlign,A=it(S.getShallow("alignMinLabel",!0),T),D=it(S.getShallow("alignMaxLabel",!0),T),M=S.getShallow("verticalAlign",!0)||S.getShallow("baseline",!0)||f.textVerticalAlign,I=it(S.getShallow("verticalAlignMinLabel",!0),M),L=it(S.getShallow("verticalAlignMaxLabel",!0),M),P=new At({x:b,y:a.labelOffset+a.labelDirection*s,rotation:f.rotation,silent:c,z2:10+(d.level||0),style:kt(S,{text:m,align:g===0?A:g===l.length-1?D:T,verticalAlign:g===0?I:g===l.length-1?L:M,fill:K(x)?x(n.type==="category"?_:n.type==="value"?y+"":y,g):x})});if(P.anid="label_"+y,p){var R=Te.makeAxisEventDataBase(t);R.targetType="axisLabel",R.value=_,R.tickIndex=g,n.type==="category"&&(R.dataIndex=y),nt(P).eventData=R}e.add(P),P.updateTransform(),v.push(P),r.add(P),P.decomposeTransform()}),v}}function o5(r,e){var t={axesInfo:{},seriesInvolved:!1,coordSysAxesInfo:{},coordSysMap:{}};return s5(t,r,e),t.seriesInvolved&&u5(t,r),t}function s5(r,e,t){var a=e.getComponent("tooltip"),n=e.getComponent("axisPointer"),i=n.get("link",!0)||[],o=[];C(t.getCoordinateSystems(),function(s){if(!s.axisPointerEnabled)return;var l=qs(s.model),u=r.coordSysAxesInfo[l]={};r.coordSysMap[l]=s;var f=s.model,h=f.getModel("tooltip",a);if(C(s.getAxes(),ot(d,!1,null)),s.getTooltipAxes&&a&&h.get("show")){var v=h.get("trigger")==="axis",c=h.get(["axisPointer","type"])==="cross",p=s.getTooltipAxes(h.get(["axisPointer","axis"]));(v||c)&&C(p.baseAxes,ot(d,c?"cross":!0,v)),c&&C(p.otherAxes,ot(d,"cross",!1))}function d(g,y,m){var _=m.model.getModel("axisPointer",n),S=_.get("show");if(!(!S||S==="auto"&&!g&&!sd(_))){y==null&&(y=_.get("triggerTooltip")),_=g?l5(m,h,n,e,g,y):_;var w=_.get("snap"),x=_.get("triggerEmphasis"),b=qs(m.model),T=y||w||m.type==="category",A=r.axesInfo[b]={key:b,axis:m,coordSys:s,axisPointerModel:_,triggerTooltip:y,triggerEmphasis:x,involveSeries:T,snap:w,useHandle:sd(_),seriesModels:[],linkGroup:null};u[b]=A,r.seriesInvolved=r.seriesInvolved||T;var D=f5(i,m);if(D!=null){var M=o[D]||(o[D]={axesInfo:{}});M.axesInfo[b]=A,M.mapper=i[D].mapper,A.linkGroup=M}}}})}function l5(r,e,t,a,n,i){var o=e.getModel("axisPointer"),s=["type","snap","lineStyle","shadowStyle","label","animation","animationDurationUpdate","animationEasingUpdate","z"],l={};C(s,function(v){l[v]=rt(o.get(v))}),l.snap=r.type!=="category"&&!!i,o.get("type")==="cross"&&(l.type="line");var u=l.label||(l.label={});if(u.show==null&&(u.show=!1),n==="cross"){var f=o.get(["label","show"]);if(u.show=f??!0,!i){var h=l.lineStyle=o.get("crossStyle");h&&j(u,h.textStyle)}}return r.model.getModel("axisPointer",new Ot(l,t,a))}function u5(r,e){e.eachSeries(function(t){var a=t.coordinateSystem,n=t.get(["tooltip","trigger"],!0),i=t.get(["tooltip","show"],!0);!a||n==="none"||n===!1||n==="item"||i===!1||t.get(["axisPointer","show"],!0)===!1||C(r.coordSysAxesInfo[qs(a.model)],function(o){var s=o.axis;a.getAxis(s.dim)===s&&(o.seriesModels.push(t),o.seriesDataCount==null&&(o.seriesDataCount=0),o.seriesDataCount+=t.getData().count())})})}function f5(r,e){for(var t=e.model,a=e.dim,n=0;n<r.length;n++){var i=r[n]||{};if(Qv(i[a+"AxisId"],t.id)||Qv(i[a+"AxisIndex"],t.componentIndex)||Qv(i[a+"AxisName"],t.name))return n}}function Qv(r,e){return r==="all"||z(r)&&vt(r,e)>=0||r===e}function h5(r){var e=ny(r);if(e){var t=e.axisPointerModel,a=e.axis.scale,n=t.option,i=t.get("status"),o=t.get("value");o!=null&&(o=a.parse(o));var s=sd(t);i==null&&(n.status=s?"show":"hide");var l=a.getExtent().slice();l[0]>l[1]&&l.reverse(),(o==null||o>l[1])&&(o=l[1]),o<l[0]&&(o=l[0]),n.value=o,s&&(n.status=e.axis.scale.isBlank()?"hide":"show")}}function ny(r){var e=(r.ecModel.getComponent("axisPointer")||{}).coordSysAxesInfo;return e&&e.axesInfo[qs(r)]}function v5(r){var e=ny(r);return e&&e.axisPointerModel}function sd(r){return!!r.get(["handle","show"])}function qs(r){return r.type+"||"+r.id}var L1={},vi=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n,i){this.axisPointerClass&&h5(t),r.prototype.render.apply(this,arguments),this._doUpdateAxisPointerClass(t,n,!0)},e.prototype.updateAxisPointer=function(t,a,n,i){this._doUpdateAxisPointerClass(t,n,!1)},e.prototype.remove=function(t,a){var n=this._axisPointer;n&&n.remove(a)},e.prototype.dispose=function(t,a){this._disposeAxisPointer(a),r.prototype.dispose.apply(this,arguments)},e.prototype._doUpdateAxisPointerClass=function(t,a,n){var i=e.getAxisPointerClass(this.axisPointerClass);if(i){var o=v5(t);o?(this._axisPointer||(this._axisPointer=new i)).render(t,o,a,n):this._disposeAxisPointer(a)}},e.prototype._disposeAxisPointer=function(t){this._axisPointer&&this._axisPointer.dispose(t),this._axisPointer=null},e.registerAxisPointerClass=function(t,a){L1[t]=a},e.getAxisPointerClass=function(t){return t&&L1[t]},e.type="axis",e}(Ht),ld=bt();function HD(r,e,t,a){var n=t.axis;if(!n.scale.isBlank()){var i=t.getModel("splitArea"),o=i.getModel("areaStyle"),s=o.get("color"),l=a.coordinateSystem.getRect(),u=n.getTicksCoords({tickModel:i,clamp:!0});if(u.length){var f=s.length,h=ld(r).splitAreaColors,v=Z(),c=0;if(h)for(var p=0;p<u.length;p++){var d=h.get(u[p].tickValue);if(d!=null){c=(d+(f-1)*p)%f;break}}var g=n.toGlobalCoord(u[0].coord),y=o.getAreaStyle();s=z(s)?s:[s];for(var p=1;p<u.length;p++){var m=n.toGlobalCoord(u[p].coord),_=void 0,S=void 0,w=void 0,x=void 0;n.isHorizontal()?(_=g,S=l.y,w=m-_,x=l.height,g=_+w):(_=l.x,S=g,w=l.width,x=m-S,g=S+x);var b=u[p-1].tickValue;b!=null&&v.set(b,c),e.add(new wt({anid:b!=null?"area_"+b:null,shape:{x:_,y:S,width:w,height:x},style:j({fill:s[c]},y),autoBatch:!0,silent:!0})),c=(c+1)%f}ld(r).splitAreaColors=v}}}function WD(r){ld(r).splitAreaColors=null}var c5=["axisLine","axisTickLabel","axisName"],p5=["splitArea","splitLine","minorSplitLine"],$D=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.axisPointerClass="CartesianAxisPointer",t}return e.prototype.render=function(t,a,n,i){this.group.removeAll();var o=this._axisGroup;if(this._axisGroup=new at,this.group.add(this._axisGroup),!!t.get("show")){var s=t.getCoordSysModel(),l=od(s,t),u=new Te(t,V({handleAutoShown:function(h){for(var v=s.coordinateSystem.getCartesians(),c=0;c<v.length;c++)if(Jp(v[c].getOtherAxis(t.axis).scale))return!0;return!1}},l));C(c5,u.add,u),this._axisGroup.add(u.getGroup()),C(p5,function(h){t.get([h,"show"])&&d5[h](this,this._axisGroup,t,s)},this);var f=i&&i.type==="changeAxisOrder"&&i.isInitSort;f||ll(o,this._axisGroup,t),r.prototype.render.call(this,t,a,n,i)}},e.prototype.remove=function(){WD(this)},e.type="cartesianAxis",e}(vi),d5={splitLine:function(r,e,t,a){var n=t.axis;if(!n.scale.isBlank()){var i=t.getModel("splitLine"),o=i.getModel("lineStyle"),s=o.get("color");s=z(s)?s:[s];for(var l=a.coordinateSystem.getRect(),u=n.isHorizontal(),f=0,h=n.getTicksCoords({tickModel:i}),v=[],c=[],p=o.getLineStyle(),d=0;d<h.length;d++){var g=n.toGlobalCoord(h[d].coord);u?(v[0]=g,v[1]=l.y,c[0]=g,c[1]=l.y+l.height):(v[0]=l.x,v[1]=g,c[0]=l.x+l.width,c[1]=g);var y=f++%s.length,m=h[d].tickValue,_=new te({anid:m!=null?"line_"+h[d].tickValue:null,autoBatch:!0,shape:{x1:v[0],y1:v[1],x2:c[0],y2:c[1]},style:j({stroke:s[y]},p),silent:!0});Qi(_.shape,p.lineWidth),e.add(_)}}},minorSplitLine:function(r,e,t,a){var n=t.axis,i=t.getModel("minorSplitLine"),o=i.getModel("lineStyle"),s=a.coordinateSystem.getRect(),l=n.isHorizontal(),u=n.getMinorTicksCoords();if(u.length)for(var f=[],h=[],v=o.getLineStyle(),c=0;c<u.length;c++)for(var p=0;p<u[c].length;p++){var d=n.toGlobalCoord(u[c][p].coord);l?(f[0]=d,f[1]=s.y,h[0]=d,h[1]=s.y+s.height):(f[0]=s.x,f[1]=d,h[0]=s.x+s.width,h[1]=d);var g=new te({anid:"minor_line_"+u[c][p].tickValue,autoBatch:!0,shape:{x1:f[0],y1:f[1],x2:h[0],y2:h[1]},style:v,silent:!0});Qi(g.shape,v.lineWidth),e.add(g)}},splitArea:function(r,e,t,a){HD(r,e,t,a)}},UD=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="xAxis",e}($D),g5=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=UD.type,t}return e.type="yAxis",e}($D),y5=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="grid",t}return e.prototype.render=function(t,a){this.group.removeAll(),t.get("show")&&this.group.add(new wt({shape:t.coordinateSystem.getRect(),style:j({fill:t.get("backgroundColor")},t.getItemStyle()),silent:!0,z2:-1}))},e.type="grid",e}(Ht),P1={offset:0};function YD(r){r.registerComponentView(y5),r.registerComponentModel(Hz),r.registerCoordinateSystem("cartesian2d",t5),ro(r,"x",nd,P1),ro(r,"y",nd,P1),r.registerComponentView(UD),r.registerComponentView(g5),r.registerPreprocessor(function(e){e.xAxis&&e.yAxis&&!e.grid&&(e.grid={})})}function m5(r){gt(YD),r.registerSeriesModel(Oz),r.registerChartView(Gz),r.registerLayout(ml("scatter"))}function _5(r){r.eachSeriesByType("radar",function(e){var t=e.getData(),a=[],n=e.coordinateSystem;if(n){var i=n.getIndicatorAxes();C(i,function(o,s){t.each(t.mapDimension(i[s].dim),function(l,u){a[u]=a[u]||[];var f=n.dataToPoint(l,s);a[u][s]=R1(f)?f:E1(n)})}),t.each(function(o){var s=TL(a[o],function(l){return R1(l)})||E1(n);a[o].push(s.slice()),t.setItemLayout(o,a[o])})}})}function R1(r){return!isNaN(r[0])&&!isNaN(r[1])}function E1(r){return[r.cx,r.cy]}function S5(r){var e=r.polar;if(e){z(e)||(e=[e]);var t=[];C(e,function(a,n){a.indicator?(a.type&&!a.shape&&(a.shape=a.type),r.radar=r.radar||[],z(r.radar)||(r.radar=[r.radar]),r.radar.push(a)):t.push(a)}),r.polar=t}C(r.series,function(a){a&&a.type==="radar"&&a.polarIndex&&(a.radarIndex=a.polarIndex)})}var x5=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){var i=t.coordinateSystem,o=this.group,s=t.getData(),l=this._data;function u(v,c){var p=v.getItemVisual(c,"symbol")||"circle";if(p!=="none"){var d=bo(v.getItemVisual(c,"symbolSize")),g=qt(p,-1,-1,2,2),y=v.getItemVisual(c,"symbolRotate")||0;return g.attr({style:{strokeNoScale:!0},z2:100,scaleX:d[0]/2,scaleY:d[1]/2,rotation:y*Math.PI/180||0}),g}}function f(v,c,p,d,g,y){p.removeAll();for(var m=0;m<c.length-1;m++){var _=u(d,g);_&&(_.__dimIdx=m,v[m]?(_.setPosition(v[m]),si[y?"initProps":"updateProps"](_,{x:c[m][0],y:c[m][1]},t,g)):_.setPosition(c[m]),p.add(_))}}function h(v){return G(v,function(c){return[i.cx,i.cy]})}s.diff(l).add(function(v){var c=s.getItemLayout(v);if(c){var p=new De,d=new Me,g={shape:{points:c}};p.shape.points=h(c),d.shape.points=h(c),Bt(p,g,t,v),Bt(d,g,t,v);var y=new at,m=new at;y.add(d),y.add(p),y.add(m),f(d.shape.points,c,m,s,v,!0),s.setItemGraphicEl(v,y)}}).update(function(v,c){var p=l.getItemGraphicEl(c),d=p.childAt(0),g=p.childAt(1),y=p.childAt(2),m={shape:{points:s.getItemLayout(v)}};m.shape.points&&(f(d.shape.points,m.shape.points,y,s,v,!1),Sr(g),Sr(d),Dt(d,m,t),Dt(g,m,t),s.setItemGraphicEl(v,p))}).remove(function(v){o.remove(l.getItemGraphicEl(v))}).execute(),s.eachItemGraphicEl(function(v,c){var p=s.getItemModel(c),d=v.childAt(0),g=v.childAt(1),y=v.childAt(2),m=s.getItemVisual(c,"style"),_=m.fill;o.add(v),d.useStyle(j(p.getModel("lineStyle").getLineStyle(),{fill:"none",stroke:_})),ue(d,p,"lineStyle"),ue(g,p,"areaStyle");var S=p.getModel("areaStyle"),w=S.isEmpty()&&S.parentModel.isEmpty();g.ignore=w,C(["emphasis","select","blur"],function(T){var A=p.getModel([T,"areaStyle"]),D=A.isEmpty()&&A.parentModel.isEmpty();g.ensureState(T).ignore=D&&w}),g.useStyle(j(S.getAreaStyle(),{fill:_,opacity:.7,decal:m.decal}));var x=p.getModel("emphasis"),b=x.getModel("itemStyle").getItemStyle();y.eachChild(function(T){if(T instanceof he){var A=T.style;T.useStyle(V({image:A.image,x:A.x,y:A.y,width:A.width,height:A.height},m))}else T.useStyle(m),T.setColor(_),T.style.strokeNoScale=!0;var D=T.ensureState("emphasis");D.style=rt(b);var M=s.getStore().get(s.getDimensionIndex(T.__dimIdx),c);(M==null||isNaN(M))&&(M=""),fe(T,re(p),{labelFetcher:s.hostModel,labelDataIndex:c,labelDimIndex:T.__dimIdx,defaultText:M,inheritColor:_,defaultOpacity:m.opacity})}),Ft(v,x.get("focus"),x.get("blurScope"),x.get("disabled"))}),this._data=s},e.prototype.remove=function(){this.group.removeAll(),this._data=null},e.type="radar",e}(Nt);const w5=x5;var b5=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t}return e.prototype.init=function(t){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new Sl(U(this.getData,this),U(this.getRawData,this))},e.prototype.getInitialData=function(t,a){return To(this,{generateCoord:"indicator_",generateCoordCount:1/0})},e.prototype.formatTooltip=function(t,a,n){var i=this.getData(),o=this.coordinateSystem,s=o.getIndicatorAxes(),l=this.getData().getName(t),u=l===""?this.name:l,f=HA(this,t);return ae("section",{header:u,sortBlocks:!0,blocks:G(s,function(h){var v=i.get(i.mapDimension(h.dim),t);return ae("nameValue",{markerType:"subItem",markerColor:f,name:h.name,value:v,sortParam:v})})})},e.prototype.getTooltipPosition=function(t){if(t!=null){for(var a=this.getData(),n=this.coordinateSystem,i=a.getValues(G(n.dimensions,function(u){return a.mapDimension(u)}),t),o=0,s=i.length;o<s;o++)if(!isNaN(i[o])){var l=n.getIndicatorAxes();return n.coordToPoint(l[o].dataToCoord(i[o]),o)}}},e.type="series.radar",e.dependencies=["radar"],e.defaultOption={z:2,colorBy:"data",coordinateSystem:"radar",legendHoverLink:!0,radarIndex:0,lineStyle:{width:2,type:"solid",join:"round"},label:{position:"top"},symbolSize:8},e}(zt);const T5=b5;var $o=zD.value;function hu(r,e){return j({show:e},r)}var A5=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.optionUpdated=function(){var t=this.get("boundaryGap"),a=this.get("splitNumber"),n=this.get("scale"),i=this.get("axisLine"),o=this.get("axisTick"),s=this.get("axisLabel"),l=this.get("axisName"),u=this.get(["axisName","show"]),f=this.get(["axisName","formatter"]),h=this.get("axisNameGap"),v=this.get("triggerEvent"),c=G(this.get("indicator")||[],function(p){p.max!=null&&p.max>0&&!p.min?p.min=0:p.min!=null&&p.min<0&&!p.max&&(p.max=0);var d=l;p.color!=null&&(d=j({color:p.color},l));var g=ft(rt(p),{boundaryGap:t,splitNumber:a,scale:n,axisLine:i,axisTick:o,axisLabel:s,name:p.text,showName:u,nameLocation:"end",nameGap:h,nameTextStyle:d,triggerEvent:v},!1);if($(f)){var y=g.name;g.name=f.replace("{value}",y??"")}else K(f)&&(g.name=f(g.name,g));var m=new Ot(g,null,this.ecModel);return Kt(m,pl.prototype),m.mainType="radar",m.componentIndex=this.componentIndex,m},this);this._indicatorModels=c},e.prototype.getIndicatorModels=function(){return this._indicatorModels},e.type="radar",e.defaultOption={z:0,center:["50%","50%"],radius:"75%",startAngle:90,axisName:{show:!0},boundaryGap:[0,0],splitNumber:5,axisNameGap:15,scale:!1,shape:"polygon",axisLine:ft({lineStyle:{color:"#bbb"}},$o.axisLine),axisLabel:hu($o.axisLabel,!1),axisTick:hu($o.axisTick,!1),splitLine:hu($o.splitLine,!0),splitArea:hu($o.splitArea,!0),indicator:[]},e}(Tt);const C5=A5;var D5=["axisLine","axisTickLabel","axisName"],M5=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){var i=this.group;i.removeAll(),this._buildAxes(t),this._buildSplitLineAndArea(t)},e.prototype._buildAxes=function(t){var a=t.coordinateSystem,n=a.getIndicatorAxes(),i=G(n,function(o){var s=o.model.get("showName")?o.name:"",l=new Te(o.model,{axisName:s,position:[a.cx,a.cy],rotation:o.angle,labelDirection:-1,tickDirection:-1,nameDirection:1});return l});C(i,function(o){C(D5,o.add,o),this.group.add(o.getGroup())},this)},e.prototype._buildSplitLineAndArea=function(t){var a=t.coordinateSystem,n=a.getIndicatorAxes();if(!n.length)return;var i=t.get("shape"),o=t.getModel("splitLine"),s=t.getModel("splitArea"),l=o.getModel("lineStyle"),u=s.getModel("areaStyle"),f=o.get("show"),h=s.get("show"),v=l.get("color"),c=u.get("color"),p=z(v)?v:[v],d=z(c)?c:[c],g=[],y=[];function m(R,E,N){var O=N%E.length;return R[O]=R[O]||[],O}if(i==="circle")for(var _=n[0].getTicksCoords(),S=a.cx,w=a.cy,x=0;x<_.length;x++){if(f){var b=m(g,p,x);g[b].push(new Qa({shape:{cx:S,cy:w,r:_[x].coord}}))}if(h&&x<_.length-1){var b=m(y,d,x);y[b].push(new eh({shape:{cx:S,cy:w,r0:_[x].coord,r:_[x+1].coord}}))}}else for(var T,A=G(n,function(R,E){var N=R.getTicksCoords();return T=T==null?N.length-1:Math.min(N.length-1,T),G(N,function(O){return a.coordToPoint(O.coord,E)})}),D=[],x=0;x<=T;x++){for(var M=[],I=0;I<n.length;I++)M.push(A[I][x]);if(M[0]&&M.push(M[0].slice()),f){var b=m(g,p,x);g[b].push(new Me({shape:{points:M}}))}if(h&&D){var b=m(y,d,x-1);y[b].push(new De({shape:{points:M.concat(D)}}))}D=M.slice().reverse()}var L=l.getLineStyle(),P=u.getAreaStyle();C(y,function(R,E){this.group.add(er(R,{style:j({stroke:"none",fill:d[E%d.length]},P),silent:!0}))},this),C(g,function(R,E){this.group.add(er(R,{style:j({fill:"none",stroke:p[E%p.length]},L),silent:!0}))},this)},e.type="radar",e}(Ht);const I5=M5;var L5=function(r){k(e,r);function e(t,a,n){var i=r.call(this,t,a,n)||this;return i.type="value",i.angle=0,i.name="",i}return e}(wr);const P5=L5;var R5=function(){function r(e,t,a){this.dimensions=[],this._model=e,this._indicatorAxes=G(e.getIndicatorModels(),function(n,i){var o="indicator_"+i,s=new P5(o,new Za);return s.name=n.get("name"),s.model=n,n.axis=s,this.dimensions.push(o),s},this),this.resize(e,a)}return r.prototype.getIndicatorAxes=function(){return this._indicatorAxes},r.prototype.dataToPoint=function(e,t){var a=this._indicatorAxes[t];return this.coordToPoint(a.dataToCoord(e),t)},r.prototype.coordToPoint=function(e,t){var a=this._indicatorAxes[t],n=a.angle,i=this.cx+e*Math.cos(n),o=this.cy-e*Math.sin(n);return[i,o]},r.prototype.pointToData=function(e){var t=e[0]-this.cx,a=e[1]-this.cy,n=Math.sqrt(t*t+a*a);t/=n,a/=n;for(var i=Math.atan2(-a,t),o=1/0,s,l=-1,u=0;u<this._indicatorAxes.length;u++){var f=this._indicatorAxes[u],h=Math.abs(i-f.angle);h<o&&(s=f,l=u,o=h)}return[l,+(s&&s.coordToData(n))]},r.prototype.resize=function(e,t){var a=e.get("center"),n=t.getWidth(),i=t.getHeight(),o=Math.min(n,i)/2;this.cx=W(a[0],n),this.cy=W(a[1],i),this.startAngle=e.get("startAngle")*Math.PI/180;var s=e.get("radius");($(s)||Ct(s))&&(s=[0,s]),this.r0=W(s[0],o),this.r=W(s[1],o),C(this._indicatorAxes,function(l,u){l.setExtent(this.r0,this.r);var f=this.startAngle+u*Math.PI*2/this._indicatorAxes.length;f=Math.atan2(Math.sin(f),Math.cos(f)),l.angle=f},this)},r.prototype.update=function(e,t){var a=this._indicatorAxes,n=this._model;C(a,function(s){s.scale.setExtent(1/0,-1/0)}),e.eachSeriesByType("radar",function(s,l){if(!(s.get("coordinateSystem")!=="radar"||e.getComponent("radar",s.get("radarIndex"))!==n)){var u=s.getData();C(a,function(f){f.scale.unionExtentFromData(u,u.mapDimension(f.dim))})}},this);var i=n.get("splitNumber"),o=new Za;o.setExtent(0,i),o.setInterval(1),C(a,function(s,l){GD(s.scale,s.model,o)})},r.prototype.convertToPixel=function(e,t,a){return console.warn("Not implemented."),null},r.prototype.convertFromPixel=function(e,t,a){return console.warn("Not implemented."),null},r.prototype.containPoint=function(e){return console.warn("Not implemented."),!1},r.create=function(e,t){var a=[];return e.eachComponent("radar",function(n){var i=new r(n,e,t);a.push(i),n.coordinateSystem=i}),e.eachSeriesByType("radar",function(n){n.get("coordinateSystem")==="radar"&&(n.coordinateSystem=a[n.get("radarIndex")||0])}),a},r.dimensions=[],r}();const E5=R5;function k5(r){r.registerCoordinateSystem("radar",E5),r.registerComponentModel(C5),r.registerComponentView(I5),r.registerVisual({seriesType:"radar",reset:function(e){var t=e.getData();t.each(function(a){t.setItemVisual(a,"legendIcon","roundRect")}),t.setVisual("legendIcon","roundRect")}})}function O5(r){gt(k5),r.registerChartView(w5),r.registerSeriesModel(T5),r.registerLayout(_5),r.registerProcessor(_l("radar")),r.registerPreprocessor(S5)}var k1="\0_ec_interaction_mutex";function N5(r,e,t){var a=iy(r);a[e]=t}function B5(r,e,t){var a=iy(r),n=a[e];n===t&&(a[e]=null)}function O1(r,e){return!!iy(r)[e]}function iy(r){return r[k1]||(r[k1]={})}Ur({type:"takeGlobalCursor",event:"globalCursorTaken",update:"update"},Yt);var V5=function(r){k(e,r);function e(t){var a=r.call(this)||this;a._zr=t;var n=U(a._mousedownHandler,a),i=U(a._mousemoveHandler,a),o=U(a._mouseupHandler,a),s=U(a._mousewheelHandler,a),l=U(a._pinchHandler,a);return a.enable=function(u,f){this.disable(),this._opt=j(rt(f)||{},{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0}),u==null&&(u=!0),(u===!0||u==="move"||u==="pan")&&(t.on("mousedown",n),t.on("mousemove",i),t.on("mouseup",o)),(u===!0||u==="scale"||u==="zoom")&&(t.on("mousewheel",s),t.on("pinch",l))},a.disable=function(){t.off("mousedown",n),t.off("mousemove",i),t.off("mouseup",o),t.off("mousewheel",s),t.off("pinch",l)},a}return e.prototype.isDragging=function(){return this._dragging},e.prototype.isPinching=function(){return this._pinching},e.prototype.setPointerChecker=function(t){this.pointerChecker=t},e.prototype.dispose=function(){this.disable()},e.prototype._mousedownHandler=function(t){if(!sm(t)){for(var a=t.target;a;){if(a.draggable)return;a=a.__hostTarget||a.parent}var n=t.offsetX,i=t.offsetY;this.pointerChecker&&this.pointerChecker(t,n,i)&&(this._x=n,this._y=i,this._dragging=!0)}},e.prototype._mousemoveHandler=function(t){if(!(!this._dragging||!Wu("moveOnMouseMove",t,this._opt)||t.gestureEvent==="pinch"||O1(this._zr,"globalPan"))){var a=t.offsetX,n=t.offsetY,i=this._x,o=this._y,s=a-i,l=n-o;this._x=a,this._y=n,this._opt.preventDefaultMouseMove&&ia(t.event),ZD(this,"pan","moveOnMouseMove",t,{dx:s,dy:l,oldX:i,oldY:o,newX:a,newY:n,isAvailableBehavior:null})}},e.prototype._mouseupHandler=function(t){sm(t)||(this._dragging=!1)},e.prototype._mousewheelHandler=function(t){var a=Wu("zoomOnMouseWheel",t,this._opt),n=Wu("moveOnMouseWheel",t,this._opt),i=t.wheelDelta,o=Math.abs(i),s=t.offsetX,l=t.offsetY;if(!(i===0||!a&&!n)){if(a){var u=o>3?1.4:o>1?1.2:1.1,f=i>0?u:1/u;Jv(this,"zoom","zoomOnMouseWheel",t,{scale:f,originX:s,originY:l,isAvailableBehavior:null})}if(n){var h=Math.abs(i),v=(i>0?1:-1)*(h>3?.4:h>1?.15:.05);Jv(this,"scrollMove","moveOnMouseWheel",t,{scrollDelta:v,originX:s,originY:l,isAvailableBehavior:null})}}},e.prototype._pinchHandler=function(t){if(!O1(this._zr,"globalPan")){var a=t.pinchScale>1?1.1:1/1.1;Jv(this,"zoom",null,t,{scale:a,originX:t.pinchX,originY:t.pinchY,isAvailableBehavior:null})}},e}(or);function Jv(r,e,t,a,n){r.pointerChecker&&r.pointerChecker(a,n.originX,n.originY)&&(ia(a.event),ZD(r,e,t,a,n))}function ZD(r,e,t,a,n){n.isAvailableBehavior=U(Wu,null,t,a),r.trigger(e,n)}function Wu(r,e,t){var a=t[r];return!r||a&&(!$(a)||e.event[a+"Key"])}const xl=V5;function oy(r,e,t){var a=r.target;a.x+=e,a.y+=t,a.dirty()}function sy(r,e,t,a){var n=r.target,i=r.zoomLimit,o=r.zoom=r.zoom||1;if(o*=e,i){var s=i.min||0,l=i.max||1/0;o=Math.max(Math.min(l,o),s)}var u=o/r.zoom;r.zoom=o,n.x-=(t-n.x)*(u-1),n.y-=(a-n.y)*(u-1),n.scaleX*=u,n.scaleY*=u,n.dirty()}var z5={axisPointer:1,tooltip:1,brush:1};function xh(r,e,t){var a=e.getComponentByElement(r.topTarget),n=a&&a.coordinateSystem;return a&&a!==t&&!z5.hasOwnProperty(a.mainType)&&n&&n.model!==t}function XD(r){if($(r)){var e=new DOMParser;r=e.parseFromString(r,"text/xml")}var t=r;for(t.nodeType===9&&(t=t.firstChild);t.nodeName.toLowerCase()!=="svg"||t.nodeType!==1;)t=t.nextSibling;return t}var jv,Af={fill:"fill",stroke:"stroke","stroke-width":"lineWidth",opacity:"opacity","fill-opacity":"fillOpacity","stroke-opacity":"strokeOpacity","stroke-dasharray":"lineDash","stroke-dashoffset":"lineDashOffset","stroke-linecap":"lineCap","stroke-linejoin":"lineJoin","stroke-miterlimit":"miterLimit","font-family":"fontFamily","font-size":"fontSize","font-style":"fontStyle","font-weight":"fontWeight","text-anchor":"textAlign",visibility:"visibility",display:"display"},N1=_t(Af),Cf={"alignment-baseline":"textBaseline","stop-color":"stopColor"},B1=_t(Cf),G5=function(){function r(){this._defs={},this._root=null}return r.prototype.parse=function(e,t){t=t||{};var a=XD(e);this._defsUsePending=[];var n=new at;this._root=n;var i=[],o=a.getAttribute("viewBox")||"",s=parseFloat(a.getAttribute("width")||t.width),l=parseFloat(a.getAttribute("height")||t.height);isNaN(s)&&(s=null),isNaN(l)&&(l=null),Ve(a,n,null,!0,!1);for(var u=a.firstChild;u;)this._parseNode(u,n,i,null,!1,!1),u=u.nextSibling;W5(this._defs,this._defsUsePending),this._defsUsePending=[];var f,h;if(o){var v=wh(o);v.length>=4&&(f={x:parseFloat(v[0]||0),y:parseFloat(v[1]||0),width:parseFloat(v[2]),height:parseFloat(v[3])})}if(f&&s!=null&&l!=null&&(h=KD(f,{x:0,y:0,width:s,height:l}),!t.ignoreViewBox)){var c=n;n=new at,n.add(c),c.scaleX=c.scaleY=h.scale,c.x=h.x,c.y=h.y}return!t.ignoreRootClip&&s!=null&&l!=null&&n.setClipPath(new wt({shape:{x:0,y:0,width:s,height:l}})),{root:n,width:s,height:l,viewBoxRect:f,viewBoxTransform:h,named:i}},r.prototype._parseNode=function(e,t,a,n,i,o){var s=e.nodeName.toLowerCase(),l,u=n;if(s==="defs"&&(i=!0),s==="text"&&(o=!0),s==="defs"||s==="switch")l=t;else{if(!i){var f=jv[s];if(f&&Y(jv,s)){l=f.call(this,e,t);var h=e.getAttribute("name");if(h){var v={name:h,namedFrom:null,svgNodeTagLower:s,el:l};a.push(v),s==="g"&&(u=v)}else n&&a.push({name:n.name,namedFrom:n,svgNodeTagLower:s,el:l});t.add(l)}}var c=V1[s];if(c&&Y(V1,s)){var p=c.call(this,e),d=e.getAttribute("id");d&&(this._defs[d]=p)}}if(l&&l.isGroup)for(var g=e.firstChild;g;)g.nodeType===1?this._parseNode(g,l,a,u,i,o):g.nodeType===3&&o&&this._parseText(g,l),g=g.nextSibling},r.prototype._parseText=function(e,t){var a=new Os({style:{text:e.textContent},silent:!0,x:this._textX||0,y:this._textY||0});Ye(t,a),Ve(e,a,this._defsUsePending,!1,!1),F5(a,t);var n=a.style,i=n.fontSize;i&&i<9&&(n.fontSize=9,a.scaleX*=i/9,a.scaleY*=i/9);var o=(n.fontSize||n.fontFamily)&&[n.fontStyle,n.fontWeight,(n.fontSize||12)+"px",n.fontFamily||"sans-serif"].join(" ");n.font=o;var s=a.getBoundingRect();return this._textX+=s.width,t.add(a),a},r.internalField=function(){jv={g:function(e,t){var a=new at;return Ye(t,a),Ve(e,a,this._defsUsePending,!1,!1),a},rect:function(e,t){var a=new wt;return Ye(t,a),Ve(e,a,this._defsUsePending,!1,!1),a.setShape({x:parseFloat(e.getAttribute("x")||"0"),y:parseFloat(e.getAttribute("y")||"0"),width:parseFloat(e.getAttribute("width")||"0"),height:parseFloat(e.getAttribute("height")||"0")}),a.silent=!0,a},circle:function(e,t){var a=new Qa;return Ye(t,a),Ve(e,a,this._defsUsePending,!1,!1),a.setShape({cx:parseFloat(e.getAttribute("cx")||"0"),cy:parseFloat(e.getAttribute("cy")||"0"),r:parseFloat(e.getAttribute("r")||"0")}),a.silent=!0,a},line:function(e,t){var a=new te;return Ye(t,a),Ve(e,a,this._defsUsePending,!1,!1),a.setShape({x1:parseFloat(e.getAttribute("x1")||"0"),y1:parseFloat(e.getAttribute("y1")||"0"),x2:parseFloat(e.getAttribute("x2")||"0"),y2:parseFloat(e.getAttribute("y2")||"0")}),a.silent=!0,a},ellipse:function(e,t){var a=new cg;return Ye(t,a),Ve(e,a,this._defsUsePending,!1,!1),a.setShape({cx:parseFloat(e.getAttribute("cx")||"0"),cy:parseFloat(e.getAttribute("cy")||"0"),rx:parseFloat(e.getAttribute("rx")||"0"),ry:parseFloat(e.getAttribute("ry")||"0")}),a.silent=!0,a},polygon:function(e,t){var a=e.getAttribute("points"),n;a&&(n=F1(a));var i=new De({shape:{points:n||[]},silent:!0});return Ye(t,i),Ve(e,i,this._defsUsePending,!1,!1),i},polyline:function(e,t){var a=e.getAttribute("points"),n;a&&(n=F1(a));var i=new Me({shape:{points:n||[]},silent:!0});return Ye(t,i),Ve(e,i,this._defsUsePending,!1,!1),i},image:function(e,t){var a=new he;return Ye(t,a),Ve(e,a,this._defsUsePending,!1,!1),a.setStyle({image:e.getAttribute("xlink:href")||e.getAttribute("href"),x:+e.getAttribute("x"),y:+e.getAttribute("y"),width:+e.getAttribute("width"),height:+e.getAttribute("height")}),a.silent=!0,a},text:function(e,t){var a=e.getAttribute("x")||"0",n=e.getAttribute("y")||"0",i=e.getAttribute("dx")||"0",o=e.getAttribute("dy")||"0";this._textX=parseFloat(a)+parseFloat(i),this._textY=parseFloat(n)+parseFloat(o);var s=new at;return Ye(t,s),Ve(e,s,this._defsUsePending,!1,!0),s},tspan:function(e,t){var a=e.getAttribute("x"),n=e.getAttribute("y");a!=null&&(this._textX=parseFloat(a)),n!=null&&(this._textY=parseFloat(n));var i=e.getAttribute("dx")||"0",o=e.getAttribute("dy")||"0",s=new at;return Ye(t,s),Ve(e,s,this._defsUsePending,!1,!0),this._textX+=parseFloat(i),this._textY+=parseFloat(o),s},path:function(e,t){var a=e.getAttribute("d")||"",n=LT(a);return Ye(t,n),Ve(e,n,this._defsUsePending,!1,!1),n.silent=!0,n}}}(),r}(),V1={lineargradient:function(r){var e=parseInt(r.getAttribute("x1")||"0",10),t=parseInt(r.getAttribute("y1")||"0",10),a=parseInt(r.getAttribute("x2")||"10",10),n=parseInt(r.getAttribute("y2")||"0",10),i=new ho(e,t,a,n);return z1(r,i),G1(r,i),i},radialgradient:function(r){var e=parseInt(r.getAttribute("cx")||"0",10),t=parseInt(r.getAttribute("cy")||"0",10),a=parseInt(r.getAttribute("r")||"0",10),n=new GT(e,t,a);return z1(r,n),G1(r,n),n}};function z1(r,e){var t=r.getAttribute("gradientUnits");t==="userSpaceOnUse"&&(e.global=!0)}function G1(r,e){for(var t=r.firstChild;t;){if(t.nodeType===1&&t.nodeName.toLocaleLowerCase()==="stop"){var a=t.getAttribute("offset"),n=void 0;a&&a.indexOf("%")>0?n=parseInt(a,10)/100:a?n=parseFloat(a):n=0;var i={};qD(t,i,i);var o=i.stopColor||t.getAttribute("stop-color")||"#000000";e.colorStops.push({offset:n,color:o})}t=t.nextSibling}}function Ye(r,e){r&&r.__inheritedStyle&&(e.__inheritedStyle||(e.__inheritedStyle={}),j(e.__inheritedStyle,r.__inheritedStyle))}function F1(r){for(var e=wh(r),t=[],a=0;a<e.length;a+=2){var n=parseFloat(e[a]),i=parseFloat(e[a+1]);t.push([n,i])}return t}function Ve(r,e,t,a,n){var i=e,o=i.__inheritedStyle=i.__inheritedStyle||{},s={};r.nodeType===1&&(Y5(r,e),qD(r,o,s),a||Z5(r,o,s)),i.style=i.style||{},o.fill!=null&&(i.style.fill=H1(i,"fill",o.fill,t)),o.stroke!=null&&(i.style.stroke=H1(i,"stroke",o.stroke,t)),C(["lineWidth","opacity","fillOpacity","strokeOpacity","miterLimit","fontSize"],function(l){o[l]!=null&&(i.style[l]=parseFloat(o[l]))}),C(["lineDashOffset","lineCap","lineJoin","fontWeight","fontFamily","fontStyle","textAlign"],function(l){o[l]!=null&&(i.style[l]=o[l])}),n&&(i.__selfStyle=s),o.lineDash&&(i.style.lineDash=G(wh(o.lineDash),function(l){return parseFloat(l)})),(o.visibility==="hidden"||o.visibility==="collapse")&&(i.invisible=!0),o.display==="none"&&(i.ignore=!0)}function F5(r,e){var t=e.__selfStyle;if(t){var a=t.textBaseline,n=a;!a||a==="auto"||a==="baseline"?n="alphabetic":a==="before-edge"||a==="text-before-edge"?n="top":a==="after-edge"||a==="text-after-edge"?n="bottom":(a==="central"||a==="mathematical")&&(n="middle"),r.style.textBaseline=n}var i=e.__inheritedStyle;if(i){var o=i.textAlign,s=o;o&&(o==="middle"&&(s="center"),r.style.textAlign=s)}}var H5=/^url\(\s*#(.*?)\)/;function H1(r,e,t,a){var n=t&&t.match(H5);if(n){var i=dr(n[1]);a.push([r,e,i]);return}return t==="none"&&(t=null),t}function W5(r,e){for(var t=0;t<e.length;t++){var a=e[t];a[0].style[a[1]]=r[a[2]]}}var $5=/-?([0-9]*\.)?[0-9]+([eE]-?[0-9]+)?/g;function wh(r){return r.match($5)||[]}var U5=/(translate|scale|rotate|skewX|skewY|matrix)\(([\-\s0-9\.eE,]*)\)/g,tc=Math.PI/180;function Y5(r,e){var t=r.getAttribute("transform");if(t){t=t.replace(/,/g," ");var a=[],n=null;t.replace(U5,function(h,v,c){return a.push(v,c),""});for(var i=a.length-1;i>0;i-=2){var o=a[i],s=a[i-1],l=wh(o);switch(n=n||Fe(),s){case"translate":Gr(n,n,[parseFloat(l[0]),parseFloat(l[1]||"0")]);break;case"scale":Kd(n,n,[parseFloat(l[0]),parseFloat(l[1]||l[0])]);break;case"rotate":oi(n,n,-parseFloat(l[0])*tc,[parseFloat(l[1]||"0"),parseFloat(l[2]||"0")]);break;case"skewX":var u=Math.tan(parseFloat(l[0])*tc);ea(n,[1,0,u,1,0,0],n);break;case"skewY":var f=Math.tan(parseFloat(l[0])*tc);ea(n,[1,f,0,1,0,0],n);break;case"matrix":n[0]=parseFloat(l[0]),n[1]=parseFloat(l[1]),n[2]=parseFloat(l[2]),n[3]=parseFloat(l[3]),n[4]=parseFloat(l[4]),n[5]=parseFloat(l[5]);break}}e.setLocalTransform(n)}}var W1=/([^\s:;]+)\s*:\s*([^:;]+)/g;function qD(r,e,t){var a=r.getAttribute("style");if(a){W1.lastIndex=0;for(var n;(n=W1.exec(a))!=null;){var i=n[1],o=Y(Af,i)?Af[i]:null;o&&(e[o]=n[2]);var s=Y(Cf,i)?Cf[i]:null;s&&(t[s]=n[2])}}}function Z5(r,e,t){for(var a=0;a<N1.length;a++){var n=N1[a],i=r.getAttribute(n);i!=null&&(e[Af[n]]=i)}for(var a=0;a<B1.length;a++){var n=B1[a],i=r.getAttribute(n);i!=null&&(t[Cf[n]]=i)}}function KD(r,e){var t=e.width/r.width,a=e.height/r.height,n=Math.min(t,a);return{scale:n,x:-(r.x+r.width/2)*n+(e.x+e.width/2),y:-(r.y+r.height/2)*n+(e.y+e.height/2)}}function X5(r,e){var t=new G5;return t.parse(r,e)}var q5=Z(["rect","circle","line","ellipse","polygon","polyline","path","text","tspan","g"]),K5=function(){function r(e,t){this.type="geoSVG",this._usedGraphicMap=Z(),this._freedGraphics=[],this._mapName=e,this._parsedXML=XD(t)}return r.prototype.load=function(){var e=this._firstGraphic;if(!e){e=this._firstGraphic=this._buildGraphic(this._parsedXML),this._freedGraphics.push(e),this._boundingRect=this._firstGraphic.boundingRect.clone();var t=J5(e.named),a=t.regions,n=t.regionsMap;this._regions=a,this._regionsMap=n}return{boundingRect:this._boundingRect,regions:this._regions,regionsMap:this._regionsMap}},r.prototype._buildGraphic=function(e){var t,a;try{t=e&&X5(e,{ignoreViewBox:!0,ignoreRootClip:!0})||{},a=t.root,Ae(a!=null)}catch(g){throw new Error(`Invalid svg format
`+g.message)}var n=new at;n.add(a),n.isGeoSVGGraphicRoot=!0;var i=t.width,o=t.height,s=t.viewBoxRect,l=this._boundingRect;if(!l){var u=void 0,f=void 0,h=void 0,v=void 0;if(i!=null?(u=0,h=i):s&&(u=s.x,h=s.width),o!=null?(f=0,v=o):s&&(f=s.y,v=s.height),u==null||f==null){var c=a.getBoundingRect();u==null&&(u=c.x,h=c.width),f==null&&(f=c.y,v=c.height)}l=this._boundingRect=new ht(u,f,h,v)}if(s){var p=KD(s,l);a.scaleX=a.scaleY=p.scale,a.x=p.x,a.y=p.y}n.setClipPath(new wt({shape:l.plain()}));var d=[];return C(t.named,function(g){q5.get(g.svgNodeTagLower)!=null&&(d.push(g),Q5(g.el))}),{root:n,boundingRect:l,named:d}},r.prototype.useGraphic=function(e){var t=this._usedGraphicMap,a=t.get(e);return a||(a=this._freedGraphics.pop()||this._buildGraphic(this._parsedXML),t.set(e,a),a)},r.prototype.freeGraphic=function(e){var t=this._usedGraphicMap,a=t.get(e);a&&(t.removeKey(e),this._freedGraphics.push(a))},r}();function Q5(r){r.silent=!1,r.isGroup&&r.traverse(function(e){e.silent=!1})}function J5(r){var e=[],t=Z();return C(r,function(a){if(a.namedFrom==null){var n=new wB(a.name,a.el);e.push(n),t.set(a.name,n)}}),{regions:e,regionsMap:t}}var ud=[126,25],$1="南海诸岛",Cn=[[[0,3.5],[7,11.2],[15,11.9],[30,7],[42,.7],[52,.7],[56,7.7],[59,.7],[64,.7],[64,0],[5,0],[0,3.5]],[[13,16.1],[19,14.7],[16,21.7],[11,23.1],[13,16.1]],[[12,32.2],[14,38.5],[15,38.5],[13,32.2],[12,32.2]],[[16,47.6],[12,53.2],[13,53.2],[18,47.6],[16,47.6]],[[6,64.4],[8,70],[9,70],[8,64.4],[6,64.4]],[[23,82.6],[29,79.8],[30,79.8],[25,82.6],[23,82.6]],[[37,70.7],[43,62.3],[44,62.3],[39,70.7],[37,70.7]],[[48,51.1],[51,45.5],[53,45.5],[50,51.1],[48,51.1]],[[51,35],[51,28.7],[53,28.7],[53,35],[51,35]],[[52,22.4],[55,17.5],[56,17.5],[53,22.4],[52,22.4]],[[58,12.6],[62,7],[63,7],[60,12.6],[58,12.6]],[[0,3.5],[0,93.1],[64,93.1],[64,0],[63,0],[63,92.4],[1,92.4],[1,3.5],[0,3.5]]];for(var Tn=0;Tn<Cn.length;Tn++)for(var Ci=0;Ci<Cn[Tn].length;Ci++)Cn[Tn][Ci][0]/=10.5,Cn[Tn][Ci][1]/=-10.5/.75,Cn[Tn][Ci][0]+=ud[0],Cn[Tn][Ci][1]+=ud[1];function j5(r,e){if(r==="china"){for(var t=0;t<e.length;t++)if(e[t].name===$1)return;e.push(new XC($1,G(Cn,function(a){return{type:"polygon",exterior:a}}),ud))}}var tG={南海诸岛:[32,80],广东:[0,-10],香港:[10,5],澳门:[-10,10],天津:[5,5]};function eG(r,e){if(r==="china"){var t=tG[e.name];if(t){var a=e.getCenter();a[0]+=t[0]/10.5,a[1]+=-t[1]/(10.5/.75),e.setCenter(a)}}}var rG=[[[123.45165252685547,25.73527164402261],[123.49731445312499,25.73527164402261],[123.49731445312499,25.750734064600884],[123.45165252685547,25.750734064600884],[123.45165252685547,25.73527164402261]]];function aG(r,e){r==="china"&&e.name==="台湾"&&e.geometries.push({type:"polygon",exterior:rG[0]})}var nG="name",iG=function(){function r(e,t,a){this.type="geoJSON",this._parsedMap=Z(),this._mapName=e,this._specialAreas=a,this._geoJSON=sG(t)}return r.prototype.load=function(e,t){t=t||nG;var a=this._parsedMap.get(t);if(!a){var n=this._parseToRegions(t);a=this._parsedMap.set(t,{regions:n,boundingRect:oG(n)})}var i=Z(),o=[];return C(a.regions,function(s){var l=s.name;e&&Y(e,l)&&(s=s.cloneShallow(l=e[l])),o.push(s),i.set(l,s)}),{regions:o,boundingRect:a.boundingRect||new ht(0,0,0,0),regionsMap:i}},r.prototype._parseToRegions=function(e){var t=this._mapName,a=this._geoJSON,n;try{n=a?TB(a,e):[]}catch(i){throw new Error(`Invalid geoJson format
`+i.message)}return j5(t,n),C(n,function(i){var o=i.name;eG(t,i),aG(t,i);var s=this._specialAreas&&this._specialAreas[o];s&&i.transformTo(s.left,s.top,s.width,s.height)},this),n},r.prototype.getMapForUser=function(){return{geoJson:this._geoJSON,geoJSON:this._geoJSON,specialAreas:this._specialAreas}},r}();function oG(r){for(var e,t=0;t<r.length;t++){var a=r[t].getBoundingRect();e=e||a.clone(),e.union(a)}return e}function sG(r){return $(r)?typeof JSON<"u"&&JSON.parse?JSON.parse(r):new Function("return ("+r+");")():r}var Uo=Z();const fa={registerMap:function(r,e,t){if(e.svg){var a=new K5(r,e.svg);Uo.set(r,a)}else{var n=e.geoJson||e.geoJSON;n&&!e.features?t=e.specialAreas:n=e;var a=new iG(r,n,t);Uo.set(r,a)}},getGeoResource:function(r){return Uo.get(r)},getMapForUser:function(r){var e=Uo.get(r);return e&&e.type==="geoJSON"&&e.getMapForUser()},load:function(r,e,t){var a=Uo.get(r);if(a)return a.load(e,t)}};var ly=["rect","circle","line","ellipse","polygon","polyline","path"],lG=Z(ly),uG=Z(ly.concat(["g"])),fG=Z(ly.concat(["g"])),QD=bt();function vu(r){var e=r.getItemStyle(),t=r.get("areaColor");return t!=null&&(e.fill=t),e}function U1(r){var e=r.style;e&&(e.stroke=e.stroke||e.fill,e.fill=null)}var hG=function(){function r(e){var t=new at;this.uid=go("ec_map_draw"),this._controller=new xl(e.getZr()),this._controllerHost={target:t},this.group=t,t.add(this._regionsGroup=new at),t.add(this._svgGroup=new at)}return r.prototype.draw=function(e,t,a,n,i){var o=e.mainType==="geo",s=e.getData&&e.getData();o&&t.eachComponent({mainType:"series",subType:"map"},function(y){!s&&y.getHostGeoModel()===e&&(s=y.getData())});var l=e.coordinateSystem,u=this._regionsGroup,f=this.group,h=l.getTransformInfo(),v=h.raw,c=h.roam,p=!u.childAt(0)||i;p?(f.x=c.x,f.y=c.y,f.scaleX=c.scaleX,f.scaleY=c.scaleY,f.dirty()):Dt(f,c,e);var d=s&&s.getVisual("visualMeta")&&s.getVisual("visualMeta").length>0,g={api:a,geo:l,mapOrGeoModel:e,data:s,isVisualEncodedByVisualMap:d,isGeo:o,transformInfoRaw:v};l.resourceType==="geoJSON"?this._buildGeoJSON(g):l.resourceType==="geoSVG"&&this._buildSVG(g),this._updateController(e,t,a),this._updateMapSelectHandler(e,u,a,n)},r.prototype._buildGeoJSON=function(e){var t=this._regionsGroupByName=Z(),a=Z(),n=this._regionsGroup,i=e.transformInfoRaw,o=e.mapOrGeoModel,s=e.data,l=e.geo.projection,u=l&&l.stream;function f(c,p){return p&&(c=p(c)),c&&[c[0]*i.scaleX+i.x,c[1]*i.scaleY+i.y]}function h(c){for(var p=[],d=!u&&l&&l.project,g=0;g<c.length;++g){var y=f(c[g],d);y&&p.push(y)}return p}function v(c){return{shape:{points:h(c)}}}n.removeAll(),C(e.geo.regions,function(c){var p=c.name,d=t.get(p),g=a.get(p)||{},y=g.dataIdx,m=g.regionModel;d||(d=t.set(p,new at),n.add(d),y=s?s.indexOfName(p):null,m=e.isGeo?o.getRegionModel(p):s?s.getItemModel(y):null,a.set(p,{dataIdx:y,regionModel:m}));var _=[],S=[];C(c.geometries,function(b){if(b.type==="polygon"){var T=[b.exterior].concat(b.interiors||[]);u&&(T=Q1(T,u)),C(T,function(D){_.push(new De(v(D)))})}else{var A=b.points;u&&(A=Q1(A,u,!0)),C(A,function(D){S.push(new Me(v(D)))})}});var w=f(c.getCenter(),l&&l.project);function x(b,T){if(b.length){var A=new dg({culling:!0,segmentIgnoreThreshold:1,shape:{paths:b}});d.add(A),Y1(e,A,y,m),Z1(e,A,p,m,o,y,w),T&&(U1(A),C(A.states,U1))}}x(_),x(S,!0)}),t.each(function(c,p){var d=a.get(p),g=d.dataIdx,y=d.regionModel;X1(e,c,p,y,o,g),q1(e,c,p,y,o),K1(e,c,p,y,o)},this)},r.prototype._buildSVG=function(e){var t=e.geo.map,a=e.transformInfoRaw;this._svgGroup.x=a.x,this._svgGroup.y=a.y,this._svgGroup.scaleX=a.scaleX,this._svgGroup.scaleY=a.scaleY,this._svgResourceChanged(t)&&(this._freeSVG(),this._useSVG(t));var n=this._svgDispatcherMap=Z(),i=!1;C(this._svgGraphicRecord.named,function(o){var s=o.name,l=e.mapOrGeoModel,u=e.data,f=o.svgNodeTagLower,h=o.el,v=u?u.indexOfName(s):null,c=l.getRegionModel(s);if(lG.get(f)!=null&&h instanceof ir&&Y1(e,h,v,c),h instanceof ir&&(h.culling=!0),h.z2EmphasisLift=0,!o.namedFrom&&(fG.get(f)!=null&&Z1(e,h,s,c,l,v,null),X1(e,h,s,c,l,v),q1(e,h,s,c,l),uG.get(f)!=null)){var p=K1(e,h,s,c,l);p==="self"&&(i=!0);var d=n.get(s)||n.set(s,[]);d.push(h)}},this),this._enableBlurEntireSVG(i,e)},r.prototype._enableBlurEntireSVG=function(e,t){if(e&&t.isGeo){var a=t.mapOrGeoModel.getModel(["blur","itemStyle"]).getItemStyle(),n=a.opacity;this._svgGraphicRecord.root.traverse(function(i){if(!i.isGroup){ei(i);var o=i.ensureState("blur").style||{};o.opacity==null&&n!=null&&(o.opacity=n),i.ensureState("emphasis")}})}},r.prototype.remove=function(){this._regionsGroup.removeAll(),this._regionsGroupByName=null,this._svgGroup.removeAll(),this._freeSVG(),this._controller.dispose(),this._controllerHost=null},r.prototype.findHighDownDispatchers=function(e,t){if(e==null)return[];var a=t.coordinateSystem;if(a.resourceType==="geoJSON"){var n=this._regionsGroupByName;if(n){var i=n.get(e);return i?[i]:[]}}else if(a.resourceType==="geoSVG")return this._svgDispatcherMap&&this._svgDispatcherMap.get(e)||[]},r.prototype._svgResourceChanged=function(e){return this._svgMapName!==e},r.prototype._useSVG=function(e){var t=fa.getGeoResource(e);if(t&&t.type==="geoSVG"){var a=t.useGraphic(this.uid);this._svgGroup.add(a.root),this._svgGraphicRecord=a,this._svgMapName=e}},r.prototype._freeSVG=function(){var e=this._svgMapName;if(e!=null){var t=fa.getGeoResource(e);t&&t.type==="geoSVG"&&t.freeGraphic(this.uid),this._svgGraphicRecord=null,this._svgDispatcherMap=null,this._svgGroup.removeAll(),this._svgMapName=null}},r.prototype._updateController=function(e,t,a){var n=e.coordinateSystem,i=this._controller,o=this._controllerHost;o.zoomLimit=e.get("scaleLimit"),o.zoom=n.getZoom(),i.enable(e.get("roam")||!1);var s=e.mainType;function l(){var u={type:"geoRoam",componentType:s};return u[s+"Id"]=e.id,u}i.off("pan").on("pan",function(u){this._mouseDownFlag=!1,oy(o,u.dx,u.dy),a.dispatchAction(V(l(),{dx:u.dx,dy:u.dy,animation:{duration:0}}))},this),i.off("zoom").on("zoom",function(u){this._mouseDownFlag=!1,sy(o,u.scale,u.originX,u.originY),a.dispatchAction(V(l(),{zoom:u.scale,originX:u.originX,originY:u.originY,animation:{duration:0}}))},this),i.setPointerChecker(function(u,f,h){return n.containPoint([f,h])&&!xh(u,a,e)})},r.prototype.resetForLabelLayout=function(){this.group.traverse(function(e){var t=e.getTextContent();t&&(t.ignore=QD(t).ignore)})},r.prototype._updateMapSelectHandler=function(e,t,a,n){var i=this;t.off("mousedown"),t.off("click"),e.get("selectedMode")&&(t.on("mousedown",function(){i._mouseDownFlag=!0}),t.on("click",function(o){i._mouseDownFlag&&(i._mouseDownFlag=!1)}))},r}();function Y1(r,e,t,a){var n=a.getModel("itemStyle"),i=a.getModel(["emphasis","itemStyle"]),o=a.getModel(["blur","itemStyle"]),s=a.getModel(["select","itemStyle"]),l=vu(n),u=vu(i),f=vu(s),h=vu(o),v=r.data;if(v){var c=v.getItemVisual(t,"style"),p=v.getItemVisual(t,"decal");r.isVisualEncodedByVisualMap&&c.fill&&(l.fill=c.fill),p&&(l.decal=ji(p,r.api))}e.setStyle(l),e.style.strokeNoScale=!0,e.ensureState("emphasis").style=u,e.ensureState("select").style=f,e.ensureState("blur").style=h,ei(e)}function Z1(r,e,t,a,n,i,o){var s=r.data,l=r.isGeo,u=s&&isNaN(s.get(s.mapDimension("value"),i)),f=s&&s.getItemLayout(i);if(l||u||f&&f.showLabel){var h=l?t:i,v=void 0;(!s||i>=0)&&(v=n);var c=o?{normal:{align:"center",verticalAlign:"middle"}}:null;fe(e,re(a),{labelFetcher:v,labelDataIndex:h,defaultText:t},c);var p=e.getTextContent();if(p&&(QD(p).ignore=p.ignore,e.textConfig&&o)){var d=e.getBoundingRect().clone();e.textConfig.layoutRect=d,e.textConfig.position=[(o[0]-d.x)/d.width*100+"%",(o[1]-d.y)/d.height*100+"%"]}e.disableLabelAnimation=!0}else e.removeTextContent(),e.removeTextConfig(),e.disableLabelAnimation=null}function X1(r,e,t,a,n,i){r.data?r.data.setItemGraphicEl(i,e):nt(e).eventData={componentType:"geo",componentIndex:n.componentIndex,geoIndex:n.componentIndex,name:t,region:a&&a.option||{}}}function q1(r,e,t,a,n){r.data||co({el:e,componentModel:n,itemName:t,itemTooltipOption:a.get("tooltip")})}function K1(r,e,t,a,n){e.highDownSilentOnTouch=!!n.get("selectedMode");var i=a.getModel("emphasis"),o=i.get("focus");return Ft(e,o,i.get("blurScope"),i.get("disabled")),r.isGeo&&CR(e,n,t),o}function Q1(r,e,t){var a=[],n;function i(){n=[]}function o(){n.length&&(a.push(n),n=[])}var s=e({polygonStart:i,polygonEnd:o,lineStart:i,lineEnd:o,point:function(l,u){isFinite(l)&&isFinite(u)&&n.push([l,u])},sphere:function(){}});return!t&&s.polygonStart(),C(r,function(l){s.lineStart();for(var u=0;u<l.length;u++)s.point(l[u][0],l[u][1]);s.lineEnd()}),!t&&s.polygonEnd(),a}const JD=hG;var vG=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n,i){if(!(i&&i.type==="mapToggleSelect"&&i.from===this.uid)){var o=this.group;if(o.removeAll(),!t.getHostGeoModel()){if(this._mapDraw&&i&&i.type==="geoRoam"&&this._mapDraw.resetForLabelLayout(),i&&i.type==="geoRoam"&&i.componentType==="series"&&i.seriesId===t.id){var s=this._mapDraw;s&&o.add(s.group)}else if(t.needsDrawMap){var s=this._mapDraw||new JD(n);o.add(s.group),s.draw(t,a,n,this,i),this._mapDraw=s}else this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null;t.get("showLegendSymbol")&&a.getComponent("legend")&&this._renderSymbols(t,a,n)}}},e.prototype.remove=function(){this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null,this.group.removeAll()},e.prototype.dispose=function(){this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null},e.prototype._renderSymbols=function(t,a,n){var i=t.originalData,o=this.group;i.each(i.mapDimension("value"),function(s,l){if(!isNaN(s)){var u=i.getItemLayout(l);if(!(!u||!u.point)){var f=u.point,h=u.offset,v=new Qa({style:{fill:t.getData().getVisual("style").fill},shape:{cx:f[0]+h*9,cy:f[1],r:3},silent:!0,z2:8+(h?0:fo+1)});if(!h){var c=t.mainSeries.getData(),p=i.getName(l),d=c.indexOfName(p),g=i.getItemModel(l),y=g.getModel("label"),m=c.getItemGraphicEl(d);fe(v,re(g),{labelFetcher:{getFormattedLabel:function(_,S){return t.getFormattedLabel(d,S)}},defaultText:p}),v.disableLabelAnimation=!0,y.get("position")||v.setTextConfig({position:"bottom"}),m.onHoverStateChange=function(_){nf(v,_)}}o.add(v)}}})},e.type="map",e}(Nt);const cG=vG;var pG=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.needsDrawMap=!1,t.seriesGroup=[],t.getTooltipPosition=function(a){if(a!=null){var n=this.getData().getName(a),i=this.coordinateSystem,o=i.getRegion(n);return o&&i.dataToPoint(o.getCenter())}},t}return e.prototype.getInitialData=function(t){for(var a=To(this,{coordDimensions:["value"],encodeDefaulter:ot(Ag,this)}),n=Z(),i=[],o=0,s=a.count();o<s;o++){var l=a.getName(o);n.set(l,!0)}var u=fa.load(this.getMapType(),this.option.nameMap,this.option.nameProperty);return C(u.regions,function(f){var h=f.name;n.get(h)||i.push(h)}),a.appendValues([],i),a},e.prototype.getHostGeoModel=function(){var t=this.option.geoIndex;return t!=null?this.ecModel.getComponent("geo",t):null},e.prototype.getMapType=function(){return(this.getHostGeoModel()||this).option.map},e.prototype.getRawValue=function(t){var a=this.getData();return a.get(a.mapDimension("value"),t)},e.prototype.getRegionModel=function(t){var a=this.getData();return a.getItemModel(a.indexOfName(t))},e.prototype.formatTooltip=function(t,a,n){for(var i=this.getData(),o=this.getRawValue(t),s=i.getName(t),l=this.seriesGroup,u=[],f=0;f<l.length;f++){var h=l[f].originalData.indexOfName(s),v=i.mapDimension("value");isNaN(l[f].originalData.get(v,h))||u.push(l[f].name)}return ae("section",{header:u.join(", "),noHeader:!u.length,blocks:[ae("nameValue",{name:s,value:o})]})},e.prototype.setZoom=function(t){this.option.zoom=t},e.prototype.setCenter=function(t){this.option.center=t},e.prototype.getLegendIcon=function(t){var a=t.icon||"roundRect",n=qt(a,0,0,t.itemWidth,t.itemHeight,t.itemStyle.fill);return n.setStyle(t.itemStyle),n.style.stroke="none",a.indexOf("empty")>-1&&(n.style.stroke=n.style.fill,n.style.fill="#fff",n.style.lineWidth=2),n},e.type="series.map",e.dependencies=["geo"],e.layoutMode="box",e.defaultOption={z:2,coordinateSystem:"geo",map:"",left:"center",top:"center",aspectScale:null,showLegendSymbol:!0,boundingCoords:null,center:null,zoom:1,scaleLimit:null,selectedMode:!0,label:{show:!1,color:"#000"},itemStyle:{borderWidth:.5,borderColor:"#444",areaColor:"#eee"},emphasis:{label:{show:!0,color:"rgb(100,0,0)"},itemStyle:{areaColor:"rgba(255,215,0,0.8)"}},select:{label:{show:!0,color:"rgb(100,0,0)"},itemStyle:{color:"rgba(255,215,0,0.8)"}},nameProperty:"name"},e}(zt);const dG=pG;function gG(r,e){var t={};return C(r,function(a){a.each(a.mapDimension("value"),function(n,i){var o="ec-"+a.getName(i);t[o]=t[o]||[],isNaN(n)||t[o].push(n)})}),r[0].map(r[0].mapDimension("value"),function(a,n){for(var i="ec-"+r[0].getName(n),o=0,s=1/0,l=-1/0,u=t[i].length,f=0;f<u;f++)s=Math.min(s,t[i][f]),l=Math.max(l,t[i][f]),o+=t[i][f];var h;return e==="min"?h=s:e==="max"?h=l:e==="average"?h=o/u:h=o,u===0?NaN:h})}function yG(r){var e={};r.eachSeriesByType("map",function(t){var a=t.getHostGeoModel(),n=a?"o"+a.id:"i"+t.getMapType();(e[n]=e[n]||[]).push(t)}),C(e,function(t,a){for(var n=gG(G(t,function(o){return o.getData()}),t[0].get("mapValueCalculation")),i=0;i<t.length;i++)t[i].originalData=t[i].getData();for(var i=0;i<t.length;i++)t[i].seriesGroup=t,t[i].needsDrawMap=i===0&&!t[i].getHostGeoModel(),t[i].setData(n.cloneShallow()),t[i].mainSeries=t[0]})}function mG(r){var e={};r.eachSeriesByType("map",function(t){var a=t.getMapType();if(!(t.getHostGeoModel()||e[a])){var n={};C(t.seriesGroup,function(o){var s=o.coordinateSystem,l=o.originalData;o.get("showLegendSymbol")&&r.getComponent("legend")&&l.each(l.mapDimension("value"),function(u,f){var h=l.getName(f),v=s.getRegion(h);if(!(!v||isNaN(u))){var c=n[h]||0,p=s.dataToPoint(v.getCenter());n[h]=c+1,l.setItemLayout(f,{point:p,offset:c})}})});var i=t.getData();i.each(function(o){var s=i.getName(o),l=i.getItemLayout(o)||{};l.showLabel=!n[s],i.setItemLayout(o,l)}),e[a]=!0}})}var J1=se,wl=function(r){k(e,r);function e(t){var a=r.call(this)||this;return a.type="view",a.dimensions=["x","y"],a._roamTransformable=new Jr,a._rawTransformable=new Jr,a.name=t,a}return e.prototype.setBoundingRect=function(t,a,n,i){return this._rect=new ht(t,a,n,i),this._rect},e.prototype.getBoundingRect=function(){return this._rect},e.prototype.setViewRect=function(t,a,n,i){this._transformTo(t,a,n,i),this._viewRect=new ht(t,a,n,i)},e.prototype._transformTo=function(t,a,n,i){var o=this.getBoundingRect(),s=this._rawTransformable;s.transform=o.calculateTransform(new ht(t,a,n,i));var l=s.parent;s.parent=null,s.decomposeTransform(),s.parent=l,this._updateTransform()},e.prototype.setCenter=function(t,a){t&&(this._center=[W(t[0],a.getWidth()),W(t[1],a.getHeight())],this._updateCenterAndZoom())},e.prototype.setZoom=function(t){t=t||1;var a=this.zoomLimit;a&&(a.max!=null&&(t=Math.min(a.max,t)),a.min!=null&&(t=Math.max(a.min,t))),this._zoom=t,this._updateCenterAndZoom()},e.prototype.getDefaultCenter=function(){var t=this.getBoundingRect(),a=t.x+t.width/2,n=t.y+t.height/2;return[a,n]},e.prototype.getCenter=function(){return this._center||this.getDefaultCenter()},e.prototype.getZoom=function(){return this._zoom||1},e.prototype.getRoamTransform=function(){return this._roamTransformable.getLocalTransform()},e.prototype._updateCenterAndZoom=function(){var t=this._rawTransformable.getLocalTransform(),a=this._roamTransformable,n=this.getDefaultCenter(),i=this.getCenter(),o=this.getZoom();i=se([],i,t),n=se([],n,t),a.originX=i[0],a.originY=i[1],a.x=n[0]-i[0],a.y=n[1]-i[1],a.scaleX=a.scaleY=o,this._updateTransform()},e.prototype._updateTransform=function(){var t=this._roamTransformable,a=this._rawTransformable;a.parent=t,t.updateTransform(),a.updateTransform(),qd(this.transform||(this.transform=[]),a.transform||Fe()),this._rawTransform=a.getLocalTransform(),this.invTransform=this.invTransform||[],lo(this.invTransform,this.transform),this.decomposeTransform()},e.prototype.getTransformInfo=function(){var t=this._rawTransformable,a=this._roamTransformable,n=new Jr;return n.transform=a.transform,n.decomposeTransform(),{roam:{x:n.x,y:n.y,scaleX:n.scaleX,scaleY:n.scaleY},raw:{x:t.x,y:t.y,scaleX:t.scaleX,scaleY:t.scaleY}}},e.prototype.getViewRect=function(){return this._viewRect},e.prototype.getViewRectAfterRoam=function(){var t=this.getBoundingRect().clone();return t.applyTransform(this.transform),t},e.prototype.dataToPoint=function(t,a,n){var i=a?this._rawTransform:this.transform;return n=n||[],i?J1(n,t,i):Se(n,t)},e.prototype.pointToData=function(t){var a=this.invTransform;return a?J1([],t,a):[t[0],t[1]]},e.prototype.convertToPixel=function(t,a,n){var i=j1(a);return i===this?i.dataToPoint(n):null},e.prototype.convertFromPixel=function(t,a,n){var i=j1(a);return i===this?i.pointToData(n):null},e.prototype.containPoint=function(t){return this.getViewRectAfterRoam().contain(t[0],t[1])},e.dimensions=["x","y"],e}(Jr);function j1(r){var e=r.seriesModel;return e?e.coordinateSystem:null}var _G={geoJSON:{aspectScale:.75,invertLongitute:!0},geoSVG:{aspectScale:1,invertLongitute:!1}},jD=["lng","lat"],tM=function(r){k(e,r);function e(t,a,n){var i=r.call(this,t)||this;i.dimensions=jD,i.type="geo",i._nameCoordMap=Z(),i.map=a;var o=n.projection,s=fa.load(a,n.nameMap,n.nameProperty),l=fa.getGeoResource(a);i.resourceType=l?l.type:null;var u=i.regions=s.regions,f=_G[l.type];i._regionsMap=s.regionsMap,i.regions=s.regions,i.projection=o;var h;if(o)for(var v=0;v<u.length;v++){var c=u[v].getBoundingRect(o);h=h||c.clone(),h.union(c)}else h=s.boundingRect;return i.setBoundingRect(h.x,h.y,h.width,h.height),i.aspectScale=o?1:it(n.aspectScale,f.aspectScale),i._invertLongitute=o?!1:f.invertLongitute,i}return e.prototype._transformTo=function(t,a,n,i){var o=this.getBoundingRect(),s=this._invertLongitute;o=o.clone(),s&&(o.y=-o.y-o.height);var l=this._rawTransformable;l.transform=o.calculateTransform(new ht(t,a,n,i));var u=l.parent;l.parent=null,l.decomposeTransform(),l.parent=u,s&&(l.scaleY=-l.scaleY),this._updateTransform()},e.prototype.getRegion=function(t){return this._regionsMap.get(t)},e.prototype.getRegionByCoord=function(t){for(var a=this.regions,n=0;n<a.length;n++){var i=a[n];if(i.type==="geoJSON"&&i.contain(t))return a[n]}},e.prototype.addGeoCoord=function(t,a){this._nameCoordMap.set(t,a)},e.prototype.getGeoCoord=function(t){var a=this._regionsMap.get(t);return this._nameCoordMap.get(t)||a&&a.getCenter()},e.prototype.dataToPoint=function(t,a,n){if($(t)&&(t=this.getGeoCoord(t)),t){var i=this.projection;return i&&(t=i.project(t)),t&&this.projectedToPoint(t,a,n)}},e.prototype.pointToData=function(t){var a=this.projection;return a&&(t=a.unproject(t)),t&&this.pointToProjected(t)},e.prototype.pointToProjected=function(t){return r.prototype.pointToData.call(this,t)},e.prototype.projectedToPoint=function(t,a,n){return r.prototype.dataToPoint.call(this,t,a,n)},e.prototype.convertToPixel=function(t,a,n){var i=tS(a);return i===this?i.dataToPoint(n):null},e.prototype.convertFromPixel=function(t,a,n){var i=tS(a);return i===this?i.pointToData(n):null},e}(wl);Kt(tM,wl);function tS(r){var e=r.geoModel,t=r.seriesModel;return e?e.coordinateSystem:t?t.coordinateSystem||(t.getReferringComponents("geo",Xt).models[0]||{}).coordinateSystem:null}const eS=tM;function rS(r,e){var t=r.get("boundingCoords");if(t!=null){var a=t[0],n=t[1];if(isFinite(a[0])&&isFinite(a[1])&&isFinite(n[0])&&isFinite(n[1])){var i=this.projection;if(i){var o=a[0],s=a[1],l=n[0],u=n[1];a=[1/0,1/0],n=[-1/0,-1/0];var f=function(x,b,T,A){for(var D=T-x,M=A-b,I=0;I<=100;I++){var L=I/100,P=i.project([x+D*L,b+M*L]);Ia(a,a,P),La(n,n,P)}};f(o,s,l,s),f(l,s,l,u),f(l,u,o,u),f(o,u,l,s)}this.setBoundingRect(a[0],a[1],n[0]-a[0],n[1]-a[1])}}var h=this.getBoundingRect(),v=r.get("layoutCenter"),c=r.get("layoutSize"),p=e.getWidth(),d=e.getHeight(),g=h.width/h.height*this.aspectScale,y=!1,m,_;v&&c&&(m=[W(v[0],p),W(v[1],d)],_=W(c,Math.min(p,d)),!isNaN(m[0])&&!isNaN(m[1])&&!isNaN(_)&&(y=!0));var S;if(y)S={},g>1?(S.width=_,S.height=_/g):(S.height=_,S.width=_*g),S.y=m[1]-S.height/2,S.x=m[0]-S.width/2;else{var w=r.getBoxLayoutParams();w.aspect=g,S=Jt(w,{width:p,height:d})}this.setViewRect(S.x,S.y,S.width,S.height),this.setCenter(r.get("center"),e),this.setZoom(r.get("zoom"))}function SG(r,e){C(e.get("geoCoord"),function(t,a){r.addGeoCoord(a,t)})}var xG=function(){function r(){this.dimensions=jD}return r.prototype.create=function(e,t){var a=[];function n(o){return{nameProperty:o.get("nameProperty"),aspectScale:o.get("aspectScale"),projection:o.get("projection")}}e.eachComponent("geo",function(o,s){var l=o.get("map"),u=new eS(l+s,l,V({nameMap:o.get("nameMap")},n(o)));u.zoomLimit=o.get("scaleLimit"),a.push(u),o.coordinateSystem=u,u.model=o,u.resize=rS,u.resize(o,t)}),e.eachSeries(function(o){var s=o.get("coordinateSystem");if(s==="geo"){var l=o.get("geoIndex")||0;o.coordinateSystem=a[l]}});var i={};return e.eachSeriesByType("map",function(o){if(!o.getHostGeoModel()){var s=o.getMapType();i[s]=i[s]||[],i[s].push(o)}}),C(i,function(o,s){var l=G(o,function(f){return f.get("nameMap")}),u=new eS(s,s,V({nameMap:Ud(l)},n(o[0])));u.zoomLimit=ie.apply(null,G(o,function(f){return f.get("scaleLimit")})),a.push(u),u.resize=rS,u.resize(o[0],t),C(o,function(f){f.coordinateSystem=u,SG(u,f)})}),a},r.prototype.getFilledRegions=function(e,t,a,n){for(var i=(e||[]).slice(),o=Z(),s=0;s<i.length;s++)o.set(i[s].name,i[s]);var l=fa.load(t,a,n);return C(l.regions,function(u){var f=u.name;!o.get(f)&&i.push({name:f})}),i},r}(),wG=new xG;const eM=wG;var bG=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,a,n){var i=fa.getGeoResource(t.map);if(i&&i.type==="geoJSON"){var o=t.itemStyle=t.itemStyle||{};"color"in o||(o.color="#eee")}this.mergeDefaultAndTheme(t,n),Jn(t,"label",["show"])},e.prototype.optionUpdated=function(){var t=this,a=this.option;a.regions=eM.getFilledRegions(a.regions,a.map,a.nameMap,a.nameProperty);var n={};this._optionModelMap=zr(a.regions||[],function(i,o){var s=o.name;return s&&(i.set(s,new Ot(o,t,t.ecModel)),o.selected&&(n[s]=!0)),i},Z()),a.selectedMap||(a.selectedMap=n)},e.prototype.getRegionModel=function(t){return this._optionModelMap.get(t)||new Ot(null,this,this.ecModel)},e.prototype.getFormattedLabel=function(t,a){var n=this.getRegionModel(t),i=a==="normal"?n.get(["label","formatter"]):n.get(["emphasis","label","formatter"]),o={name:t};if(K(i))return o.status=a,i(o);if($(i))return i.replace("{a}",t??"")},e.prototype.setZoom=function(t){this.option.zoom=t},e.prototype.setCenter=function(t){this.option.center=t},e.prototype.select=function(t){var a=this.option,n=a.selectedMode;if(n){n!=="multiple"&&(a.selectedMap=null);var i=a.selectedMap||(a.selectedMap={});i[t]=!0}},e.prototype.unSelect=function(t){var a=this.option.selectedMap;a&&(a[t]=!1)},e.prototype.toggleSelected=function(t){this[this.isSelected(t)?"unSelect":"select"](t)},e.prototype.isSelected=function(t){var a=this.option.selectedMap;return!!(a&&a[t])},e.type="geo",e.layoutMode="box",e.defaultOption={z:0,show:!0,left:"center",top:"center",aspectScale:null,silent:!1,map:"",boundingCoords:null,center:null,zoom:1,scaleLimit:null,label:{show:!1,color:"#000"},itemStyle:{borderWidth:.5,borderColor:"#444"},emphasis:{label:{show:!0,color:"rgb(100,0,0)"},itemStyle:{color:"rgba(255,215,0,0.8)"}},select:{label:{show:!0,color:"rgb(100,0,0)"},itemStyle:{color:"rgba(255,215,0,0.8)"}},regions:[]},e}(Tt);const TG=bG;function aS(r,e){return r.pointToProjected?r.pointToProjected(e):r.pointToData(e)}function uy(r,e,t,a){var n=r.getZoom(),i=r.getCenter(),o=e.zoom,s=r.projectedToPoint?r.projectedToPoint(i):r.dataToPoint(i);if(e.dx!=null&&e.dy!=null&&(s[0]-=e.dx,s[1]-=e.dy,r.setCenter(aS(r,s),a)),o!=null){if(t){var l=t.min||0,u=t.max||1/0;o=Math.max(Math.min(n*o,u),l)/n}r.scaleX*=o,r.scaleY*=o;var f=(e.originX-r.x)*(o-1),h=(e.originY-r.y)*(o-1);r.x-=f,r.y-=h,r.updateTransform(),r.setCenter(aS(r,s),a),r.setZoom(o*n)}return{center:r.getCenter(),zoom:r.getZoom()}}var AG=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.focusBlurEnabled=!0,t}return e.prototype.init=function(t,a){this._api=a},e.prototype.render=function(t,a,n,i){if(this._model=t,!t.get("show")){this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null;return}this._mapDraw||(this._mapDraw=new JD(n));var o=this._mapDraw;o.draw(t,a,n,this,i),o.group.on("click",this._handleRegionClick,this),o.group.silent=t.get("silent"),this.group.add(o.group),this.updateSelectStatus(t,a,n)},e.prototype._handleRegionClick=function(t){var a;zn(t.target,function(n){return(a=nt(n).eventData)!=null},!0),a&&this._api.dispatchAction({type:"geoToggleSelect",geoId:this._model.id,name:a.name})},e.prototype.updateSelectStatus=function(t,a,n){var i=this;this._mapDraw.group.traverse(function(o){var s=nt(o).eventData;if(s)return i._model.isSelected(s.name)?n.enterSelect(o):n.leaveSelect(o),!0})},e.prototype.findHighDownDispatchers=function(t){return this._mapDraw&&this._mapDraw.findHighDownDispatchers(t,this._model)},e.prototype.dispose=function(){this._mapDraw&&this._mapDraw.remove()},e.type="geo",e}(Ht);const CG=AG;function DG(r,e,t){fa.registerMap(r,e,t)}function rM(r){r.registerCoordinateSystem("geo",eM),r.registerComponentModel(TG),r.registerComponentView(CG),r.registerImpl("registerMap",DG),r.registerImpl("getMap",function(t){return fa.getMapForUser(t)});function e(t,a){a.update="geo:updateSelectStatus",r.registerAction(a,function(n,i){var o={},s=[];return i.eachComponent({mainType:"geo",query:n},function(l){l[t](n.name);var u=l.coordinateSystem;C(u.regions,function(h){o[h.name]=l.isSelected(h.name)||!1});var f=[];C(o,function(h,v){o[v]&&f.push(v)}),s.push({geoIndex:l.componentIndex,name:f})}),{selected:o,allSelected:s,name:n.name}})}e("toggleSelected",{type:"geoToggleSelect",event:"geoselectchanged"}),e("select",{type:"geoSelect",event:"geoselected"}),e("unSelect",{type:"geoUnSelect",event:"geounselected"}),r.registerAction({type:"geoRoam",event:"geoRoam",update:"updateTransform"},function(t,a,n){var i=t.componentType||"series";a.eachComponent({mainType:i,query:t},function(o){var s=o.coordinateSystem;if(s.type==="geo"){var l=uy(s,t,o.get("scaleLimit"),n);o.setCenter&&o.setCenter(l.center),o.setZoom&&o.setZoom(l.zoom),i==="series"&&C(o.seriesGroup,function(u){u.setCenter(l.center),u.setZoom(l.zoom)})}})})}function MG(r){gt(rM),r.registerChartView(cG),r.registerSeriesModel(dG),r.registerLayout(mG),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,yG),tC("map",r.registerAction)}function IG(r){var e=r;e.hierNode={defaultAncestor:null,ancestor:e,prelim:0,modifier:0,change:0,shift:0,i:0,thread:null};for(var t=[e],a,n;a=t.pop();)if(n=a.children,a.isExpand&&n.length)for(var i=n.length,o=i-1;o>=0;o--){var s=n[o];s.hierNode={defaultAncestor:null,ancestor:s,prelim:0,modifier:0,change:0,shift:0,i:o,thread:null},t.push(s)}}function LG(r,e){var t=r.isExpand?r.children:[],a=r.parentNode.children,n=r.hierNode.i?a[r.hierNode.i-1]:null;if(t.length){EG(r);var i=(t[0].hierNode.prelim+t[t.length-1].hierNode.prelim)/2;n?(r.hierNode.prelim=n.hierNode.prelim+e(r,n),r.hierNode.modifier=r.hierNode.prelim-i):r.hierNode.prelim=i}else n&&(r.hierNode.prelim=n.hierNode.prelim+e(r,n));r.parentNode.hierNode.defaultAncestor=kG(r,n,r.parentNode.hierNode.defaultAncestor||a[0],e)}function PG(r){var e=r.hierNode.prelim+r.parentNode.hierNode.modifier;r.setLayout({x:e},!0),r.hierNode.modifier+=r.parentNode.hierNode.modifier}function nS(r){return arguments.length?r:BG}function ls(r,e){return r-=Math.PI/2,{x:e*Math.cos(r),y:e*Math.sin(r)}}function RG(r,e){return Jt(r.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()})}function EG(r){for(var e=r.children,t=e.length,a=0,n=0;--t>=0;){var i=e[t];i.hierNode.prelim+=a,i.hierNode.modifier+=a,n+=i.hierNode.change,a+=i.hierNode.shift+n}}function kG(r,e,t,a){if(e){for(var n=r,i=r,o=i.parentNode.children[0],s=e,l=n.hierNode.modifier,u=i.hierNode.modifier,f=o.hierNode.modifier,h=s.hierNode.modifier;s=ec(s),i=rc(i),s&&i;){n=ec(n),o=rc(o),n.hierNode.ancestor=r;var v=s.hierNode.prelim+h-i.hierNode.prelim-u+a(s,i);v>0&&(NG(OG(s,r,t),r,v),u+=v,l+=v),h+=s.hierNode.modifier,u+=i.hierNode.modifier,l+=n.hierNode.modifier,f+=o.hierNode.modifier}s&&!ec(n)&&(n.hierNode.thread=s,n.hierNode.modifier+=h-l),i&&!rc(o)&&(o.hierNode.thread=i,o.hierNode.modifier+=u-f,t=r)}return t}function ec(r){var e=r.children;return e.length&&r.isExpand?e[e.length-1]:r.hierNode.thread}function rc(r){var e=r.children;return e.length&&r.isExpand?e[0]:r.hierNode.thread}function OG(r,e,t){return r.hierNode.ancestor.parentNode===e.parentNode?r.hierNode.ancestor:t}function NG(r,e,t){var a=t/(e.hierNode.i-r.hierNode.i);e.hierNode.change-=a,e.hierNode.shift+=t,e.hierNode.modifier+=t,e.hierNode.prelim+=t,r.hierNode.change+=a}function BG(r,e){return r.parentNode===e.parentNode?1:2}var VG=function(){function r(){this.parentPoint=[],this.childPoints=[]}return r}(),zG=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new VG},e.prototype.buildPath=function(t,a){var n=a.childPoints,i=n.length,o=a.parentPoint,s=n[0],l=n[i-1];if(i===1){t.moveTo(o[0],o[1]),t.lineTo(s[0],s[1]);return}var u=a.orient,f=u==="TB"||u==="BT"?0:1,h=1-f,v=W(a.forkPosition,1),c=[];c[f]=o[f],c[h]=o[h]+(l[h]-o[h])*v,t.moveTo(o[0],o[1]),t.lineTo(c[0],c[1]),t.moveTo(s[0],s[1]),c[f]=s[f],t.lineTo(c[0],c[1]),c[f]=l[f],t.lineTo(c[0],c[1]),t.lineTo(l[0],l[1]);for(var p=1;p<i-1;p++){var d=n[p];t.moveTo(d[0],d[1]),c[f]=d[f],t.lineTo(c[0],c[1])}},e}(yt),GG=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._mainGroup=new at,t}return e.prototype.init=function(t,a){this._controller=new xl(a.getZr()),this._controllerHost={target:this.group},this.group.add(this._mainGroup)},e.prototype.render=function(t,a,n){var i=t.getData(),o=t.layoutInfo,s=this._mainGroup,l=t.get("layout");l==="radial"?(s.x=o.x+o.width/2,s.y=o.y+o.height/2):(s.x=o.x,s.y=o.y),this._updateViewCoordSys(t,n),this._updateController(t,a,n);var u=this._data;i.diff(u).add(function(f){iS(i,f)&&oS(i,f,null,s,t)}).update(function(f,h){var v=u.getItemGraphicEl(h);if(!iS(i,f)){v&&lS(u,h,v,s,t);return}oS(i,f,v,s,t)}).remove(function(f){var h=u.getItemGraphicEl(f);h&&lS(u,f,h,s,t)}).execute(),this._nodeScaleRatio=t.get("nodeScaleRatio"),this._updateNodeAndLinkScale(t),t.get("expandAndCollapse")===!0&&i.eachItemGraphicEl(function(f,h){f.off("click").on("click",function(){n.dispatchAction({type:"treeExpandAndCollapse",seriesId:t.id,dataIndex:h})})}),this._data=i},e.prototype._updateViewCoordSys=function(t,a){var n=t.getData(),i=[];n.each(function(h){var v=n.getItemLayout(h);v&&!isNaN(v.x)&&!isNaN(v.y)&&i.push([+v.x,+v.y])});var o=[],s=[];Jf(i,o,s);var l=this._min,u=this._max;s[0]-o[0]===0&&(o[0]=l?l[0]:o[0]-1,s[0]=u?u[0]:s[0]+1),s[1]-o[1]===0&&(o[1]=l?l[1]:o[1]-1,s[1]=u?u[1]:s[1]+1);var f=t.coordinateSystem=new wl;f.zoomLimit=t.get("scaleLimit"),f.setBoundingRect(o[0],o[1],s[0]-o[0],s[1]-o[1]),f.setCenter(t.get("center"),a),f.setZoom(t.get("zoom")),this.group.attr({x:f.x,y:f.y,scaleX:f.scaleX,scaleY:f.scaleY}),this._min=o,this._max=s},e.prototype._updateController=function(t,a,n){var i=this,o=this._controller,s=this._controllerHost,l=this.group;o.setPointerChecker(function(u,f,h){var v=l.getBoundingRect();return v.applyTransform(l.transform),v.contain(f,h)&&!xh(u,n,t)}),o.enable(t.get("roam")),s.zoomLimit=t.get("scaleLimit"),s.zoom=t.coordinateSystem.getZoom(),o.off("pan").off("zoom").on("pan",function(u){oy(s,u.dx,u.dy),n.dispatchAction({seriesId:t.id,type:"treeRoam",dx:u.dx,dy:u.dy})}).on("zoom",function(u){sy(s,u.scale,u.originX,u.originY),n.dispatchAction({seriesId:t.id,type:"treeRoam",zoom:u.scale,originX:u.originX,originY:u.originY}),i._updateNodeAndLinkScale(t),n.updateLabelLayout()})},e.prototype._updateNodeAndLinkScale=function(t){var a=t.getData(),n=this._getNodeGlobalScale(t);a.eachItemGraphicEl(function(i,o){i.setSymbolScale(n)})},e.prototype._getNodeGlobalScale=function(t){var a=t.coordinateSystem;if(a.type!=="view")return 1;var n=this._nodeScaleRatio,i=a.scaleX||1,o=a.getZoom(),s=(o-1)*n+1;return s/i},e.prototype.dispose=function(){this._controller&&this._controller.dispose(),this._controllerHost=null},e.prototype.remove=function(){this._mainGroup.removeAll(),this._data=null},e.type="tree",e}(Nt);function iS(r,e){var t=r.getItemLayout(e);return t&&!isNaN(t.x)&&!isNaN(t.y)}function oS(r,e,t,a,n){var i=!t,o=r.tree.getNodeByDataIndex(e),s=o.getModel(),l=o.getVisual("style").fill,u=o.isExpand===!1&&o.children.length!==0?l:"#fff",f=r.tree.root,h=o.parentNode===f?o:o.parentNode||o,v=r.getItemGraphicEl(h.dataIndex),c=h.getLayout(),p=v?{x:v.__oldX,y:v.__oldY,rawX:v.__radialOldRawX,rawY:v.__radialOldRawY}:c,d=o.getLayout();i?(t=new dl(r,e,null,{symbolInnerColor:u,useNameLabel:!0}),t.x=p.x,t.y=p.y):t.updateData(r,e,null,{symbolInnerColor:u,useNameLabel:!0}),t.__radialOldRawX=t.__radialRawX,t.__radialOldRawY=t.__radialRawY,t.__radialRawX=d.rawX,t.__radialRawY=d.rawY,a.add(t),r.setItemGraphicEl(e,t),t.__oldX=t.x,t.__oldY=t.y,Dt(t,{x:d.x,y:d.y},n);var g=t.getSymbolPath();if(n.get("layout")==="radial"){var y=f.children[0],m=y.getLayout(),_=y.children.length,S=void 0,w=void 0;if(d.x===m.x&&o.isExpand===!0&&y.children.length){var x={x:(y.children[0].getLayout().x+y.children[_-1].getLayout().x)/2,y:(y.children[0].getLayout().y+y.children[_-1].getLayout().y)/2};S=Math.atan2(x.y-m.y,x.x-m.x),S<0&&(S=Math.PI*2+S),w=x.x<m.x,w&&(S=S-Math.PI)}else S=Math.atan2(d.y-m.y,d.x-m.x),S<0&&(S=Math.PI*2+S),o.children.length===0||o.children.length!==0&&o.isExpand===!1?(w=d.x<m.x,w&&(S=S-Math.PI)):(w=d.x>m.x,w||(S=S-Math.PI));var b=w?"left":"right",T=s.getModel("label"),A=T.get("rotate"),D=A*(Math.PI/180),M=g.getTextContent();M&&(g.setTextConfig({position:T.get("position")||b,rotation:A==null?-S:D,origin:"center"}),M.setStyle("verticalAlign","middle"))}var I=s.get(["emphasis","focus"]),L=I==="relative"?qu(o.getAncestorsIndices(),o.getDescendantIndices()):I==="ancestor"?o.getAncestorsIndices():I==="descendant"?o.getDescendantIndices():null;L&&(nt(t).focus=L),FG(n,o,f,t,p,c,d,a),t.__edge&&(t.onHoverStateChange=function(P){if(P!=="blur"){var R=o.parentNode&&r.getItemGraphicEl(o.parentNode.dataIndex);R&&R.hoverState===sl||nf(t.__edge,P)}})}function FG(r,e,t,a,n,i,o,s){var l=e.getModel(),u=r.get("edgeShape"),f=r.get("layout"),h=r.getOrient(),v=r.get(["lineStyle","curveness"]),c=r.get("edgeForkPosition"),p=l.getModel("lineStyle").getLineStyle(),d=a.__edge;if(u==="curve")e.parentNode&&e.parentNode!==t&&(d||(d=a.__edge=new rh({shape:fd(f,h,v,n,n)})),Dt(d,{shape:fd(f,h,v,i,o)},r));else if(u==="polyline"&&f==="orthogonal"&&e!==t&&e.children&&e.children.length!==0&&e.isExpand===!0){for(var g=e.children,y=[],m=0;m<g.length;m++){var _=g[m].getLayout();y.push([_.x,_.y])}d||(d=a.__edge=new zG({shape:{parentPoint:[o.x,o.y],childPoints:[[o.x,o.y]],orient:h,forkPosition:c}})),Dt(d,{shape:{parentPoint:[o.x,o.y],childPoints:y}},r)}d&&!(u==="polyline"&&!e.isExpand)&&(d.useStyle(j({strokeNoScale:!0,fill:null},p)),ue(d,l,"lineStyle"),ei(d),s.add(d))}function sS(r,e,t,a,n){var i=e.tree.root,o=aM(i,r),s=o.source,l=o.sourceLayout,u=e.getItemGraphicEl(r.dataIndex);if(u){var f=e.getItemGraphicEl(s.dataIndex),h=f.__edge,v=u.__edge||(s.isExpand===!1||s.children.length===1?h:void 0),c=a.get("edgeShape"),p=a.get("layout"),d=a.get("orient"),g=a.get(["lineStyle","curveness"]);v&&(c==="curve"?$a(v,{shape:fd(p,d,g,l,l),style:{opacity:0}},a,{cb:function(){t.remove(v)},removeOpt:n}):c==="polyline"&&a.get("layout")==="orthogonal"&&$a(v,{shape:{parentPoint:[l.x,l.y],childPoints:[[l.x,l.y]]},style:{opacity:0}},a,{cb:function(){t.remove(v)},removeOpt:n}))}}function aM(r,e){for(var t=e.parentNode===r?e:e.parentNode||e,a;a=t.getLayout(),a==null;)t=t.parentNode===r?t:t.parentNode||t;return{source:t,sourceLayout:a}}function lS(r,e,t,a,n){var i=r.tree.getNodeByDataIndex(e),o=r.tree.root,s=aM(o,i).sourceLayout,l={duration:n.get("animationDurationUpdate"),easing:n.get("animationEasingUpdate")};$a(t,{x:s.x+1,y:s.y+1},n,{cb:function(){a.remove(t),r.setItemGraphicEl(e,null)},removeOpt:l}),t.fadeOut(null,r.hostModel,{fadeLabel:!0,animation:l}),i.children.forEach(function(u){sS(u,r,a,n,l)}),sS(i,r,a,n,l)}function fd(r,e,t,a,n){var i,o,s,l,u,f,h,v;if(r==="radial"){u=a.rawX,h=a.rawY,f=n.rawX,v=n.rawY;var c=ls(u,h),p=ls(u,h+(v-h)*t),d=ls(f,v+(h-v)*t),g=ls(f,v);return{x1:c.x||0,y1:c.y||0,x2:g.x||0,y2:g.y||0,cpx1:p.x||0,cpy1:p.y||0,cpx2:d.x||0,cpy2:d.y||0}}else u=a.x,h=a.y,f=n.x,v=n.y,(e==="LR"||e==="RL")&&(i=u+(f-u)*t,o=h,s=f+(u-f)*t,l=v),(e==="TB"||e==="BT")&&(i=u,o=h+(v-h)*t,s=f,l=v+(h-v)*t);return{x1:u,y1:h,x2:f,y2:v,cpx1:i,cpy1:o,cpx2:s,cpy2:l}}const HG=GG;var nr=bt();function nM(r){var e=r.mainData,t=r.datas;t||(t={main:e},r.datasAttr={main:"data"}),r.datas=r.mainData=null,iM(e,t,r),C(t,function(a){C(e.TRANSFERABLE_METHODS,function(n){a.wrapMethod(n,ot(WG,r))})}),e.wrapMethod("cloneShallow",ot(UG,r)),C(e.CHANGABLE_METHODS,function(a){e.wrapMethod(a,ot($G,r))}),Ae(t[e.dataType]===e)}function WG(r,e){if(XG(this)){var t=V({},nr(this).datas);t[this.dataType]=e,iM(e,t,r)}else fy(e,this.dataType,nr(this).mainData,r);return e}function $G(r,e){return r.struct&&r.struct.update(),e}function UG(r,e){return C(nr(e).datas,function(t,a){t!==e&&fy(t.cloneShallow(),a,e,r)}),e}function YG(r){var e=nr(this).mainData;return r==null||e==null?e:nr(e).datas[r]}function ZG(){var r=nr(this).mainData;return r==null?[{data:r}]:G(_t(nr(r).datas),function(e){return{type:e,data:nr(r).datas[e]}})}function XG(r){return nr(r).mainData===r}function iM(r,e,t){nr(r).datas={},C(e,function(a,n){fy(a,n,r,t)})}function fy(r,e,t,a){nr(t).datas[e]=r,nr(r).mainData=t,r.dataType=e,a.struct&&(r[a.structAttr]=a.struct,a.struct[a.datasAttr[e]]=r),r.getLinkedData=YG,r.getLinkedDataAll=ZG}var qG=function(){function r(e,t){this.depth=0,this.height=0,this.dataIndex=-1,this.children=[],this.viewChildren=[],this.isExpand=!1,this.name=e||"",this.hostTree=t}return r.prototype.isRemoved=function(){return this.dataIndex<0},r.prototype.eachNode=function(e,t,a){K(e)&&(a=t,t=e,e=null),e=e||{},$(e)&&(e={order:e});var n=e.order||"preorder",i=this[e.attr||"children"],o;n==="preorder"&&(o=t.call(a,this));for(var s=0;!o&&s<i.length;s++)i[s].eachNode(e,t,a);n==="postorder"&&t.call(a,this)},r.prototype.updateDepthAndHeight=function(e){var t=0;this.depth=e;for(var a=0;a<this.children.length;a++){var n=this.children[a];n.updateDepthAndHeight(e+1),n.height>t&&(t=n.height)}this.height=t+1},r.prototype.getNodeById=function(e){if(this.getId()===e)return this;for(var t=0,a=this.children,n=a.length;t<n;t++){var i=a[t].getNodeById(e);if(i)return i}},r.prototype.contains=function(e){if(e===this)return!0;for(var t=0,a=this.children,n=a.length;t<n;t++){var i=a[t].contains(e);if(i)return i}},r.prototype.getAncestors=function(e){for(var t=[],a=e?this:this.parentNode;a;)t.push(a),a=a.parentNode;return t.reverse(),t},r.prototype.getAncestorsIndices=function(){for(var e=[],t=this;t;)e.push(t.dataIndex),t=t.parentNode;return e.reverse(),e},r.prototype.getDescendantIndices=function(){var e=[];return this.eachNode(function(t){e.push(t.dataIndex)}),e},r.prototype.getValue=function(e){var t=this.hostTree.data;return t.getStore().get(t.getDimensionIndex(e||"value"),this.dataIndex)},r.prototype.setLayout=function(e,t){this.dataIndex>=0&&this.hostTree.data.setItemLayout(this.dataIndex,e,t)},r.prototype.getLayout=function(){return this.hostTree.data.getItemLayout(this.dataIndex)},r.prototype.getModel=function(e){if(!(this.dataIndex<0)){var t=this.hostTree,a=t.data.getItemModel(this.dataIndex);return a.getModel(e)}},r.prototype.getLevelModel=function(){return(this.hostTree.levelModels||[])[this.depth]},r.prototype.setVisual=function(e,t){this.dataIndex>=0&&this.hostTree.data.setItemVisual(this.dataIndex,e,t)},r.prototype.getVisual=function(e){return this.hostTree.data.getItemVisual(this.dataIndex,e)},r.prototype.getRawIndex=function(){return this.hostTree.data.getRawIndex(this.dataIndex)},r.prototype.getId=function(){return this.hostTree.data.getId(this.dataIndex)},r.prototype.getChildIndex=function(){if(this.parentNode){for(var e=this.parentNode.children,t=0;t<e.length;++t)if(e[t]===this)return t;return-1}return-1},r.prototype.isAncestorOf=function(e){for(var t=e.parentNode;t;){if(t===this)return!0;t=t.parentNode}return!1},r.prototype.isDescendantOf=function(e){return e!==this&&e.isAncestorOf(this)},r}(),hy=function(){function r(e){this.type="tree",this._nodes=[],this.hostModel=e}return r.prototype.eachNode=function(e,t,a){this.root.eachNode(e,t,a)},r.prototype.getNodeByDataIndex=function(e){var t=this.data.getRawIndex(e);return this._nodes[t]},r.prototype.getNodeById=function(e){return this.root.getNodeById(e)},r.prototype.update=function(){for(var e=this.data,t=this._nodes,a=0,n=t.length;a<n;a++)t[a].dataIndex=-1;for(var a=0,n=e.count();a<n;a++)t[e.getRawIndex(a)].dataIndex=a},r.prototype.clearLayouts=function(){this.data.clearItemLayouts()},r.createTree=function(e,t,a){var n=new r(t),i=[],o=1;s(e);function s(f,h){var v=f.value;o=Math.max(o,z(v)?v.length:1),i.push(f);var c=new qG(Qt(f.name,""),n);h?KG(c,h):n.root=c,n._nodes.push(c);var p=f.children;if(p)for(var d=0;d<p.length;d++)s(p[d],c)}n.root.updateDepthAndHeight(0);var l=vl(i,{coordDimensions:["value"],dimensionsCount:o}).dimensions,u=new be(l,t);return u.initData(i),a&&a(u),nM({mainData:u,struct:n,structAttr:"tree"}),n.update(),n},r}();function KG(r,e){var t=e.children;r.parentNode!==e&&(t.push(r),r.parentNode=e)}function Ks(r,e,t){if(r&&vt(e,r.type)>=0){var a=t.getData().tree.root,n=r.targetNode;if($(n)&&(n=a.getNodeById(n)),n&&a.contains(n))return{node:n};var i=r.targetNodeId;if(i!=null&&(n=a.getNodeById(i)))return{node:n}}}function oM(r){for(var e=[];r;)r=r.parentNode,r&&e.push(r);return e.reverse()}function vy(r,e){var t=oM(r);return vt(t,e)>=0}function bh(r,e){for(var t=[];r;){var a=r.dataIndex;t.push({name:r.name,dataIndex:a,value:e.getRawValue(a)}),r=r.parentNode}return t.reverse(),t}var QG=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.hasSymbolVisual=!0,t.ignoreStyleOnData=!0,t}return e.prototype.getInitialData=function(t){var a={name:t.name,children:t.data},n=t.leaves||{},i=new Ot(n,this,this.ecModel),o=hy.createTree(a,this,s);function s(h){h.wrapMethod("getItemModel",function(v,c){var p=o.getNodeByDataIndex(c);return p&&p.children.length&&p.isExpand||(v.parentModel=i),v})}var l=0;o.eachNode("preorder",function(h){h.depth>l&&(l=h.depth)});var u=t.expandAndCollapse,f=u&&t.initialTreeDepth>=0?t.initialTreeDepth:l;return o.root.eachNode("preorder",function(h){var v=h.hostTree.data.getRawDataItem(h.dataIndex);h.isExpand=v&&v.collapsed!=null?!v.collapsed:h.depth<=f}),o.data},e.prototype.getOrient=function(){var t=this.get("orient");return t==="horizontal"?t="LR":t==="vertical"&&(t="TB"),t},e.prototype.setZoom=function(t){this.option.zoom=t},e.prototype.setCenter=function(t){this.option.center=t},e.prototype.formatTooltip=function(t,a,n){for(var i=this.getData().tree,o=i.root.children[0],s=i.getNodeByDataIndex(t),l=s.getValue(),u=s.name;s&&s!==o;)u=s.parentNode.name+"."+u,s=s.parentNode;return ae("nameValue",{name:u,value:l,noValue:isNaN(l)||l==null})},e.prototype.getDataParams=function(t){var a=r.prototype.getDataParams.apply(this,arguments),n=this.getData().tree.getNodeByDataIndex(t);return a.treeAncestors=bh(n,this),a.collapsed=!n.isExpand,a},e.type="series.tree",e.layoutMode="box",e.defaultOption={z:2,coordinateSystem:"view",left:"12%",top:"12%",right:"12%",bottom:"12%",layout:"orthogonal",edgeShape:"curve",edgeForkPosition:"50%",roam:!1,nodeScaleRatio:.4,center:null,zoom:1,orient:"LR",symbol:"emptyCircle",symbolSize:7,expandAndCollapse:!0,initialTreeDepth:2,lineStyle:{color:"#ccc",width:1.5,curveness:.5},itemStyle:{color:"lightsteelblue",borderWidth:1.5},label:{show:!0},animationEasing:"linear",animationDuration:700,animationDurationUpdate:500},e}(zt);const JG=QG;function jG(r,e,t){for(var a=[r],n=[],i;i=a.pop();)if(n.push(i),i.isExpand){var o=i.children;if(o.length)for(var s=0;s<o.length;s++)a.push(o[s])}for(;i=n.pop();)e(i,t)}function Yo(r,e){for(var t=[r],a;a=t.pop();)if(e(a),a.isExpand){var n=a.children;if(n.length)for(var i=n.length-1;i>=0;i--)t.push(n[i])}}function tF(r,e){r.eachSeriesByType("tree",function(t){eF(t,e)})}function eF(r,e){var t=RG(r,e);r.layoutInfo=t;var a=r.get("layout"),n=0,i=0,o=null;a==="radial"?(n=2*Math.PI,i=Math.min(t.height,t.width)/2,o=nS(function(_,S){return(_.parentNode===S.parentNode?1:2)/_.depth})):(n=t.width,i=t.height,o=nS());var s=r.getData().tree.root,l=s.children[0];if(l){IG(s),jG(l,LG,o),s.hierNode.modifier=-l.hierNode.prelim,Yo(l,PG);var u=l,f=l,h=l;Yo(l,function(_){var S=_.getLayout().x;S<u.getLayout().x&&(u=_),S>f.getLayout().x&&(f=_),_.depth>h.depth&&(h=_)});var v=u===f?1:o(u,f)/2,c=v-u.getLayout().x,p=0,d=0,g=0,y=0;if(a==="radial")p=n/(f.getLayout().x+v+c),d=i/(h.depth-1||1),Yo(l,function(_){g=(_.getLayout().x+c)*p,y=(_.depth-1)*d;var S=ls(g,y);_.setLayout({x:S.x,y:S.y,rawX:g,rawY:y},!0)});else{var m=r.getOrient();m==="RL"||m==="LR"?(d=i/(f.getLayout().x+v+c),p=n/(h.depth-1||1),Yo(l,function(_){y=(_.getLayout().x+c)*d,g=m==="LR"?(_.depth-1)*p:n-(_.depth-1)*p,_.setLayout({x:g,y},!0)})):(m==="TB"||m==="BT")&&(p=n/(f.getLayout().x+v+c),d=i/(h.depth-1||1),Yo(l,function(_){g=(_.getLayout().x+c)*p,y=m==="TB"?(_.depth-1)*d:i-(_.depth-1)*d,_.setLayout({x:g,y},!0)}))}}}function rF(r){r.eachSeriesByType("tree",function(e){var t=e.getData(),a=t.tree;a.eachNode(function(n){var i=n.getModel(),o=i.getModel("itemStyle").getItemStyle(),s=t.ensureUniqueItemVisual(n.dataIndex,"style");V(s,o)})})}function aF(r){r.registerAction({type:"treeExpandAndCollapse",event:"treeExpandAndCollapse",update:"update"},function(e,t){t.eachComponent({mainType:"series",subType:"tree",query:e},function(a){var n=e.dataIndex,i=a.getData().tree,o=i.getNodeByDataIndex(n);o.isExpand=!o.isExpand})}),r.registerAction({type:"treeRoam",event:"treeRoam",update:"none"},function(e,t,a){t.eachComponent({mainType:"series",subType:"tree",query:e},function(n){var i=n.coordinateSystem,o=uy(i,e,void 0,a);n.setCenter&&n.setCenter(o.center),n.setZoom&&n.setZoom(o.zoom)})})}function nF(r){r.registerChartView(HG),r.registerSeriesModel(JG),r.registerLayout(tF),r.registerVisual(rF),aF(r)}var uS=["treemapZoomToNode","treemapRender","treemapMove"];function iF(r){for(var e=0;e<uS.length;e++)r.registerAction({type:uS[e],update:"updateView"},Yt);r.registerAction({type:"treemapRootToNode",update:"updateView"},function(t,a){a.eachComponent({mainType:"series",subType:"treemap",query:t},n);function n(i,o){var s=["treemapZoomToNode","treemapRootToNode"],l=Ks(t,s,i);if(l){var u=i.getViewRoot();u&&(t.direction=vy(u,l.node)?"rollUp":"drillDown"),i.resetViewRoot(l.node)}}})}function sM(r){var e=r.getData(),t=e.tree,a={};t.eachNode(function(n){for(var i=n;i&&i.depth>1;)i=i.parentNode;var o=zp(r.ecModel,i.name||i.dataIndex+"",a);n.setVisual("decal",o)})}var oF=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.preventUsingHoverLayer=!0,t}return e.prototype.getInitialData=function(t,a){var n={name:t.name,children:t.data};lM(n);var i=t.levels||[],o=this.designatedVisualItemStyle={},s=new Ot({itemStyle:o},this,a);i=t.levels=sF(i,a);var l=G(i||[],function(h){return new Ot(h,s,a)},this),u=hy.createTree(n,this,f);function f(h){h.wrapMethod("getItemModel",function(v,c){var p=u.getNodeByDataIndex(c),d=p?l[p.depth]:null;return v.parentModel=d||s,v})}return u.data},e.prototype.optionUpdated=function(){this.resetViewRoot()},e.prototype.formatTooltip=function(t,a,n){var i=this.getData(),o=this.getRawValue(t),s=i.getName(t);return ae("nameValue",{name:s,value:o})},e.prototype.getDataParams=function(t){var a=r.prototype.getDataParams.apply(this,arguments),n=this.getData().tree.getNodeByDataIndex(t);return a.treeAncestors=bh(n,this),a.treePathInfo=a.treeAncestors,a},e.prototype.setLayoutInfo=function(t){this.layoutInfo=this.layoutInfo||{},V(this.layoutInfo,t)},e.prototype.mapIdToIndex=function(t){var a=this._idIndexMap;a||(a=this._idIndexMap=Z(),this._idIndexMapCount=0);var n=a.get(t);return n==null&&a.set(t,n=this._idIndexMapCount++),n},e.prototype.getViewRoot=function(){return this._viewRoot},e.prototype.resetViewRoot=function(t){t?this._viewRoot=t:t=this._viewRoot;var a=this.getRawData().tree.root;(!t||t!==a&&!a.contains(t))&&(this._viewRoot=a)},e.prototype.enableAriaDecal=function(){sM(this)},e.type="series.treemap",e.layoutMode="box",e.defaultOption={progressive:0,left:"center",top:"middle",width:"80%",height:"80%",sort:!0,clipWindow:"origin",squareRatio:.5*(1+Math.sqrt(5)),leafDepth:null,drillDownIcon:"▶",zoomToNodeRatio:.32*.32,roam:!0,nodeClick:"zoomToNode",animation:!0,animationDurationUpdate:900,animationEasing:"quinticInOut",breadcrumb:{show:!0,height:22,left:"center",top:"bottom",emptyItemWidth:25,itemStyle:{color:"rgba(0,0,0,0.7)",textStyle:{color:"#fff"}},emphasis:{itemStyle:{color:"rgba(0,0,0,0.9)"}}},label:{show:!0,distance:0,padding:5,position:"inside",color:"#fff",overflow:"truncate"},upperLabel:{show:!1,position:[0,"50%"],height:20,overflow:"truncate",verticalAlign:"middle"},itemStyle:{color:null,colorAlpha:null,colorSaturation:null,borderWidth:0,gapWidth:0,borderColor:"#fff",borderColorSaturation:null},emphasis:{upperLabel:{show:!0,position:[0,"50%"],overflow:"truncate",verticalAlign:"middle"}},visualDimension:0,visualMin:null,visualMax:null,color:[],colorAlpha:null,colorSaturation:null,colorMappingBy:"index",visibleMin:10,childrenVisibleMin:null,levels:[]},e}(zt);function lM(r){var e=0;C(r.children,function(a){lM(a);var n=a.value;z(n)&&(n=n[0]),e+=n});var t=r.value;z(t)&&(t=t[0]),(t==null||isNaN(t))&&(t=e),t<0&&(t=0),z(r.value)?r.value[0]=t:r.value=t}function sF(r,e){var t=Pt(e.get("color")),a=Pt(e.get(["aria","decal","decals"]));if(t){r=r||[];var n,i;C(r,function(s){var l=new Ot(s),u=l.get("color"),f=l.get("decal");(l.get(["itemStyle","color"])||u&&u!=="none")&&(n=!0),(l.get(["itemStyle","decal"])||f&&f!=="none")&&(i=!0)});var o=r[0]||(r[0]={});return n||(o.color=t.slice()),!i&&a&&(o.decal=a.slice()),r}}const lF=oF;var uF=8,fS=8,ac=5,fF=function(){function r(e){this.group=new at,e.add(this.group)}return r.prototype.render=function(e,t,a,n){var i=e.getModel("breadcrumb"),o=this.group;if(o.removeAll(),!(!i.get("show")||!a)){var s=i.getModel("itemStyle"),l=i.getModel("emphasis"),u=s.getModel("textStyle"),f=l.getModel(["itemStyle","textStyle"]),h={pos:{left:i.get("left"),right:i.get("right"),top:i.get("top"),bottom:i.get("bottom")},box:{width:t.getWidth(),height:t.getHeight()},emptyItemWidth:i.get("emptyItemWidth"),totalWidth:0,renderList:[]};this._prepare(a,h,u),this._renderContent(e,h,s,l,u,f,n),hh(o,h.pos,h.box)}},r.prototype._prepare=function(e,t,a){for(var n=e;n;n=n.parentNode){var i=Qt(n.getModel().get("name"),""),o=a.getTextRect(i),s=Math.max(o.width+uF*2,t.emptyItemWidth);t.totalWidth+=s+fS,t.renderList.push({node:n,text:i,width:s})}},r.prototype._renderContent=function(e,t,a,n,i,o,s){for(var l=0,u=t.emptyItemWidth,f=e.get(["breadcrumb","height"]),h=kE(t.pos,t.box),v=t.totalWidth,c=t.renderList,p=n.getModel("itemStyle").getItemStyle(),d=c.length-1;d>=0;d--){var g=c[d],y=g.node,m=g.width,_=g.text;v>h.width&&(v-=m-u,m=u,_=null);var S=new De({shape:{points:hF(l,0,m,f,d===c.length-1,d===0)},style:j(a.getItemStyle(),{lineJoin:"bevel"}),textContent:new At({style:kt(i,{text:_})}),textConfig:{position:"inside"},z2:fo*1e4,onclick:ot(s,y)});S.disableLabelAnimation=!0,S.getTextContent().ensureState("emphasis").style=kt(o,{text:_}),S.ensureState("emphasis").style=p,Ft(S,n.get("focus"),n.get("blurScope"),n.get("disabled")),this.group.add(S),vF(S,e,y),l+=m+fS}},r.prototype.remove=function(){this.group.removeAll()},r}();function hF(r,e,t,a,n,i){var o=[[n?r:r-ac,e],[r+t,e],[r+t,e+a],[n?r:r-ac,e+a]];return!i&&o.splice(2,0,[r+t+ac,e+a/2]),!n&&o.push([r,e+a/2]),o}function vF(r,e,t){nt(r).eventData={componentType:"series",componentSubType:"treemap",componentIndex:e.componentIndex,seriesIndex:e.seriesIndex,seriesName:e.name,seriesType:"treemap",selfType:"breadcrumb",nodeData:{dataIndex:t&&t.dataIndex,name:t&&t.name},treePathInfo:t&&bh(t,e)}}const cF=fF;var pF=function(){function r(){this._storage=[],this._elExistsMap={}}return r.prototype.add=function(e,t,a,n,i){return this._elExistsMap[e.id]?!1:(this._elExistsMap[e.id]=!0,this._storage.push({el:e,target:t,duration:a,delay:n,easing:i}),!0)},r.prototype.finished=function(e){return this._finishedCallback=e,this},r.prototype.start=function(){for(var e=this,t=this._storage.length,a=function(){t--,t<=0&&(e._storage.length=0,e._elExistsMap={},e._finishedCallback&&e._finishedCallback())},n=0,i=this._storage.length;n<i;n++){var o=this._storage[n];o.el.animateTo(o.target,{duration:o.duration,delay:o.delay,easing:o.easing,setToFinal:!0,done:a,aborted:a})}return this},r}();function dF(){return new pF}var hd=at,hS=wt,vS=3,cS="label",pS="upperLabel",gF=fo*10,yF=fo*2,mF=fo*3,Dn=ti([["fill","color"],["stroke","strokeColor"],["lineWidth","strokeWidth"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"]]),dS=function(r){var e=Dn(r);return e.stroke=e.fill=e.lineWidth=null,e},Df=bt(),_F=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._state="ready",t._storage=Zo(),t}return e.prototype.render=function(t,a,n,i){var o=a.findComponents({mainType:"series",subType:"treemap",query:i});if(!(vt(o,t)<0)){this.seriesModel=t,this.api=n,this.ecModel=a;var s=["treemapZoomToNode","treemapRootToNode"],l=Ks(i,s,t),u=i&&i.type,f=t.layoutInfo,h=!this._oldTree,v=this._storage,c=u==="treemapRootToNode"&&l&&v?{rootNodeGroup:v.nodeGroup[l.node.getRawIndex()],direction:i.direction}:null,p=this._giveContainerGroup(f),d=t.get("animation"),g=this._doRender(p,t,c);d&&!h&&(!u||u==="treemapZoomToNode"||u==="treemapRootToNode")?this._doAnimation(p,g,t,c):g.renderFinally(),this._resetController(n),this._renderBreadcrumb(t,n,l)}},e.prototype._giveContainerGroup=function(t){var a=this._containerGroup;return a||(a=this._containerGroup=new hd,this._initEvents(a),this.group.add(a)),a.x=t.x,a.y=t.y,a},e.prototype._doRender=function(t,a,n){var i=a.getData().tree,o=this._oldTree,s=Zo(),l=Zo(),u=this._storage,f=[];function h(g,y,m,_){return SF(a,l,u,n,s,f,g,y,m,_)}c(i.root?[i.root]:[],o&&o.root?[o.root]:[],t,i===o||!o,0);var v=p(u);return this._oldTree=i,this._storage=l,{lastsForAnimation:s,willDeleteEls:v,renderFinally:d};function c(g,y,m,_,S){_?(y=g,C(g,function(b,T){!b.isRemoved()&&x(T,T)})):new ua(y,g,w,w).add(x).update(x).remove(ot(x,null)).execute();function w(b){return b.getId()}function x(b,T){var A=b!=null?g[b]:null,D=T!=null?y[T]:null,M=h(A,D,m,S);M&&c(A&&A.viewChildren||[],D&&D.viewChildren||[],M,_,S+1)}}function p(g){var y=Zo();return g&&C(g,function(m,_){var S=y[_];C(m,function(w){w&&(S.push(w),Df(w).willDelete=!0)})}),y}function d(){C(v,function(g){C(g,function(y){y.parent&&y.parent.remove(y)})}),C(f,function(g){g.invisible=!0,g.dirty()})}},e.prototype._doAnimation=function(t,a,n,i){var o=n.get("animationDurationUpdate"),s=n.get("animationEasing"),l=(K(o)?0:o)||0,u=(K(s)?null:s)||"cubicOut",f=dF();C(a.willDeleteEls,function(h,v){C(h,function(c,p){if(!c.invisible){var d=c.parent,g,y=Df(d);if(i&&i.direction==="drillDown")g=d===i.rootNodeGroup?{shape:{x:0,y:0,width:y.nodeWidth,height:y.nodeHeight},style:{opacity:0}}:{style:{opacity:0}};else{var m=0,_=0;y.willDelete||(m=y.nodeWidth/2,_=y.nodeHeight/2),g=v==="nodeGroup"?{x:m,y:_,style:{opacity:0}}:{shape:{x:m,y:_,width:0,height:0},style:{opacity:0}}}g&&f.add(c,g,l,0,u)}})}),C(this._storage,function(h,v){C(h,function(c,p){var d=a.lastsForAnimation[v][p],g={};d&&(c instanceof at?d.oldX!=null&&(g.x=c.x,g.y=c.y,c.x=d.oldX,c.y=d.oldY):(d.oldShape&&(g.shape=V({},c.shape),c.setShape(d.oldShape)),d.fadein?(c.setStyle("opacity",0),g.style={opacity:1}):c.style.opacity!==1&&(g.style={opacity:1})),f.add(c,g,l,0,u))})},this),this._state="animating",f.finished(U(function(){this._state="ready",a.renderFinally()},this)).start()},e.prototype._resetController=function(t){var a=this._controller;a||(a=this._controller=new xl(t.getZr()),a.enable(this.seriesModel.get("roam")),a.on("pan",U(this._onPan,this)),a.on("zoom",U(this._onZoom,this)));var n=new ht(0,0,t.getWidth(),t.getHeight());a.setPointerChecker(function(i,o,s){return n.contain(o,s)})},e.prototype._clearController=function(){var t=this._controller;t&&(t.dispose(),t=null)},e.prototype._onPan=function(t){if(this._state!=="animating"&&(Math.abs(t.dx)>vS||Math.abs(t.dy)>vS)){var a=this.seriesModel.getData().tree.root;if(!a)return;var n=a.getLayout();if(!n)return;this.api.dispatchAction({type:"treemapMove",from:this.uid,seriesId:this.seriesModel.id,rootRect:{x:n.x+t.dx,y:n.y+t.dy,width:n.width,height:n.height}})}},e.prototype._onZoom=function(t){var a=t.originX,n=t.originY;if(this._state!=="animating"){var i=this.seriesModel.getData().tree.root;if(!i)return;var o=i.getLayout();if(!o)return;var s=new ht(o.x,o.y,o.width,o.height),l=this.seriesModel.layoutInfo;a-=l.x,n-=l.y;var u=Fe();Gr(u,u,[-a,-n]),Kd(u,u,[t.scale,t.scale]),Gr(u,u,[a,n]),s.applyTransform(u),this.api.dispatchAction({type:"treemapRender",from:this.uid,seriesId:this.seriesModel.id,rootRect:{x:s.x,y:s.y,width:s.width,height:s.height}})}},e.prototype._initEvents=function(t){var a=this;t.on("click",function(n){if(a._state==="ready"){var i=a.seriesModel.get("nodeClick",!0);if(i){var o=a.findTarget(n.offsetX,n.offsetY);if(o){var s=o.node;if(s.getLayout().isLeafRoot)a._rootToNode(o);else if(i==="zoomToNode")a._zoomToNode(o);else if(i==="link"){var l=s.hostTree.data.getItemModel(s.dataIndex),u=l.get("link",!0),f=l.get("target",!0)||"blank";u&&hf(u,f)}}}}},this)},e.prototype._renderBreadcrumb=function(t,a,n){var i=this;n||(n=t.get("leafDepth",!0)!=null?{node:t.getViewRoot()}:this.findTarget(a.getWidth()/2,a.getHeight()/2),n||(n={node:t.getData().tree.root})),(this._breadcrumb||(this._breadcrumb=new cF(this.group))).render(t,a,n.node,function(o){i._state!=="animating"&&(vy(t.getViewRoot(),o)?i._rootToNode({node:o}):i._zoomToNode({node:o}))})},e.prototype.remove=function(){this._clearController(),this._containerGroup&&this._containerGroup.removeAll(),this._storage=Zo(),this._state="ready",this._breadcrumb&&this._breadcrumb.remove()},e.prototype.dispose=function(){this._clearController()},e.prototype._zoomToNode=function(t){this.api.dispatchAction({type:"treemapZoomToNode",from:this.uid,seriesId:this.seriesModel.id,targetNode:t.node})},e.prototype._rootToNode=function(t){this.api.dispatchAction({type:"treemapRootToNode",from:this.uid,seriesId:this.seriesModel.id,targetNode:t.node})},e.prototype.findTarget=function(t,a){var n,i=this.seriesModel.getViewRoot();return i.eachNode({attr:"viewChildren",order:"preorder"},function(o){var s=this._storage.background[o.getRawIndex()];if(s){var l=s.transformCoordToLocal(t,a),u=s.shape;if(u.x<=l[0]&&l[0]<=u.x+u.width&&u.y<=l[1]&&l[1]<=u.y+u.height)n={node:o,offsetX:l[0],offsetY:l[1]};else return!1}},this),n},e.type="treemap",e}(Nt);function Zo(){return{nodeGroup:[],background:[],content:[]}}function SF(r,e,t,a,n,i,o,s,l,u){if(!o)return;var f=o.getLayout(),h=r.getData(),v=o.getModel();if(h.setItemGraphicEl(o.dataIndex,null),!f||!f.isInView)return;var c=f.width,p=f.height,d=f.borderWidth,g=f.invisible,y=o.getRawIndex(),m=s&&s.getRawIndex(),_=o.viewChildren,S=f.upperHeight,w=_&&_.length,x=v.getModel("itemStyle"),b=v.getModel(["emphasis","itemStyle"]),T=v.getModel(["blur","itemStyle"]),A=v.getModel(["select","itemStyle"]),D=x.get("borderRadius")||0,M=J("nodeGroup",hd);if(!M)return;if(l.add(M),M.x=f.x||0,M.y=f.y||0,M.markRedraw(),Df(M).nodeWidth=c,Df(M).nodeHeight=p,f.isAboveViewRoot)return M;var I=J("background",hS,u,yF);I&&B(M,I,w&&f.upperLabelHeight);var L=v.getModel("emphasis"),P=L.get("focus"),R=L.get("blurScope"),E=L.get("disabled"),N=P==="ancestor"?o.getAncestorsIndices():P==="descendant"?o.getDescendantIndices():P;if(w)Bs(M)&&Bn(M,!1),I&&(Bn(I,!E),h.setItemGraphicEl(o.dataIndex,I),Pp(I,N,R));else{var O=J("content",hS,u,mF);O&&F(M,O),I.disableMorphing=!0,I&&Bs(I)&&Bn(I,!1),Bn(M,!E),h.setItemGraphicEl(o.dataIndex,M),Pp(M,N,R)}return M;function B(pt,et,dt){var st=nt(et);if(st.dataIndex=o.dataIndex,st.seriesIndex=r.seriesIndex,et.setShape({x:0,y:0,width:c,height:p,r:D}),g)H(et);else{et.invisible=!1;var q=o.getVisual("style"),lt=q.stroke,Vt=dS(x);Vt.fill=lt;var xt=Dn(b);xt.fill=b.get("borderColor");var Wt=Dn(T);Wt.fill=T.get("borderColor");var Gt=Dn(A);if(Gt.fill=A.get("borderColor"),dt){var ve=c-2*d;X(et,lt,q.opacity,{x:d,y:0,width:ve,height:S})}else et.removeTextContent();et.setStyle(Vt),et.ensureState("emphasis").style=xt,et.ensureState("blur").style=Wt,et.ensureState("select").style=Gt,ei(et)}pt.add(et)}function F(pt,et){var dt=nt(et);dt.dataIndex=o.dataIndex,dt.seriesIndex=r.seriesIndex;var st=Math.max(c-2*d,0),q=Math.max(p-2*d,0);if(et.culling=!0,et.setShape({x:d,y:d,width:st,height:q,r:D}),g)H(et);else{et.invisible=!1;var lt=o.getVisual("style"),Vt=lt.fill,xt=dS(x);xt.fill=Vt,xt.decal=lt.decal;var Wt=Dn(b),Gt=Dn(T),ve=Dn(A);X(et,Vt,lt.opacity,null),et.setStyle(xt),et.ensureState("emphasis").style=Wt,et.ensureState("blur").style=Gt,et.ensureState("select").style=ve,ei(et)}pt.add(et)}function H(pt){!pt.invisible&&i.push(pt)}function X(pt,et,dt,st){var q=v.getModel(st?pS:cS),lt=Qt(v.get("name"),null),Vt=q.getShallow("show");fe(pt,re(v,st?pS:cS),{defaultText:Vt?lt:null,inheritColor:et,defaultOpacity:dt,labelFetcher:r,labelDataIndex:o.dataIndex});var xt=pt.getTextContent();if(xt){var Wt=xt.style,Gt=Zd(Wt.padding||0);st&&(pt.setTextConfig({layoutRect:st}),xt.disableLabelLayout=!0),xt.beforeUpdate=function(){var Yr=Math.max((st?st.width:pt.shape.width)-Gt[1]-Gt[3],0),Ie=Math.max((st?st.height:pt.shape.height)-Gt[0]-Gt[2],0);(Wt.width!==Yr||Wt.height!==Ie)&&xt.setStyle({width:Yr,height:Ie})},Wt.truncateMinChar=2,Wt.lineOverflow="truncate",Q(Wt,st,f);var ve=xt.getState("emphasis");Q(ve?ve.style:null,st,f)}}function Q(pt,et,dt){var st=pt?pt.text:null;if(!et&&dt.isLeafRoot&&st!=null){var q=r.get("drillDownIcon",!0);pt.text=q?q+" "+st:st}}function J(pt,et,dt,st){var q=m!=null&&t[pt][m],lt=n[pt];return q?(t[pt][m]=null,ct(lt,q)):g||(q=new et,q instanceof ir&&(q.z2=xF(dt,st)),St(lt,q)),e[pt][y]=q}function ct(pt,et){var dt=pt[y]={};et instanceof hd?(dt.oldX=et.x,dt.oldY=et.y):dt.oldShape=V({},et.shape)}function St(pt,et){var dt=pt[y]={},st=o.parentNode,q=et instanceof at;if(st&&(!a||a.direction==="drillDown")){var lt=0,Vt=0,xt=n.background[st.getRawIndex()];!a&&xt&&xt.oldShape&&(lt=xt.oldShape.width,Vt=xt.oldShape.height),q?(dt.oldX=0,dt.oldY=Vt):dt.oldShape={x:lt,y:Vt,width:0,height:0}}dt.fadein=!q}}function xF(r,e){return r*gF+e}const wF=_F;var Qs=C,bF=tt,Mf=-1,cy=function(){function r(e){var t=e.mappingMethod,a=e.type,n=this.option=rt(e);this.type=a,this.mappingMethod=t,this._normalizeData=CF[t];var i=r.visualHandlers[a];this.applyVisual=i.applyVisual,this.getColorMapper=i.getColorMapper,this._normalizedToVisual=i._normalizedToVisual[t],t==="piecewise"?(nc(n),TF(n)):t==="category"?n.categories?AF(n):nc(n,!0):(Ae(t!=="linear"||n.dataExtent),nc(n))}return r.prototype.mapValueToVisual=function(e){var t=this._normalizeData(e);return this._normalizedToVisual(t,e)},r.prototype.getNormalizer=function(){return U(this._normalizeData,this)},r.listVisualTypes=function(){return _t(r.visualHandlers)},r.isValidType=function(e){return r.visualHandlers.hasOwnProperty(e)},r.eachVisual=function(e,t,a){tt(e)?C(e,t,a):t.call(a,e)},r.mapVisual=function(e,t,a){var n,i=z(e)?[]:tt(e)?{}:(n=!0,null);return r.eachVisual(e,function(o,s){var l=t.call(a,o,s);n?i=l:i[s]=l}),i},r.retrieveVisuals=function(e){var t={},a;return e&&Qs(r.visualHandlers,function(n,i){e.hasOwnProperty(i)&&(t[i]=e[i],a=!0)}),a?t:null},r.prepareVisualTypes=function(e){if(z(e))e=e.slice();else if(bF(e)){var t=[];Qs(e,function(a,n){t.push(n)}),e=t}else return[];return e.sort(function(a,n){return n==="color"&&a!=="color"&&a.indexOf("color")===0?1:-1}),e},r.dependsOn=function(e,t){return t==="color"?!!(e&&e.indexOf(t)===0):e===t},r.findPieceIndex=function(e,t,a){for(var n,i=1/0,o=0,s=t.length;o<s;o++){var l=t[o].value;if(l!=null){if(l===e||$(l)&&l===e+"")return o;a&&v(l,o)}}for(var o=0,s=t.length;o<s;o++){var u=t[o],f=u.interval,h=u.close;if(f){if(f[0]===-1/0){if(pu(h[1],e,f[1]))return o}else if(f[1]===1/0){if(pu(h[0],f[0],e))return o}else if(pu(h[0],f[0],e)&&pu(h[1],e,f[1]))return o;a&&v(f[0],o),a&&v(f[1],o)}}if(a)return e===1/0?t.length-1:e===-1/0?0:n;function v(c,p){var d=Math.abs(c-e);d<i&&(i=d,n=p)}},r.visualHandlers={color:{applyVisual:Xo("color"),getColorMapper:function(){var e=this.option;return U(e.mappingMethod==="category"?function(t,a){return!a&&(t=this._normalizeData(t)),us.call(this,t)}:function(t,a,n){var i=!!n;return!a&&(t=this._normalizeData(t)),n=Vh(t,e.parsedVisual,n),i?n:ra(n,"rgba")},this)},_normalizedToVisual:{linear:function(e){return ra(Vh(e,this.option.parsedVisual),"rgba")},category:us,piecewise:function(e,t){var a=cd.call(this,t);return a==null&&(a=ra(Vh(e,this.option.parsedVisual),"rgba")),a},fixed:Mn}},colorHue:cu(function(e,t){return ps(e,t)}),colorSaturation:cu(function(e,t){return ps(e,null,t)}),colorLightness:cu(function(e,t){return ps(e,null,null,t)}),colorAlpha:cu(function(e,t){return Ju(e,t)}),decal:{applyVisual:Xo("decal"),_normalizedToVisual:{linear:null,category:us,piecewise:null,fixed:null}},opacity:{applyVisual:Xo("opacity"),_normalizedToVisual:vd([0,1])},liftZ:{applyVisual:Xo("liftZ"),_normalizedToVisual:{linear:Mn,category:Mn,piecewise:Mn,fixed:Mn}},symbol:{applyVisual:function(e,t,a){var n=this.mapValueToVisual(e);a("symbol",n)},_normalizedToVisual:{linear:gS,category:us,piecewise:function(e,t){var a=cd.call(this,t);return a==null&&(a=gS.call(this,e)),a},fixed:Mn}},symbolSize:{applyVisual:Xo("symbolSize"),_normalizedToVisual:vd([0,1])}},r}();function TF(r){var e=r.pieceList;r.hasSpecialVisual=!1,C(e,function(t,a){t.originIndex=a,t.visual!=null&&(r.hasSpecialVisual=!0)})}function AF(r){var e=r.categories,t=r.categoryMap={},a=r.visual;if(Qs(e,function(o,s){t[o]=s}),!z(a)){var n=[];tt(a)?Qs(a,function(o,s){var l=t[s];n[l??Mf]=o}):n[Mf]=a,a=uM(r,n)}for(var i=e.length-1;i>=0;i--)a[i]==null&&(delete t[e[i]],e.pop())}function nc(r,e){var t=r.visual,a=[];tt(t)?Qs(t,function(i){a.push(i)}):t!=null&&a.push(t);var n={color:1,symbol:1};!e&&a.length===1&&!n.hasOwnProperty(r.type)&&(a[1]=a[0]),uM(r,a)}function cu(r){return{applyVisual:function(e,t,a){var n=this.mapValueToVisual(e);a("color",r(t("color"),n))},_normalizedToVisual:vd([0,1])}}function gS(r){var e=this.option.visual;return e[Math.round(It(r,[0,1],[0,e.length-1],!0))]||{}}function Xo(r){return function(e,t,a){a(r,this.mapValueToVisual(e))}}function us(r){var e=this.option.visual;return e[this.option.loop&&r!==Mf?r%e.length:r]}function Mn(){return this.option.visual[0]}function vd(r){return{linear:function(e){return It(e,r,this.option.visual,!0)},category:us,piecewise:function(e,t){var a=cd.call(this,t);return a==null&&(a=It(e,r,this.option.visual,!0)),a},fixed:Mn}}function cd(r){var e=this.option,t=e.pieceList;if(e.hasSpecialVisual){var a=cy.findPieceIndex(r,t),n=t[a];if(n&&n.visual)return n.visual[this.type]}}function uM(r,e){return r.visual=e,r.type==="color"&&(r.parsedVisual=G(e,function(t){var a=He(t);return a||[0,0,0,1]})),e}var CF={linear:function(r){return It(r,this.option.dataExtent,[0,1],!0)},piecewise:function(r){var e=this.option.pieceList,t=cy.findPieceIndex(r,e,!0);if(t!=null)return It(t,[0,e.length-1],[0,1],!0)},category:function(r){var e=this.option.categories?this.option.categoryMap[r]:r;return e??Mf},fixed:Yt};function pu(r,e,t){return r?e<=t:e<t}const le=cy;var DF="itemStyle",fM=bt();const MF={seriesType:"treemap",reset:function(r){var e=r.getData().tree,t=e.root;t.isRemoved()||hM(t,{},r.getViewRoot().getAncestors(),r)}};function hM(r,e,t,a){var n=r.getModel(),i=r.getLayout(),o=r.hostTree.data;if(!(!i||i.invisible||!i.isInView)){var s=n.getModel(DF),l=IF(s,e,a),u=o.ensureUniqueItemVisual(r.dataIndex,"style"),f=s.get("borderColor"),h=s.get("borderColorSaturation"),v;h!=null&&(v=yS(l),f=LF(h,v)),u.stroke=f;var c=r.viewChildren;if(!c||!c.length)v=yS(l),u.fill=v;else{var p=PF(r,n,i,s,l,c);C(c,function(d,g){if(d.depth>=t.length||d===t[d.depth]){var y=RF(n,l,d,g,p,a);hM(d,y,t,a)}})}}}function IF(r,e,t){var a=V({},e),n=t.designatedVisualItemStyle;return C(["color","colorAlpha","colorSaturation"],function(i){n[i]=e[i];var o=r.get(i);n[i]=null,o!=null&&(a[i]=o)}),a}function yS(r){var e=ic(r,"color");if(e){var t=ic(r,"colorAlpha"),a=ic(r,"colorSaturation");return a&&(e=ps(e,null,null,a)),t&&(e=Ju(e,t)),e}}function LF(r,e){return e!=null?ps(e,null,null,r):null}function ic(r,e){var t=r[e];if(t!=null&&t!=="none")return t}function PF(r,e,t,a,n,i){if(!(!i||!i.length)){var o=oc(e,"color")||n.color!=null&&n.color!=="none"&&(oc(e,"colorAlpha")||oc(e,"colorSaturation"));if(o){var s=e.get("visualMin"),l=e.get("visualMax"),u=t.dataExtent.slice();s!=null&&s<u[0]&&(u[0]=s),l!=null&&l>u[1]&&(u[1]=l);var f=e.get("colorMappingBy"),h={type:o.name,dataExtent:u,visual:o.range};h.type==="color"&&(f==="index"||f==="id")?(h.mappingMethod="category",h.loop=!0):h.mappingMethod="linear";var v=new le(h);return fM(v).drColorMappingBy=f,v}}}function oc(r,e){var t=r.get(e);return z(t)&&t.length?{name:e,range:t}:null}function RF(r,e,t,a,n,i){var o=V({},e);if(n){var s=n.type,l=s==="color"&&fM(n).drColorMappingBy,u=l==="index"?a:l==="id"?i.mapIdToIndex(t.getId()):t.getValue(r.get("visualDimension"));o[s]=n.mapValueToVisual(u)}return o}var Js=Math.max,If=Math.min,mS=ie,py=C,vM=["itemStyle","borderWidth"],EF=["itemStyle","gapWidth"],kF=["upperLabel","show"],OF=["upperLabel","height"];const NF={seriesType:"treemap",reset:function(r,e,t,a){var n=t.getWidth(),i=t.getHeight(),o=r.option,s=Jt(r.getBoxLayoutParams(),{width:t.getWidth(),height:t.getHeight()}),l=o.size||[],u=W(mS(s.width,l[0]),n),f=W(mS(s.height,l[1]),i),h=a&&a.type,v=["treemapZoomToNode","treemapRootToNode"],c=Ks(a,v,r),p=h==="treemapRender"||h==="treemapMove"?a.rootRect:null,d=r.getViewRoot(),g=oM(d);if(h!=="treemapMove"){var y=h==="treemapZoomToNode"?HF(r,c,d,u,f):p?[p.width,p.height]:[u,f],m=o.sort;m&&m!=="asc"&&m!=="desc"&&(m="desc");var _={squareRatio:o.squareRatio,sort:m,leafDepth:o.leafDepth};d.hostTree.clearLayouts();var S={x:0,y:0,width:y[0],height:y[1],area:y[0]*y[1]};d.setLayout(S),cM(d,_,!1,0),S=d.getLayout(),py(g,function(x,b){var T=(g[b+1]||d).getValue();x.setLayout(V({dataExtent:[T,T],borderWidth:0,upperHeight:0},S))})}var w=r.getData().tree.root;w.setLayout(WF(s,p,c),!0),r.setLayoutInfo(s),pM(w,new ht(-s.x,-s.y,n,i),g,d,0)}};function cM(r,e,t,a){var n,i;if(!r.isRemoved()){var o=r.getLayout();n=o.width,i=o.height;var s=r.getModel(),l=s.get(vM),u=s.get(EF)/2,f=dM(s),h=Math.max(l,f),v=l-u,c=h-u;r.setLayout({borderWidth:l,upperHeight:h,upperLabelHeight:f},!0),n=Js(n-2*v,0),i=Js(i-v-c,0);var p=n*i,d=BF(r,s,p,e,t,a);if(d.length){var g={x:v,y:c,width:n,height:i},y=If(n,i),m=1/0,_=[];_.area=0;for(var S=0,w=d.length;S<w;){var x=d[S];_.push(x),_.area+=x.getLayout().area;var b=FF(_,y,e.squareRatio);b<=m?(S++,m=b):(_.area-=_.pop().getLayout().area,_S(_,y,g,u,!1),y=If(g.width,g.height),_.length=_.area=0,m=1/0)}if(_.length&&_S(_,y,g,u,!0),!t){var T=s.get("childrenVisibleMin");T!=null&&p<T&&(t=!0)}for(var S=0,w=d.length;S<w;S++)cM(d[S],e,t,a+1)}}}function BF(r,e,t,a,n,i){var o=r.children||[],s=a.sort;s!=="asc"&&s!=="desc"&&(s=null);var l=a.leafDepth!=null&&a.leafDepth<=i;if(n&&!l)return r.viewChildren=[];o=Lt(o,function(c){return!c.isRemoved()}),zF(o,s);var u=GF(e,o,s);if(u.sum===0)return r.viewChildren=[];if(u.sum=VF(e,t,u.sum,s,o),u.sum===0)return r.viewChildren=[];for(var f=0,h=o.length;f<h;f++){var v=o[f].getValue()/u.sum*t;o[f].setLayout({area:v})}return l&&(o.length&&r.setLayout({isLeafRoot:!0},!0),o.length=0),r.viewChildren=o,r.setLayout({dataExtent:u.dataExtent},!0),o}function VF(r,e,t,a,n){if(!a)return t;for(var i=r.get("visibleMin"),o=n.length,s=o,l=o-1;l>=0;l--){var u=n[a==="asc"?o-l-1:l].getValue();u/t*e<i&&(s=l,t-=u)}return a==="asc"?n.splice(0,o-s):n.splice(s,o-s),t}function zF(r,e){return e&&r.sort(function(t,a){var n=e==="asc"?t.getValue()-a.getValue():a.getValue()-t.getValue();return n===0?e==="asc"?t.dataIndex-a.dataIndex:a.dataIndex-t.dataIndex:n}),r}function GF(r,e,t){for(var a=0,n=0,i=e.length;n<i;n++)a+=e[n].getValue();var o=r.get("visualDimension"),s;return!e||!e.length?s=[NaN,NaN]:o==="value"&&t?(s=[e[e.length-1].getValue(),e[0].getValue()],t==="asc"&&s.reverse()):(s=[1/0,-1/0],py(e,function(l){var u=l.getValue(o);u<s[0]&&(s[0]=u),u>s[1]&&(s[1]=u)})),{sum:a,dataExtent:s}}function FF(r,e,t){for(var a=0,n=1/0,i=0,o=void 0,s=r.length;i<s;i++)o=r[i].getLayout().area,o&&(o<n&&(n=o),o>a&&(a=o));var l=r.area*r.area,u=e*e*t;return l?Js(u*a/l,l/(u*n)):1/0}function _S(r,e,t,a,n){var i=e===t.width?0:1,o=1-i,s=["x","y"],l=["width","height"],u=t[s[i]],f=e?r.area/e:0;(n||f>t[l[o]])&&(f=t[l[o]]);for(var h=0,v=r.length;h<v;h++){var c=r[h],p={},d=f?c.getLayout().area/f:0,g=p[l[o]]=Js(f-2*a,0),y=t[s[i]]+t[l[i]]-u,m=h===v-1||y<d?y:d,_=p[l[i]]=Js(m-2*a,0);p[s[o]]=t[s[o]]+If(a,g/2),p[s[i]]=u+If(a,_/2),u+=m,c.setLayout(p,!0)}t[s[o]]+=f,t[l[o]]-=f}function HF(r,e,t,a,n){var i=(e||{}).node,o=[a,n];if(!i||i===t)return o;for(var s,l=a*n,u=l*r.option.zoomToNodeRatio;s=i.parentNode;){for(var f=0,h=s.children,v=0,c=h.length;v<c;v++)f+=h[v].getValue();var p=i.getValue();if(p===0)return o;u*=f/p;var d=s.getModel(),g=d.get(vM),y=Math.max(g,dM(d));u+=4*g*g+(3*g+y)*Math.pow(u,.5),u>Pm&&(u=Pm),i=s}u<l&&(u=l);var m=Math.pow(u/l,.5);return[a*m,n*m]}function WF(r,e,t){if(e)return{x:e.x,y:e.y};var a={x:0,y:0};if(!t)return a;var n=t.node,i=n.getLayout();if(!i)return a;for(var o=[i.width/2,i.height/2],s=n;s;){var l=s.getLayout();o[0]+=l.x,o[1]+=l.y,s=s.parentNode}return{x:r.width/2-o[0],y:r.height/2-o[1]}}function pM(r,e,t,a,n){var i=r.getLayout(),o=t[n],s=o&&o===r;if(!(o&&!s||n===t.length&&r!==a)){r.setLayout({isInView:!0,invisible:!s&&!e.intersect(i),isAboveViewRoot:s},!0);var l=new ht(e.x-i.x,e.y-i.y,e.width,e.height);py(r.viewChildren||[],function(u){pM(u,l,t,a,n+1)})}}function dM(r){return r.get(kF)?r.get(OF):0}function $F(r){r.registerSeriesModel(lF),r.registerChartView(wF),r.registerVisual(MF),r.registerLayout(NF),iF(r)}function UF(r){var e=r.findComponents({mainType:"legend"});!e||!e.length||r.eachSeriesByType("graph",function(t){var a=t.getCategoriesData(),n=t.getGraph(),i=n.data,o=a.mapArray(a.getName);i.filterSelf(function(s){var l=i.getItemModel(s),u=l.getShallow("category");if(u!=null){Ct(u)&&(u=o[u]);for(var f=0;f<e.length;f++)if(!e[f].isSelected(u))return!1}return!0})})}function YF(r){var e={};r.eachSeriesByType("graph",function(t){var a=t.getCategoriesData(),n=t.getData(),i={};a.each(function(o){var s=a.getName(o);i["ec-"+s]=o;var l=a.getItemModel(o),u=l.getModel("itemStyle").getItemStyle();u.fill||(u.fill=t.getColorFromPalette(s,e)),a.setItemVisual(o,"style",u);for(var f=["symbol","symbolSize","symbolKeepAspect"],h=0;h<f.length;h++){var v=l.getShallow(f[h],!0);v!=null&&a.setItemVisual(o,f[h],v)}}),a.count()&&n.each(function(o){var s=n.getItemModel(o),l=s.getShallow("category");if(l!=null){$(l)&&(l=i["ec-"+l]);var u=a.getItemVisual(l,"style"),f=n.ensureUniqueItemVisual(o,"style");V(f,u);for(var h=["symbol","symbolSize","symbolKeepAspect"],v=0;v<h.length;v++)n.setItemVisual(o,h[v],a.getItemVisual(l,h[v]))}})})}function du(r){return r instanceof Array||(r=[r,r]),r}function ZF(r){r.eachSeriesByType("graph",function(e){var t=e.getGraph(),a=e.getEdgeData(),n=du(e.get("edgeSymbol")),i=du(e.get("edgeSymbolSize"));a.setVisual("fromSymbol",n&&n[0]),a.setVisual("toSymbol",n&&n[1]),a.setVisual("fromSymbolSize",i&&i[0]),a.setVisual("toSymbolSize",i&&i[1]),a.setVisual("style",e.getModel("lineStyle").getLineStyle()),a.each(function(o){var s=a.getItemModel(o),l=t.getEdgeByIndex(o),u=du(s.getShallow("symbol",!0)),f=du(s.getShallow("symbolSize",!0)),h=s.getModel("lineStyle").getLineStyle(),v=a.ensureUniqueItemVisual(o,"style");switch(V(v,h),v.stroke){case"source":{var c=l.node1.getVisual("style");v.stroke=c&&c.fill;break}case"target":{var c=l.node2.getVisual("style");v.stroke=c&&c.fill;break}}u[0]&&l.setVisual("fromSymbol",u[0]),u[1]&&l.setVisual("toSymbol",u[1]),f[0]&&l.setVisual("fromSymbolSize",f[0]),f[1]&&l.setVisual("toSymbolSize",f[1])})})}var pd="-->",Th=function(r){return r.get("autoCurveness")||null},gM=function(r,e){var t=Th(r),a=20,n=[];if(Ct(t))a=t;else if(z(t)){r.__curvenessList=t;return}e>a&&(a=e);var i=a%2?a+2:a+3;n=[];for(var o=0;o<i;o++)n.push((o%2?o+1:o)/10*(o%2?-1:1));r.__curvenessList=n},js=function(r,e,t){var a=[r.id,r.dataIndex].join("."),n=[e.id,e.dataIndex].join(".");return[t.uid,a,n].join(pd)},yM=function(r){var e=r.split(pd);return[e[0],e[2],e[1]].join(pd)},XF=function(r,e){var t=js(r.node1,r.node2,e);return e.__edgeMap[t]},qF=function(r,e){var t=dd(js(r.node1,r.node2,e),e),a=dd(js(r.node2,r.node1,e),e);return t+a},dd=function(r,e){var t=e.__edgeMap;return t[r]?t[r].length:0};function KF(r){Th(r)&&(r.__curvenessList=[],r.__edgeMap={},gM(r))}function QF(r,e,t,a){if(Th(t)){var n=js(r,e,t),i=t.__edgeMap,o=i[yM(n)];i[n]&&!o?i[n].isForward=!0:o&&i[n]&&(o.isForward=!0,i[n].isForward=!1),i[n]=i[n]||[],i[n].push(a)}}function dy(r,e,t,a){var n=Th(e),i=z(n);if(!n)return null;var o=XF(r,e);if(!o)return null;for(var s=-1,l=0;l<o.length;l++)if(o[l]===t){s=l;break}var u=qF(r,e);gM(e,u),r.lineStyle=r.lineStyle||{};var f=js(r.node1,r.node2,e),h=e.__curvenessList,v=i||u%2?0:1;if(o.isForward)return h[v+s];var c=yM(f),p=dd(c,e),d=h[s+p+v];return a?i?n&&n[0]===0?(p+v)%2?d:-d:((p%2?0:1)+v)%2?d:-d:(p+v)%2?d:-d:h[s+p+v]}function mM(r){var e=r.coordinateSystem;if(!(e&&e.type!=="view")){var t=r.getGraph();t.eachNode(function(a){var n=a.getModel();a.setLayout([+n.get("x"),+n.get("y")])}),gy(t,r)}}function gy(r,e){r.eachEdge(function(t,a){var n=Br(t.getModel().get(["lineStyle","curveness"]),-dy(t,e,a,!0),0),i=ta(t.node1.getLayout()),o=ta(t.node2.getLayout()),s=[i,o];+n&&s.push([(i[0]+o[0])/2-(i[1]-o[1])*n,(i[1]+o[1])/2-(o[0]-i[0])*n]),t.setLayout(s)})}function JF(r,e){r.eachSeriesByType("graph",function(t){var a=t.get("layout"),n=t.coordinateSystem;if(n&&n.type!=="view"){var i=t.getData(),o=[];C(n.dimensions,function(v){o=o.concat(i.mapDimensionsAll(v))});for(var s=0;s<i.count();s++){for(var l=[],u=!1,f=0;f<o.length;f++){var h=i.get(o[f],s);isNaN(h)||(u=!0),l.push(h)}u?i.setItemLayout(s,n.dataToPoint(l)):i.setItemLayout(s,[NaN,NaN])}gy(i.graph,t)}else(!a||a==="none")&&mM(t)})}function fs(r){var e=r.coordinateSystem;if(e.type!=="view")return 1;var t=r.option.nodeScaleRatio,a=e.scaleX,n=e.getZoom(),i=(n-1)*t+1;return i/a}function hs(r){var e=r.getVisual("symbolSize");return e instanceof Array&&(e=(e[0]+e[1])/2),+e}var SS=Math.PI,sc=[];function yy(r,e,t,a){var n=r.coordinateSystem;if(!(n&&n.type!=="view")){var i=n.getBoundingRect(),o=r.getData(),s=o.graph,l=i.width/2+i.x,u=i.height/2+i.y,f=Math.min(i.width,i.height)/2,h=o.count();if(o.setLayout({cx:l,cy:u}),!!h){if(t){var v=n.pointToData(a),c=v[0],p=v[1],d=[c-l,p-u];so(d,d),Iu(d,d,f),t.setLayout([l+d[0],u+d[1]],!0);var g=r.get(["circular","rotateLabel"]);_M(t,g,l,u)}jF[e](r,s,o,f,l,u,h),s.eachEdge(function(y,m){var _=Br(y.getModel().get(["lineStyle","curveness"]),dy(y,r,m),0),S=ta(y.node1.getLayout()),w=ta(y.node2.getLayout()),x,b=(S[0]+w[0])/2,T=(S[1]+w[1])/2;+_&&(_*=3,x=[l*_+b*(1-_),u*_+T*(1-_)]),y.setLayout([S,w,x])})}}}var jF={value:function(r,e,t,a,n,i,o){var s=0,l=t.getSum("value"),u=Math.PI*2/(l||o);e.eachNode(function(f){var h=f.getValue("value"),v=u*(l?h:1)/2;s+=v,f.setLayout([a*Math.cos(s)+n,a*Math.sin(s)+i]),s+=v})},symbolSize:function(r,e,t,a,n,i,o){var s=0;sc.length=o;var l=fs(r);e.eachNode(function(h){var v=hs(h);isNaN(v)&&(v=2),v<0&&(v=0),v*=l;var c=Math.asin(v/2/a);isNaN(c)&&(c=SS/2),sc[h.dataIndex]=c,s+=c*2});var u=(2*SS-s)/o/2,f=0;e.eachNode(function(h){var v=u+sc[h.dataIndex];f+=v,(!h.getLayout()||!h.getLayout().fixed)&&h.setLayout([a*Math.cos(f)+n,a*Math.sin(f)+i]),f+=v})}};function _M(r,e,t,a){var n=r.getGraphicEl();if(n){var i=r.getModel(),o=i.get(["label","rotate"])||0,s=n.getSymbolPath();if(e){var l=r.getLayout(),u=Math.atan2(l[1]-a,l[0]-t);u<0&&(u=Math.PI*2+u);var f=l[0]<t;f&&(u=u-Math.PI);var h=f?"left":"right";s.setTextConfig({rotation:-u,position:h,origin:"center"});var v=s.ensureState("emphasis");V(v.textConfig||(v.textConfig={}),{position:h})}else s.setTextConfig({rotation:o*=Math.PI/180})}}function t3(r){r.eachSeriesByType("graph",function(e){e.get("layout")==="circular"&&yy(e,"symbolSize")})}var Di=ep;function e3(r,e,t){for(var a=r,n=e,i=t.rect,o=i.width,s=i.height,l=[i.x+o/2,i.y+s/2],u=t.gravity==null?.1:t.gravity,f=0;f<a.length;f++){var h=a[f];h.p||(h.p=ii(o*(Math.random()-.5)+l[0],s*(Math.random()-.5)+l[1])),h.pp=ta(h.p),h.edges=null}var v=t.friction==null?.6:t.friction,c=v,p,d;return{warmUp:function(){c=v*.8},setFixed:function(g){a[g].fixed=!0},setUnfixed:function(g){a[g].fixed=!1},beforeStep:function(g){p=g},afterStep:function(g){d=g},step:function(g){p&&p(a,n);for(var y=[],m=a.length,_=0;_<n.length;_++){var S=n[_];if(!S.ignoreForceLayout){var w=S.n1,x=S.n2;On(y,x.p,w.p);var b=rp(y)-S.d,T=x.w/(w.w+x.w);isNaN(T)&&(T=0),so(y,y),!w.fixed&&Di(w.p,w.p,y,T*b*c),!x.fixed&&Di(x.p,x.p,y,-(1-T)*b*c)}}for(var _=0;_<m;_++){var A=a[_];A.fixed||(On(y,l,A.p),Di(A.p,A.p,y,u*c))}for(var _=0;_<m;_++)for(var w=a[_],D=_+1;D<m;D++){var x=a[D];On(y,x.p,w.p);var b=rp(y);b===0&&(PL(y,Math.random()-.5,Math.random()-.5),b=1);var M=(w.rep+x.rep)/b/b;!w.fixed&&Di(w.pp,w.pp,y,M),!x.fixed&&Di(x.pp,x.pp,y,-M)}for(var I=[],_=0;_<m;_++){var A=a[_];A.fixed||(On(I,A.p,A.pp),Di(A.p,A.p,I,c),Se(A.pp,A.p))}c=c*.992;var L=c<.01;d&&d(a,n,L),g&&g(L)}}}function r3(r){r.eachSeriesByType("graph",function(e){var t=e.coordinateSystem;if(!(t&&t.type!=="view"))if(e.get("layout")==="force"){var a=e.preservedPoints||{},n=e.getGraph(),i=n.data,o=n.edgeData,s=e.getModel("force"),l=s.get("initLayout");e.preservedPoints?i.each(function(_){var S=i.getId(_);i.setItemLayout(_,a[S]||[NaN,NaN])}):!l||l==="none"?mM(e):l==="circular"&&yy(e,"value");var u=i.getDataExtent("value"),f=o.getDataExtent("value"),h=s.get("repulsion"),v=s.get("edgeLength"),c=z(h)?h:[h,h],p=z(v)?v:[v,v];p=[p[1],p[0]];var d=i.mapArray("value",function(_,S){var w=i.getItemLayout(S),x=It(_,u,c);return isNaN(x)&&(x=(c[0]+c[1])/2),{w:x,rep:x,fixed:i.getItemModel(S).get("fixed"),p:!w||isNaN(w[0])||isNaN(w[1])?null:w}}),g=o.mapArray("value",function(_,S){var w=n.getEdgeByIndex(S),x=It(_,f,p);isNaN(x)&&(x=(p[0]+p[1])/2);var b=w.getModel(),T=Br(w.getModel().get(["lineStyle","curveness"]),-dy(w,e,S,!0),0);return{n1:d[w.node1.dataIndex],n2:d[w.node2.dataIndex],d:x,curveness:T,ignoreForceLayout:b.get("ignoreForceLayout")}}),y=t.getBoundingRect(),m=e3(d,g,{rect:y,gravity:s.get("gravity"),friction:s.get("friction")});m.beforeStep(function(_,S){for(var w=0,x=_.length;w<x;w++)_[w].fixed&&Se(_[w].p,n.getNodeByIndex(w).getLayout())}),m.afterStep(function(_,S,w){for(var x=0,b=_.length;x<b;x++)_[x].fixed||n.getNodeByIndex(x).setLayout(_[x].p),a[i.getId(x)]=_[x].p;for(var x=0,b=S.length;x<b;x++){var T=S[x],A=n.getEdgeByIndex(x),D=T.n1.p,M=T.n2.p,I=A.getLayout();I=I?I.slice():[],I[0]=I[0]||[],I[1]=I[1]||[],Se(I[0],D),Se(I[1],M),+T.curveness&&(I[2]=[(D[0]+M[0])/2-(D[1]-M[1])*T.curveness,(D[1]+M[1])/2-(M[0]-D[0])*T.curveness]),A.setLayout(I)}}),e.forceLayout=m,e.preservedPoints=a,m.step()}else e.forceLayout=null})}function a3(r,e,t){var a=V(r.getBoxLayoutParams(),{aspect:t});return Jt(a,{width:e.getWidth(),height:e.getHeight()})}function n3(r,e){var t=[];return r.eachSeriesByType("graph",function(a){var n=a.get("coordinateSystem");if(!n||n==="view"){var i=a.getData(),o=i.mapArray(function(g){var y=i.getItemModel(g);return[+y.get("x"),+y.get("y")]}),s=[],l=[];Jf(o,s,l),l[0]-s[0]===0&&(l[0]+=1,s[0]-=1),l[1]-s[1]===0&&(l[1]+=1,s[1]-=1);var u=(l[0]-s[0])/(l[1]-s[1]),f=a3(a,e,u);isNaN(u)&&(s=[f.x,f.y],l=[f.x+f.width,f.y+f.height]);var h=l[0]-s[0],v=l[1]-s[1],c=f.width,p=f.height,d=a.coordinateSystem=new wl;d.zoomLimit=a.get("scaleLimit"),d.setBoundingRect(s[0],s[1],h,v),d.setViewRect(f.x,f.y,c,p),d.setCenter(a.get("center"),e),d.setZoom(a.get("zoom")),t.push(d)}}),t}var xS=te.prototype,lc=rh.prototype,SM=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.percent=1}return r}();(function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e})(SM);function uc(r){return isNaN(+r.cpx1)||isNaN(+r.cpy1)}var i3=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a.type="ec-line",a}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new SM},e.prototype.buildPath=function(t,a){uc(a)?xS.buildPath.call(this,t,a):lc.buildPath.call(this,t,a)},e.prototype.pointAt=function(t){return uc(this.shape)?xS.pointAt.call(this,t):lc.pointAt.call(this,t)},e.prototype.tangentAt=function(t){var a=this.shape,n=uc(a)?[a.x2-a.x1,a.y2-a.y1]:lc.tangentAt.call(this,t);return so(n,n)},e}(yt),fc=["fromSymbol","toSymbol"];function wS(r){return"_"+r+"Type"}function bS(r,e,t){var a=e.getItemVisual(t,r);if(!a||a==="none")return a;var n=e.getItemVisual(t,r+"Size"),i=e.getItemVisual(t,r+"Rotate"),o=e.getItemVisual(t,r+"Offset"),s=e.getItemVisual(t,r+"KeepAspect"),l=bo(n),u=ui(o||0,l);return a+l+u+(i||"")+(s||"")}function TS(r,e,t){var a=e.getItemVisual(t,r);if(!(!a||a==="none")){var n=e.getItemVisual(t,r+"Size"),i=e.getItemVisual(t,r+"Rotate"),o=e.getItemVisual(t,r+"Offset"),s=e.getItemVisual(t,r+"KeepAspect"),l=bo(n),u=ui(o||0,l),f=qt(a,-l[0]/2+u[0],-l[1]/2+u[1],l[0],l[1],null,s);return f.__specifiedRotation=i==null||isNaN(i)?void 0:+i*Math.PI/180||0,f.name=r,f}}function o3(r){var e=new i3({name:"line",subPixelOptimize:!0});return gd(e.shape,r),e}function gd(r,e){r.x1=e[0][0],r.y1=e[0][1],r.x2=e[1][0],r.y2=e[1][1],r.percent=1;var t=e[2];t?(r.cpx1=t[0],r.cpy1=t[1]):(r.cpx1=NaN,r.cpy1=NaN)}var s3=function(r){k(e,r);function e(t,a,n){var i=r.call(this)||this;return i._createLine(t,a,n),i}return e.prototype._createLine=function(t,a,n){var i=t.hostModel,o=t.getItemLayout(a),s=o3(o);s.shape.percent=0,Bt(s,{shape:{percent:1}},i,a),this.add(s),C(fc,function(l){var u=TS(l,t,a);this.add(u),this[wS(l)]=bS(l,t,a)},this),this._updateCommonStl(t,a,n)},e.prototype.updateData=function(t,a,n){var i=t.hostModel,o=this.childOfName("line"),s=t.getItemLayout(a),l={shape:{}};gd(l.shape,s),Dt(o,l,i,a),C(fc,function(u){var f=bS(u,t,a),h=wS(u);if(this[h]!==f){this.remove(this.childOfName(u));var v=TS(u,t,a);this.add(v)}this[h]=f},this),this._updateCommonStl(t,a,n)},e.prototype.getLinePath=function(){return this.childAt(0)},e.prototype._updateCommonStl=function(t,a,n){var i=t.hostModel,o=this.childOfName("line"),s=n&&n.emphasisLineStyle,l=n&&n.blurLineStyle,u=n&&n.selectLineStyle,f=n&&n.labelStatesModels,h=n&&n.emphasisDisabled,v=n&&n.focus,c=n&&n.blurScope;if(!n||t.hasItemOption){var p=t.getItemModel(a),d=p.getModel("emphasis");s=d.getModel("lineStyle").getLineStyle(),l=p.getModel(["blur","lineStyle"]).getLineStyle(),u=p.getModel(["select","lineStyle"]).getLineStyle(),h=d.get("disabled"),v=d.get("focus"),c=d.get("blurScope"),f=re(p)}var g=t.getItemVisual(a,"style"),y=g.stroke;o.useStyle(g),o.style.fill=null,o.style.strokeNoScale=!0,o.ensureState("emphasis").style=s,o.ensureState("blur").style=l,o.ensureState("select").style=u,C(fc,function(x){var b=this.childOfName(x);if(b){b.setColor(y),b.style.opacity=g.opacity;for(var T=0;T<Ce.length;T++){var A=Ce[T],D=o.getState(A);if(D){var M=D.style||{},I=b.ensureState(A),L=I.style||(I.style={});M.stroke!=null&&(L[b.__isEmptyBrush?"stroke":"fill"]=M.stroke),M.opacity!=null&&(L.opacity=M.opacity)}}b.markRedraw()}},this);var m=i.getRawValue(a);fe(this,f,{labelDataIndex:a,labelFetcher:{getFormattedLabel:function(x,b){return i.getFormattedLabel(x,b,t.dataType)}},inheritColor:y||"#000",defaultOpacity:g.opacity,defaultText:(m==null?t.getName(a):isFinite(m)?$t(m):m)+""});var _=this.getTextContent();if(_){var S=f.normal;_.__align=_.style.align,_.__verticalAlign=_.style.verticalAlign,_.__position=S.get("position")||"middle";var w=S.get("distance");z(w)||(w=[w,w]),_.__labelDistance=w}this.setTextConfig({position:null,local:!0,inside:!1}),Ft(this,v,c,h)},e.prototype.highlight=function(){sa(this)},e.prototype.downplay=function(){la(this)},e.prototype.updateLayout=function(t,a){this.setLinePoints(t.getItemLayout(a))},e.prototype.setLinePoints=function(t){var a=this.childOfName("line");gd(a.shape,t),a.dirty()},e.prototype.beforeUpdate=function(){var t=this,a=t.childOfName("fromSymbol"),n=t.childOfName("toSymbol"),i=t.getTextContent();if(!a&&!n&&(!i||i.ignore))return;for(var o=1,s=this.parent;s;)s.scaleX&&(o/=s.scaleX),s=s.parent;var l=t.childOfName("line");if(!this.__dirty&&!l.__dirty)return;var u=l.shape.percent,f=l.pointAt(0),h=l.pointAt(u),v=On([],h,f);so(v,v);function c(D,M){var I=D.__specifiedRotation;if(I==null){var L=l.tangentAt(M);D.attr("rotation",(M===1?-1:1)*Math.PI/2-Math.atan2(L[1],L[0]))}else D.attr("rotation",I)}if(a&&(a.setPosition(f),c(a,0),a.scaleX=a.scaleY=o*u,a.markRedraw()),n&&(n.setPosition(h),c(n,1),n.scaleX=n.scaleY=o*u,n.markRedraw()),i&&!i.ignore){i.x=i.y=0,i.originX=i.originY=0;var p=void 0,d=void 0,g=i.__labelDistance,y=g[0]*o,m=g[1]*o,_=u/2,S=l.tangentAt(_),w=[S[1],-S[0]],x=l.pointAt(_);w[1]>0&&(w[0]=-w[0],w[1]=-w[1]);var b=S[0]<0?-1:1;if(i.__position!=="start"&&i.__position!=="end"){var T=-Math.atan2(S[1],S[0]);h[0]<f[0]&&(T=Math.PI+T),i.rotation=T}var A=void 0;switch(i.__position){case"insideStartTop":case"insideMiddleTop":case"insideEndTop":case"middle":A=-m,d="bottom";break;case"insideStartBottom":case"insideMiddleBottom":case"insideEndBottom":A=m,d="top";break;default:A=0,d="middle"}switch(i.__position){case"end":i.x=v[0]*y+h[0],i.y=v[1]*m+h[1],p=v[0]>.8?"left":v[0]<-.8?"right":"center",d=v[1]>.8?"top":v[1]<-.8?"bottom":"middle";break;case"start":i.x=-v[0]*y+f[0],i.y=-v[1]*m+f[1],p=v[0]>.8?"right":v[0]<-.8?"left":"center",d=v[1]>.8?"bottom":v[1]<-.8?"top":"middle";break;case"insideStartTop":case"insideStart":case"insideStartBottom":i.x=y*b+f[0],i.y=f[1]+A,p=S[0]<0?"right":"left",i.originX=-y*b,i.originY=-A;break;case"insideMiddleTop":case"insideMiddle":case"insideMiddleBottom":case"middle":i.x=x[0],i.y=x[1]+A,p="center",i.originY=-A;break;case"insideEndTop":case"insideEnd":case"insideEndBottom":i.x=-y*b+h[0],i.y=h[1]+A,p=S[0]>=0?"right":"left",i.originX=y*b,i.originY=-A;break}i.scaleX=i.scaleY=o,i.setStyle({verticalAlign:i.__verticalAlign||d,align:i.__align||p})}},e}(at);const my=s3;var _y=function(){function r(e){this.group=new at,this._LineCtor=e||my}return r.prototype.updateData=function(e){var t=this;this._progressiveEls=null;var a=this,n=a.group,i=a._lineData;a._lineData=e,i||n.removeAll();var o=AS(e);e.diff(i).add(function(s){t._doAdd(e,s,o)}).update(function(s,l){t._doUpdate(i,e,l,s,o)}).remove(function(s){n.remove(i.getItemGraphicEl(s))}).execute()},r.prototype.updateLayout=function(){var e=this._lineData;e&&e.eachItemGraphicEl(function(t,a){t.updateLayout(e,a)},this)},r.prototype.incrementalPrepareUpdate=function(e){this._seriesScope=AS(e),this._lineData=null,this.group.removeAll()},r.prototype.incrementalUpdate=function(e,t){this._progressiveEls=[];function a(s){!s.isGroup&&!l3(s)&&(s.incremental=!0,s.ensureState("emphasis").hoverLayer=!0)}for(var n=e.start;n<e.end;n++){var i=t.getItemLayout(n);if(hc(i)){var o=new this._LineCtor(t,n,this._seriesScope);o.traverse(a),this.group.add(o),t.setItemGraphicEl(n,o),this._progressiveEls.push(o)}}},r.prototype.remove=function(){this.group.removeAll()},r.prototype.eachRendered=function(e){Ja(this._progressiveEls||this.group,e)},r.prototype._doAdd=function(e,t,a){var n=e.getItemLayout(t);if(hc(n)){var i=new this._LineCtor(e,t,a);e.setItemGraphicEl(t,i),this.group.add(i)}},r.prototype._doUpdate=function(e,t,a,n,i){var o=e.getItemGraphicEl(a);if(!hc(t.getItemLayout(n))){this.group.remove(o);return}o?o.updateData(t,n,i):o=new this._LineCtor(t,n,i),t.setItemGraphicEl(n,o),this.group.add(o)},r}();function l3(r){return r.animators&&r.animators.length>0}function AS(r){var e=r.hostModel,t=e.getModel("emphasis");return{lineStyle:e.getModel("lineStyle").getLineStyle(),emphasisLineStyle:t.getModel(["lineStyle"]).getLineStyle(),blurLineStyle:e.getModel(["blur","lineStyle"]).getLineStyle(),selectLineStyle:e.getModel(["select","lineStyle"]).getLineStyle(),emphasisDisabled:t.get("disabled"),blurScope:t.get("blurScope"),focus:t.get("focus"),labelStatesModels:re(e)}}function CS(r){return isNaN(r[0])||isNaN(r[1])}function hc(r){return r&&!CS(r[0])&&!CS(r[1])}var vc=[],cc=[],pc=[],Mi=ne,dc=Wn,DS=Math.abs;function MS(r,e,t){for(var a=r[0],n=r[1],i=r[2],o=1/0,s,l=t*t,u=.1,f=.1;f<=.9;f+=.1){vc[0]=Mi(a[0],n[0],i[0],f),vc[1]=Mi(a[1],n[1],i[1],f);var h=DS(dc(vc,e)-l);h<o&&(o=h,s=f)}for(var v=0;v<32;v++){var c=s+u;cc[0]=Mi(a[0],n[0],i[0],s),cc[1]=Mi(a[1],n[1],i[1],s),pc[0]=Mi(a[0],n[0],i[0],c),pc[1]=Mi(a[1],n[1],i[1],c);var h=dc(cc,e)-l;if(DS(h)<.01)break;var p=dc(pc,e)-l;u/=2,h<0?p>=0?s=s+u:s=s-u:p>=0?s=s-u:s=s+u}return s}function gc(r,e){var t=[],a=Ls,n=[[],[],[]],i=[[],[]],o=[];e/=2,r.eachEdge(function(s,l){var u=s.getLayout(),f=s.getVisual("fromSymbol"),h=s.getVisual("toSymbol");u.__original||(u.__original=[ta(u[0]),ta(u[1])],u[2]&&u.__original.push(ta(u[2])));var v=u.__original;if(u[2]!=null){if(Se(n[0],v[0]),Se(n[1],v[2]),Se(n[2],v[1]),f&&f!=="none"){var c=hs(s.node1),p=MS(n,v[0],c*e);a(n[0][0],n[1][0],n[2][0],p,t),n[0][0]=t[3],n[1][0]=t[4],a(n[0][1],n[1][1],n[2][1],p,t),n[0][1]=t[3],n[1][1]=t[4]}if(h&&h!=="none"){var c=hs(s.node2),p=MS(n,v[1],c*e);a(n[0][0],n[1][0],n[2][0],p,t),n[1][0]=t[1],n[2][0]=t[2],a(n[0][1],n[1][1],n[2][1],p,t),n[1][1]=t[1],n[2][1]=t[2]}Se(u[0],n[0]),Se(u[1],n[2]),Se(u[2],n[1])}else{if(Se(i[0],v[0]),Se(i[1],v[1]),On(o,i[1],i[0]),so(o,o),f&&f!=="none"){var c=hs(s.node1);ep(i[0],i[0],o,c*e)}if(h&&h!=="none"){var c=hs(s.node2);ep(i[1],i[1],o,-c*e)}Se(u[0],i[0]),Se(u[1],i[1])}})}function IS(r){return r.type==="view"}var u3=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,a){var n=new gl,i=new _y,o=this.group;this._controller=new xl(a.getZr()),this._controllerHost={target:o},o.add(n.group),o.add(i.group),this._symbolDraw=n,this._lineDraw=i,this._firstRender=!0},e.prototype.render=function(t,a,n){var i=this,o=t.coordinateSystem;this._model=t;var s=this._symbolDraw,l=this._lineDraw,u=this.group;if(IS(o)){var f={x:o.x,y:o.y,scaleX:o.scaleX,scaleY:o.scaleY};this._firstRender?u.attr(f):Dt(u,f,t)}gc(t.getGraph(),fs(t));var h=t.getData();s.updateData(h);var v=t.getEdgeData();l.updateData(v),this._updateNodeAndLinkScale(),this._updateController(t,a,n),clearTimeout(this._layoutTimeout);var c=t.forceLayout,p=t.get(["force","layoutAnimation"]);c&&this._startForceLayoutIteration(c,p);var d=t.get("layout");h.graph.eachNode(function(_){var S=_.dataIndex,w=_.getGraphicEl(),x=_.getModel();if(w){w.off("drag").off("dragend");var b=x.get("draggable");b&&w.on("drag",function(A){switch(d){case"force":c.warmUp(),!i._layouting&&i._startForceLayoutIteration(c,p),c.setFixed(S),h.setItemLayout(S,[w.x,w.y]);break;case"circular":h.setItemLayout(S,[w.x,w.y]),_.setLayout({fixed:!0},!0),yy(t,"symbolSize",_,[A.offsetX,A.offsetY]),i.updateLayout(t);break;case"none":default:h.setItemLayout(S,[w.x,w.y]),gy(t.getGraph(),t),i.updateLayout(t);break}}).on("dragend",function(){c&&c.setUnfixed(S)}),w.setDraggable(b,!!x.get("cursor"));var T=x.get(["emphasis","focus"]);T==="adjacency"&&(nt(w).focus=_.getAdjacentDataIndices())}}),h.graph.eachEdge(function(_){var S=_.getGraphicEl(),w=_.getModel().get(["emphasis","focus"]);S&&w==="adjacency"&&(nt(S).focus={edge:[_.dataIndex],node:[_.node1.dataIndex,_.node2.dataIndex]})});var g=t.get("layout")==="circular"&&t.get(["circular","rotateLabel"]),y=h.getLayout("cx"),m=h.getLayout("cy");h.graph.eachNode(function(_){_M(_,g,y,m)}),this._firstRender=!1},e.prototype.dispose=function(){this.remove(),this._controller&&this._controller.dispose(),this._controllerHost=null},e.prototype._startForceLayoutIteration=function(t,a){var n=this;(function i(){t.step(function(o){n.updateLayout(n._model),(n._layouting=!o)&&(a?n._layoutTimeout=setTimeout(i,16):i())})})()},e.prototype._updateController=function(t,a,n){var i=this,o=this._controller,s=this._controllerHost,l=this.group;if(o.setPointerChecker(function(u,f,h){var v=l.getBoundingRect();return v.applyTransform(l.transform),v.contain(f,h)&&!xh(u,n,t)}),!IS(t.coordinateSystem)){o.disable();return}o.enable(t.get("roam")),s.zoomLimit=t.get("scaleLimit"),s.zoom=t.coordinateSystem.getZoom(),o.off("pan").off("zoom").on("pan",function(u){oy(s,u.dx,u.dy),n.dispatchAction({seriesId:t.id,type:"graphRoam",dx:u.dx,dy:u.dy})}).on("zoom",function(u){sy(s,u.scale,u.originX,u.originY),n.dispatchAction({seriesId:t.id,type:"graphRoam",zoom:u.scale,originX:u.originX,originY:u.originY}),i._updateNodeAndLinkScale(),gc(t.getGraph(),fs(t)),i._lineDraw.updateLayout(),n.updateLabelLayout()})},e.prototype._updateNodeAndLinkScale=function(){var t=this._model,a=t.getData(),n=fs(t);a.eachItemGraphicEl(function(i,o){i&&i.setSymbolScale(n)})},e.prototype.updateLayout=function(t){gc(t.getGraph(),fs(t)),this._symbolDraw.updateLayout(),this._lineDraw.updateLayout()},e.prototype.remove=function(){clearTimeout(this._layoutTimeout),this._layouting=!1,this._layoutTimeout=null,this._symbolDraw&&this._symbolDraw.remove(),this._lineDraw&&this._lineDraw.remove()},e.type="graph",e}(Nt);const f3=u3;function Ii(r){return"_EC_"+r}var h3=function(){function r(e){this.type="graph",this.nodes=[],this.edges=[],this._nodesMap={},this._edgesMap={},this._directed=e||!1}return r.prototype.isDirected=function(){return this._directed},r.prototype.addNode=function(e,t){e=e==null?""+t:""+e;var a=this._nodesMap;if(!a[Ii(e)]){var n=new In(e,t);return n.hostGraph=this,this.nodes.push(n),a[Ii(e)]=n,n}},r.prototype.getNodeByIndex=function(e){var t=this.data.getRawIndex(e);return this.nodes[t]},r.prototype.getNodeById=function(e){return this._nodesMap[Ii(e)]},r.prototype.addEdge=function(e,t,a){var n=this._nodesMap,i=this._edgesMap;if(Ct(e)&&(e=this.nodes[e]),Ct(t)&&(t=this.nodes[t]),e instanceof In||(e=n[Ii(e)]),t instanceof In||(t=n[Ii(t)]),!(!e||!t)){var o=e.id+"-"+t.id,s=new xM(e,t,a);return s.hostGraph=this,this._directed&&(e.outEdges.push(s),t.inEdges.push(s)),e.edges.push(s),e!==t&&t.edges.push(s),this.edges.push(s),i[o]=s,s}},r.prototype.getEdgeByIndex=function(e){var t=this.edgeData.getRawIndex(e);return this.edges[t]},r.prototype.getEdge=function(e,t){e instanceof In&&(e=e.id),t instanceof In&&(t=t.id);var a=this._edgesMap;return this._directed?a[e+"-"+t]:a[e+"-"+t]||a[t+"-"+e]},r.prototype.eachNode=function(e,t){for(var a=this.nodes,n=a.length,i=0;i<n;i++)a[i].dataIndex>=0&&e.call(t,a[i],i)},r.prototype.eachEdge=function(e,t){for(var a=this.edges,n=a.length,i=0;i<n;i++)a[i].dataIndex>=0&&a[i].node1.dataIndex>=0&&a[i].node2.dataIndex>=0&&e.call(t,a[i],i)},r.prototype.breadthFirstTraverse=function(e,t,a,n){if(t instanceof In||(t=this._nodesMap[Ii(t)]),!!t){for(var i=a==="out"?"outEdges":a==="in"?"inEdges":"edges",o=0;o<this.nodes.length;o++)this.nodes[o].__visited=!1;if(!e.call(n,t,null))for(var s=[t];s.length;)for(var l=s.shift(),u=l[i],o=0;o<u.length;o++){var f=u[o],h=f.node1===l?f.node2:f.node1;if(!h.__visited){if(e.call(n,h,l))return;s.push(h),h.__visited=!0}}}},r.prototype.update=function(){for(var e=this.data,t=this.edgeData,a=this.nodes,n=this.edges,i=0,o=a.length;i<o;i++)a[i].dataIndex=-1;for(var i=0,o=e.count();i<o;i++)a[e.getRawIndex(i)].dataIndex=i;t.filterSelf(function(s){var l=n[t.getRawIndex(s)];return l.node1.dataIndex>=0&&l.node2.dataIndex>=0});for(var i=0,o=n.length;i<o;i++)n[i].dataIndex=-1;for(var i=0,o=t.count();i<o;i++)n[t.getRawIndex(i)].dataIndex=i},r.prototype.clone=function(){for(var e=new r(this._directed),t=this.nodes,a=this.edges,n=0;n<t.length;n++)e.addNode(t[n].id,t[n].dataIndex);for(var n=0;n<a.length;n++){var i=a[n];e.addEdge(i.node1.id,i.node2.id,i.dataIndex)}return e},r}(),In=function(){function r(e,t){this.inEdges=[],this.outEdges=[],this.edges=[],this.dataIndex=-1,this.id=e??"",this.dataIndex=t??-1}return r.prototype.degree=function(){return this.edges.length},r.prototype.inDegree=function(){return this.inEdges.length},r.prototype.outDegree=function(){return this.outEdges.length},r.prototype.getModel=function(e){if(!(this.dataIndex<0)){var t=this.hostGraph,a=t.data.getItemModel(this.dataIndex);return a.getModel(e)}},r.prototype.getAdjacentDataIndices=function(){for(var e={edge:[],node:[]},t=0;t<this.edges.length;t++){var a=this.edges[t];a.dataIndex<0||(e.edge.push(a.dataIndex),e.node.push(a.node1.dataIndex,a.node2.dataIndex))}return e},r.prototype.getTrajectoryDataIndices=function(){for(var e=Z(),t=Z(),a=0;a<this.edges.length;a++){var n=this.edges[a];if(!(n.dataIndex<0)){e.set(n.dataIndex,!0);for(var i=[n.node1],o=[n.node2],s=0;s<i.length;){var l=i[s];s++,t.set(l.dataIndex,!0);for(var u=0;u<l.inEdges.length;u++)e.set(l.inEdges[u].dataIndex,!0),i.push(l.inEdges[u].node1)}for(s=0;s<o.length;){var f=o[s];s++,t.set(f.dataIndex,!0);for(var u=0;u<f.outEdges.length;u++)e.set(f.outEdges[u].dataIndex,!0),o.push(f.outEdges[u].node2)}}}return{edge:e.keys(),node:t.keys()}},r}(),xM=function(){function r(e,t,a){this.dataIndex=-1,this.node1=e,this.node2=t,this.dataIndex=a??-1}return r.prototype.getModel=function(e){if(!(this.dataIndex<0)){var t=this.hostGraph,a=t.edgeData.getItemModel(this.dataIndex);return a.getModel(e)}},r.prototype.getAdjacentDataIndices=function(){return{edge:[this.dataIndex],node:[this.node1.dataIndex,this.node2.dataIndex]}},r.prototype.getTrajectoryDataIndices=function(){var e=Z(),t=Z();e.set(this.dataIndex,!0);for(var a=[this.node1],n=[this.node2],i=0;i<a.length;){var o=a[i];i++,t.set(o.dataIndex,!0);for(var s=0;s<o.inEdges.length;s++)e.set(o.inEdges[s].dataIndex,!0),a.push(o.inEdges[s].node1)}for(i=0;i<n.length;){var l=n[i];i++,t.set(l.dataIndex,!0);for(var s=0;s<l.outEdges.length;s++)e.set(l.outEdges[s].dataIndex,!0),n.push(l.outEdges[s].node2)}return{edge:e.keys(),node:t.keys()}},r}();function wM(r,e){return{getValue:function(t){var a=this[r][e];return a.getStore().get(a.getDimensionIndex(t||"value"),this.dataIndex)},setVisual:function(t,a){this.dataIndex>=0&&this[r][e].setItemVisual(this.dataIndex,t,a)},getVisual:function(t){return this[r][e].getItemVisual(this.dataIndex,t)},setLayout:function(t,a){this.dataIndex>=0&&this[r][e].setItemLayout(this.dataIndex,t,a)},getLayout:function(){return this[r][e].getItemLayout(this.dataIndex)},getGraphicEl:function(){return this[r][e].getItemGraphicEl(this.dataIndex)},getRawIndex:function(){return this[r][e].getRawIndex(this.dataIndex)}}}Kt(In,wM("hostGraph","data"));Kt(xM,wM("hostGraph","edgeData"));function bM(r,e,t,a,n){for(var i=new h3(a),o=0;o<r.length;o++)i.addNode(ie(r[o].id,r[o].name,o),o);for(var s=[],l=[],u=0,o=0;o<e.length;o++){var f=e[o],h=f.source,v=f.target;i.addEdge(h,v,u)&&(l.push(f),s.push(ie(Qt(f.id,null),h+" > "+v)),u++)}var c=t.get("coordinateSystem"),p;if(c==="cartesian2d"||c==="polar")p=va(r,t);else{var d=fl.get(c),g=d?d.dimensions||[]:[];vt(g,"value")<0&&g.concat(["value"]);var y=vl(r,{coordDimensions:g,encodeDefine:t.getEncode()}).dimensions;p=new be(y,t),p.initData(r)}var m=new be(["value"],t);return m.initData(l,s),n&&n(p,m),nM({mainData:p,struct:i,structAttr:"graph",datas:{node:p,edge:m},datasAttr:{node:"data",edge:"edgeData"}}),i.update(),i}var v3=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t}return e.prototype.init=function(t){r.prototype.init.apply(this,arguments);var a=this;function n(){return a._categoriesData}this.legendVisualProvider=new Sl(n,n),this.fillDataTextStyle(t.edges||t.links),this._updateCategoriesData()},e.prototype.mergeOption=function(t){r.prototype.mergeOption.apply(this,arguments),this.fillDataTextStyle(t.edges||t.links),this._updateCategoriesData()},e.prototype.mergeDefaultAndTheme=function(t){r.prototype.mergeDefaultAndTheme.apply(this,arguments),Jn(t,"edgeLabel",["show"])},e.prototype.getInitialData=function(t,a){var n=t.edges||t.links||[],i=t.data||t.nodes||[],o=this;if(i&&n){KF(this);var s=bM(i,n,this,!0,l);return C(s.edges,function(u){QF(u.node1,u.node2,this,u.dataIndex)},this),s.data}function l(u,f){u.wrapMethod("getItemModel",function(p){var d=o._categoriesModels,g=p.getShallow("category"),y=d[g];return y&&(y.parentModel=p.parentModel,p.parentModel=y),p});var h=Ot.prototype.getModel;function v(p,d){var g=h.call(this,p,d);return g.resolveParentPath=c,g}f.wrapMethod("getItemModel",function(p){return p.resolveParentPath=c,p.getModel=v,p});function c(p){if(p&&(p[0]==="label"||p[1]==="label")){var d=p.slice();return p[0]==="label"?d[0]="edgeLabel":p[1]==="label"&&(d[1]="edgeLabel"),d}return p}}},e.prototype.getGraph=function(){return this.getData().graph},e.prototype.getEdgeData=function(){return this.getGraph().edgeData},e.prototype.getCategoriesData=function(){return this._categoriesData},e.prototype.formatTooltip=function(t,a,n){if(n==="edge"){var i=this.getData(),o=this.getDataParams(t,n),s=i.graph.getEdgeByIndex(t),l=i.getName(s.node1.dataIndex),u=i.getName(s.node2.dataIndex),f=[];return l!=null&&f.push(l),u!=null&&f.push(u),ae("nameValue",{name:f.join(" > "),value:o.value,noValue:o.value==null})}var h=$A({series:this,dataIndex:t,multipleSeries:a});return h},e.prototype._updateCategoriesData=function(){var t=G(this.option.categories||[],function(n){return n.value!=null?n:V({value:0},n)}),a=new be(["value"],this);a.initData(t),this._categoriesData=a,this._categoriesModels=a.mapArray(function(n){return a.getItemModel(n)})},e.prototype.setZoom=function(t){this.option.zoom=t},e.prototype.setCenter=function(t){this.option.center=t},e.prototype.isAnimationEnabled=function(){return r.prototype.isAnimationEnabled.call(this)&&!(this.get("layout")==="force"&&this.get(["force","layoutAnimation"]))},e.type="series.graph",e.dependencies=["grid","polar","geo","singleAxis","calendar"],e.defaultOption={z:2,coordinateSystem:"view",legendHoverLink:!0,layout:null,circular:{rotateLabel:!1},force:{initLayout:null,repulsion:[0,50],gravity:.1,friction:.6,edgeLength:30,layoutAnimation:!0},left:"center",top:"center",symbol:"circle",symbolSize:10,edgeSymbol:["none","none"],edgeSymbolSize:10,edgeLabel:{position:"middle",distance:5},draggable:!1,roam:!1,center:null,zoom:1,nodeScaleRatio:.6,label:{show:!1,formatter:"{b}"},itemStyle:{},lineStyle:{color:"#aaa",width:1,opacity:.5},emphasis:{scale:!0,label:{show:!0}},select:{itemStyle:{borderColor:"#212121"}}},e}(zt);const c3=v3;var p3={type:"graphRoam",event:"graphRoam",update:"none"};function d3(r){r.registerChartView(f3),r.registerSeriesModel(c3),r.registerProcessor(UF),r.registerVisual(YF),r.registerVisual(ZF),r.registerLayout(JF),r.registerLayout(r.PRIORITY.VISUAL.POST_CHART_LAYOUT,t3),r.registerLayout(r3),r.registerCoordinateSystem("graphView",{dimensions:wl.dimensions,create:n3}),r.registerAction({type:"focusNodeAdjacency",event:"focusNodeAdjacency",update:"series:focusNodeAdjacency"},Yt),r.registerAction({type:"unfocusNodeAdjacency",event:"unfocusNodeAdjacency",update:"series:unfocusNodeAdjacency"},Yt),r.registerAction(p3,function(e,t,a){t.eachComponent({mainType:"series",query:e},function(n){var i=n.coordinateSystem,o=uy(i,e,void 0,a);n.setCenter&&n.setCenter(o.center),n.setZoom&&n.setZoom(o.zoom)})})}var g3=function(){function r(){this.angle=0,this.width=10,this.r=10,this.x=0,this.y=0}return r}(),y3=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a.type="pointer",a}return e.prototype.getDefaultShape=function(){return new g3},e.prototype.buildPath=function(t,a){var n=Math.cos,i=Math.sin,o=a.r,s=a.width,l=a.angle,u=a.x-n(l)*s*(s>=o/3?1:2),f=a.y-i(l)*s*(s>=o/3?1:2);l=a.angle-Math.PI/2,t.moveTo(u,f),t.lineTo(a.x+n(l)*s,a.y+i(l)*s),t.lineTo(a.x+n(a.angle)*o,a.y+i(a.angle)*o),t.lineTo(a.x-n(l)*s,a.y-i(l)*s),t.lineTo(u,f)},e}(yt);function m3(r,e){var t=r.get("center"),a=e.getWidth(),n=e.getHeight(),i=Math.min(a,n),o=W(t[0],e.getWidth()),s=W(t[1],e.getHeight()),l=W(r.get("radius"),i/2);return{cx:o,cy:s,r:l}}function gu(r,e){var t=r==null?"":r+"";return e&&($(e)?t=e.replace("{value}",t):K(e)&&(t=e(r))),t}var _3=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){this.group.removeAll();var i=t.get(["axisLine","lineStyle","color"]),o=m3(t,n);this._renderMain(t,a,n,i,o),this._data=t.getData()},e.prototype.dispose=function(){},e.prototype._renderMain=function(t,a,n,i,o){var s=this.group,l=t.get("clockwise"),u=-t.get("startAngle")/180*Math.PI,f=-t.get("endAngle")/180*Math.PI,h=t.getModel("axisLine"),v=h.get("roundCap"),c=v?Tf:Be,p=h.get("show"),d=h.getModel("lineStyle"),g=d.get("width"),y=[u,f];og(y,!l),u=y[0],f=y[1];for(var m=f-u,_=u,S=[],w=0;p&&w<i.length;w++){var x=Math.min(Math.max(i[w][0],0),1);f=u+m*x;var b=new c({shape:{startAngle:_,endAngle:f,cx:o.cx,cy:o.cy,clockwise:l,r0:o.r-g,r:o.r},silent:!0});b.setStyle({fill:i[w][1]}),b.setStyle(d.getLineStyle(["color","width"])),S.push(b),_=f}S.reverse(),C(S,function(A){return s.add(A)});var T=function(A){if(A<=0)return i[0][1];var D;for(D=0;D<i.length;D++)if(i[D][0]>=A&&(D===0?0:i[D-1][0])<A)return i[D][1];return i[D-1][1]};this._renderTicks(t,a,n,T,o,u,f,l,g),this._renderTitleAndDetail(t,a,n,T,o),this._renderAnchor(t,o),this._renderPointer(t,a,n,T,o,u,f,l,g)},e.prototype._renderTicks=function(t,a,n,i,o,s,l,u,f){for(var h=this.group,v=o.cx,c=o.cy,p=o.r,d=+t.get("min"),g=+t.get("max"),y=t.getModel("splitLine"),m=t.getModel("axisTick"),_=t.getModel("axisLabel"),S=t.get("splitNumber"),w=m.get("splitNumber"),x=W(y.get("length"),p),b=W(m.get("length"),p),T=s,A=(l-s)/S,D=A/w,M=y.getModel("lineStyle").getLineStyle(),I=m.getModel("lineStyle").getLineStyle(),L=y.get("distance"),P,R,E=0;E<=S;E++){if(P=Math.cos(T),R=Math.sin(T),y.get("show")){var N=L?L+f:f,O=new te({shape:{x1:P*(p-N)+v,y1:R*(p-N)+c,x2:P*(p-x-N)+v,y2:R*(p-x-N)+c},style:M,silent:!0});M.stroke==="auto"&&O.setStyle({stroke:i(E/S)}),h.add(O)}if(_.get("show")){var N=_.get("distance")+L,B=gu($t(E/S*(g-d)+d),_.get("formatter")),F=i(E/S),H=P*(p-x-N)+v,X=R*(p-x-N)+c,Q=_.get("rotate"),J=0;Q==="radial"?(J=-T+2*Math.PI,J>Math.PI/2&&(J+=Math.PI)):Q==="tangential"?J=-T-Math.PI/2:Ct(Q)&&(J=Q*Math.PI/180),J===0?h.add(new At({style:kt(_,{text:B,x:H,y:X,verticalAlign:R<-.8?"top":R>.8?"bottom":"middle",align:P<-.4?"left":P>.4?"right":"center"},{inheritColor:F}),silent:!0})):h.add(new At({style:kt(_,{text:B,x:H,y:X,verticalAlign:"middle",align:"center"},{inheritColor:F}),silent:!0,originX:H,originY:X,rotation:J}))}if(m.get("show")&&E!==S){var N=m.get("distance");N=N?N+f:f;for(var ct=0;ct<=w;ct++){P=Math.cos(T),R=Math.sin(T);var St=new te({shape:{x1:P*(p-N)+v,y1:R*(p-N)+c,x2:P*(p-b-N)+v,y2:R*(p-b-N)+c},silent:!0,style:I});I.stroke==="auto"&&St.setStyle({stroke:i((E+ct/w)/S)}),h.add(St),T+=D}T-=D}else T+=A}},e.prototype._renderPointer=function(t,a,n,i,o,s,l,u,f){var h=this.group,v=this._data,c=this._progressEls,p=[],d=t.get(["pointer","show"]),g=t.getModel("progress"),y=g.get("show"),m=t.getData(),_=m.mapDimension("value"),S=+t.get("min"),w=+t.get("max"),x=[S,w],b=[s,l];function T(D,M){var I=m.getItemModel(D),L=I.getModel("pointer"),P=W(L.get("width"),o.r),R=W(L.get("length"),o.r),E=t.get(["pointer","icon"]),N=L.get("offsetCenter"),O=W(N[0],o.r),B=W(N[1],o.r),F=L.get("keepAspect"),H;return E?H=qt(E,O-P/2,B-R,P,R,null,F):H=new y3({shape:{angle:-Math.PI/2,width:P,r:R,x:O,y:B}}),H.rotation=-(M+Math.PI/2),H.x=o.cx,H.y=o.cy,H}function A(D,M){var I=g.get("roundCap"),L=I?Tf:Be,P=g.get("overlap"),R=P?g.get("width"):f/m.count(),E=P?o.r-R:o.r-(D+1)*R,N=P?o.r:o.r-D*R,O=new L({shape:{startAngle:s,endAngle:M,cx:o.cx,cy:o.cy,clockwise:u,r0:E,r:N}});return P&&(O.z2=w-m.get(_,D)%w),O}(y||d)&&(m.diff(v).add(function(D){var M=m.get(_,D);if(d){var I=T(D,s);Bt(I,{rotation:-((isNaN(+M)?b[0]:It(M,x,b,!0))+Math.PI/2)},t),h.add(I),m.setItemGraphicEl(D,I)}if(y){var L=A(D,s),P=g.get("clip");Bt(L,{shape:{endAngle:It(M,x,b,P)}},t),h.add(L),Mp(t.seriesIndex,m.dataType,D,L),p[D]=L}}).update(function(D,M){var I=m.get(_,D);if(d){var L=v.getItemGraphicEl(M),P=L?L.rotation:s,R=T(D,P);R.rotation=P,Dt(R,{rotation:-((isNaN(+I)?b[0]:It(I,x,b,!0))+Math.PI/2)},t),h.add(R),m.setItemGraphicEl(D,R)}if(y){var E=c[M],N=E?E.shape.endAngle:s,O=A(D,N),B=g.get("clip");Dt(O,{shape:{endAngle:It(I,x,b,B)}},t),h.add(O),Mp(t.seriesIndex,m.dataType,D,O),p[D]=O}}).execute(),m.each(function(D){var M=m.getItemModel(D),I=M.getModel("emphasis"),L=I.get("focus"),P=I.get("blurScope"),R=I.get("disabled");if(d){var E=m.getItemGraphicEl(D),N=m.getItemVisual(D,"style"),O=N.fill;if(E instanceof he){var B=E.style;E.useStyle(V({image:B.image,x:B.x,y:B.y,width:B.width,height:B.height},N))}else E.useStyle(N),E.type!=="pointer"&&E.setColor(O);E.setStyle(M.getModel(["pointer","itemStyle"]).getItemStyle()),E.style.fill==="auto"&&E.setStyle("fill",i(It(m.get(_,D),x,[0,1],!0))),E.z2EmphasisLift=0,ue(E,M),Ft(E,L,P,R)}if(y){var F=p[D];F.useStyle(m.getItemVisual(D,"style")),F.setStyle(M.getModel(["progress","itemStyle"]).getItemStyle()),F.z2EmphasisLift=0,ue(F,M),Ft(F,L,P,R)}}),this._progressEls=p)},e.prototype._renderAnchor=function(t,a){var n=t.getModel("anchor"),i=n.get("show");if(i){var o=n.get("size"),s=n.get("icon"),l=n.get("offsetCenter"),u=n.get("keepAspect"),f=qt(s,a.cx-o/2+W(l[0],a.r),a.cy-o/2+W(l[1],a.r),o,o,null,u);f.z2=n.get("showAbove")?1:0,f.setStyle(n.getModel("itemStyle").getItemStyle()),this.group.add(f)}},e.prototype._renderTitleAndDetail=function(t,a,n,i,o){var s=this,l=t.getData(),u=l.mapDimension("value"),f=+t.get("min"),h=+t.get("max"),v=new at,c=[],p=[],d=t.isAnimationEnabled(),g=t.get(["pointer","showAbove"]);l.diff(this._data).add(function(y){c[y]=new At({silent:!0}),p[y]=new At({silent:!0})}).update(function(y,m){c[y]=s._titleEls[m],p[y]=s._detailEls[m]}).execute(),l.each(function(y){var m=l.getItemModel(y),_=l.get(u,y),S=new at,w=i(It(_,[f,h],[0,1],!0)),x=m.getModel("title");if(x.get("show")){var b=x.get("offsetCenter"),T=o.cx+W(b[0],o.r),A=o.cy+W(b[1],o.r),D=c[y];D.attr({z2:g?0:2,style:kt(x,{x:T,y:A,text:l.getName(y),align:"center",verticalAlign:"middle"},{inheritColor:w})}),S.add(D)}var M=m.getModel("detail");if(M.get("show")){var I=M.get("offsetCenter"),L=o.cx+W(I[0],o.r),P=o.cy+W(I[1],o.r),R=W(M.get("width"),o.r),E=W(M.get("height"),o.r),N=t.get(["progress","show"])?l.getItemVisual(y,"style").fill:w,D=p[y],O=M.get("formatter");D.attr({z2:g?0:2,style:kt(M,{x:L,y:P,text:gu(_,O),width:isNaN(R)?null:R,height:isNaN(E)?null:E,align:"center",verticalAlign:"middle"},{inheritColor:N})}),XT(D,{normal:M},_,function(F){return gu(F,O)}),d&&qT(D,y,l,t,{getFormattedLabel:function(F,H,X,Q,J,ct){return gu(ct?ct.interpolatedValue:_,O)}}),S.add(D)}v.add(S)}),this.group.add(v),this._titleEls=c,this._detailEls=p},e.type="gauge",e}(Nt);const S3=_3;var x3=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.visualStyleAccessPath="itemStyle",t}return e.prototype.getInitialData=function(t,a){return To(this,["value"])},e.type="series.gauge",e.defaultOption={z:2,colorBy:"data",center:["50%","50%"],legendHoverLink:!0,radius:"75%",startAngle:225,endAngle:-45,clockwise:!0,min:0,max:100,splitNumber:10,axisLine:{show:!0,roundCap:!1,lineStyle:{color:[[1,"#E6EBF8"]],width:10}},progress:{show:!1,overlap:!0,width:10,roundCap:!1,clip:!0},splitLine:{show:!0,length:10,distance:10,lineStyle:{color:"#63677A",width:3,type:"solid"}},axisTick:{show:!0,splitNumber:5,length:6,distance:10,lineStyle:{color:"#63677A",width:1,type:"solid"}},axisLabel:{show:!0,distance:15,color:"#464646",fontSize:12,rotate:0},pointer:{icon:null,offsetCenter:[0,0],show:!0,showAbove:!0,length:"60%",width:6,keepAspect:!1},anchor:{show:!1,showAbove:!1,size:6,icon:"circle",offsetCenter:[0,0],keepAspect:!1,itemStyle:{color:"#fff",borderWidth:0,borderColor:"#5470c6"}},title:{show:!0,offsetCenter:[0,"20%"],color:"#464646",fontSize:16,valueAnimation:!1},detail:{show:!0,backgroundColor:"rgba(0,0,0,0)",borderWidth:0,borderColor:"#ccc",width:100,height:null,padding:[5,10],offsetCenter:[0,"40%"],color:"#464646",fontSize:30,fontWeight:"bold",lineHeight:30,valueAnimation:!1}},e}(zt);const w3=x3;function b3(r){r.registerChartView(S3),r.registerSeriesModel(w3)}var T3=["itemStyle","opacity"],A3=function(r){k(e,r);function e(t,a){var n=r.call(this)||this,i=n,o=new Me,s=new At;return i.setTextContent(s),n.setTextGuideLine(o),n.updateData(t,a,!0),n}return e.prototype.updateData=function(t,a,n){var i=this,o=t.hostModel,s=t.getItemModel(a),l=t.getItemLayout(a),u=s.getModel("emphasis"),f=s.get(T3);f=f??1,n||Sr(i),i.useStyle(t.getItemVisual(a,"style")),i.style.lineJoin="round",n?(i.setShape({points:l.points}),i.style.opacity=0,Bt(i,{style:{opacity:f}},o,a)):Dt(i,{style:{opacity:f},shape:{points:l.points}},o,a),ue(i,s),this._updateLabel(t,a),Ft(this,u.get("focus"),u.get("blurScope"),u.get("disabled"))},e.prototype._updateLabel=function(t,a){var n=this,i=this.getTextGuideLine(),o=n.getTextContent(),s=t.hostModel,l=t.getItemModel(a),u=t.getItemLayout(a),f=u.label,h=t.getItemVisual(a,"style"),v=h.fill;fe(o,re(l),{labelFetcher:t.hostModel,labelDataIndex:a,defaultOpacity:h.opacity,defaultText:t.getName(a)},{normal:{align:f.textAlign,verticalAlign:f.verticalAlign}}),n.setTextConfig({local:!0,inside:!!f.inside,insideStroke:v,outsideFill:v});var c=f.linePoints;i.setShape({points:c}),n.textGuideLineConfig={anchor:c?new ut(c[0][0],c[0][1]):null},Dt(o,{style:{x:f.x,y:f.y}},s,a),o.attr({rotation:f.rotation,originX:f.x,originY:f.y,z2:10}),Kg(n,Qg(l),{stroke:v})},e}(De),C3=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.ignoreLabelLineUpdate=!0,t}return e.prototype.render=function(t,a,n){var i=t.getData(),o=this._data,s=this.group;i.diff(o).add(function(l){var u=new A3(i,l);i.setItemGraphicEl(l,u),s.add(u)}).update(function(l,u){var f=o.getItemGraphicEl(u);f.updateData(i,l),s.add(f),i.setItemGraphicEl(l,f)}).remove(function(l){var u=o.getItemGraphicEl(l);Vs(u,t,l)}).execute(),this._data=i},e.prototype.remove=function(){this.group.removeAll(),this._data=null},e.prototype.dispose=function(){},e.type="funnel",e}(Nt);const D3=C3;var M3=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new Sl(U(this.getData,this),U(this.getRawData,this)),this._defaultLabelLine(t)},e.prototype.getInitialData=function(t,a){return To(this,{coordDimensions:["value"],encodeDefaulter:ot(Ag,this)})},e.prototype._defaultLabelLine=function(t){Jn(t,"labelLine",["show"]);var a=t.labelLine,n=t.emphasis.labelLine;a.show=a.show&&t.label.show,n.show=n.show&&t.emphasis.label.show},e.prototype.getDataParams=function(t){var a=this.getData(),n=r.prototype.getDataParams.call(this,t),i=a.mapDimension("value"),o=a.getSum(i);return n.percent=o?+(a.get(i,t)/o*100).toFixed(2):0,n.$vars.push("percent"),n},e.type="series.funnel",e.defaultOption={z:2,legendHoverLink:!0,colorBy:"data",left:80,top:60,right:80,bottom:60,minSize:"0%",maxSize:"100%",sort:"descending",orient:"vertical",gap:0,funnelAlign:"center",label:{show:!0,position:"outer"},labelLine:{show:!0,length:20,lineStyle:{width:1}},itemStyle:{borderColor:"#fff",borderWidth:1},emphasis:{label:{show:!0}},select:{itemStyle:{borderColor:"#212121"}}},e}(zt);const I3=M3;function L3(r,e){return Jt(r.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()})}function P3(r,e){for(var t=r.mapDimension("value"),a=r.mapArray(t,function(l){return l}),n=[],i=e==="ascending",o=0,s=r.count();o<s;o++)n[o]=o;return K(e)?n.sort(e):e!=="none"&&n.sort(function(l,u){return i?a[l]-a[u]:a[u]-a[l]}),n}function R3(r){var e=r.hostModel,t=e.get("orient");r.each(function(a){var n=r.getItemModel(a),i=n.getModel("label"),o=i.get("position"),s=n.getModel("labelLine"),l=r.getItemLayout(a),u=l.points,f=o==="inner"||o==="inside"||o==="center"||o==="insideLeft"||o==="insideRight",h,v,c,p;if(f)o==="insideLeft"?(v=(u[0][0]+u[3][0])/2+5,c=(u[0][1]+u[3][1])/2,h="left"):o==="insideRight"?(v=(u[1][0]+u[2][0])/2-5,c=(u[1][1]+u[2][1])/2,h="right"):(v=(u[0][0]+u[1][0]+u[2][0]+u[3][0])/4,c=(u[0][1]+u[1][1]+u[2][1]+u[3][1])/4,h="center"),p=[[v,c],[v,c]];else{var d=void 0,g=void 0,y=void 0,m=void 0,_=s.get("length");o==="left"?(d=(u[3][0]+u[0][0])/2,g=(u[3][1]+u[0][1])/2,y=d-_,v=y-5,h="right"):o==="right"?(d=(u[1][0]+u[2][0])/2,g=(u[1][1]+u[2][1])/2,y=d+_,v=y+5,h="left"):o==="top"?(d=(u[3][0]+u[0][0])/2,g=(u[3][1]+u[0][1])/2,m=g-_,c=m-5,h="center"):o==="bottom"?(d=(u[1][0]+u[2][0])/2,g=(u[1][1]+u[2][1])/2,m=g+_,c=m+5,h="center"):o==="rightTop"?(d=t==="horizontal"?u[3][0]:u[1][0],g=t==="horizontal"?u[3][1]:u[1][1],t==="horizontal"?(m=g-_,c=m-5,h="center"):(y=d+_,v=y+5,h="top")):o==="rightBottom"?(d=u[2][0],g=u[2][1],t==="horizontal"?(m=g+_,c=m+5,h="center"):(y=d+_,v=y+5,h="bottom")):o==="leftTop"?(d=u[0][0],g=t==="horizontal"?u[0][1]:u[1][1],t==="horizontal"?(m=g-_,c=m-5,h="center"):(y=d-_,v=y-5,h="right")):o==="leftBottom"?(d=t==="horizontal"?u[1][0]:u[3][0],g=t==="horizontal"?u[1][1]:u[2][1],t==="horizontal"?(m=g+_,c=m+5,h="center"):(y=d-_,v=y-5,h="right")):(d=(u[1][0]+u[2][0])/2,g=(u[1][1]+u[2][1])/2,t==="horizontal"?(m=g+_,c=m+5,h="center"):(y=d+_,v=y+5,h="left")),t==="horizontal"?(y=d,v=y):(m=g,c=m),p=[[d,g],[y,m]]}l.label={linePoints:p,x:v,y:c,verticalAlign:"middle",textAlign:h,inside:f}})}function E3(r,e){r.eachSeriesByType("funnel",function(t){var a=t.getData(),n=a.mapDimension("value"),i=t.get("sort"),o=L3(t,e),s=t.get("orient"),l=o.width,u=o.height,f=P3(a,i),h=o.x,v=o.y,c=s==="horizontal"?[W(t.get("minSize"),u),W(t.get("maxSize"),u)]:[W(t.get("minSize"),l),W(t.get("maxSize"),l)],p=a.getDataExtent(n),d=t.get("min"),g=t.get("max");d==null&&(d=Math.min(p[0],0)),g==null&&(g=p[1]);var y=t.get("funnelAlign"),m=t.get("gap"),_=s==="horizontal"?l:u,S=(_-m*(a.count()-1))/a.count(),w=function(P,R){if(s==="horizontal"){var E=a.get(n,P)||0,N=It(E,[d,g],c,!0),O=void 0;switch(y){case"top":O=v;break;case"center":O=v+(u-N)/2;break;case"bottom":O=v+(u-N);break}return[[R,O],[R,O+N]]}var B=a.get(n,P)||0,F=It(B,[d,g],c,!0),H;switch(y){case"left":H=h;break;case"center":H=h+(l-F)/2;break;case"right":H=h+l-F;break}return[[H,R],[H+F,R]]};i==="ascending"&&(S=-S,m=-m,s==="horizontal"?h+=l:v+=u,f=f.reverse());for(var x=0;x<f.length;x++){var b=f[x],T=f[x+1],A=a.getItemModel(b);if(s==="horizontal"){var D=A.get(["itemStyle","width"]);D==null?D=S:(D=W(D,l),i==="ascending"&&(D=-D));var M=w(b,h),I=w(T,h+D);h+=D+m,a.setItemLayout(b,{points:M.concat(I.slice().reverse())})}else{var L=A.get(["itemStyle","height"]);L==null?L=S:(L=W(L,u),i==="ascending"&&(L=-L));var M=w(b,v),I=w(T,v+L);v+=L+m,a.setItemLayout(b,{points:M.concat(I.slice().reverse())})}}R3(a)})}function k3(r){r.registerChartView(D3),r.registerSeriesModel(I3),r.registerLayout(E3),r.registerProcessor(_l("funnel"))}var O3=.3,N3=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._dataGroup=new at,t._initialized=!1,t}return e.prototype.init=function(){this.group.add(this._dataGroup)},e.prototype.render=function(t,a,n,i){this._progressiveEls=null;var o=this._dataGroup,s=t.getData(),l=this._data,u=t.coordinateSystem,f=u.dimensions,h=PS(t);s.diff(l).add(v).update(c).remove(p).execute();function v(g){var y=LS(s,o,g,f,u);yc(y,s,g,h)}function c(g,y){var m=l.getItemGraphicEl(y),_=TM(s,g,f,u);s.setItemGraphicEl(g,m),Dt(m,{shape:{points:_}},t,g),Sr(m),yc(m,s,g,h)}function p(g){var y=l.getItemGraphicEl(g);o.remove(y)}if(!this._initialized){this._initialized=!0;var d=B3(u,t,function(){setTimeout(function(){o.removeClipPath()})});o.setClipPath(d)}this._data=s},e.prototype.incrementalPrepareRender=function(t,a,n){this._initialized=!0,this._data=null,this._dataGroup.removeAll()},e.prototype.incrementalRender=function(t,a,n){for(var i=a.getData(),o=a.coordinateSystem,s=o.dimensions,l=PS(a),u=this._progressiveEls=[],f=t.start;f<t.end;f++){var h=LS(i,this._dataGroup,f,s,o);h.incremental=!0,yc(h,i,f,l),u.push(h)}},e.prototype.remove=function(){this._dataGroup&&this._dataGroup.removeAll(),this._data=null},e.type="parallel",e}(Nt);function B3(r,e,t){var a=r.model,n=r.getRect(),i=new wt({shape:{x:n.x,y:n.y,width:n.width,height:n.height}}),o=a.get("layout")==="horizontal"?"width":"height";return i.setShape(o,0),Bt(i,{shape:{width:n.width,height:n.height}},e,t),i}function TM(r,e,t,a){for(var n=[],i=0;i<t.length;i++){var o=t[i],s=r.get(r.mapDimension(o),e);V3(s,a.getAxis(o).type)||n.push(a.dataToPoint(s,o))}return n}function LS(r,e,t,a,n){var i=TM(r,t,a,n),o=new Me({shape:{points:i},z2:10});return e.add(o),r.setItemGraphicEl(t,o),o}function PS(r){var e=r.get("smooth",!0);return e===!0&&(e=O3),e=oa(e),Is(e)&&(e=0),{smooth:e}}function yc(r,e,t,a){r.useStyle(e.getItemVisual(t,"style")),r.style.fill=null,r.setShape("smooth",a.smooth);var n=e.getItemModel(t),i=n.getModel("emphasis");ue(r,n,"lineStyle"),Ft(r,i.get("focus"),i.get("blurScope"),i.get("disabled"))}function V3(r,e){return e==="category"?r==null:r==null||isNaN(r)}const z3=N3;var G3=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.visualStyleAccessPath="lineStyle",t.visualDrawType="stroke",t}return e.prototype.getInitialData=function(t,a){return va(null,this,{useEncodeDefaulter:U(F3,null,this)})},e.prototype.getRawIndicesByActiveState=function(t){var a=this.coordinateSystem,n=this.getData(),i=[];return a.eachActiveState(n,function(o,s){t===o&&i.push(n.getRawIndex(s))}),i},e.type="series.parallel",e.dependencies=["parallel"],e.defaultOption={z:2,coordinateSystem:"parallel",parallelIndex:0,label:{show:!1},inactiveOpacity:.05,activeOpacity:1,lineStyle:{width:1,opacity:.45,type:"solid"},emphasis:{label:{show:!1}},progressive:500,smooth:!1,animationEasing:"linear"},e}(zt);function F3(r){var e=r.ecModel.getComponent("parallel",r.get("parallelIndex"));if(e){var t={};return C(e.dimensions,function(a){var n=H3(a);t[a]=n}),t}}function H3(r){return+r.replace("dim","")}const W3=G3;var $3=["lineStyle","opacity"],U3={seriesType:"parallel",reset:function(r,e){var t=r.coordinateSystem,a={normal:r.get(["lineStyle","opacity"]),active:r.get("activeOpacity"),inactive:r.get("inactiveOpacity")};return{progress:function(n,i){t.eachActiveState(i,function(o,s){var l=a[o];if(o==="normal"&&i.hasItemOption){var u=i.getItemModel(s).get($3,!0);u!=null&&(l=u)}var f=i.ensureUniqueItemVisual(s,"style");f.opacity=l},n.start,n.end)}}}};const Y3=U3;function Z3(r){X3(r),q3(r)}function X3(r){if(!r.parallel){var e=!1;C(r.series,function(t){t&&t.type==="parallel"&&(e=!0)}),e&&(r.parallel=[{}])}}function q3(r){var e=Pt(r.parallelAxis);C(e,function(t){if(tt(t)){var a=t.parallelIndex||0,n=Pt(r.parallel)[a];n&&n.parallelAxisDefault&&ft(t,n.parallelAxisDefault,!1)}})}var K3=5,Q3=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){this._model=t,this._api=n,this._handlers||(this._handlers={},C(J3,function(i,o){n.getZr().on(o,this._handlers[o]=U(i,this))},this)),wo(this,"_throttledDispatchExpand",t.get("axisExpandRate"),"fixRate")},e.prototype.dispose=function(t,a){Hs(this,"_throttledDispatchExpand"),C(this._handlers,function(n,i){a.getZr().off(i,n)}),this._handlers=null},e.prototype._throttledDispatchExpand=function(t){this._dispatchExpand(t)},e.prototype._dispatchExpand=function(t){t&&this._api.dispatchAction(V({type:"parallelAxisExpand"},t))},e.type="parallel",e}(Ht),J3={mousedown:function(r){mc(this,"click")&&(this._mouseDownPoint=[r.offsetX,r.offsetY])},mouseup:function(r){var e=this._mouseDownPoint;if(mc(this,"click")&&e){var t=[r.offsetX,r.offsetY],a=Math.pow(e[0]-t[0],2)+Math.pow(e[1]-t[1],2);if(a>K3)return;var n=this._model.coordinateSystem.getSlidedAxisExpandWindow([r.offsetX,r.offsetY]);n.behavior!=="none"&&this._dispatchExpand({axisExpandWindow:n.axisExpandWindow})}this._mouseDownPoint=null},mousemove:function(r){if(!(this._mouseDownPoint||!mc(this,"mousemove"))){var e=this._model,t=e.coordinateSystem.getSlidedAxisExpandWindow([r.offsetX,r.offsetY]),a=t.behavior;a==="jump"&&this._throttledDispatchExpand.debounceNextCall(e.get("axisExpandDebounce")),this._throttledDispatchExpand(a==="none"?null:{axisExpandWindow:t.axisExpandWindow,animation:a==="jump"?null:{duration:0}})}}};function mc(r,e){var t=r._model;return t.get("axisExpandable")&&t.get("axisExpandTriggerOn")===e}const j3=Q3;var tH=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(){r.prototype.init.apply(this,arguments),this.mergeOption({})},e.prototype.mergeOption=function(t){var a=this.option;t&&ft(a,t,!0),this._initDimensions()},e.prototype.contains=function(t,a){var n=t.get("parallelIndex");return n!=null&&a.getComponent("parallel",n)===this},e.prototype.setAxisExpand=function(t){C(["axisExpandable","axisExpandCenter","axisExpandCount","axisExpandWidth","axisExpandWindow"],function(a){t.hasOwnProperty(a)&&(this.option[a]=t[a])},this)},e.prototype._initDimensions=function(){var t=this.dimensions=[],a=this.parallelAxisIndex=[],n=Lt(this.ecModel.queryComponents({mainType:"parallelAxis"}),function(i){return(i.get("parallelIndex")||0)===this.componentIndex},this);C(n,function(i){t.push("dim"+i.get("dim")),a.push(i.componentIndex)})},e.type="parallel",e.dependencies=["parallelAxis"],e.layoutMode="box",e.defaultOption={z:0,left:80,top:60,right:80,bottom:60,layout:"horizontal",axisExpandable:!1,axisExpandCenter:null,axisExpandCount:0,axisExpandWidth:50,axisExpandRate:17,axisExpandDebounce:50,axisExpandSlideTriggerArea:[-.15,.05,.4],axisExpandTriggerOn:"click",parallelAxisDefault:null},e}(Tt);const eH=tH;var rH=function(r){k(e,r);function e(t,a,n,i,o){var s=r.call(this,t,a,n)||this;return s.type=i||"value",s.axisIndex=o,s}return e.prototype.isHorizontal=function(){return this.coordinateSystem.getModel().get("layout")!=="horizontal"},e}(wr);const aH=rH;function ci(r,e,t,a,n,i){r=r||0;var o=t[1]-t[0];if(n!=null&&(n=Li(n,[0,o])),i!=null&&(i=Math.max(i,n??0)),a==="all"){var s=Math.abs(e[1]-e[0]);s=Li(s,[0,o]),n=i=Li(s,[n,i]),a=0}e[0]=Li(e[0],t),e[1]=Li(e[1],t);var l=_c(e,a);e[a]+=r;var u=n||0,f=t.slice();l.sign<0?f[0]+=u:f[1]-=u,e[a]=Li(e[a],f);var h;return h=_c(e,a),n!=null&&(h.sign!==l.sign||h.span<n)&&(e[1-a]=e[a]+l.sign*n),h=_c(e,a),i!=null&&h.span>i&&(e[1-a]=e[a]+h.sign*i),e}function _c(r,e){var t=r[e]-r[1-e];return{span:Math.abs(t),sign:t>0?-1:t<0?1:e?-1:1}}function Li(r,e){return Math.min(e[1]!=null?e[1]:1/0,Math.max(e[0]!=null?e[0]:-1/0,r))}var Sc=C,AM=Math.min,CM=Math.max,RS=Math.floor,nH=Math.ceil,ES=$t,iH=Math.PI,oH=function(){function r(e,t,a){this.type="parallel",this._axesMap=Z(),this._axesLayout={},this.dimensions=e.dimensions,this._model=e,this._init(e,t,a)}return r.prototype._init=function(e,t,a){var n=e.dimensions,i=e.parallelAxisIndex;Sc(n,function(o,s){var l=i[s],u=t.getComponent("parallelAxis",l),f=this._axesMap.set(o,new aH(o,_h(u),[0,0],u.get("type"),l)),h=f.type==="category";f.onBand=h&&u.get("boundaryGap"),f.inverse=u.get("inverse"),u.axis=f,f.model=u,f.coordinateSystem=u.coordinateSystem=this},this)},r.prototype.update=function(e,t){this._updateAxesFromSeries(this._model,e)},r.prototype.containPoint=function(e){var t=this._makeLayoutInfo(),a=t.axisBase,n=t.layoutBase,i=t.pixelDimIndex,o=e[1-i],s=e[i];return o>=a&&o<=a+t.axisLength&&s>=n&&s<=n+t.layoutLength},r.prototype.getModel=function(){return this._model},r.prototype._updateAxesFromSeries=function(e,t){t.eachSeries(function(a){if(e.contains(a,t)){var n=a.getData();Sc(this.dimensions,function(i){var o=this._axesMap.get(i);o.scale.unionExtentFromData(n,n.mapDimension(i)),to(o.scale,o.model)},this)}},this)},r.prototype.resize=function(e,t){this._rect=Jt(e.getBoxLayoutParams(),{width:t.getWidth(),height:t.getHeight()}),this._layoutAxes()},r.prototype.getRect=function(){return this._rect},r.prototype._makeLayoutInfo=function(){var e=this._model,t=this._rect,a=["x","y"],n=["width","height"],i=e.get("layout"),o=i==="horizontal"?0:1,s=t[n[o]],l=[0,s],u=this.dimensions.length,f=yu(e.get("axisExpandWidth"),l),h=yu(e.get("axisExpandCount")||0,[0,u]),v=e.get("axisExpandable")&&u>3&&u>h&&h>1&&f>0&&s>0,c=e.get("axisExpandWindow"),p;if(c)p=yu(c[1]-c[0],l),c[1]=c[0]+p;else{p=yu(f*(h-1),l);var d=e.get("axisExpandCenter")||RS(u/2);c=[f*d-p/2],c[1]=c[0]+p}var g=(s-p)/(u-h);g<3&&(g=0);var y=[RS(ES(c[0]/f,1))+1,nH(ES(c[1]/f,1))-1],m=g/f*c[0];return{layout:i,pixelDimIndex:o,layoutBase:t[a[o]],layoutLength:s,axisBase:t[a[1-o]],axisLength:t[n[1-o]],axisExpandable:v,axisExpandWidth:f,axisCollapseWidth:g,axisExpandWindow:c,axisCount:u,winInnerIndices:y,axisExpandWindow0Pos:m}},r.prototype._layoutAxes=function(){var e=this._rect,t=this._axesMap,a=this.dimensions,n=this._makeLayoutInfo(),i=n.layout;t.each(function(o){var s=[0,n.axisLength],l=o.inverse?1:0;o.setExtent(s[l],s[1-l])}),Sc(a,function(o,s){var l=(n.axisExpandable?lH:sH)(s,n),u={horizontal:{x:l.position,y:n.axisLength},vertical:{x:0,y:l.position}},f={horizontal:iH/2,vertical:0},h=[u[i].x+e.x,u[i].y+e.y],v=f[i],c=Fe();oi(c,c,v),Gr(c,c,h),this._axesLayout[o]={position:h,rotation:v,transform:c,axisNameAvailableWidth:l.axisNameAvailableWidth,axisLabelShow:l.axisLabelShow,nameTruncateMaxWidth:l.nameTruncateMaxWidth,tickDirection:1,labelDirection:1}},this)},r.prototype.getAxis=function(e){return this._axesMap.get(e)},r.prototype.dataToPoint=function(e,t){return this.axisCoordToPoint(this._axesMap.get(t).dataToCoord(e),t)},r.prototype.eachActiveState=function(e,t,a,n){a==null&&(a=0),n==null&&(n=e.count());var i=this._axesMap,o=this.dimensions,s=[],l=[];C(o,function(g){s.push(e.mapDimension(g)),l.push(i.get(g).model)});for(var u=this.hasAxisBrushed(),f=a;f<n;f++){var h=void 0;if(!u)h="normal";else{h="active";for(var v=e.getValues(s,f),c=0,p=o.length;c<p;c++){var d=l[c].getActiveState(v[c]);if(d==="inactive"){h="inactive";break}}}t(h,f)}},r.prototype.hasAxisBrushed=function(){for(var e=this.dimensions,t=this._axesMap,a=!1,n=0,i=e.length;n<i;n++)t.get(e[n]).model.getActiveState()!=="normal"&&(a=!0);return a},r.prototype.axisCoordToPoint=function(e,t){var a=this._axesLayout[t];return mr([e,0],a.transform)},r.prototype.getAxisLayout=function(e){return rt(this._axesLayout[e])},r.prototype.getSlidedAxisExpandWindow=function(e){var t=this._makeLayoutInfo(),a=t.pixelDimIndex,n=t.axisExpandWindow.slice(),i=n[1]-n[0],o=[0,t.axisExpandWidth*(t.axisCount-1)];if(!this.containPoint(e))return{behavior:"none",axisExpandWindow:n};var s=e[a]-t.layoutBase-t.axisExpandWindow0Pos,l,u="slide",f=t.axisCollapseWidth,h=this._model.get("axisExpandSlideTriggerArea"),v=h[0]!=null;if(f)v&&f&&s<i*h[0]?(u="jump",l=s-i*h[2]):v&&f&&s>i*(1-h[0])?(u="jump",l=s-i*(1-h[2])):(l=s-i*h[1])>=0&&(l=s-i*(1-h[1]))<=0&&(l=0),l*=t.axisExpandWidth/f,l?ci(l,n,o,"all"):u="none";else{var c=n[1]-n[0],p=o[1]*s/c;n=[CM(0,p-c/2)],n[1]=AM(o[1],n[0]+c),n[0]=n[1]-c}return{axisExpandWindow:n,behavior:u}},r}();function yu(r,e){return AM(CM(r,e[0]),e[1])}function sH(r,e){var t=e.layoutLength/(e.axisCount-1);return{position:t*r,axisNameAvailableWidth:t,axisLabelShow:!0}}function lH(r,e){var t=e.layoutLength,a=e.axisExpandWidth,n=e.axisCount,i=e.axisCollapseWidth,o=e.winInnerIndices,s,l=i,u=!1,f;return r<o[0]?(s=r*i,f=i):r<=o[1]?(s=e.axisExpandWindow0Pos+r*a-e.axisExpandWindow[0],l=a,u=!0):(s=t-(n-1-r)*i,f=i),{position:s,axisNameAvailableWidth:l,axisLabelShow:u,nameTruncateMaxWidth:f}}function uH(r,e){var t=[];return r.eachComponent("parallel",function(a,n){var i=new oH(a,r,e);i.name="parallel_"+n,i.resize(a,e),a.coordinateSystem=i,i.model=a,t.push(i)}),r.eachSeries(function(a){if(a.get("coordinateSystem")==="parallel"){var n=a.getReferringComponents("parallel",Xt).models[0];a.coordinateSystem=n.coordinateSystem}}),t}var fH={create:uH};const hH=fH;var DM=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.activeIntervals=[],t}return e.prototype.getAreaSelectStyle=function(){return ti([["fill","color"],["lineWidth","borderWidth"],["stroke","borderColor"],["width","width"],["opacity","opacity"]])(this.getModel("areaSelectStyle"))},e.prototype.setActiveIntervals=function(t){var a=this.activeIntervals=rt(t);if(a)for(var n=a.length-1;n>=0;n--)ar(a[n])},e.prototype.getActiveState=function(t){var a=this.activeIntervals;if(!a.length)return"normal";if(t==null||isNaN(+t))return"inactive";if(a.length===1){var n=a[0];if(n[0]<=t&&t<=n[1])return"active"}else for(var i=0,o=a.length;i<o;i++)if(a[i][0]<=t&&t<=a[i][1])return"active";return"inactive"},e}(Tt);Kt(DM,pl);const kS=DM;var ai=!0,tl=Math.min,ao=Math.max,vH=Math.pow,cH=1e4,pH=6,dH=6,OS="globalPan",gH={w:[0,0],e:[0,1],n:[1,0],s:[1,1]},yH={w:"ew",e:"ew",n:"ns",s:"ns",ne:"nesw",sw:"nesw",nw:"nwse",se:"nwse"},NS={brushStyle:{lineWidth:2,stroke:"rgba(210,219,238,0.3)",fill:"#D2DBEE"},transformable:!0,brushMode:"single",removeOnClick:!1},mH=0,_H=function(r){k(e,r);function e(t){var a=r.call(this)||this;return a._track=[],a._covers=[],a._handlers={},a._zr=t,a.group=new at,a._uid="brushController_"+mH++,C(CH,function(n,i){this._handlers[i]=U(n,this)},a),a}return e.prototype.enableBrush=function(t){return this._brushType&&this._doDisableBrush(),t.brushType&&this._doEnableBrush(t),this},e.prototype._doEnableBrush=function(t){var a=this._zr;this._enableGlobalPan||N5(a,OS,this._uid),C(this._handlers,function(n,i){a.on(i,n)}),this._brushType=t.brushType,this._brushOption=ft(rt(NS),t,!0)},e.prototype._doDisableBrush=function(){var t=this._zr;B5(t,OS,this._uid),C(this._handlers,function(a,n){t.off(n,a)}),this._brushType=this._brushOption=null},e.prototype.setPanels=function(t){if(t&&t.length){var a=this._panels={};C(t,function(n){a[n.panelId]=rt(n)})}else this._panels=null;return this},e.prototype.mount=function(t){t=t||{},this._enableGlobalPan=t.enableGlobalPan;var a=this.group;return this._zr.add(a),a.attr({x:t.x||0,y:t.y||0,rotation:t.rotation||0,scaleX:t.scaleX||1,scaleY:t.scaleY||1}),this._transform=a.getLocalTransform(),this},e.prototype.updateCovers=function(t){t=G(t,function(v){return ft(rt(NS),v,!0)});var a="\0-brush-index-",n=this._covers,i=this._covers=[],o=this,s=this._creatingCover;return new ua(n,t,u,l).add(f).update(f).remove(h).execute(),this;function l(v,c){return(v.id!=null?v.id:a+c)+"-"+v.brushType}function u(v,c){return l(v.__brushOption,c)}function f(v,c){var p=t[v];if(c!=null&&n[c]===s)i[v]=n[c];else{var d=i[v]=c!=null?(n[c].__brushOption=p,n[c]):IM(o,MM(o,p));Sy(o,d)}}function h(v){n[v]!==s&&o.group.remove(n[v])}},e.prototype.unmount=function(){return this.enableBrush(!1),yd(this),this._zr.remove(this.group),this},e.prototype.dispose=function(){this.unmount(),this.off()},e}(or);function MM(r,e){var t=Ah[e.brushType].createCover(r,e);return t.__brushOption=e,PM(t,e),r.group.add(t),t}function IM(r,e){var t=xy(e);return t.endCreating&&(t.endCreating(r,e),PM(e,e.__brushOption)),e}function LM(r,e){var t=e.__brushOption;xy(e).updateCoverShape(r,e,t.range,t)}function PM(r,e){var t=e.z;t==null&&(t=cH),r.traverse(function(a){a.z=t,a.z2=t})}function Sy(r,e){xy(e).updateCommon(r,e),LM(r,e)}function xy(r){return Ah[r.__brushOption.brushType]}function wy(r,e,t){var a=r._panels;if(!a)return ai;var n,i=r._transform;return C(a,function(o){o.isTargetByCursor(e,t,i)&&(n=o)}),n}function RM(r,e){var t=r._panels;if(!t)return ai;var a=e.__brushOption.panelId;return a!=null?t[a]:ai}function yd(r){var e=r._covers,t=e.length;return C(e,function(a){r.group.remove(a)},r),e.length=0,!!t}function ni(r,e){var t=G(r._covers,function(a){var n=a.__brushOption,i=rt(n.range);return{brushType:n.brushType,panelId:n.panelId,range:i}});r.trigger("brush",{areas:t,isEnd:!!e.isEnd,removeOnClick:!!e.removeOnClick})}function SH(r){var e=r._track;if(!e.length)return!1;var t=e[e.length-1],a=e[0],n=t[0]-a[0],i=t[1]-a[1],o=vH(n*n+i*i,.5);return o>pH}function EM(r){var e=r.length-1;return e<0&&(e=0),[r[0],r[e]]}function kM(r,e,t,a){var n=new at;return n.add(new wt({name:"main",style:by(t),silent:!0,draggable:!0,cursor:"move",drift:ot(BS,r,e,n,["n","s","w","e"]),ondragend:ot(ni,e,{isEnd:!0})})),C(a,function(i){n.add(new wt({name:i.join(""),style:{opacity:0},draggable:!0,silent:!0,invisible:!0,drift:ot(BS,r,e,n,i),ondragend:ot(ni,e,{isEnd:!0})}))}),n}function OM(r,e,t,a){var n=a.brushStyle.lineWidth||0,i=ao(n,dH),o=t[0][0],s=t[1][0],l=o-n/2,u=s-n/2,f=t[0][1],h=t[1][1],v=f-i+n/2,c=h-i+n/2,p=f-o,d=h-s,g=p+n,y=d+n;qr(r,e,"main",o,s,p,d),a.transformable&&(qr(r,e,"w",l,u,i,y),qr(r,e,"e",v,u,i,y),qr(r,e,"n",l,u,g,i),qr(r,e,"s",l,c,g,i),qr(r,e,"nw",l,u,i,i),qr(r,e,"ne",v,u,i,i),qr(r,e,"sw",l,c,i,i),qr(r,e,"se",v,c,i,i))}function md(r,e){var t=e.__brushOption,a=t.transformable,n=e.childAt(0);n.useStyle(by(t)),n.attr({silent:!a,cursor:a?"move":"default"}),C([["w"],["e"],["n"],["s"],["s","e"],["s","w"],["n","e"],["n","w"]],function(i){var o=e.childOfName(i.join("")),s=i.length===1?_d(r,i[0]):wH(r,i);o&&o.attr({silent:!a,invisible:!a,cursor:a?yH[s]+"-resize":null})})}function qr(r,e,t,a,n,i,o){var s=e.childOfName(t);s&&s.setShape(TH(Ty(r,e,[[a,n],[a+i,n+o]])))}function by(r){return j({strokeNoScale:!0},r.brushStyle)}function NM(r,e,t,a){var n=[tl(r,t),tl(e,a)],i=[ao(r,t),ao(e,a)];return[[n[0],i[0]],[n[1],i[1]]]}function xH(r){return Xn(r.group)}function _d(r,e){var t={w:"left",e:"right",n:"top",s:"bottom"},a={left:"w",right:"e",top:"n",bottom:"s"},n=nh(t[e],xH(r));return a[n]}function wH(r,e){var t=[_d(r,e[0]),_d(r,e[1])];return(t[0]==="e"||t[0]==="w")&&t.reverse(),t.join("")}function BS(r,e,t,a,n,i){var o=t.__brushOption,s=r.toRectRange(o.range),l=BM(e,n,i);C(a,function(u){var f=gH[u];s[f[0]][f[1]]+=l[f[0]]}),o.range=r.fromRectRange(NM(s[0][0],s[1][0],s[0][1],s[1][1])),Sy(e,t),ni(e,{isEnd:!1})}function bH(r,e,t,a){var n=e.__brushOption.range,i=BM(r,t,a);C(n,function(o){o[0]+=i[0],o[1]+=i[1]}),Sy(r,e),ni(r,{isEnd:!1})}function BM(r,e,t){var a=r.group,n=a.transformCoordToLocal(e,t),i=a.transformCoordToLocal(0,0);return[n[0]-i[0],n[1]-i[1]]}function Ty(r,e,t){var a=RM(r,e);return a&&a!==ai?a.clipPath(t,r._transform):rt(t)}function TH(r){var e=tl(r[0][0],r[1][0]),t=tl(r[0][1],r[1][1]),a=ao(r[0][0],r[1][0]),n=ao(r[0][1],r[1][1]);return{x:e,y:t,width:a-e,height:n-t}}function AH(r,e,t){if(!(!r._brushType||DH(r,e.offsetX,e.offsetY))){var a=r._zr,n=r._covers,i=wy(r,e,t);if(!r._dragging)for(var o=0;o<n.length;o++){var s=n[o].__brushOption;if(i&&(i===ai||s.panelId===i.panelId)&&Ah[s.brushType].contain(n[o],t[0],t[1]))return}i&&a.setCursorStyle("crosshair")}}function Sd(r){var e=r.event;e.preventDefault&&e.preventDefault()}function xd(r,e,t){return r.childOfName("main").contain(e,t)}function VM(r,e,t,a){var n=r._creatingCover,i=r._creatingPanel,o=r._brushOption,s;if(r._track.push(t.slice()),SH(r)||n){if(i&&!n){o.brushMode==="single"&&yd(r);var l=rt(o);l.brushType=VS(l.brushType,i),l.panelId=i===ai?null:i.panelId,n=r._creatingCover=MM(r,l),r._covers.push(n)}if(n){var u=Ah[VS(r._brushType,i)],f=n.__brushOption;f.range=u.getCreatingRange(Ty(r,n,r._track)),a&&(IM(r,n),u.updateCommon(r,n)),LM(r,n),s={isEnd:a}}}else a&&o.brushMode==="single"&&o.removeOnClick&&wy(r,e,t)&&yd(r)&&(s={isEnd:a,removeOnClick:!0});return s}function VS(r,e){return r==="auto"?e.defaultBrushType:r}var CH={mousedown:function(r){if(this._dragging)zS(this,r);else if(!r.target||!r.target.draggable){Sd(r);var e=this.group.transformCoordToLocal(r.offsetX,r.offsetY);this._creatingCover=null;var t=this._creatingPanel=wy(this,r,e);t&&(this._dragging=!0,this._track=[e.slice()])}},mousemove:function(r){var e=r.offsetX,t=r.offsetY,a=this.group.transformCoordToLocal(e,t);if(AH(this,r,a),this._dragging){Sd(r);var n=VM(this,r,a,!1);n&&ni(this,n)}},mouseup:function(r){zS(this,r)}};function zS(r,e){if(r._dragging){Sd(e);var t=e.offsetX,a=e.offsetY,n=r.group.transformCoordToLocal(t,a),i=VM(r,e,n,!0);r._dragging=!1,r._track=[],r._creatingCover=null,i&&ni(r,i)}}function DH(r,e,t){var a=r._zr;return e<0||e>a.getWidth()||t<0||t>a.getHeight()}var Ah={lineX:GS(0),lineY:GS(1),rect:{createCover:function(r,e){function t(a){return a}return kM({toRectRange:t,fromRectRange:t},r,e,[["w"],["e"],["n"],["s"],["s","e"],["s","w"],["n","e"],["n","w"]])},getCreatingRange:function(r){var e=EM(r);return NM(e[1][0],e[1][1],e[0][0],e[0][1])},updateCoverShape:function(r,e,t,a){OM(r,e,t,a)},updateCommon:md,contain:xd},polygon:{createCover:function(r,e){var t=new at;return t.add(new Me({name:"main",style:by(e),silent:!0})),t},getCreatingRange:function(r){return r},endCreating:function(r,e){e.remove(e.childAt(0)),e.add(new De({name:"main",draggable:!0,drift:ot(bH,r,e),ondragend:ot(ni,r,{isEnd:!0})}))},updateCoverShape:function(r,e,t,a){e.childAt(0).setShape({points:Ty(r,e,t)})},updateCommon:md,contain:xd}};function GS(r){return{createCover:function(e,t){return kM({toRectRange:function(a){var n=[a,[0,100]];return r&&n.reverse(),n},fromRectRange:function(a){return a[r]}},e,t,[[["w"],["e"]],[["n"],["s"]]][r])},getCreatingRange:function(e){var t=EM(e),a=tl(t[0][r],t[1][r]),n=ao(t[0][r],t[1][r]);return[a,n]},updateCoverShape:function(e,t,a,n){var i,o=RM(e,t);if(o!==ai&&o.getLinearBrushOtherExtent)i=o.getLinearBrushOtherExtent(r);else{var s=e._zr;i=[0,[s.getWidth(),s.getHeight()][1-r]]}var l=[a,i];r&&l.reverse(),OM(e,t,l,n)},updateCommon:md,contain:xd}}const Ay=_H;function zM(r){return r=Cy(r),function(e){return UT(e,r)}}function GM(r,e){return r=Cy(r),function(t){var a=e??t,n=a?r.width:r.height,i=a?r.x:r.y;return[i,i+(n||0)]}}function FM(r,e,t){var a=Cy(r);return function(n,i){return a.contain(i[0],i[1])&&!xh(n,e,t)}}function Cy(r){return ht.create(r)}var MH=["axisLine","axisTickLabel","axisName"],IH=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,a){r.prototype.init.apply(this,arguments),(this._brushController=new Ay(a.getZr())).on("brush",U(this._onBrush,this))},e.prototype.render=function(t,a,n,i){if(!LH(t,a,i)){this.axisModel=t,this.api=n,this.group.removeAll();var o=this._axisGroup;if(this._axisGroup=new at,this.group.add(this._axisGroup),!!t.get("show")){var s=RH(t,a),l=s.coordinateSystem,u=t.getAreaSelectStyle(),f=u.width,h=t.axis.dim,v=l.getAxisLayout(h),c=V({strokeContainThreshold:f},v),p=new Te(t,c);C(MH,p.add,p),this._axisGroup.add(p.getGroup()),this._refreshBrushController(c,u,t,s,f,n),ll(o,this._axisGroup,t)}}},e.prototype._refreshBrushController=function(t,a,n,i,o,s){var l=n.axis.getExtent(),u=l[1]-l[0],f=Math.min(30,Math.abs(u)*.1),h=ht.create({x:l[0],y:-o/2,width:u,height:o});h.x-=f,h.width+=2*f,this._brushController.mount({enableGlobalPan:!0,rotation:t.rotation,x:t.position[0],y:t.position[1]}).setPanels([{panelId:"pl",clipPath:zM(h),isTargetByCursor:FM(h,s,i),getLinearBrushOtherExtent:GM(h,0)}]).enableBrush({brushType:"lineX",brushStyle:a,removeOnClick:!0}).updateCovers(PH(n))},e.prototype._onBrush=function(t){var a=t.areas,n=this.axisModel,i=n.axis,o=G(a,function(s){return[i.coordToData(s.range[0],!0),i.coordToData(s.range[1],!0)]});(!n.option.realtime===t.isEnd||t.removeOnClick)&&this.api.dispatchAction({type:"axisAreaSelect",parallelAxisId:n.id,intervals:o})},e.prototype.dispose=function(){this._brushController.dispose()},e.type="parallelAxis",e}(Ht);function LH(r,e,t){return t&&t.type==="axisAreaSelect"&&e.findComponents({mainType:"parallelAxis",query:t})[0]===r}function PH(r){var e=r.axis;return G(r.activeIntervals,function(t){return{brushType:"lineX",panelId:"pl",range:[e.dataToCoord(t[0],!0),e.dataToCoord(t[1],!0)]}})}function RH(r,e){return e.getComponent("parallel",r.get("parallelIndex"))}const EH=IH;var kH={type:"axisAreaSelect",event:"axisAreaSelected"};function OH(r){r.registerAction(kH,function(e,t){t.eachComponent({mainType:"parallelAxis",query:e},function(a){a.axis.model.setActiveIntervals(e.intervals)})}),r.registerAction("parallelAxisExpand",function(e,t){t.eachComponent({mainType:"parallel",query:e},function(a){a.setAxisExpand(e)})})}var NH={type:"value",areaSelectStyle:{width:20,borderWidth:1,borderColor:"rgba(160,197,232)",color:"rgba(160,197,232)",opacity:.3},realtime:!0,z:10};function HM(r){r.registerComponentView(j3),r.registerComponentModel(eH),r.registerCoordinateSystem("parallel",hH),r.registerPreprocessor(Z3),r.registerComponentModel(kS),r.registerComponentView(EH),ro(r,"parallel",kS,NH),OH(r)}function BH(r){gt(HM),r.registerChartView(z3),r.registerSeriesModel(W3),r.registerVisual(r.PRIORITY.VISUAL.BRUSH,Y3)}var VH=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.cpx1=0,this.cpy1=0,this.cpx2=0,this.cpy2=0,this.extent=0}return r}(),zH=function(r){k(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new VH},e.prototype.buildPath=function(t,a){var n=a.extent;t.moveTo(a.x1,a.y1),t.bezierCurveTo(a.cpx1,a.cpy1,a.cpx2,a.cpy2,a.x2,a.y2),a.orient==="vertical"?(t.lineTo(a.x2+n,a.y2),t.bezierCurveTo(a.cpx2+n,a.cpy2,a.cpx1+n,a.cpy1,a.x1+n,a.y1)):(t.lineTo(a.x2,a.y2+n),t.bezierCurveTo(a.cpx2,a.cpy2+n,a.cpx1,a.cpy1+n,a.x1,a.y1+n)),t.closePath()},e.prototype.highlight=function(){sa(this)},e.prototype.downplay=function(){la(this)},e}(yt),GH=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._focusAdjacencyDisabled=!1,t}return e.prototype.render=function(t,a,n){var i=this,o=t.getGraph(),s=this.group,l=t.layoutInfo,u=l.width,f=l.height,h=t.getData(),v=t.getData("edge"),c=t.get("orient");this._model=t,s.removeAll(),s.x=l.x,s.y=l.y,o.eachEdge(function(p){var d=new zH,g=nt(d);g.dataIndex=p.dataIndex,g.seriesIndex=t.seriesIndex,g.dataType="edge";var y=p.getModel(),m=y.getModel("lineStyle"),_=m.get("curveness"),S=p.node1.getLayout(),w=p.node1.getModel(),x=w.get("localX"),b=w.get("localY"),T=p.node2.getLayout(),A=p.node2.getModel(),D=A.get("localX"),M=A.get("localY"),I=p.getLayout(),L,P,R,E,N,O,B,F;d.shape.extent=Math.max(1,I.dy),d.shape.orient=c,c==="vertical"?(L=(x!=null?x*u:S.x)+I.sy,P=(b!=null?b*f:S.y)+S.dy,R=(D!=null?D*u:T.x)+I.ty,E=M!=null?M*f:T.y,N=L,O=P*(1-_)+E*_,B=R,F=P*_+E*(1-_)):(L=(x!=null?x*u:S.x)+S.dx,P=(b!=null?b*f:S.y)+I.sy,R=D!=null?D*u:T.x,E=(M!=null?M*f:T.y)+I.ty,N=L*(1-_)+R*_,O=P,B=L*_+R*(1-_),F=E),d.setShape({x1:L,y1:P,x2:R,y2:E,cpx1:N,cpy1:O,cpx2:B,cpy2:F}),d.useStyle(m.getItemStyle()),FS(d.style,c,p);var H=""+y.get("value"),X=re(y,"edgeLabel");fe(d,X,{labelFetcher:{getFormattedLabel:function(ct,St,pt,et,dt,st){return t.getFormattedLabel(ct,St,"edge",et,Br(dt,X.normal&&X.normal.get("formatter"),H),st)}},labelDataIndex:p.dataIndex,defaultText:H}),d.setTextConfig({position:"inside"});var Q=y.getModel("emphasis");ue(d,y,"lineStyle",function(ct){var St=ct.getItemStyle();return FS(St,c,p),St}),s.add(d),v.setItemGraphicEl(p.dataIndex,d);var J=Q.get("focus");Ft(d,J==="adjacency"?p.getAdjacentDataIndices():J==="trajectory"?p.getTrajectoryDataIndices():J,Q.get("blurScope"),Q.get("disabled"))}),o.eachNode(function(p){var d=p.getLayout(),g=p.getModel(),y=g.get("localX"),m=g.get("localY"),_=g.getModel("emphasis"),S=new wt({shape:{x:y!=null?y*u:d.x,y:m!=null?m*f:d.y,width:d.dx,height:d.dy},style:g.getModel("itemStyle").getItemStyle(),z2:10});fe(S,re(g),{labelFetcher:{getFormattedLabel:function(x,b){return t.getFormattedLabel(x,b,"node")}},labelDataIndex:p.dataIndex,defaultText:p.id}),S.disableLabelAnimation=!0,S.setStyle("fill",p.getVisual("color")),S.setStyle("decal",p.getVisual("style").decal),ue(S,g),s.add(S),h.setItemGraphicEl(p.dataIndex,S),nt(S).dataType="node";var w=_.get("focus");Ft(S,w==="adjacency"?p.getAdjacentDataIndices():w==="trajectory"?p.getTrajectoryDataIndices():w,_.get("blurScope"),_.get("disabled"))}),h.eachItemGraphicEl(function(p,d){var g=h.getItemModel(d);g.get("draggable")&&(p.drift=function(y,m){i._focusAdjacencyDisabled=!0,this.shape.x+=y,this.shape.y+=m,this.dirty(),n.dispatchAction({type:"dragNode",seriesId:t.id,dataIndex:h.getRawIndex(d),localX:this.shape.x/u,localY:this.shape.y/f})},p.ondragend=function(){i._focusAdjacencyDisabled=!1},p.draggable=!0,p.cursor="move")}),!this._data&&t.isAnimationEnabled()&&s.setClipPath(FH(s.getBoundingRect(),t,function(){s.removeClipPath()})),this._data=t.getData()},e.prototype.dispose=function(){},e.type="sankey",e}(Nt);function FS(r,e,t){switch(r.fill){case"source":r.fill=t.node1.getVisual("color"),r.decal=t.node1.getVisual("style").decal;break;case"target":r.fill=t.node2.getVisual("color"),r.decal=t.node2.getVisual("style").decal;break;case"gradient":var a=t.node1.getVisual("color"),n=t.node2.getVisual("color");$(a)&&$(n)&&(r.fill=new ho(0,0,+(e==="horizontal"),+(e==="vertical"),[{color:a,offset:0},{color:n,offset:1}]))}}function FH(r,e,t){var a=new wt({shape:{x:r.x-10,y:r.y-10,width:0,height:r.height+20}});return Bt(a,{shape:{width:r.width+20}},e,t),a}const HH=GH;var WH=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.getInitialData=function(t,a){var n=t.edges||t.links,i=t.data||t.nodes,o=t.levels;this.levelModels=[];for(var s=this.levelModels,l=0;l<o.length;l++)o[l].depth!=null&&o[l].depth>=0&&(s[o[l].depth]=new Ot(o[l],this,a));if(i&&n){var u=bM(i,n,this,!0,f);return u.data}function f(h,v){h.wrapMethod("getItemModel",function(c,p){var d=c.parentModel,g=d.getData().getItemLayout(p);if(g){var y=g.depth,m=d.levelModels[y];m&&(c.parentModel=m)}return c}),v.wrapMethod("getItemModel",function(c,p){var d=c.parentModel,g=d.getGraph().getEdgeByIndex(p),y=g.node1.getLayout();if(y){var m=y.depth,_=d.levelModels[m];_&&(c.parentModel=_)}return c})}},e.prototype.setNodePosition=function(t,a){var n=this.option.data||this.option.nodes,i=n[t];i.localX=a[0],i.localY=a[1]},e.prototype.getGraph=function(){return this.getData().graph},e.prototype.getEdgeData=function(){return this.getGraph().edgeData},e.prototype.formatTooltip=function(t,a,n){function i(c){return isNaN(c)||c==null}if(n==="edge"){var o=this.getDataParams(t,n),s=o.data,l=o.value,u=s.source+" -- "+s.target;return ae("nameValue",{name:u,value:l,noValue:i(l)})}else{var f=this.getGraph().getNodeByIndex(t),h=f.getLayout().value,v=this.getDataParams(t,n).data.name;return ae("nameValue",{name:v!=null?v+"":null,value:h,noValue:i(h)})}},e.prototype.optionUpdated=function(){},e.prototype.getDataParams=function(t,a){var n=r.prototype.getDataParams.call(this,t,a);if(n.value==null&&a==="node"){var i=this.getGraph().getNodeByIndex(t),o=i.getLayout().value;n.value=o}return n},e.type="series.sankey",e.defaultOption={z:2,coordinateSystem:"view",left:"5%",top:"5%",right:"20%",bottom:"5%",orient:"horizontal",nodeWidth:20,nodeGap:8,draggable:!0,layoutIterations:32,label:{show:!0,position:"right",fontSize:12},edgeLabel:{show:!1,fontSize:12},levels:[],nodeAlign:"justify",lineStyle:{color:"#314656",opacity:.2,curveness:.5},emphasis:{label:{show:!0},lineStyle:{opacity:.5}},select:{itemStyle:{borderColor:"#212121"}},animationEasing:"linear",animationDuration:1e3},e}(zt);const $H=WH;function UH(r,e){r.eachSeriesByType("sankey",function(t){var a=t.get("nodeWidth"),n=t.get("nodeGap"),i=YH(t,e);t.layoutInfo=i;var o=i.width,s=i.height,l=t.getGraph(),u=l.nodes,f=l.edges;XH(u);var h=Lt(u,function(d){return d.getLayout().value===0}),v=h.length!==0?0:t.get("layoutIterations"),c=t.get("orient"),p=t.get("nodeAlign");ZH(u,f,a,n,o,s,v,c,p)})}function YH(r,e){return Jt(r.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()})}function ZH(r,e,t,a,n,i,o,s,l){qH(r,e,t,n,i,s,l),jH(r,e,i,n,a,o,s),l4(r,s)}function XH(r){C(r,function(e){var t=Ga(e.outEdges,Lf),a=Ga(e.inEdges,Lf),n=e.getValue()||0,i=Math.max(t,a,n);e.setLayout({value:i},!0)})}function qH(r,e,t,a,n,i,o){for(var s=[],l=[],u=[],f=[],h=0,v=0;v<e.length;v++)s[v]=1;for(var v=0;v<r.length;v++)l[v]=r[v].inEdges.length,l[v]===0&&u.push(r[v]);for(var c=-1;u.length;){for(var p=0;p<u.length;p++){var d=u[p],g=d.hostGraph.data.getRawDataItem(d.dataIndex),y=g.depth!=null&&g.depth>=0;y&&g.depth>c&&(c=g.depth),d.setLayout({depth:y?g.depth:h},!0),i==="vertical"?d.setLayout({dy:t},!0):d.setLayout({dx:t},!0);for(var m=0;m<d.outEdges.length;m++){var _=d.outEdges[m],S=e.indexOf(_);s[S]=0;var w=_.node2,x=r.indexOf(w);--l[x]===0&&f.indexOf(w)<0&&f.push(w)}}++h,u=f,f=[]}for(var v=0;v<s.length;v++)if(s[v]===1)throw new Error("Sankey is a DAG, the original data has cycle!");var b=c>h-1?c:h-1;o&&o!=="left"&&KH(r,o,i,b);var T=i==="vertical"?(n-t)/b:(a-t)/b;JH(r,T,i)}function WM(r){var e=r.hostGraph.data.getRawDataItem(r.dataIndex);return e.depth!=null&&e.depth>=0}function KH(r,e,t,a){if(e==="right"){for(var n=[],i=r,o=0;i.length;){for(var s=0;s<i.length;s++){var l=i[s];l.setLayout({skNodeHeight:o},!0);for(var u=0;u<l.inEdges.length;u++){var f=l.inEdges[u];n.indexOf(f.node1)<0&&n.push(f.node1)}}i=n,n=[],++o}C(r,function(h){WM(h)||h.setLayout({depth:Math.max(0,a-h.getLayout().skNodeHeight)},!0)})}else e==="justify"&&QH(r,a)}function QH(r,e){C(r,function(t){!WM(t)&&!t.outEdges.length&&t.setLayout({depth:e},!0)})}function JH(r,e,t){C(r,function(a){var n=a.getLayout().depth*e;t==="vertical"?a.setLayout({y:n},!0):a.setLayout({x:n},!0)})}function jH(r,e,t,a,n,i,o){var s=t4(r,o);e4(s,e,t,a,n,o),xc(s,n,t,a,o);for(var l=1;i>0;i--)l*=.99,r4(s,l,o),xc(s,n,t,a,o),s4(s,l,o),xc(s,n,t,a,o)}function t4(r,e){var t=[],a=e==="vertical"?"y":"x",n=Tp(r,function(i){return i.getLayout()[a]});return n.keys.sort(function(i,o){return i-o}),C(n.keys,function(i){t.push(n.buckets.get(i))}),t}function e4(r,e,t,a,n,i){var o=1/0;C(r,function(s){var l=s.length,u=0;C(s,function(h){u+=h.getLayout().value});var f=i==="vertical"?(a-(l-1)*n)/u:(t-(l-1)*n)/u;f<o&&(o=f)}),C(r,function(s){C(s,function(l,u){var f=l.getLayout().value*o;i==="vertical"?(l.setLayout({x:u},!0),l.setLayout({dx:f},!0)):(l.setLayout({y:u},!0),l.setLayout({dy:f},!0))})}),C(e,function(s){var l=+s.getValue()*o;s.setLayout({dy:l},!0)})}function xc(r,e,t,a,n){var i=n==="vertical"?"x":"y";C(r,function(o){o.sort(function(d,g){return d.getLayout()[i]-g.getLayout()[i]});for(var s,l,u,f=0,h=o.length,v=n==="vertical"?"dx":"dy",c=0;c<h;c++)l=o[c],u=f-l.getLayout()[i],u>0&&(s=l.getLayout()[i]+u,n==="vertical"?l.setLayout({x:s},!0):l.setLayout({y:s},!0)),f=l.getLayout()[i]+l.getLayout()[v]+e;var p=n==="vertical"?a:t;if(u=f-e-p,u>0){s=l.getLayout()[i]-u,n==="vertical"?l.setLayout({x:s},!0):l.setLayout({y:s},!0),f=s;for(var c=h-2;c>=0;--c)l=o[c],u=l.getLayout()[i]+l.getLayout()[v]+e-f,u>0&&(s=l.getLayout()[i]-u,n==="vertical"?l.setLayout({x:s},!0):l.setLayout({y:s},!0)),f=l.getLayout()[i]}})}function r4(r,e,t){C(r.slice().reverse(),function(a){C(a,function(n){if(n.outEdges.length){var i=Ga(n.outEdges,a4,t)/Ga(n.outEdges,Lf);if(isNaN(i)){var o=n.outEdges.length;i=o?Ga(n.outEdges,n4,t)/o:0}if(t==="vertical"){var s=n.getLayout().x+(i-Xa(n,t))*e;n.setLayout({x:s},!0)}else{var l=n.getLayout().y+(i-Xa(n,t))*e;n.setLayout({y:l},!0)}}})})}function a4(r,e){return Xa(r.node2,e)*r.getValue()}function n4(r,e){return Xa(r.node2,e)}function i4(r,e){return Xa(r.node1,e)*r.getValue()}function o4(r,e){return Xa(r.node1,e)}function Xa(r,e){return e==="vertical"?r.getLayout().x+r.getLayout().dx/2:r.getLayout().y+r.getLayout().dy/2}function Lf(r){return r.getValue()}function Ga(r,e,t){for(var a=0,n=r.length,i=-1;++i<n;){var o=+e(r[i],t);isNaN(o)||(a+=o)}return a}function s4(r,e,t){C(r,function(a){C(a,function(n){if(n.inEdges.length){var i=Ga(n.inEdges,i4,t)/Ga(n.inEdges,Lf);if(isNaN(i)){var o=n.inEdges.length;i=o?Ga(n.inEdges,o4,t)/o:0}if(t==="vertical"){var s=n.getLayout().x+(i-Xa(n,t))*e;n.setLayout({x:s},!0)}else{var l=n.getLayout().y+(i-Xa(n,t))*e;n.setLayout({y:l},!0)}}})})}function l4(r,e){var t=e==="vertical"?"x":"y";C(r,function(a){a.outEdges.sort(function(n,i){return n.node2.getLayout()[t]-i.node2.getLayout()[t]}),a.inEdges.sort(function(n,i){return n.node1.getLayout()[t]-i.node1.getLayout()[t]})}),C(r,function(a){var n=0,i=0;C(a.outEdges,function(o){o.setLayout({sy:n},!0),n+=o.getLayout().dy}),C(a.inEdges,function(o){o.setLayout({ty:i},!0),i+=o.getLayout().dy})})}function u4(r){r.eachSeriesByType("sankey",function(e){var t=e.getGraph(),a=t.nodes,n=t.edges;if(a.length){var i=1/0,o=-1/0;C(a,function(s){var l=s.getLayout().value;l<i&&(i=l),l>o&&(o=l)}),C(a,function(s){var l=new le({type:"color",mappingMethod:"linear",dataExtent:[i,o],visual:e.get("color")}),u=l.mapValueToVisual(s.getLayout().value),f=s.getModel().get(["itemStyle","color"]);f!=null?(s.setVisual("color",f),s.setVisual("style",{fill:f})):(s.setVisual("color",u),s.setVisual("style",{fill:u}))})}n.length&&C(n,function(s){var l=s.getModel().get("lineStyle");s.setVisual("style",l)})})}function f4(r){r.registerChartView(HH),r.registerSeriesModel($H),r.registerLayout(UH),r.registerVisual(u4),r.registerAction({type:"dragNode",event:"dragnode",update:"update"},function(e,t){t.eachComponent({mainType:"series",subType:"sankey",query:e},function(a){a.setNodePosition(e.dataIndex,[e.localX,e.localY])})})}var $M=function(){function r(){}return r.prototype.getInitialData=function(e,t){var a,n=t.getComponent("xAxis",this.get("xAxisIndex")),i=t.getComponent("yAxis",this.get("yAxisIndex")),o=n.get("type"),s=i.get("type"),l;o==="category"?(e.layout="horizontal",a=n.getOrdinalMeta(),l=!0):s==="category"?(e.layout="vertical",a=i.getOrdinalMeta(),l=!0):e.layout=e.layout||"horizontal";var u=["x","y"],f=e.layout==="horizontal"?0:1,h=this._baseAxisDim=u[f],v=u[1-f],c=[n,i],p=c[f].get("type"),d=c[1-f].get("type"),g=e.data;if(g&&l){var y=[];C(g,function(S,w){var x;z(S)?(x=S.slice(),S.unshift(w)):z(S.value)?(x=V({},S),x.value=x.value.slice(),S.value.unshift(w)):x=S,y.push(x)}),e.data=y}var m=this.defaultValueDimensions,_=[{name:h,type:_f(p),ordinalMeta:a,otherDims:{tooltip:!1,itemName:0},dimsDef:["base"]},{name:v,type:_f(d),dimsDef:m.slice()}];return To(this,{coordDimensions:_,dimensionsCount:m.length+1,encodeDefaulter:ot(yA,_,this)})},r.prototype.getBaseAxis=function(){var e=this._baseAxisDim;return this.ecModel.getComponent(e+"Axis",this.get(e+"AxisIndex")).axis},r}(),UM=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.defaultValueDimensions=[{name:"min",defaultTooltip:!0},{name:"Q1",defaultTooltip:!0},{name:"median",defaultTooltip:!0},{name:"Q3",defaultTooltip:!0},{name:"max",defaultTooltip:!0}],t.visualDrawType="stroke",t}return e.type="series.boxplot",e.dependencies=["xAxis","yAxis","grid"],e.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,layout:null,boxWidth:[7,50],itemStyle:{color:"#fff",borderWidth:1},emphasis:{scale:!0,itemStyle:{borderWidth:2,shadowBlur:5,shadowOffsetX:1,shadowOffsetY:1,shadowColor:"rgba(0,0,0,0.2)"}},animationDuration:800},e}(zt);Kt(UM,$M,!0);const h4=UM;var v4=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){var i=t.getData(),o=this.group,s=this._data;this._data||o.removeAll();var l=t.get("layout")==="horizontal"?1:0;i.diff(s).add(function(u){if(i.hasValue(u)){var f=i.getItemLayout(u),h=HS(f,i,u,l,!0);i.setItemGraphicEl(u,h),o.add(h)}}).update(function(u,f){var h=s.getItemGraphicEl(f);if(!i.hasValue(u)){o.remove(h);return}var v=i.getItemLayout(u);h?(Sr(h),YM(v,h,i,u)):h=HS(v,i,u,l),o.add(h),i.setItemGraphicEl(u,h)}).remove(function(u){var f=s.getItemGraphicEl(u);f&&o.remove(f)}).execute(),this._data=i},e.prototype.remove=function(t){var a=this.group,n=this._data;this._data=null,n&&n.eachItemGraphicEl(function(i){i&&a.remove(i)})},e.type="boxplot",e}(Nt),c4=function(){function r(){}return r}(),p4=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a.type="boxplotBoxPath",a}return e.prototype.getDefaultShape=function(){return new c4},e.prototype.buildPath=function(t,a){var n=a.points,i=0;for(t.moveTo(n[i][0],n[i][1]),i++;i<4;i++)t.lineTo(n[i][0],n[i][1]);for(t.closePath();i<n.length;i++)t.moveTo(n[i][0],n[i][1]),i++,t.lineTo(n[i][0],n[i][1])},e}(yt);function HS(r,e,t,a,n){var i=r.ends,o=new p4({shape:{points:n?d4(i,a,r):i}});return YM(r,o,e,t,n),o}function YM(r,e,t,a,n){var i=t.hostModel,o=si[n?"initProps":"updateProps"];o(e,{shape:{points:r.ends}},i,a),e.useStyle(t.getItemVisual(a,"style")),e.style.strokeNoScale=!0,e.z2=100;var s=t.getItemModel(a),l=s.getModel("emphasis");ue(e,s),Ft(e,l.get("focus"),l.get("blurScope"),l.get("disabled"))}function d4(r,e,t){return G(r,function(a){return a=a.slice(),a[e]=t.initBaseline,a})}const g4=v4;var Ds=C;function y4(r){var e=m4(r);Ds(e,function(t){var a=t.seriesModels;a.length&&(_4(t),Ds(a,function(n,i){S4(n,t.boxOffsetList[i],t.boxWidthList[i])}))})}function m4(r){var e=[],t=[];return r.eachSeriesByType("boxplot",function(a){var n=a.getBaseAxis(),i=vt(t,n);i<0&&(i=t.length,t[i]=n,e[i]={axis:n,seriesModels:[]}),e[i].seriesModels.push(a)}),e}function _4(r){var e=r.axis,t=r.seriesModels,a=t.length,n=r.boxWidthList=[],i=r.boxOffsetList=[],o=[],s;if(e.type==="category")s=e.getBandWidth();else{var l=0;Ds(t,function(p){l=Math.max(l,p.getData().count())});var u=e.getExtent();s=Math.abs(u[1]-u[0])/l}Ds(t,function(p){var d=p.get("boxWidth");z(d)||(d=[d,d]),o.push([W(d[0],s)||0,W(d[1],s)||0])});var f=s*.8-2,h=f/a*.3,v=(f-h*(a-1))/a,c=v/2-f/2;Ds(t,function(p,d){i.push(c),c+=h+v,n.push(Math.min(Math.max(v,o[d][0]),o[d][1]))})}function S4(r,e,t){var a=r.coordinateSystem,n=r.getData(),i=t/2,o=r.get("layout")==="horizontal"?0:1,s=1-o,l=["x","y"],u=n.mapDimension(l[o]),f=n.mapDimensionsAll(l[s]);if(u==null||f.length<5)return;for(var h=0;h<n.count();h++){var v=n.get(u,h),c=_(v,f[2],h),p=_(v,f[0],h),d=_(v,f[1],h),g=_(v,f[3],h),y=_(v,f[4],h),m=[];S(m,d,!1),S(m,g,!0),m.push(p,d,y,g),w(m,p),w(m,y),w(m,c),n.setItemLayout(h,{initBaseline:c[s],ends:m})}function _(x,b,T){var A=n.get(b,T),D=[];D[o]=x,D[s]=A;var M;return isNaN(x)||isNaN(A)?M=[NaN,NaN]:(M=a.dataToPoint(D),M[o]+=e),M}function S(x,b,T){var A=b.slice(),D=b.slice();A[o]+=i,D[o]-=i,T?x.push(A,D):x.push(D,A)}function w(x,b){var T=b.slice(),A=b.slice();T[o]-=i,A[o]+=i,x.push(T,A)}}function x4(r,e){e=e||{};for(var t=[],a=[],n=e.boundIQR,i=n==="none"||n===0,o=0;o<r.length;o++){var s=ar(r[o].slice()),l=Kh(s,.25),u=Kh(s,.5),f=Kh(s,.75),h=s[0],v=s[s.length-1],c=(n??1.5)*(f-l),p=i?h:Math.max(h,l-c),d=i?v:Math.min(v,f+c),g=e.itemNameFormatter,y=K(g)?g({value:o}):$(g)?g.replace("{value}",o+""):o+"";t.push([y,p,l,u,f,d]);for(var m=0;m<s.length;m++){var _=s[m];if(_<p||_>d){var S=[y,_];a.push(S)}}}return{boxData:t,outliers:a}}var w4={type:"echarts:boxplot",transform:function(e){var t=e.upstream;if(t.sourceFormat!==ye){var a="";Mt(a)}var n=x4(t.getRawData(),e.config);return[{dimensions:["ItemName","Low","Q1","Q2","Q3","High"],data:n.boxData},{data:n.outliers}]}};function b4(r){r.registerSeriesModel(h4),r.registerChartView(g4),r.registerLayout(y4),r.registerTransform(w4)}var T4=["color","borderColor"],A4=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){this.group.removeClipPath(),this._progressiveEls=null,this._updateDrawMode(t),this._isLargeDraw?this._renderLarge(t):this._renderNormal(t)},e.prototype.incrementalPrepareRender=function(t,a,n){this._clear(),this._updateDrawMode(t)},e.prototype.incrementalRender=function(t,a,n,i){this._progressiveEls=[],this._isLargeDraw?this._incrementalRenderLarge(t,a):this._incrementalRenderNormal(t,a)},e.prototype.eachRendered=function(t){Ja(this._progressiveEls||this.group,t)},e.prototype._updateDrawMode=function(t){var a=t.pipelineContext.large;(this._isLargeDraw==null||a!==this._isLargeDraw)&&(this._isLargeDraw=a,this._clear())},e.prototype._renderNormal=function(t){var a=t.getData(),n=this._data,i=this.group,o=a.getLayout("isSimpleBox"),s=t.get("clip",!0),l=t.coordinateSystem,u=l.getArea&&l.getArea();this._data||i.removeAll(),a.diff(n).add(function(f){if(a.hasValue(f)){var h=a.getItemLayout(f);if(s&&WS(u,h))return;var v=wc(h,f,!0);Bt(v,{shape:{points:h.ends}},t,f),bc(v,a,f,o),i.add(v),a.setItemGraphicEl(f,v)}}).update(function(f,h){var v=n.getItemGraphicEl(h);if(!a.hasValue(f)){i.remove(v);return}var c=a.getItemLayout(f);if(s&&WS(u,c)){i.remove(v);return}v?(Dt(v,{shape:{points:c.ends}},t,f),Sr(v)):v=wc(c),bc(v,a,f,o),i.add(v),a.setItemGraphicEl(f,v)}).remove(function(f){var h=n.getItemGraphicEl(f);h&&i.remove(h)}).execute(),this._data=a},e.prototype._renderLarge=function(t){this._clear(),$S(t,this.group);var a=t.get("clip",!0)?yl(t.coordinateSystem,!1,t):null;a?this.group.setClipPath(a):this.group.removeClipPath()},e.prototype._incrementalRenderNormal=function(t,a){for(var n=a.getData(),i=n.getLayout("isSimpleBox"),o;(o=t.next())!=null;){var s=n.getItemLayout(o),l=wc(s);bc(l,n,o,i),l.incremental=!0,this.group.add(l),this._progressiveEls.push(l)}},e.prototype._incrementalRenderLarge=function(t,a){$S(a,this.group,this._progressiveEls,!0)},e.prototype.remove=function(t){this._clear()},e.prototype._clear=function(){this.group.removeAll(),this._data=null},e.type="candlestick",e}(Nt),C4=function(){function r(){}return r}(),D4=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a.type="normalCandlestickBox",a}return e.prototype.getDefaultShape=function(){return new C4},e.prototype.buildPath=function(t,a){var n=a.points;this.__simpleBox?(t.moveTo(n[4][0],n[4][1]),t.lineTo(n[6][0],n[6][1])):(t.moveTo(n[0][0],n[0][1]),t.lineTo(n[1][0],n[1][1]),t.lineTo(n[2][0],n[2][1]),t.lineTo(n[3][0],n[3][1]),t.closePath(),t.moveTo(n[4][0],n[4][1]),t.lineTo(n[5][0],n[5][1]),t.moveTo(n[6][0],n[6][1]),t.lineTo(n[7][0],n[7][1]))},e}(yt);function wc(r,e,t){var a=r.ends;return new D4({shape:{points:t?M4(a,r):a},z2:100})}function WS(r,e){for(var t=!0,a=0;a<e.ends.length;a++)if(r.contain(e.ends[a][0],e.ends[a][1])){t=!1;break}return t}function bc(r,e,t,a){var n=e.getItemModel(t);r.useStyle(e.getItemVisual(t,"style")),r.style.strokeNoScale=!0,r.__simpleBox=a,ue(r,n)}function M4(r,e){return G(r,function(t){return t=t.slice(),t[1]=e.initBaseline,t})}var I4=function(){function r(){}return r}(),Tc=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a.type="largeCandlestickBox",a}return e.prototype.getDefaultShape=function(){return new I4},e.prototype.buildPath=function(t,a){for(var n=a.points,i=0;i<n.length;)if(this.__sign===n[i++]){var o=n[i++];t.moveTo(o,n[i++]),t.lineTo(o,n[i++])}else i+=3},e}(yt);function $S(r,e,t,a){var n=r.getData(),i=n.getLayout("largePoints"),o=new Tc({shape:{points:i},__sign:1,ignoreCoarsePointer:!0});e.add(o);var s=new Tc({shape:{points:i},__sign:-1,ignoreCoarsePointer:!0});e.add(s);var l=new Tc({shape:{points:i},__sign:0,ignoreCoarsePointer:!0});e.add(l),Ac(1,o,r),Ac(-1,s,r),Ac(0,l,r),a&&(o.incremental=!0,s.incremental=!0),t&&t.push(o,s)}function Ac(r,e,t,a){var n=t.get(["itemStyle",r>0?"borderColor":"borderColor0"])||t.get(["itemStyle",r>0?"color":"color0"]);r===0&&(n=t.get(["itemStyle","borderColorDoji"]));var i=t.getModel("itemStyle").getItemStyle(T4);e.useStyle(i),e.style.fill=null,e.style.stroke=n}const L4=A4;var ZM=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.defaultValueDimensions=[{name:"open",defaultTooltip:!0},{name:"close",defaultTooltip:!0},{name:"lowest",defaultTooltip:!0},{name:"highest",defaultTooltip:!0}],t}return e.prototype.getShadowDim=function(){return"open"},e.prototype.brushSelector=function(t,a,n){var i=a.getItemLayout(t);return i&&n.rect(i.brushRect)},e.type="series.candlestick",e.dependencies=["xAxis","yAxis","grid"],e.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,layout:null,clip:!0,itemStyle:{color:"#eb5454",color0:"#47b262",borderColor:"#eb5454",borderColor0:"#47b262",borderColorDoji:null,borderWidth:1},emphasis:{scale:!0,itemStyle:{borderWidth:2}},barMaxWidth:null,barMinWidth:null,barWidth:null,large:!0,largeThreshold:600,progressive:3e3,progressiveThreshold:1e4,progressiveChunkMode:"mod",animationEasing:"linear",animationDuration:300},e}(zt);Kt(ZM,$M,!0);const P4=ZM;function R4(r){!r||!z(r.series)||C(r.series,function(e){tt(e)&&e.type==="k"&&(e.type="candlestick")})}var E4=["itemStyle","borderColor"],k4=["itemStyle","borderColor0"],O4=["itemStyle","borderColorDoji"],N4=["itemStyle","color"],B4=["itemStyle","color0"],V4={seriesType:"candlestick",plan:xo(),performRawSeries:!0,reset:function(r,e){function t(i,o){return o.get(i>0?N4:B4)}function a(i,o){return o.get(i===0?O4:i>0?E4:k4)}if(!e.isSeriesFiltered(r)){var n=r.pipelineContext.large;return!n&&{progress:function(i,o){for(var s;(s=i.next())!=null;){var l=o.getItemModel(s),u=o.getItemLayout(s).sign,f=l.getItemStyle();f.fill=t(u,l),f.stroke=a(u,l)||f.fill;var h=o.ensureUniqueItemVisual(s,"style");V(h,f)}}}}}};const z4=V4;var G4={seriesType:"candlestick",plan:xo(),reset:function(r){var e=r.coordinateSystem,t=r.getData(),a=F4(r,t),n=0,i=1,o=["x","y"],s=t.getDimensionIndex(t.mapDimension(o[n])),l=G(t.mapDimensionsAll(o[i]),t.getDimensionIndex,t),u=l[0],f=l[1],h=l[2],v=l[3];if(t.setLayout({candleWidth:a,isSimpleBox:a<=1.3}),s<0||l.length<4)return;return{progress:r.pipelineContext.large?p:c};function c(d,g){for(var y,m=g.getStore();(y=d.next())!=null;){var _=m.get(s,y),S=m.get(u,y),w=m.get(f,y),x=m.get(h,y),b=m.get(v,y),T=Math.min(S,w),A=Math.max(S,w),D=N(T,_),M=N(A,_),I=N(x,_),L=N(b,_),P=[];O(P,M,0),O(P,D,1),P.push(F(L),F(M),F(I),F(D));var R=g.getItemModel(y),E=!!R.get(["itemStyle","borderColorDoji"]);g.setItemLayout(y,{sign:US(m,y,S,w,f,E),initBaseline:S>w?M[i]:D[i],ends:P,brushRect:B(x,b,_)})}function N(H,X){var Q=[];return Q[n]=X,Q[i]=H,isNaN(X)||isNaN(H)?[NaN,NaN]:e.dataToPoint(Q)}function O(H,X,Q){var J=X.slice(),ct=X.slice();J[n]=Vu(J[n]+a/2,1,!1),ct[n]=Vu(ct[n]-a/2,1,!0),Q?H.push(J,ct):H.push(ct,J)}function B(H,X,Q){var J=N(H,Q),ct=N(X,Q);return J[n]-=a/2,ct[n]-=a/2,{x:J[0],y:J[1],width:a,height:ct[1]-J[1]}}function F(H){return H[n]=Vu(H[n],1),H}}function p(d,g){for(var y=Or(d.count*4),m=0,_,S=[],w=[],x,b=g.getStore(),T=!!r.get(["itemStyle","borderColorDoji"]);(x=d.next())!=null;){var A=b.get(s,x),D=b.get(u,x),M=b.get(f,x),I=b.get(h,x),L=b.get(v,x);if(isNaN(A)||isNaN(I)||isNaN(L)){y[m++]=NaN,m+=3;continue}y[m++]=US(b,x,D,M,f,T),S[n]=A,S[i]=I,_=e.dataToPoint(S,null,w),y[m++]=_?_[0]:NaN,y[m++]=_?_[1]:NaN,S[i]=L,_=e.dataToPoint(S,null,w),y[m++]=_?_[1]:NaN}g.setLayout("largePoints",y)}}};function US(r,e,t,a,n,i){var o;return t>a?o=-1:t<a?o=1:o=i?0:e>0?r.get(n,e-1)<=a?1:-1:1,o}function F4(r,e){var t=r.getBaseAxis(),a,n=t.type==="category"?t.getBandWidth():(a=t.getExtent(),Math.abs(a[1]-a[0])/e.count()),i=W(it(r.get("barMaxWidth"),n),n),o=W(it(r.get("barMinWidth"),1),n),s=r.get("barWidth");return s!=null?W(s,n):Math.max(Math.min(n/2,i),o)}const H4=G4;function W4(r){r.registerChartView(L4),r.registerSeriesModel(P4),r.registerPreprocessor(R4),r.registerVisual(z4),r.registerLayout(H4)}function YS(r,e){var t=e.rippleEffectColor||e.color;r.eachChild(function(a){a.attr({z:e.z,zlevel:e.zlevel,style:{stroke:e.brushType==="stroke"?t:null,fill:e.brushType==="fill"?t:null}})})}var $4=function(r){k(e,r);function e(t,a){var n=r.call(this)||this,i=new dl(t,a),o=new at;return n.add(i),n.add(o),n.updateData(t,a),n}return e.prototype.stopEffectAnimation=function(){this.childAt(1).removeAll()},e.prototype.startEffectAnimation=function(t){for(var a=t.symbolType,n=t.color,i=t.rippleNumber,o=this.childAt(1),s=0;s<i;s++){var l=qt(a,-1,-1,2,2,n);l.attr({style:{strokeNoScale:!0},z2:99,silent:!0,scaleX:.5,scaleY:.5});var u=-s/i*t.period+t.effectOffset;l.animate("",!0).when(t.period,{scaleX:t.rippleScale/2,scaleY:t.rippleScale/2}).delay(u).start(),l.animateStyle(!0).when(t.period,{opacity:0}).delay(u).start(),o.add(l)}YS(o,t)},e.prototype.updateEffectAnimation=function(t){for(var a=this._effectCfg,n=this.childAt(1),i=["symbolType","period","rippleScale","rippleNumber"],o=0;o<i.length;o++){var s=i[o];if(a[s]!==t[s]){this.stopEffectAnimation(),this.startEffectAnimation(t);return}}YS(n,t)},e.prototype.highlight=function(){sa(this)},e.prototype.downplay=function(){la(this)},e.prototype.getSymbolType=function(){var t=this.childAt(0);return t&&t.getSymbolType()},e.prototype.updateData=function(t,a){var n=this,i=t.hostModel;this.childAt(0).updateData(t,a);var o=this.childAt(1),s=t.getItemModel(a),l=t.getItemVisual(a,"symbol"),u=bo(t.getItemVisual(a,"symbolSize")),f=t.getItemVisual(a,"style"),h=f&&f.fill,v=s.getModel("emphasis");o.setScale(u),o.traverse(function(g){g.setStyle("fill",h)});var c=ui(t.getItemVisual(a,"symbolOffset"),u);c&&(o.x=c[0],o.y=c[1]);var p=t.getItemVisual(a,"symbolRotate");o.rotation=(p||0)*Math.PI/180||0;var d={};d.showEffectOn=i.get("showEffectOn"),d.rippleScale=s.get(["rippleEffect","scale"]),d.brushType=s.get(["rippleEffect","brushType"]),d.period=s.get(["rippleEffect","period"])*1e3,d.effectOffset=a/t.count(),d.z=i.getShallow("z")||0,d.zlevel=i.getShallow("zlevel")||0,d.symbolType=l,d.color=h,d.rippleEffectColor=s.get(["rippleEffect","color"]),d.rippleNumber=s.get(["rippleEffect","number"]),d.showEffectOn==="render"?(this._effectCfg?this.updateEffectAnimation(d):this.startEffectAnimation(d),this._effectCfg=d):(this._effectCfg=null,this.stopEffectAnimation(),this.onHoverStateChange=function(g){g==="emphasis"?d.showEffectOn!=="render"&&n.startEffectAnimation(d):g==="normal"&&d.showEffectOn!=="render"&&n.stopEffectAnimation()}),this._effectCfg=d,Ft(this,v.get("focus"),v.get("blurScope"),v.get("disabled"))},e.prototype.fadeOut=function(t){t&&t()},e}(at);const U4=$4;var Y4=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(){this._symbolDraw=new gl(U4)},e.prototype.render=function(t,a,n){var i=t.getData(),o=this._symbolDraw;o.updateData(i,{clipShape:this._getClipShape(t)}),this.group.add(o.group)},e.prototype._getClipShape=function(t){var a=t.coordinateSystem,n=a&&a.getArea&&a.getArea();return t.get("clip",!0)?n:null},e.prototype.updateTransform=function(t,a,n){var i=t.getData();this.group.dirty();var o=ml("").reset(t,a,n);o.progress&&o.progress({start:0,end:i.count(),count:i.count()},i),this._symbolDraw.updateLayout()},e.prototype._updateGroupTransform=function(t){var a=t.coordinateSystem;a&&a.getRoamTransform&&(this.group.transform=XL(a.getRoamTransform()),this.group.decomposeTransform())},e.prototype.remove=function(t,a){this._symbolDraw&&this._symbolDraw.remove(!0)},e.type="effectScatter",e}(Nt);const Z4=Y4;var X4=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t}return e.prototype.getInitialData=function(t,a){return va(null,this,{useEncodeDefaulter:!0})},e.prototype.brushSelector=function(t,a,n){return n.point(a.getItemLayout(t))},e.type="series.effectScatter",e.dependencies=["grid","polar"],e.defaultOption={coordinateSystem:"cartesian2d",z:2,legendHoverLink:!0,effectType:"ripple",progressive:0,showEffectOn:"render",clip:!0,rippleEffect:{period:4,scale:2.5,brushType:"fill",number:3},universalTransition:{divideShape:"clone"},symbolSize:10},e}(zt);const q4=X4;function K4(r){r.registerChartView(Z4),r.registerSeriesModel(q4),r.registerLayout(ml("effectScatter"))}var Q4=function(r){k(e,r);function e(t,a,n){var i=r.call(this)||this;return i.add(i.createLine(t,a,n)),i._updateEffectSymbol(t,a),i}return e.prototype.createLine=function(t,a,n){return new my(t,a,n)},e.prototype._updateEffectSymbol=function(t,a){var n=t.getItemModel(a),i=n.getModel("effect"),o=i.get("symbolSize"),s=i.get("symbol");z(o)||(o=[o,o]);var l=t.getItemVisual(a,"style"),u=i.get("color")||l&&l.stroke,f=this.childAt(1);this._symbolType!==s&&(this.remove(f),f=qt(s,-.5,-.5,1,1,u),f.z2=100,f.culling=!0,this.add(f)),f&&(f.setStyle("shadowColor",u),f.setStyle(i.getItemStyle(["color"])),f.scaleX=o[0],f.scaleY=o[1],f.setColor(u),this._symbolType=s,this._symbolScale=o,this._updateEffectAnimation(t,i,a))},e.prototype._updateEffectAnimation=function(t,a,n){var i=this.childAt(1);if(i){var o=t.getItemLayout(n),s=a.get("period")*1e3,l=a.get("loop"),u=a.get("roundTrip"),f=a.get("constantSpeed"),h=ie(a.get("delay"),function(c){return c/t.count()*s/3});if(i.ignore=!0,this._updateAnimationPoints(i,o),f>0&&(s=this._getLineLength(i)/f*1e3),s!==this._period||l!==this._loop||u!==this._roundTrip){i.stopAnimation();var v=void 0;K(h)?v=h(n):v=h,i.__t>0&&(v=-s*i.__t),this._animateSymbol(i,s,v,l,u)}this._period=s,this._loop=l,this._roundTrip=u}},e.prototype._animateSymbol=function(t,a,n,i,o){if(a>0){t.__t=0;var s=this,l=t.animate("",i).when(o?a*2:a,{__t:o?2:1}).delay(n).during(function(){s._updateSymbolPosition(t)});i||l.done(function(){s.remove(t)}),l.start()}},e.prototype._getLineLength=function(t){return Ma(t.__p1,t.__cp1)+Ma(t.__cp1,t.__p2)},e.prototype._updateAnimationPoints=function(t,a){t.__p1=a[0],t.__p2=a[1],t.__cp1=a[2]||[(a[0][0]+a[1][0])/2,(a[0][1]+a[1][1])/2]},e.prototype.updateData=function(t,a,n){this.childAt(0).updateData(t,a,n),this._updateEffectSymbol(t,a)},e.prototype._updateSymbolPosition=function(t){var a=t.__p1,n=t.__p2,i=t.__cp1,o=t.__t<1?t.__t:2-t.__t,s=[t.x,t.y],l=s.slice(),u=ne,f=up;s[0]=u(a[0],i[0],n[0],o),s[1]=u(a[1],i[1],n[1],o);var h=t.__t<1?f(a[0],i[0],n[0],o):f(n[0],i[0],a[0],1-o),v=t.__t<1?f(a[1],i[1],n[1],o):f(n[1],i[1],a[1],1-o);t.rotation=-Math.atan2(v,h)-Math.PI/2,(this._symbolType==="line"||this._symbolType==="rect"||this._symbolType==="roundRect")&&(t.__lastT!==void 0&&t.__lastT<t.__t?(t.scaleY=Ma(l,s)*1.05,o===1&&(s[0]=l[0]+(s[0]-l[0])/2,s[1]=l[1]+(s[1]-l[1])/2)):t.__lastT===1?t.scaleY=2*Ma(a,s):t.scaleY=this._symbolScale[1]),t.__lastT=t.__t,t.ignore=!1,t.x=s[0],t.y=s[1]},e.prototype.updateLayout=function(t,a){this.childAt(0).updateLayout(t,a);var n=t.getItemModel(a).getModel("effect");this._updateEffectAnimation(t,n,a)},e}(at);const XM=Q4;var J4=function(r){k(e,r);function e(t,a,n){var i=r.call(this)||this;return i._createPolyline(t,a,n),i}return e.prototype._createPolyline=function(t,a,n){var i=t.getItemLayout(a),o=new Me({shape:{points:i}});this.add(o),this._updateCommonStl(t,a,n)},e.prototype.updateData=function(t,a,n){var i=t.hostModel,o=this.childAt(0),s={shape:{points:t.getItemLayout(a)}};Dt(o,s,i,a),this._updateCommonStl(t,a,n)},e.prototype._updateCommonStl=function(t,a,n){var i=this.childAt(0),o=t.getItemModel(a),s=n&&n.emphasisLineStyle,l=n&&n.focus,u=n&&n.blurScope,f=n&&n.emphasisDisabled;if(!n||t.hasItemOption){var h=o.getModel("emphasis");s=h.getModel("lineStyle").getLineStyle(),f=h.get("disabled"),l=h.get("focus"),u=h.get("blurScope")}i.useStyle(t.getItemVisual(a,"style")),i.style.fill=null,i.style.strokeNoScale=!0;var v=i.ensureState("emphasis");v.style=s,Ft(this,l,u,f)},e.prototype.updateLayout=function(t,a){var n=this.childAt(0);n.setShape("points",t.getItemLayout(a))},e}(at);const qM=J4;var j4=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t._lastFrame=0,t._lastFramePercent=0,t}return e.prototype.createLine=function(t,a,n){return new qM(t,a,n)},e.prototype._updateAnimationPoints=function(t,a){this._points=a;for(var n=[0],i=0,o=1;o<a.length;o++){var s=a[o-1],l=a[o];i+=Ma(s,l),n.push(i)}if(i===0){this._length=0;return}for(var o=0;o<n.length;o++)n[o]/=i;this._offsets=n,this._length=i},e.prototype._getLineLength=function(){return this._length},e.prototype._updateSymbolPosition=function(t){var a=t.__t<1?t.__t:2-t.__t,n=this._points,i=this._offsets,o=n.length;if(i){var s=this._lastFrame,l;if(a<this._lastFramePercent){var u=Math.min(s+1,o-1);for(l=u;l>=0&&!(i[l]<=a);l--);l=Math.min(l,o-2)}else{for(l=s;l<o&&!(i[l]>a);l++);l=Math.min(l-1,o-2)}var f=(a-i[l])/(i[l+1]-i[l]),h=n[l],v=n[l+1];t.x=h[0]*(1-f)+f*v[0],t.y=h[1]*(1-f)+f*v[1];var c=t.__t<1?v[0]-h[0]:h[0]-v[0],p=t.__t<1?v[1]-h[1]:h[1]-v[1];t.rotation=-Math.atan2(p,c)-Math.PI/2,this._lastFrame=l,this._lastFramePercent=a,t.ignore=!1}},e}(XM);const tW=j4;var eW=function(){function r(){this.polyline=!1,this.curveness=0,this.segs=[]}return r}(),rW=function(r){k(e,r);function e(t){var a=r.call(this,t)||this;return a._off=0,a.hoverDataIdx=-1,a}return e.prototype.reset=function(){this.notClear=!1,this._off=0},e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new eW},e.prototype.buildPath=function(t,a){var n=a.segs,i=a.curveness,o;if(a.polyline)for(o=this._off;o<n.length;){var s=n[o++];if(s>0){t.moveTo(n[o++],n[o++]);for(var l=1;l<s;l++)t.lineTo(n[o++],n[o++])}}else for(o=this._off;o<n.length;){var u=n[o++],f=n[o++],h=n[o++],v=n[o++];if(t.moveTo(u,f),i>0){var c=(u+h)/2-(f-v)*i,p=(f+v)/2-(h-u)*i;t.quadraticCurveTo(c,p,h,v)}else t.lineTo(h,v)}this.incremental&&(this._off=o,this.notClear=!0)},e.prototype.findDataIndex=function(t,a){var n=this.shape,i=n.segs,o=n.curveness,s=this.style.lineWidth;if(n.polyline)for(var l=0,u=0;u<i.length;){var f=i[u++];if(f>0)for(var h=i[u++],v=i[u++],c=1;c<f;c++){var p=i[u++],d=i[u++];if(Ca(h,v,p,d,s,t,a))return l}l++}else for(var l=0,u=0;u<i.length;){var h=i[u++],v=i[u++],p=i[u++],d=i[u++];if(o>0){var g=(h+p)/2-(v-d)*o,y=(v+d)/2-(p-h)*o;if(sT(h,v,g,y,p,d,s,t,a))return l}else if(Ca(h,v,p,d,s,t,a))return l;l++}return-1},e.prototype.contain=function(t,a){var n=this.transformCoordToLocal(t,a),i=this.getBoundingRect();if(t=n[0],a=n[1],i.contain(t,a)){var o=this.hoverDataIdx=this.findDataIndex(t,a);return o>=0}return this.hoverDataIdx=-1,!1},e.prototype.getBoundingRect=function(){var t=this._rect;if(!t){for(var a=this.shape,n=a.segs,i=1/0,o=1/0,s=-1/0,l=-1/0,u=0;u<n.length;){var f=n[u++],h=n[u++];i=Math.min(f,i),s=Math.max(f,s),o=Math.min(h,o),l=Math.max(h,l)}t=this._rect=new ht(i,o,s,l)}return t},e}(yt),aW=function(){function r(){this.group=new at}return r.prototype.updateData=function(e){this._clear();var t=this._create();t.setShape({segs:e.getLayout("linesPoints")}),this._setCommon(t,e)},r.prototype.incrementalPrepareUpdate=function(e){this.group.removeAll(),this._clear()},r.prototype.incrementalUpdate=function(e,t){var a=this._newAdded[0],n=t.getLayout("linesPoints"),i=a&&a.shape.segs;if(i&&i.length<2e4){var o=i.length,s=new Float32Array(o+n.length);s.set(i),s.set(n,o),a.setShape({segs:s})}else{this._newAdded=[];var l=this._create();l.incremental=!0,l.setShape({segs:n}),this._setCommon(l,t),l.__startIndex=e.start}},r.prototype.remove=function(){this._clear()},r.prototype.eachRendered=function(e){this._newAdded[0]&&e(this._newAdded[0])},r.prototype._create=function(){var e=new rW({cursor:"default",ignoreCoarsePointer:!0});return this._newAdded.push(e),this.group.add(e),e},r.prototype._setCommon=function(e,t,a){var n=t.hostModel;e.setShape({polyline:n.get("polyline"),curveness:n.get(["lineStyle","curveness"])}),e.useStyle(n.getModel("lineStyle").getLineStyle()),e.style.strokeNoScale=!0;var i=t.getVisual("style");i&&i.stroke&&e.setStyle("stroke",i.stroke),e.setStyle("fill",null);var o=nt(e);o.seriesIndex=n.seriesIndex,e.on("mousemove",function(s){o.dataIndex=null;var l=e.hoverDataIdx;l>0&&(o.dataIndex=l+e.__startIndex)})},r.prototype._clear=function(){this._newAdded=[],this.group.removeAll()},r}(),nW={seriesType:"lines",plan:xo(),reset:function(r){var e=r.coordinateSystem;if(e){var t=r.get("polyline"),a=r.pipelineContext.large;return{progress:function(n,i){var o=[];if(a){var s=void 0,l=n.end-n.start;if(t){for(var u=0,f=n.start;f<n.end;f++)u+=r.getLineCoordsCount(f);s=new Float32Array(l+u*2)}else s=new Float32Array(l*4);for(var h=0,v=[],f=n.start;f<n.end;f++){var c=r.getLineCoords(f,o);t&&(s[h++]=c);for(var p=0;p<c;p++)v=e.dataToPoint(o[p],!1,v),s[h++]=v[0],s[h++]=v[1]}i.setLayout("linesPoints",s)}else for(var f=n.start;f<n.end;f++){var d=i.getItemModel(f),c=r.getLineCoords(f,o),g=[];if(t)for(var y=0;y<c;y++)g.push(e.dataToPoint(o[y]));else{g[0]=e.dataToPoint(o[0]),g[1]=e.dataToPoint(o[1]);var m=d.get(["lineStyle","curveness"]);+m&&(g[2]=[(g[0][0]+g[1][0])/2-(g[0][1]-g[1][1])*m,(g[0][1]+g[1][1])/2-(g[1][0]-g[0][0])*m])}i.setItemLayout(f,g)}}}}}};const KM=nW;var iW=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){var i=t.getData(),o=this._updateLineDraw(i,t),s=t.get("zlevel"),l=t.get(["effect","trailLength"]),u=n.getZr(),f=u.painter.getType()==="svg";f||u.painter.getLayer(s).clear(!0),this._lastZlevel!=null&&!f&&u.configLayer(this._lastZlevel,{motionBlur:!1}),this._showEffect(t)&&l>0&&(f||u.configLayer(s,{motionBlur:!0,lastFrameAlpha:Math.max(Math.min(l/10+.9,1),0)})),o.updateData(i);var h=t.get("clip",!0)&&yl(t.coordinateSystem,!1,t);h?this.group.setClipPath(h):this.group.removeClipPath(),this._lastZlevel=s,this._finished=!0},e.prototype.incrementalPrepareRender=function(t,a,n){var i=t.getData(),o=this._updateLineDraw(i,t);o.incrementalPrepareUpdate(i),this._clearLayer(n),this._finished=!1},e.prototype.incrementalRender=function(t,a,n){this._lineDraw.incrementalUpdate(t,a.getData()),this._finished=t.end===a.getData().count()},e.prototype.eachRendered=function(t){this._lineDraw&&this._lineDraw.eachRendered(t)},e.prototype.updateTransform=function(t,a,n){var i=t.getData(),o=t.pipelineContext;if(!this._finished||o.large||o.progressiveRender)return{update:!0};var s=KM.reset(t,a,n);s.progress&&s.progress({start:0,end:i.count(),count:i.count()},i),this._lineDraw.updateLayout(),this._clearLayer(n)},e.prototype._updateLineDraw=function(t,a){var n=this._lineDraw,i=this._showEffect(a),o=!!a.get("polyline"),s=a.pipelineContext,l=s.large;return(!n||i!==this._hasEffet||o!==this._isPolyline||l!==this._isLargeDraw)&&(n&&n.remove(),n=this._lineDraw=l?new aW:new _y(o?i?tW:qM:i?XM:my),this._hasEffet=i,this._isPolyline=o,this._isLargeDraw=l),this.group.add(n.group),n},e.prototype._showEffect=function(t){return!!t.get(["effect","show"])},e.prototype._clearLayer=function(t){var a=t.getZr(),n=a.painter.getType()==="svg";!n&&this._lastZlevel!=null&&a.painter.getLayer(this._lastZlevel).clear(!0)},e.prototype.remove=function(t,a){this._lineDraw&&this._lineDraw.remove(),this._lineDraw=null,this._clearLayer(a)},e.prototype.dispose=function(t,a){this.remove(t,a)},e.type="lines",e}(Nt);const oW=iW;var sW=typeof Uint32Array>"u"?Array:Uint32Array,lW=typeof Float64Array>"u"?Array:Float64Array;function ZS(r){var e=r.data;e&&e[0]&&e[0][0]&&e[0][0].coord&&(r.data=G(e,function(t){var a=[t[0].coord,t[1].coord],n={coords:a};return t[0].name&&(n.fromName=t[0].name),t[1].name&&(n.toName=t[1].name),Ud([n,t[0],t[1]])}))}var uW=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.visualStyleAccessPath="lineStyle",t.visualDrawType="stroke",t}return e.prototype.init=function(t){t.data=t.data||[],ZS(t);var a=this._processFlatCoordsArray(t.data);this._flatCoords=a.flatCoords,this._flatCoordsOffset=a.flatCoordsOffset,a.flatCoords&&(t.data=new Float32Array(a.count)),r.prototype.init.apply(this,arguments)},e.prototype.mergeOption=function(t){if(ZS(t),t.data){var a=this._processFlatCoordsArray(t.data);this._flatCoords=a.flatCoords,this._flatCoordsOffset=a.flatCoordsOffset,a.flatCoords&&(t.data=new Float32Array(a.count))}r.prototype.mergeOption.apply(this,arguments)},e.prototype.appendData=function(t){var a=this._processFlatCoordsArray(t.data);a.flatCoords&&(this._flatCoords?(this._flatCoords=qu(this._flatCoords,a.flatCoords),this._flatCoordsOffset=qu(this._flatCoordsOffset,a.flatCoordsOffset)):(this._flatCoords=a.flatCoords,this._flatCoordsOffset=a.flatCoordsOffset),t.data=new Float32Array(a.count)),this.getRawData().appendData(t.data)},e.prototype._getCoordsFromItemModel=function(t){var a=this.getData().getItemModel(t),n=a.option instanceof Array?a.option:a.getShallow("coords");return n},e.prototype.getLineCoordsCount=function(t){return this._flatCoordsOffset?this._flatCoordsOffset[t*2+1]:this._getCoordsFromItemModel(t).length},e.prototype.getLineCoords=function(t,a){if(this._flatCoordsOffset){for(var n=this._flatCoordsOffset[t*2],i=this._flatCoordsOffset[t*2+1],o=0;o<i;o++)a[o]=a[o]||[],a[o][0]=this._flatCoords[n+o*2],a[o][1]=this._flatCoords[n+o*2+1];return i}else{for(var s=this._getCoordsFromItemModel(t),o=0;o<s.length;o++)a[o]=a[o]||[],a[o][0]=s[o][0],a[o][1]=s[o][1];return s.length}},e.prototype._processFlatCoordsArray=function(t){var a=0;if(this._flatCoords&&(a=this._flatCoords.length),Ct(t[0])){for(var n=t.length,i=new sW(n),o=new lW(n),s=0,l=0,u=0,f=0;f<n;){u++;var h=t[f++];i[l++]=s+a,i[l++]=h;for(var v=0;v<h;v++){var c=t[f++],p=t[f++];o[s++]=c,o[s++]=p}}return{flatCoordsOffset:new Uint32Array(i.buffer,0,l),flatCoords:o,count:u}}return{flatCoordsOffset:null,flatCoords:null,count:t.length}},e.prototype.getInitialData=function(t,a){var n=new be(["value"],this);return n.hasItemOption=!1,n.initData(t.data,[],function(i,o,s,l){if(i instanceof Array)return NaN;n.hasItemOption=!0;var u=i.value;if(u!=null)return u instanceof Array?u[l]:u}),n},e.prototype.formatTooltip=function(t,a,n){var i=this.getData(),o=i.getItemModel(t),s=o.get("name");if(s)return s;var l=o.get("fromName"),u=o.get("toName"),f=[];return l!=null&&f.push(l),u!=null&&f.push(u),ae("nameValue",{name:f.join(" > ")})},e.prototype.preventIncremental=function(){return!!this.get(["effect","show"])},e.prototype.getProgressive=function(){var t=this.option.progressive;return t??(this.option.large?1e4:this.get("progressive"))},e.prototype.getProgressiveThreshold=function(){var t=this.option.progressiveThreshold;return t??(this.option.large?2e4:this.get("progressiveThreshold"))},e.prototype.getZLevelKey=function(){var t=this.getModel("effect"),a=t.get("trailLength");return this.getData().count()>this.getProgressiveThreshold()?this.id:t.get("show")&&a>0?a+"":""},e.type="series.lines",e.dependencies=["grid","polar","geo","calendar"],e.defaultOption={coordinateSystem:"geo",z:2,legendHoverLink:!0,xAxisIndex:0,yAxisIndex:0,symbol:["none","none"],symbolSize:[10,10],geoIndex:0,effect:{show:!1,period:4,constantSpeed:0,symbol:"circle",symbolSize:3,loop:!0,trailLength:.2},large:!1,largeThreshold:2e3,polyline:!1,clip:!0,label:{show:!1,position:"end"},lineStyle:{opacity:.5}},e}(zt);const fW=uW;function mu(r){return r instanceof Array||(r=[r,r]),r}var hW={seriesType:"lines",reset:function(r){var e=mu(r.get("symbol")),t=mu(r.get("symbolSize")),a=r.getData();a.setVisual("fromSymbol",e&&e[0]),a.setVisual("toSymbol",e&&e[1]),a.setVisual("fromSymbolSize",t&&t[0]),a.setVisual("toSymbolSize",t&&t[1]);function n(i,o){var s=i.getItemModel(o),l=mu(s.getShallow("symbol",!0)),u=mu(s.getShallow("symbolSize",!0));l[0]&&i.setItemVisual(o,"fromSymbol",l[0]),l[1]&&i.setItemVisual(o,"toSymbol",l[1]),u[0]&&i.setItemVisual(o,"fromSymbolSize",u[0]),u[1]&&i.setItemVisual(o,"toSymbolSize",u[1])}return{dataEach:a.hasItemOption?n:null}}};const vW=hW;function cW(r){r.registerChartView(oW),r.registerSeriesModel(fW),r.registerLayout(KM),r.registerVisual(vW)}var pW=256,dW=function(){function r(){this.blurSize=30,this.pointSize=20,this.maxOpacity=1,this.minOpacity=0,this._gradientPixels={inRange:null,outOfRange:null};var e=Ha.createCanvas();this.canvas=e}return r.prototype.update=function(e,t,a,n,i,o){var s=this._getBrush(),l=this._getGradient(i,"inRange"),u=this._getGradient(i,"outOfRange"),f=this.pointSize+this.blurSize,h=this.canvas,v=h.getContext("2d"),c=e.length;h.width=t,h.height=a;for(var p=0;p<c;++p){var d=e[p],g=d[0],y=d[1],m=d[2],_=n(m);v.globalAlpha=_,v.drawImage(s,g-f,y-f)}if(!h.width||!h.height)return h;for(var S=v.getImageData(0,0,h.width,h.height),w=S.data,x=0,b=w.length,T=this.minOpacity,A=this.maxOpacity,D=A-T;x<b;){var _=w[x+3]/256,M=Math.floor(_*(pW-1))*4;if(_>0){var I=o(_)?l:u;_>0&&(_=_*D+T),w[x++]=I[M],w[x++]=I[M+1],w[x++]=I[M+2],w[x++]=I[M+3]*_*256}else x+=4}return v.putImageData(S,0,0),h},r.prototype._getBrush=function(){var e=this._brushCanvas||(this._brushCanvas=Ha.createCanvas()),t=this.pointSize+this.blurSize,a=t*2;e.width=a,e.height=a;var n=e.getContext("2d");return n.clearRect(0,0,a,a),n.shadowOffsetX=a,n.shadowBlur=this.blurSize,n.shadowColor="#000",n.beginPath(),n.arc(-t,t,this.pointSize,0,Math.PI*2,!0),n.closePath(),n.fill(),e},r.prototype._getGradient=function(e,t){for(var a=this._gradientPixels,n=a[t]||(a[t]=new Uint8ClampedArray(256*4)),i=[0,0,0,0],o=0,s=0;s<256;s++)e[t](s/255,!0,i),n[o++]=i[0],n[o++]=i[1],n[o++]=i[2],n[o++]=i[3];return n},r}();const gW=dW;function yW(r,e,t){var a=r[1]-r[0];e=G(e,function(o){return{interval:[(o.interval[0]-r[0])/a,(o.interval[1]-r[0])/a]}});var n=e.length,i=0;return function(o){var s;for(s=i;s<n;s++){var l=e[s].interval;if(l[0]<=o&&o<=l[1]){i=s;break}}if(s===n)for(s=i-1;s>=0;s--){var l=e[s].interval;if(l[0]<=o&&o<=l[1]){i=s;break}}return s>=0&&s<n&&t[s]}}function mW(r,e){var t=r[1]-r[0];return e=[(e[0]-r[0])/t,(e[1]-r[0])/t],function(a){return a>=e[0]&&a<=e[1]}}function XS(r){var e=r.dimensions;return e[0]==="lng"&&e[1]==="lat"}var _W=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){var i;a.eachComponent("visualMap",function(s){s.eachTargetSeries(function(l){l===t&&(i=s)})}),this._progressiveEls=null,this.group.removeAll();var o=t.coordinateSystem;o.type==="cartesian2d"||o.type==="calendar"?this._renderOnCartesianAndCalendar(t,n,0,t.getData().count()):XS(o)&&this._renderOnGeo(o,t,i,n)},e.prototype.incrementalPrepareRender=function(t,a,n){this.group.removeAll()},e.prototype.incrementalRender=function(t,a,n,i){var o=a.coordinateSystem;o&&(XS(o)?this.render(a,n,i):(this._progressiveEls=[],this._renderOnCartesianAndCalendar(a,i,t.start,t.end,!0)))},e.prototype.eachRendered=function(t){Ja(this._progressiveEls||this.group,t)},e.prototype._renderOnCartesianAndCalendar=function(t,a,n,i,o){var s=t.coordinateSystem,l=hi(s,"cartesian2d"),u,f,h,v;if(l){var c=s.getAxis("x"),p=s.getAxis("y");u=c.getBandWidth()+.5,f=p.getBandWidth()+.5,h=c.scale.getExtent(),v=p.scale.getExtent()}for(var d=this.group,g=t.getData(),y=t.getModel(["emphasis","itemStyle"]).getItemStyle(),m=t.getModel(["blur","itemStyle"]).getItemStyle(),_=t.getModel(["select","itemStyle"]).getItemStyle(),S=t.get(["itemStyle","borderRadius"]),w=re(t),x=t.getModel("emphasis"),b=x.get("focus"),T=x.get("blurScope"),A=x.get("disabled"),D=l?[g.mapDimension("x"),g.mapDimension("y"),g.mapDimension("value")]:[g.mapDimension("time"),g.mapDimension("value")],M=n;M<i;M++){var I=void 0,L=g.getItemVisual(M,"style");if(l){var P=g.get(D[0],M),R=g.get(D[1],M);if(isNaN(g.get(D[2],M))||isNaN(P)||isNaN(R)||P<h[0]||P>h[1]||R<v[0]||R>v[1])continue;var E=s.dataToPoint([P,R]);I=new wt({shape:{x:E[0]-u/2,y:E[1]-f/2,width:u,height:f},style:L})}else{if(isNaN(g.get(D[1],M)))continue;I=new wt({z2:1,shape:s.dataToRect([g.get(D[0],M)]).contentShape,style:L})}if(g.hasItemOption){var N=g.getItemModel(M),O=N.getModel("emphasis");y=O.getModel("itemStyle").getItemStyle(),m=N.getModel(["blur","itemStyle"]).getItemStyle(),_=N.getModel(["select","itemStyle"]).getItemStyle(),S=N.get(["itemStyle","borderRadius"]),b=O.get("focus"),T=O.get("blurScope"),A=O.get("disabled"),w=re(N)}I.shape.r=S;var B=t.getRawValue(M),F="-";B&&B[2]!=null&&(F=B[2]+""),fe(I,w,{labelFetcher:t,labelDataIndex:M,defaultOpacity:L.opacity,defaultText:F}),I.ensureState("emphasis").style=y,I.ensureState("blur").style=m,I.ensureState("select").style=_,Ft(I,b,T,A),I.incremental=o,o&&(I.states.emphasis.hoverLayer=!0),d.add(I),g.setItemGraphicEl(M,I),this._progressiveEls&&this._progressiveEls.push(I)}},e.prototype._renderOnGeo=function(t,a,n,i){var o=n.targetVisuals.inRange,s=n.targetVisuals.outOfRange,l=a.getData(),u=this._hmLayer||this._hmLayer||new gW;u.blurSize=a.get("blurSize"),u.pointSize=a.get("pointSize"),u.minOpacity=a.get("minOpacity"),u.maxOpacity=a.get("maxOpacity");var f=t.getViewRect().clone(),h=t.getRoamTransform();f.applyTransform(h);var v=Math.max(f.x,0),c=Math.max(f.y,0),p=Math.min(f.width+f.x,i.getWidth()),d=Math.min(f.height+f.y,i.getHeight()),g=p-v,y=d-c,m=[l.mapDimension("lng"),l.mapDimension("lat"),l.mapDimension("value")],_=l.mapArray(m,function(b,T,A){var D=t.dataToPoint([b,T]);return D[0]-=v,D[1]-=c,D.push(A),D}),S=n.getExtent(),w=n.type==="visualMap.continuous"?mW(S,n.option.range):yW(S,n.getPieceList(),n.option.selected);u.update(_,g,y,o.color.getNormalizer(),{inRange:o.color.getColorMapper(),outOfRange:s.color.getColorMapper()},w);var x=new he({style:{width:g,height:y,x:v,y:c,image:u.canvas},silent:!0});this.group.add(x)},e.type="heatmap",e}(Nt);const SW=_W;var xW=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.getInitialData=function(t,a){return va(null,this,{generateCoord:"value"})},e.prototype.preventIncremental=function(){var t=fl.get(this.get("coordinateSystem"));if(t&&t.dimensions)return t.dimensions[0]==="lng"&&t.dimensions[1]==="lat"},e.type="series.heatmap",e.dependencies=["grid","geo","calendar"],e.defaultOption={coordinateSystem:"cartesian2d",z:2,geoIndex:0,blurSize:30,pointSize:20,maxOpacity:1,minOpacity:0,select:{itemStyle:{borderColor:"#212121"}}},e}(zt);const wW=xW;function bW(r){r.registerChartView(SW),r.registerSeriesModel(wW)}var TW=["itemStyle","borderWidth"],qS=[{xy:"x",wh:"width",index:0,posDesc:["left","right"]},{xy:"y",wh:"height",index:1,posDesc:["top","bottom"]}],Cc=new Qa,AW=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){var i=this.group,o=t.getData(),s=this._data,l=t.coordinateSystem,u=l.getBaseAxis(),f=u.isHorizontal(),h=l.master.getRect(),v={ecSize:{width:n.getWidth(),height:n.getHeight()},seriesModel:t,coordSys:l,coordSysExtent:[[h.x,h.x+h.width],[h.y,h.y+h.height]],isHorizontal:f,valueDim:qS[+f],categoryDim:qS[1-+f]};o.diff(s).add(function(p){if(o.hasValue(p)){var d=QS(o,p),g=KS(o,p,d,v),y=JS(o,v,g);o.setItemGraphicEl(p,y),i.add(y),tx(y,v,g)}}).update(function(p,d){var g=s.getItemGraphicEl(d);if(!o.hasValue(p)){i.remove(g);return}var y=QS(o,p),m=KS(o,p,y,v),_=rI(o,m);g&&_!==g.__pictorialShapeStr&&(i.remove(g),o.setItemGraphicEl(p,null),g=null),g?RW(g,v,m):g=JS(o,v,m,!0),o.setItemGraphicEl(p,g),g.__pictorialSymbolMeta=m,i.add(g),tx(g,v,m)}).remove(function(p){var d=s.getItemGraphicEl(p);d&&jS(s,p,d.__pictorialSymbolMeta.animationModel,d)}).execute();var c=t.get("clip",!0)?yl(t.coordinateSystem,!1,t):null;return c?i.setClipPath(c):i.removeClipPath(),this._data=o,this.group},e.prototype.remove=function(t,a){var n=this.group,i=this._data;t.get("animation")?i&&i.eachItemGraphicEl(function(o){jS(i,nt(o).dataIndex,t,o)}):n.removeAll()},e.type="pictorialBar",e}(Nt);function KS(r,e,t,a){var n=r.getItemLayout(e),i=t.get("symbolRepeat"),o=t.get("symbolClip"),s=t.get("symbolPosition")||"start",l=t.get("symbolRotate"),u=(l||0)*Math.PI/180||0,f=t.get("symbolPatternSize")||2,h=t.isAnimationEnabled(),v={dataIndex:e,layout:n,itemModel:t,symbolType:r.getItemVisual(e,"symbol")||"circle",style:r.getItemVisual(e,"style"),symbolClip:o,symbolRepeat:i,symbolRepeatDirection:t.get("symbolRepeatDirection"),symbolPatternSize:f,rotation:u,animationModel:h?t:null,hoverScale:h&&t.get(["emphasis","scale"]),z2:t.getShallow("z",!0)||0};CW(t,i,n,a,v),DW(r,e,n,i,o,v.boundingLength,v.pxSign,f,a,v),MW(t,v.symbolScale,u,a,v);var c=v.symbolSize,p=ui(t.get("symbolOffset"),c);return IW(t,c,n,i,o,p,s,v.valueLineWidth,v.boundingLength,v.repeatCutLength,a,v),v}function CW(r,e,t,a,n){var i=a.valueDim,o=r.get("symbolBoundingData"),s=a.coordSys.getOtherAxis(a.coordSys.getBaseAxis()),l=s.toGlobalCoord(s.dataToCoord(0)),u=1-+(t[i.wh]<=0),f;if(z(o)){var h=[Dc(s,o[0])-l,Dc(s,o[1])-l];h[1]<h[0]&&h.reverse(),f=h[u]}else o!=null?f=Dc(s,o)-l:e?f=a.coordSysExtent[i.index][u]-l:f=t[i.wh];n.boundingLength=f,e&&(n.repeatCutLength=t[i.wh]),n.pxSign=f>0?1:-1}function Dc(r,e){return r.toGlobalCoord(r.dataToCoord(r.scale.parse(e)))}function DW(r,e,t,a,n,i,o,s,l,u){var f=l.valueDim,h=l.categoryDim,v=Math.abs(t[h.wh]),c=r.getItemVisual(e,"symbolSize"),p;z(c)?p=c.slice():c==null?p=["100%","100%"]:p=[c,c],p[h.index]=W(p[h.index],v),p[f.index]=W(p[f.index],a?v:Math.abs(i)),u.symbolSize=p;var d=u.symbolScale=[p[0]/s,p[1]/s];d[f.index]*=(l.isHorizontal?-1:1)*o}function MW(r,e,t,a,n){var i=r.get(TW)||0;i&&(Cc.attr({scaleX:e[0],scaleY:e[1],rotation:t}),Cc.updateTransform(),i/=Cc.getLineScale(),i*=e[a.valueDim.index]),n.valueLineWidth=i||0}function IW(r,e,t,a,n,i,o,s,l,u,f,h){var v=f.categoryDim,c=f.valueDim,p=h.pxSign,d=Math.max(e[c.index]+s,0),g=d;if(a){var y=Math.abs(l),m=ie(r.get("symbolMargin"),"15%")+"",_=!1;m.lastIndexOf("!")===m.length-1&&(_=!0,m=m.slice(0,m.length-1));var S=W(m,e[c.index]),w=Math.max(d+S*2,0),x=_?0:S*2,b=Zb(a),T=b?a:ex((y+x)/w),A=y-T*d;S=A/2/(_?T:Math.max(T-1,1)),w=d+S*2,x=_?0:S*2,!b&&a!=="fixed"&&(T=u?ex((Math.abs(u)+x)/w):0),g=T*w-x,h.repeatTimes=T,h.symbolMargin=S}var D=p*(g/2),M=h.pathPosition=[];M[v.index]=t[v.wh]/2,M[c.index]=o==="start"?D:o==="end"?l-D:l/2,i&&(M[0]+=i[0],M[1]+=i[1]);var I=h.bundlePosition=[];I[v.index]=t[v.xy],I[c.index]=t[c.xy];var L=h.barRectShape=V({},t);L[c.wh]=p*Math.max(Math.abs(t[c.wh]),Math.abs(M[c.index]+D)),L[v.wh]=t[v.wh];var P=h.clipShape={};P[v.xy]=-t[v.xy],P[v.wh]=f.ecSize[v.wh],P[c.xy]=0,P[c.wh]=t[c.wh]}function QM(r){var e=r.symbolPatternSize,t=qt(r.symbolType,-e/2,-e/2,e,e);return t.attr({culling:!0}),t.type!=="image"&&t.setStyle({strokeNoScale:!0}),t}function JM(r,e,t,a){var n=r.__pictorialBundle,i=t.symbolSize,o=t.valueLineWidth,s=t.pathPosition,l=e.valueDim,u=t.repeatTimes||0,f=0,h=i[e.valueDim.index]+o+t.symbolMargin*2;for(Dy(r,function(d){d.__pictorialAnimationIndex=f,d.__pictorialRepeatTimes=u,f<u?qi(d,null,p(f),t,a):qi(d,null,{scaleX:0,scaleY:0},t,a,function(){n.remove(d)}),f++});f<u;f++){var v=QM(t);v.__pictorialAnimationIndex=f,v.__pictorialRepeatTimes=u,n.add(v);var c=p(f);qi(v,{x:c.x,y:c.y,scaleX:0,scaleY:0},{scaleX:c.scaleX,scaleY:c.scaleY,rotation:c.rotation},t,a)}function p(d){var g=s.slice(),y=t.pxSign,m=d;return(t.symbolRepeatDirection==="start"?y>0:y<0)&&(m=u-1-d),g[l.index]=h*(m-u/2+.5)+s[l.index],{x:g[0],y:g[1],scaleX:t.symbolScale[0],scaleY:t.symbolScale[1],rotation:t.rotation}}}function jM(r,e,t,a){var n=r.__pictorialBundle,i=r.__pictorialMainPath;i?qi(i,null,{x:t.pathPosition[0],y:t.pathPosition[1],scaleX:t.symbolScale[0],scaleY:t.symbolScale[1],rotation:t.rotation},t,a):(i=r.__pictorialMainPath=QM(t),n.add(i),qi(i,{x:t.pathPosition[0],y:t.pathPosition[1],scaleX:0,scaleY:0,rotation:t.rotation},{scaleX:t.symbolScale[0],scaleY:t.symbolScale[1]},t,a))}function tI(r,e,t){var a=V({},e.barRectShape),n=r.__pictorialBarRect;n?qi(n,null,{shape:a},e,t):(n=r.__pictorialBarRect=new wt({z2:2,shape:a,silent:!0,style:{stroke:"transparent",fill:"transparent",lineWidth:0}}),n.disableMorphing=!0,r.add(n))}function eI(r,e,t,a){if(t.symbolClip){var n=r.__pictorialClipPath,i=V({},t.clipShape),o=e.valueDim,s=t.animationModel,l=t.dataIndex;if(n)Dt(n,{shape:i},s,l);else{i[o.wh]=0,n=new wt({shape:i}),r.__pictorialBundle.setClipPath(n),r.__pictorialClipPath=n;var u={};u[o.wh]=t.clipShape[o.wh],si[a?"updateProps":"initProps"](n,{shape:u},s,l)}}}function QS(r,e){var t=r.getItemModel(e);return t.getAnimationDelayParams=LW,t.isAnimationEnabled=PW,t}function LW(r){return{index:r.__pictorialAnimationIndex,count:r.__pictorialRepeatTimes}}function PW(){return this.parentModel.isAnimationEnabled()&&!!this.getShallow("animation")}function JS(r,e,t,a){var n=new at,i=new at;return n.add(i),n.__pictorialBundle=i,i.x=t.bundlePosition[0],i.y=t.bundlePosition[1],t.symbolRepeat?JM(n,e,t):jM(n,e,t),tI(n,t,a),eI(n,e,t,a),n.__pictorialShapeStr=rI(r,t),n.__pictorialSymbolMeta=t,n}function RW(r,e,t){var a=t.animationModel,n=t.dataIndex,i=r.__pictorialBundle;Dt(i,{x:t.bundlePosition[0],y:t.bundlePosition[1]},a,n),t.symbolRepeat?JM(r,e,t,!0):jM(r,e,t,!0),tI(r,t,!0),eI(r,e,t,!0)}function jS(r,e,t,a){var n=a.__pictorialBarRect;n&&n.removeTextContent();var i=[];Dy(a,function(o){i.push(o)}),a.__pictorialMainPath&&i.push(a.__pictorialMainPath),a.__pictorialClipPath&&(t=null),C(i,function(o){$a(o,{scaleX:0,scaleY:0},t,e,function(){a.parent&&a.parent.remove(a)})}),r.setItemGraphicEl(e,null)}function rI(r,e){return[r.getItemVisual(e.dataIndex,"symbol")||"none",!!e.symbolRepeat,!!e.symbolClip].join(":")}function Dy(r,e,t){C(r.__pictorialBundle.children(),function(a){a!==r.__pictorialBarRect&&e.call(t,a)})}function qi(r,e,t,a,n,i){e&&r.attr(e),a.symbolClip&&!n?t&&r.attr(t):t&&si[n?"updateProps":"initProps"](r,t,a.animationModel,a.dataIndex,i)}function tx(r,e,t){var a=t.dataIndex,n=t.itemModel,i=n.getModel("emphasis"),o=i.getModel("itemStyle").getItemStyle(),s=n.getModel(["blur","itemStyle"]).getItemStyle(),l=n.getModel(["select","itemStyle"]).getItemStyle(),u=n.getShallow("cursor"),f=i.get("focus"),h=i.get("blurScope"),v=i.get("scale");Dy(r,function(d){if(d instanceof he){var g=d.style;d.useStyle(V({image:g.image,x:g.x,y:g.y,width:g.width,height:g.height},t.style))}else d.useStyle(t.style);var y=d.ensureState("emphasis");y.style=o,v&&(y.scaleX=d.scaleX*1.1,y.scaleY=d.scaleY*1.1),d.ensureState("blur").style=s,d.ensureState("select").style=l,u&&(d.cursor=u),d.z2=t.z2});var c=e.valueDim.posDesc[+(t.boundingLength>0)],p=r.__pictorialBarRect;p.ignoreClip=!0,fe(p,re(n),{labelFetcher:e.seriesModel,labelDataIndex:a,defaultText:eo(e.seriesModel.getData(),a),inheritColor:t.style.fill,defaultOpacity:t.style.opacity,defaultOutsidePosition:c}),Ft(r,f,h,i.get("disabled"))}function ex(r){var e=Math.round(r);return Math.abs(r-e)<1e-4?e:Math.ceil(r)}const EW=AW;var kW=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t.defaultSymbol="roundRect",t}return e.prototype.getInitialData=function(t){return t.stack=null,r.prototype.getInitialData.apply(this,arguments)},e.type="series.pictorialBar",e.dependencies=["grid"],e.defaultOption=ja(Xs.defaultOption,{symbol:"circle",symbolSize:null,symbolRotate:null,symbolPosition:null,symbolOffset:null,symbolMargin:null,symbolRepeat:!1,symbolRepeatDirection:"end",symbolClip:!1,symbolBoundingData:null,symbolPatternSize:400,barGap:"-100%",clip:!1,progressive:0,emphasis:{scale:!1},select:{itemStyle:{borderColor:"#212121"}}}),e}(Xs);const OW=kW;function NW(r){r.registerChartView(EW),r.registerSeriesModel(OW),r.registerLayout(r.PRIORITY.VISUAL.LAYOUT,ot(BC,"pictorialBar")),r.registerLayout(r.PRIORITY.VISUAL.PROGRESSIVE_LAYOUT,VC("pictorialBar"))}var BW=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._layers=[],t}return e.prototype.render=function(t,a,n){var i=t.getData(),o=this,s=this.group,l=t.getLayerSeries(),u=i.getLayout("layoutInfo"),f=u.rect,h=u.boundaryGap;s.x=0,s.y=f.y+h[0];function v(g){return g.name}var c=new ua(this._layersSeries||[],l,v,v),p=[];c.add(U(d,this,"add")).update(U(d,this,"update")).remove(U(d,this,"remove")).execute();function d(g,y,m){var _=o._layers;if(g==="remove"){s.remove(_[y]);return}for(var S=[],w=[],x,b=l[y].indices,T=0;T<b.length;T++){var A=i.getItemLayout(b[T]),D=A.x,M=A.y0,I=A.y;S.push(D,M),w.push(D,M+I),x=i.getItemVisual(b[T],"style")}var L,P=i.getItemLayout(b[0]),R=t.getModel("label"),E=R.get("margin"),N=t.getModel("emphasis");if(g==="add"){var O=p[y]=new at;L=new DD({shape:{points:S,stackedOnPoints:w,smooth:.4,stackedOnSmooth:.4,smoothConstraint:!1},z2:0}),O.add(L),s.add(O),t.isAnimationEnabled()&&L.setClipPath(VW(L.getBoundingRect(),t,function(){L.removeClipPath()}))}else{var O=_[m];L=O.childAt(0),s.add(O),p[y]=O,Dt(L,{shape:{points:S,stackedOnPoints:w}},t),Sr(L)}fe(L,re(t),{labelDataIndex:b[T-1],defaultText:i.getName(b[T-1]),inheritColor:x.fill},{normal:{verticalAlign:"middle"}}),L.setTextConfig({position:null,local:!0});var B=L.getTextContent();B&&(B.x=P.x-E,B.y=P.y0+P.y/2),L.useStyle(x),i.setItemGraphicEl(y,L),ue(L,t),Ft(L,N.get("focus"),N.get("blurScope"),N.get("disabled"))}this._layersSeries=l,this._layers=p},e.type="themeRiver",e}(Nt);function VW(r,e,t){var a=new wt({shape:{x:r.x-10,y:r.y-10,width:0,height:r.height+20}});return Bt(a,{shape:{x:r.x-50,width:r.width+100,height:r.height+20}},e,t),a}const zW=BW;var Mc=2,GW=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new Sl(U(this.getData,this),U(this.getRawData,this))},e.prototype.fixData=function(t){var a=t.length,n={},i=Tp(t,function(v){return n.hasOwnProperty(v[0]+"")||(n[v[0]+""]=-1),v[2]}),o=[];i.buckets.each(function(v,c){o.push({name:c,dataList:v})});for(var s=o.length,l=0;l<s;++l){for(var u=o[l].name,f=0;f<o[l].dataList.length;++f){var h=o[l].dataList[f][0]+"";n[h]=l}for(var h in n)n.hasOwnProperty(h)&&n[h]!==l&&(n[h]=l,t[a]=[h,0,u],a++)}return t},e.prototype.getInitialData=function(t,a){for(var n=this.getReferringComponents("singleAxis",Xt).models[0],i=n.get("type"),o=Lt(t.data,function(p){return p[2]!==void 0}),s=this.fixData(o||[]),l=[],u=this.nameMap=Z(),f=0,h=0;h<s.length;++h)l.push(s[h][Mc]),u.get(s[h][Mc])||(u.set(s[h][Mc],f),f++);var v=vl(s,{coordDimensions:["single"],dimensionsDefine:[{name:"time",type:_f(i)},{name:"value",type:"float"},{name:"name",type:"ordinal"}],encodeDefine:{single:0,value:1,itemName:2}}).dimensions,c=new be(v,this);return c.initData(s),c},e.prototype.getLayerSeries=function(){for(var t=this.getData(),a=t.count(),n=[],i=0;i<a;++i)n[i]=i;var o=t.mapDimension("single"),s=Tp(n,function(u){return t.get("name",u)}),l=[];return s.buckets.each(function(u,f){u.sort(function(h,v){return t.get(o,h)-t.get(o,v)}),l.push({name:f,indices:u})}),l},e.prototype.getAxisTooltipData=function(t,a,n){z(t)||(t=t?[t]:[]);for(var i=this.getData(),o=this.getLayerSeries(),s=[],l=o.length,u,f=0;f<l;++f){for(var h=Number.MAX_VALUE,v=-1,c=o[f].indices.length,p=0;p<c;++p){var d=i.get(t[0],o[f].indices[p]),g=Math.abs(d-a);g<=h&&(u=d,h=g,v=o[f].indices[p])}s.push(v)}return{dataIndices:s,nestestValue:u}},e.prototype.formatTooltip=function(t,a,n){var i=this.getData(),o=i.getName(t),s=i.get(i.mapDimension("value"),t);return ae("nameValue",{name:o,value:s})},e.type="series.themeRiver",e.dependencies=["singleAxis"],e.defaultOption={z:2,colorBy:"data",coordinateSystem:"singleAxis",boundaryGap:["10%","10%"],singleAxisIndex:0,animationEasing:"linear",label:{margin:4,show:!0,position:"left",fontSize:11},emphasis:{label:{show:!0}}},e}(zt);const FW=GW;function HW(r,e){r.eachSeriesByType("themeRiver",function(t){var a=t.getData(),n=t.coordinateSystem,i={},o=n.getRect();i.rect=o;var s=t.get("boundaryGap"),l=n.getAxis();if(i.boundaryGap=s,l.orient==="horizontal"){s[0]=W(s[0],o.height),s[1]=W(s[1],o.height);var u=o.height-s[0]-s[1];rx(a,t,u)}else{s[0]=W(s[0],o.width),s[1]=W(s[1],o.width);var f=o.width-s[0]-s[1];rx(a,t,f)}a.setLayout("layoutInfo",i)})}function rx(r,e,t){if(r.count())for(var a=e.coordinateSystem,n=e.getLayerSeries(),i=r.mapDimension("single"),o=r.mapDimension("value"),s=G(n,function(g){return G(g.indices,function(y){var m=a.dataToPoint(r.get(i,y));return m[1]=r.get(o,y),m})}),l=WW(s),u=l.y0,f=t/l.max,h=n.length,v=n[0].indices.length,c,p=0;p<v;++p){c=u[p]*f,r.setItemLayout(n[0].indices[p],{layerIndex:0,x:s[0][p][0],y0:c,y:s[0][p][1]*f});for(var d=1;d<h;++d)c+=s[d-1][p][1]*f,r.setItemLayout(n[d].indices[p],{layerIndex:d,x:s[d][p][0],y0:c,y:s[d][p][1]*f})}}function WW(r){for(var e=r.length,t=r[0].length,a=[],n=[],i=0,o=0;o<t;++o){for(var s=0,l=0;l<e;++l)s+=r[l][o][1];s>i&&(i=s),a.push(s)}for(var u=0;u<t;++u)n[u]=(i-a[u])/2;i=0;for(var f=0;f<t;++f){var h=a[f]+n[f];h>i&&(i=h)}return{y0:n,max:i}}function $W(r){r.registerChartView(zW),r.registerSeriesModel(FW),r.registerLayout(HW),r.registerProcessor(_l("themeRiver"))}var UW=2,YW=4,ax=function(r){k(e,r);function e(t,a,n,i){var o=r.call(this)||this;o.z2=UW,o.textConfig={inside:!0},nt(o).seriesIndex=a.seriesIndex;var s=new At({z2:YW,silent:t.getModel().get(["label","silent"])});return o.setTextContent(s),o.updateData(!0,t,a,n,i),o}return e.prototype.updateData=function(t,a,n,i,o){this.node=a,a.piece=this,n=n||this._seriesModel,i=i||this._ecModel;var s=this;nt(s).dataIndex=a.dataIndex;var l=a.getModel(),u=l.getModel("emphasis"),f=a.getLayout(),h=V({},f);h.label=null;var v=a.getVisual("style");v.lineJoin="bevel";var c=a.getVisual("decal");c&&(v.decal=ji(c,o));var p=Hn(l.getModel("itemStyle"),h,!0);V(h,p),C(Ce,function(m){var _=s.ensureState(m),S=l.getModel([m,"itemStyle"]);_.style=S.getItemStyle();var w=Hn(S,h);w&&(_.shape=w)}),t?(s.setShape(h),s.shape.r=f.r0,Bt(s,{shape:{r:f.r}},n,a.dataIndex)):(Dt(s,{shape:h},n),Sr(s)),s.useStyle(v),this._updateLabel(n);var d=l.getShallow("cursor");d&&s.attr("cursor",d),this._seriesModel=n||this._seriesModel,this._ecModel=i||this._ecModel;var g=u.get("focus"),y=g==="ancestor"?a.getAncestorsIndices():g==="descendant"?a.getDescendantIndices():g;Ft(this,y,u.get("blurScope"),u.get("disabled"))},e.prototype._updateLabel=function(t){var a=this,n=this.node.getModel(),i=n.getModel("label"),o=this.node.getLayout(),s=o.endAngle-o.startAngle,l=(o.startAngle+o.endAngle)/2,u=Math.cos(l),f=Math.sin(l),h=this,v=h.getTextContent(),c=this.node.dataIndex,p=i.get("minAngle")/180*Math.PI,d=i.get("show")&&!(p!=null&&Math.abs(s)<p);v.ignore=!d,C(Ns,function(y){var m=y==="normal"?n.getModel("label"):n.getModel([y,"label"]),_=y==="normal",S=_?v:v.ensureState(y),w=t.getFormattedLabel(c,y);_&&(w=w||a.node.name),S.style=kt(m,{},null,y!=="normal",!0),w&&(S.style.text=w);var x=m.get("show");x!=null&&!_&&(S.ignore=!x);var b=g(m,"position"),T=_?h:h.states[y],A=T.style.fill;T.textConfig={outsideFill:m.get("color")==="inherit"?A:null,inside:b!=="outside"};var D,M=g(m,"distance")||0,I=g(m,"align"),L=g(m,"rotate"),P=Math.PI*.5,R=Math.PI*1.5,E=Ge(L==="tangential"?Math.PI/2-l:l),N=E>P&&!Es(E-P)&&E<R;b==="outside"?(D=o.r+M,I=N?"right":"left"):!I||I==="center"?(s===2*Math.PI&&o.r0===0?D=0:D=(o.r+o.r0)/2,I="center"):I==="left"?(D=o.r0+M,I=N?"right":"left"):I==="right"&&(D=o.r-M,I=N?"left":"right"),S.style.align=I,S.style.verticalAlign=g(m,"verticalAlign")||"middle",S.x=D*u+o.cx,S.y=D*f+o.cy;var O=0;L==="radial"?O=Ge(-l)+(N?Math.PI:0):L==="tangential"?O=Ge(Math.PI/2-l)+(N?Math.PI:0):Ct(L)&&(O=L*Math.PI/180),S.rotation=Ge(O)});function g(y,m){var _=y.get(m);return _??i.get(m)}v.dirtyStyle()},e}(Be),wd="sunburstRootToNode",nx="sunburstHighlight",ZW="sunburstUnhighlight";function XW(r){r.registerAction({type:wd,update:"updateView"},function(e,t){t.eachComponent({mainType:"series",subType:"sunburst",query:e},a);function a(n,i){var o=Ks(e,[wd],n);if(o){var s=n.getViewRoot();s&&(e.direction=vy(s,o.node)?"rollUp":"drillDown"),n.resetViewRoot(o.node)}}}),r.registerAction({type:nx,update:"none"},function(e,t,a){e=V({},e),t.eachComponent({mainType:"series",subType:"sunburst",query:e},n);function n(i){var o=Ks(e,[nx],i);o&&(e.dataIndex=o.node.dataIndex)}a.dispatchAction(V(e,{type:"highlight"}))}),r.registerAction({type:ZW,update:"updateView"},function(e,t,a){e=V({},e),a.dispatchAction(V(e,{type:"downplay"}))})}var qW=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n,i){var o=this;this.seriesModel=t,this.api=n,this.ecModel=a;var s=t.getData(),l=s.tree.root,u=t.getViewRoot(),f=this.group,h=t.get("renderLabelForZeroData"),v=[];u.eachNode(function(m){v.push(m)});var c=this._oldChildren||[];p(v,c),y(l,u),this._initEvents(),this._oldChildren=v;function p(m,_){if(m.length===0&&_.length===0)return;new ua(_,m,S,S).add(w).update(w).remove(ot(w,null)).execute();function S(x){return x.getId()}function w(x,b){var T=x==null?null:m[x],A=b==null?null:_[b];d(T,A)}}function d(m,_){if(!h&&m&&!m.getValue()&&(m=null),m!==l&&_!==l){if(_&&_.piece)m?(_.piece.updateData(!1,m,t,a,n),s.setItemGraphicEl(m.dataIndex,_.piece)):g(_);else if(m){var S=new ax(m,t,a,n);f.add(S),s.setItemGraphicEl(m.dataIndex,S)}}}function g(m){m&&m.piece&&(f.remove(m.piece),m.piece=null)}function y(m,_){_.depth>0?(o.virtualPiece?o.virtualPiece.updateData(!1,m,t,a,n):(o.virtualPiece=new ax(m,t,a,n),f.add(o.virtualPiece)),_.piece.off("click"),o.virtualPiece.on("click",function(S){o._rootToNode(_.parentNode)})):o.virtualPiece&&(f.remove(o.virtualPiece),o.virtualPiece=null)}},e.prototype._initEvents=function(){var t=this;this.group.off("click"),this.group.on("click",function(a){var n=!1,i=t.seriesModel.getViewRoot();i.eachNode(function(o){if(!n&&o.piece&&o.piece===a.target){var s=o.getModel().get("nodeClick");if(s==="rootToNode")t._rootToNode(o);else if(s==="link"){var l=o.getModel(),u=l.get("link");if(u){var f=l.get("target",!0)||"_blank";hf(u,f)}}n=!0}})})},e.prototype._rootToNode=function(t){t!==this.seriesModel.getViewRoot()&&this.api.dispatchAction({type:wd,from:this.uid,seriesId:this.seriesModel.id,targetNode:t})},e.prototype.containPoint=function(t,a){var n=a.getData(),i=n.getItemLayout(0);if(i){var o=t[0]-i.cx,s=t[1]-i.cy,l=Math.sqrt(o*o+s*s);return l<=i.r&&l>=i.r0}},e.type="sunburst",e}(Nt);const KW=qW;var QW=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.ignoreStyleOnData=!0,t}return e.prototype.getInitialData=function(t,a){var n={name:t.name,children:t.data};aI(n);var i=this._levelModels=G(t.levels||[],function(l){return new Ot(l,this,a)},this),o=hy.createTree(n,this,s);function s(l){l.wrapMethod("getItemModel",function(u,f){var h=o.getNodeByDataIndex(f),v=i[h.depth];return v&&(u.parentModel=v),u})}return o.data},e.prototype.optionUpdated=function(){this.resetViewRoot()},e.prototype.getDataParams=function(t){var a=r.prototype.getDataParams.apply(this,arguments),n=this.getData().tree.getNodeByDataIndex(t);return a.treePathInfo=bh(n,this),a},e.prototype.getLevelModel=function(t){return this._levelModels&&this._levelModels[t.depth]},e.prototype.getViewRoot=function(){return this._viewRoot},e.prototype.resetViewRoot=function(t){t?this._viewRoot=t:t=this._viewRoot;var a=this.getRawData().tree.root;(!t||t!==a&&!a.contains(t))&&(this._viewRoot=a)},e.prototype.enableAriaDecal=function(){sM(this)},e.type="series.sunburst",e.defaultOption={z:2,center:["50%","50%"],radius:[0,"75%"],clockwise:!0,startAngle:90,minAngle:0,stillShowZeroSum:!0,nodeClick:"rootToNode",renderLabelForZeroData:!1,label:{rotate:"radial",show:!0,opacity:1,align:"center",position:"inside",distance:5,silent:!0},itemStyle:{borderWidth:1,borderColor:"white",borderType:"solid",shadowBlur:0,shadowColor:"rgba(0, 0, 0, 0.2)",shadowOffsetX:0,shadowOffsetY:0,opacity:1},emphasis:{focus:"descendant"},blur:{itemStyle:{opacity:.2},label:{opacity:.1}},animationType:"expansion",animationDuration:1e3,animationDurationUpdate:500,data:[],sort:"desc"},e}(zt);function aI(r){var e=0;C(r.children,function(a){aI(a);var n=a.value;z(n)&&(n=n[0]),e+=n});var t=r.value;z(t)&&(t=t[0]),(t==null||isNaN(t))&&(t=e),t<0&&(t=0),z(r.value)?r.value[0]=t:r.value=t}const JW=QW;var ix=Math.PI/180;function jW(r,e,t){e.eachSeriesByType(r,function(a){var n=a.get("center"),i=a.get("radius");z(i)||(i=[0,i]),z(n)||(n=[n,n]);var o=t.getWidth(),s=t.getHeight(),l=Math.min(o,s),u=W(n[0],o),f=W(n[1],s),h=W(i[0],l/2),v=W(i[1],l/2),c=-a.get("startAngle")*ix,p=a.get("minAngle")*ix,d=a.getData().tree.root,g=a.getViewRoot(),y=g.depth,m=a.get("sort");m!=null&&nI(g,m);var _=0;C(g.children,function(E){!isNaN(E.getValue())&&_++});var S=g.getValue(),w=Math.PI/(S||_)*2,x=g.depth>0,b=g.height-(x?-1:1),T=(v-h)/(b||1),A=a.get("clockwise"),D=a.get("stillShowZeroSum"),M=A?1:-1,I=function(E,N){if(E){var O=N;if(E!==d){var B=E.getValue(),F=S===0&&D?w:B*w;F<p&&(F=p),O=N+M*F;var H=E.depth-y-(x?-1:1),X=h+T*H,Q=h+T*(H+1),J=a.getLevelModel(E);if(J){var ct=J.get("r0",!0),St=J.get("r",!0),pt=J.get("radius",!0);pt!=null&&(ct=pt[0],St=pt[1]),ct!=null&&(X=W(ct,l/2)),St!=null&&(Q=W(St,l/2))}E.setLayout({angle:F,startAngle:N,endAngle:O,clockwise:A,cx:u,cy:f,r0:X,r:Q})}if(E.children&&E.children.length){var et=0;C(E.children,function(dt){et+=I(dt,N+et)})}return O-N}};if(x){var L=h,P=h+T,R=Math.PI*2;d.setLayout({angle:R,startAngle:c,endAngle:c+R,clockwise:A,cx:u,cy:f,r0:L,r:P})}I(g,c)})}function nI(r,e){var t=r.children||[];r.children=t$(t,e),t.length&&C(r.children,function(a){nI(a,e)})}function t$(r,e){if(K(e)){var t=G(r,function(n,i){var o=n.getValue();return{params:{depth:n.depth,height:n.height,dataIndex:n.dataIndex,getValue:function(){return o}},index:i}});return t.sort(function(n,i){return e(n.params,i.params)}),G(t,function(n){return r[n.index]})}else{var a=e==="asc";return r.sort(function(n,i){var o=(n.getValue()-i.getValue())*(a?1:-1);return o===0?(n.dataIndex-i.dataIndex)*(a?-1:1):o})}}function e$(r){var e={};function t(a,n,i){for(var o=a;o&&o.depth>1;)o=o.parentNode;var s=n.getColorFromPalette(o.name||o.dataIndex+"",e);return a.depth>1&&$(s)&&(s=vp(s,(a.depth-1)/(i-1)*.5)),s}r.eachSeriesByType("sunburst",function(a){var n=a.getData(),i=n.tree;i.eachNode(function(o){var s=o.getModel(),l=s.getModel("itemStyle").getItemStyle();l.fill||(l.fill=t(o,a,i.root.height));var u=n.ensureUniqueItemVisual(o.dataIndex,"style");V(u,l)})})}function r$(r){r.registerChartView(KW),r.registerSeriesModel(JW),r.registerLayout(ot(jW,"sunburst")),r.registerProcessor(ot(_l,"sunburst")),r.registerVisual(e$),XW(r)}var ox={color:"fill",borderColor:"stroke"},a$={symbol:1,symbolSize:1,symbolKeepAspect:1,legendIcon:1,visualMeta:1,liftZ:1,decal:1},aa=bt(),n$=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.optionUpdated=function(){this.currentZLevel=this.get("zlevel",!0),this.currentZ=this.get("z",!0)},e.prototype.getInitialData=function(t,a){return va(null,this)},e.prototype.getDataParams=function(t,a,n){var i=r.prototype.getDataParams.call(this,t,a);return n&&(i.info=aa(n).info),i},e.type="series.custom",e.dependencies=["grid","polar","geo","singleAxis","calendar"],e.defaultOption={coordinateSystem:"cartesian2d",z:2,legendHoverLink:!0,clip:!1},e}(zt);const i$=n$;function o$(r,e){return e=e||[0,0],G(["x","y"],function(t,a){var n=this.getAxis(t),i=e[a],o=r[a]/2;return n.type==="category"?n.getBandWidth():Math.abs(n.dataToCoord(i-o)-n.dataToCoord(i+o))},this)}function s$(r){var e=r.master.getRect();return{coordSys:{type:"cartesian2d",x:e.x,y:e.y,width:e.width,height:e.height},api:{coord:function(t){return r.dataToPoint(t)},size:U(o$,r)}}}function l$(r,e){return e=e||[0,0],G([0,1],function(t){var a=e[t],n=r[t]/2,i=[],o=[];return i[t]=a-n,o[t]=a+n,i[1-t]=o[1-t]=e[1-t],Math.abs(this.dataToPoint(i)[t]-this.dataToPoint(o)[t])},this)}function u$(r){var e=r.getBoundingRect();return{coordSys:{type:"geo",x:e.x,y:e.y,width:e.width,height:e.height,zoom:r.getZoom()},api:{coord:function(t){return r.dataToPoint(t)},size:U(l$,r)}}}function f$(r,e){var t=this.getAxis(),a=e instanceof Array?e[0]:e,n=(r instanceof Array?r[0]:r)/2;return t.type==="category"?t.getBandWidth():Math.abs(t.dataToCoord(a-n)-t.dataToCoord(a+n))}function h$(r){var e=r.getRect();return{coordSys:{type:"singleAxis",x:e.x,y:e.y,width:e.width,height:e.height},api:{coord:function(t){return r.dataToPoint(t)},size:U(f$,r)}}}function v$(r,e){return e=e||[0,0],G(["Radius","Angle"],function(t,a){var n="get"+t+"Axis",i=this[n](),o=e[a],s=r[a]/2,l=i.type==="category"?i.getBandWidth():Math.abs(i.dataToCoord(o-s)-i.dataToCoord(o+s));return t==="Angle"&&(l=l*Math.PI/180),l},this)}function c$(r){var e=r.getRadiusAxis(),t=r.getAngleAxis(),a=e.getExtent();return a[0]>a[1]&&a.reverse(),{coordSys:{type:"polar",cx:r.cx,cy:r.cy,r:a[1],r0:a[0]},api:{coord:function(n){var i=e.dataToRadius(n[0]),o=t.dataToAngle(n[1]),s=r.coordToPoint([i,o]);return s.push(i,o*Math.PI/180),s},size:U(v$,r)}}}function p$(r){var e=r.getRect(),t=r.getRangeInfo();return{coordSys:{type:"calendar",x:e.x,y:e.y,width:e.width,height:e.height,cellWidth:r.getCellWidth(),cellHeight:r.getCellHeight(),rangeInfo:{start:t.start,end:t.end,weeks:t.weeks,dayCount:t.allDay}},api:{coord:function(a,n){return r.dataToPoint(a,n)}}}}function iI(r,e,t,a){return r&&(r.legacy||r.legacy!==!1&&!t&&!a&&e!=="tspan"&&(e==="text"||Y(r,"text")))}function oI(r,e,t){var a=r,n,i,o;if(e==="text")o=a;else{o={},Y(a,"text")&&(o.text=a.text),Y(a,"rich")&&(o.rich=a.rich),Y(a,"textFill")&&(o.fill=a.textFill),Y(a,"textStroke")&&(o.stroke=a.textStroke),Y(a,"fontFamily")&&(o.fontFamily=a.fontFamily),Y(a,"fontSize")&&(o.fontSize=a.fontSize),Y(a,"fontStyle")&&(o.fontStyle=a.fontStyle),Y(a,"fontWeight")&&(o.fontWeight=a.fontWeight),i={type:"text",style:o,silent:!0},n={};var s=Y(a,"textPosition");t?n.position=s?a.textPosition:"inside":s&&(n.position=a.textPosition),Y(a,"textPosition")&&(n.position=a.textPosition),Y(a,"textOffset")&&(n.offset=a.textOffset),Y(a,"textRotation")&&(n.rotation=a.textRotation),Y(a,"textDistance")&&(n.distance=a.textDistance)}return sx(o,r),C(o.rich,function(l){sx(l,l)}),{textConfig:n,textContent:i}}function sx(r,e){e&&(e.font=e.textFont||e.font,Y(e,"textStrokeWidth")&&(r.lineWidth=e.textStrokeWidth),Y(e,"textAlign")&&(r.align=e.textAlign),Y(e,"textVerticalAlign")&&(r.verticalAlign=e.textVerticalAlign),Y(e,"textLineHeight")&&(r.lineHeight=e.textLineHeight),Y(e,"textWidth")&&(r.width=e.textWidth),Y(e,"textHeight")&&(r.height=e.textHeight),Y(e,"textBackgroundColor")&&(r.backgroundColor=e.textBackgroundColor),Y(e,"textPadding")&&(r.padding=e.textPadding),Y(e,"textBorderColor")&&(r.borderColor=e.textBorderColor),Y(e,"textBorderWidth")&&(r.borderWidth=e.textBorderWidth),Y(e,"textBorderRadius")&&(r.borderRadius=e.textBorderRadius),Y(e,"textBoxShadowColor")&&(r.shadowColor=e.textBoxShadowColor),Y(e,"textBoxShadowBlur")&&(r.shadowBlur=e.textBoxShadowBlur),Y(e,"textBoxShadowOffsetX")&&(r.shadowOffsetX=e.textBoxShadowOffsetX),Y(e,"textBoxShadowOffsetY")&&(r.shadowOffsetY=e.textBoxShadowOffsetY))}function lx(r,e,t){var a=r;a.textPosition=a.textPosition||t.position||"inside",t.offset!=null&&(a.textOffset=t.offset),t.rotation!=null&&(a.textRotation=t.rotation),t.distance!=null&&(a.textDistance=t.distance);var n=a.textPosition.indexOf("inside")>=0,i=r.fill||"#000";ux(a,e);var o=a.textFill==null;return n?o&&(a.textFill=t.insideFill||"#fff",!a.textStroke&&t.insideStroke&&(a.textStroke=t.insideStroke),!a.textStroke&&(a.textStroke=i),a.textStrokeWidth==null&&(a.textStrokeWidth=2)):(o&&(a.textFill=r.fill||t.outsideFill||"#000"),!a.textStroke&&t.outsideStroke&&(a.textStroke=t.outsideStroke)),a.text=e.text,a.rich=e.rich,C(e.rich,function(s){ux(s,s)}),a}function ux(r,e){e&&(Y(e,"fill")&&(r.textFill=e.fill),Y(e,"stroke")&&(r.textStroke=e.fill),Y(e,"lineWidth")&&(r.textStrokeWidth=e.lineWidth),Y(e,"font")&&(r.font=e.font),Y(e,"fontStyle")&&(r.fontStyle=e.fontStyle),Y(e,"fontWeight")&&(r.fontWeight=e.fontWeight),Y(e,"fontSize")&&(r.fontSize=e.fontSize),Y(e,"fontFamily")&&(r.fontFamily=e.fontFamily),Y(e,"align")&&(r.textAlign=e.align),Y(e,"verticalAlign")&&(r.textVerticalAlign=e.verticalAlign),Y(e,"lineHeight")&&(r.textLineHeight=e.lineHeight),Y(e,"width")&&(r.textWidth=e.width),Y(e,"height")&&(r.textHeight=e.height),Y(e,"backgroundColor")&&(r.textBackgroundColor=e.backgroundColor),Y(e,"padding")&&(r.textPadding=e.padding),Y(e,"borderColor")&&(r.textBorderColor=e.borderColor),Y(e,"borderWidth")&&(r.textBorderWidth=e.borderWidth),Y(e,"borderRadius")&&(r.textBorderRadius=e.borderRadius),Y(e,"shadowColor")&&(r.textBoxShadowColor=e.shadowColor),Y(e,"shadowBlur")&&(r.textBoxShadowBlur=e.shadowBlur),Y(e,"shadowOffsetX")&&(r.textBoxShadowOffsetX=e.shadowOffsetX),Y(e,"shadowOffsetY")&&(r.textBoxShadowOffsetY=e.shadowOffsetY),Y(e,"textShadowColor")&&(r.textShadowColor=e.textShadowColor),Y(e,"textShadowBlur")&&(r.textShadowBlur=e.textShadowBlur),Y(e,"textShadowOffsetX")&&(r.textShadowOffsetX=e.textShadowOffsetX),Y(e,"textShadowOffsetY")&&(r.textShadowOffsetY=e.textShadowOffsetY))}var sI={position:["x","y"],scale:["scaleX","scaleY"],origin:["originX","originY"]},fx=_t(sI);zr(Fr,function(r,e){return r[e]=1,r},{});Fr.join(", ");var Pf=["","style","shape","extra"],no=bt();function My(r,e,t,a,n){var i=r+"Animation",o=vo(r,a,n)||{},s=no(e).userDuring;return o.duration>0&&(o.during=s?U(_$,{el:e,userDuring:s}):null,o.setToFinal=!0,o.scope=r),V(o,t[i]),o}function $u(r,e,t,a){a=a||{};var n=a.dataIndex,i=a.isInit,o=a.clearStyle,s=t.isAnimationEnabled(),l=no(r),u=e.style;l.userDuring=e.during;var f={},h={};if(x$(r,e,h),vx("shape",e,h),vx("extra",e,h),!i&&s&&(S$(r,e,f),hx("shape",r,e,f),hx("extra",r,e,f),w$(r,e,u,f)),h.style=u,d$(r,h,o),y$(r,e),s)if(i){var v={};C(Pf,function(p){var d=p?e[p]:e;d&&d.enterFrom&&(p&&(v[p]=v[p]||{}),V(p?v[p]:v,d.enterFrom))});var c=My("enter",r,e,t,n);c.duration>0&&r.animateFrom(v,c)}else g$(r,e,n||0,t,f);lI(r,e),u?r.dirty():r.markRedraw()}function lI(r,e){for(var t=no(r).leaveToProps,a=0;a<Pf.length;a++){var n=Pf[a],i=n?e[n]:e;i&&i.leaveTo&&(t||(t=no(r).leaveToProps={}),n&&(t[n]=t[n]||{}),V(n?t[n]:t,i.leaveTo))}}function Ch(r,e,t,a){if(r){var n=r.parent,i=no(r).leaveToProps;if(i){var o=My("update",r,e,t,0);o.done=function(){n.remove(r),a&&a()},r.animateTo(i,o)}else n.remove(r),a&&a()}}function Qn(r){return r==="all"}function d$(r,e,t){var a=e.style;if(!r.isGroup&&a){if(t){r.useStyle({});for(var n=r.animators,i=0;i<n.length;i++){var o=n[i];o.targetName==="style"&&o.changeTarget(r.style)}}r.setStyle(a)}e&&(e.style=null,e&&r.attr(e),e.style=a)}function g$(r,e,t,a,n){if(n){var i=My("update",r,e,a,t);i.duration>0&&r.animateFrom(n,i)}}function y$(r,e){Y(e,"silent")&&(r.silent=e.silent),Y(e,"ignore")&&(r.ignore=e.ignore),r instanceof ir&&Y(e,"invisible")&&(r.invisible=e.invisible),r instanceof yt&&Y(e,"autoBatch")&&(r.autoBatch=e.autoBatch)}var Mr={},m$={setTransform:function(r,e){return Mr.el[r]=e,this},getTransform:function(r){return Mr.el[r]},setShape:function(r,e){var t=Mr.el,a=t.shape||(t.shape={});return a[r]=e,t.dirtyShape&&t.dirtyShape(),this},getShape:function(r){var e=Mr.el.shape;if(e)return e[r]},setStyle:function(r,e){var t=Mr.el,a=t.style;return a&&(a[r]=e,t.dirtyStyle&&t.dirtyStyle()),this},getStyle:function(r){var e=Mr.el.style;if(e)return e[r]},setExtra:function(r,e){var t=Mr.el.extra||(Mr.el.extra={});return t[r]=e,this},getExtra:function(r){var e=Mr.el.extra;if(e)return e[r]}};function _$(){var r=this,e=r.el;if(e){var t=no(e).userDuring,a=r.userDuring;if(t!==a){r.el=r.userDuring=null;return}Mr.el=e,a(m$)}}function hx(r,e,t,a){var n=t[r];if(n){var i=e[r],o;if(i){var s=t.transition,l=n.transition;if(l)if(!o&&(o=a[r]={}),Qn(l))V(o,i);else for(var u=Pt(l),f=0;f<u.length;f++){var h=u[f],v=i[h];o[h]=v}else if(Qn(s)||vt(s,r)>=0){!o&&(o=a[r]={});for(var c=_t(i),f=0;f<c.length;f++){var h=c[f],v=i[h];b$(n[h],v)&&(o[h]=v)}}}}}function vx(r,e,t){var a=e[r];if(a)for(var n=t[r]={},i=_t(a),o=0;o<i.length;o++){var s=i[o];n[s]=ds(a[s])}}function S$(r,e,t){for(var a=e.transition,n=Qn(a)?Fr:Pt(a||[]),i=0;i<n.length;i++){var o=n[i];if(!(o==="style"||o==="shape"||o==="extra")){var s=r[o];t[o]=s}}}function x$(r,e,t){for(var a=0;a<fx.length;a++){var n=fx[a],i=sI[n],o=e[n];o&&(t[i[0]]=o[0],t[i[1]]=o[1])}for(var a=0;a<Fr.length;a++){var s=Fr[a];e[s]!=null&&(t[s]=e[s])}}function w$(r,e,t,a){if(t){var n=r.style,i;if(n){var o=t.transition,s=e.transition;if(o&&!Qn(o)){var l=Pt(o);!i&&(i=a.style={});for(var u=0;u<l.length;u++){var f=l[u],h=n[f];i[f]=h}}else if(r.getAnimationStyleProps&&(Qn(s)||Qn(o)||vt(s,"style")>=0)){var v=r.getAnimationStyleProps(),c=v?v.style:null;if(c){!i&&(i=a.style={});for(var p=_t(t),u=0;u<p.length;u++){var f=p[u];if(c[f]){var h=n[f];i[f]=h}}}}}}}function b$(r,e){return ge(r)?r!==e:r!=null&&isFinite(r)}var uI=bt(),T$=["percent","easing","shape","style","extra"];function fI(r){r.stopAnimation("keyframe"),r.attr(uI(r))}function Rf(r,e,t){if(!(!t.isAnimationEnabled()||!e)){if(z(e)){C(e,function(s){Rf(r,s,t)});return}var a=e.keyframes,n=e.duration;if(t&&n==null){var i=vo("enter",t,0);n=i&&i.duration}if(!(!a||!n)){var o=uI(r);C(Pf,function(s){if(!(s&&!r[s])){var l;a.sort(function(u,f){return u.percent-f.percent}),C(a,function(u){var f=r.animators,h=s?u[s]:u;if(h){var v=_t(h);if(s||(v=Lt(v,function(d){return vt(T$,d)<0})),!!v.length){l||(l=r.animate(s,e.loop,!0),l.scope="keyframe");for(var c=0;c<f.length;c++)f[c]!==l&&f[c].targetName===l.targetName&&f[c].stopTracks(v);s&&(o[s]=o[s]||{});var p=s?o[s]:o;C(v,function(d){p[d]=((s?r[s]:r)||{})[d]}),l.whenWithKeys(n*u.percent,h,v,u.easing)}}}),l&&l.delay(e.delay||0).duration(n).start(e.easing)}})}}}var na="emphasis",Oa="normal",Iy="blur",Ly="select",qa=[Oa,na,Iy,Ly],Ic={normal:["itemStyle"],emphasis:[na,"itemStyle"],blur:[Iy,"itemStyle"],select:[Ly,"itemStyle"]},Lc={normal:["label"],emphasis:[na,"label"],blur:[Iy,"label"],select:[Ly,"label"]},A$=["x","y"],C$="e\0\0",Ze={normal:{},emphasis:{},blur:{},select:{}},D$={cartesian2d:s$,geo:u$,single:h$,polar:c$,calendar:p$};function bd(r){return r instanceof yt}function Td(r){return r instanceof ir}function M$(r,e){e.copyTransform(r),Td(e)&&Td(r)&&(e.setStyle(r.style),e.z=r.z,e.z2=r.z2,e.zlevel=r.zlevel,e.invisible=r.invisible,e.ignore=r.ignore,bd(e)&&bd(r)&&e.setShape(r.shape))}var I$=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n,i){this._progressiveEls=null;var o=this._data,s=t.getData(),l=this.group,u=cx(t,s,a,n);o||l.removeAll(),s.diff(o).add(function(h){Pc(n,null,h,u(h,i),t,l,s)}).remove(function(h){var v=o.getItemGraphicEl(h);v&&Ch(v,aa(v).option,t)}).update(function(h,v){var c=o.getItemGraphicEl(v);Pc(n,c,h,u(h,i),t,l,s)}).execute();var f=t.get("clip",!0)?yl(t.coordinateSystem,!1,t):null;f?l.setClipPath(f):l.removeClipPath(),this._data=s},e.prototype.incrementalPrepareRender=function(t,a,n){this.group.removeAll(),this._data=null},e.prototype.incrementalRender=function(t,a,n,i,o){var s=a.getData(),l=cx(a,s,n,i),u=this._progressiveEls=[];function f(c){c.isGroup||(c.incremental=!0,c.ensureState("emphasis").hoverLayer=!0)}for(var h=t.start;h<t.end;h++){var v=Pc(null,null,h,l(h,o),a,this.group,s);v&&(v.traverse(f),u.push(v))}},e.prototype.eachRendered=function(t){Ja(this._progressiveEls||this.group,t)},e.prototype.filterForExposedEvent=function(t,a,n,i){var o=a.element;if(o==null||n.name===o)return!0;for(;(n=n.__hostTarget||n.parent)&&n!==this.group;)if(n.name===o)return!0;return!1},e.type="custom",e}(Nt);const L$=I$;function Py(r){var e=r.type,t;if(e==="path"){var a=r.shape,n=a.width!=null&&a.height!=null?{x:a.x||0,y:a.y||0,width:a.width,height:a.height}:null,i=cI(a);t=ah(i,null,n,a.layout||"center"),aa(t).customPathData=i}else if(e==="image")t=new he({}),aa(t).customImagePath=r.style.image;else if(e==="text")t=new At({});else if(e==="group")t=new at;else{if(e==="compoundPath")throw new Error('"compoundPath" is not supported yet.');var o=yg(e);if(!o){var s="";Mt(s)}t=new o}return aa(t).customGraphicType=e,t.name=r.name,t.z2EmphasisLift=1,t.z2SelectLift=1,t}function Ry(r,e,t,a,n,i,o){fI(e);var s=n&&n.normal.cfg;s&&e.setTextConfig(s),a&&a.transition==null&&(a.transition=A$);var l=a&&a.style;if(l){if(e.type==="text"){var u=l;Y(u,"textFill")&&(u.fill=u.textFill),Y(u,"textStroke")&&(u.stroke=u.textStroke)}var f=void 0,h=bd(e)?l.decal:null;r&&h&&(h.dirty=!0,f=ji(h,r)),l.__decalPattern=f}if(Td(e)&&l){var f=l.__decalPattern;f&&(l.decal=f)}$u(e,a,i,{dataIndex:t,isInit:o,clearStyle:!0}),Rf(e,a.keyframeAnimation,i)}function hI(r,e,t,a,n){var i=e.isGroup?null:e,o=n&&n[r].cfg;if(i){var s=i.ensureState(r);if(a===!1){var l=i.getState(r);l&&(l.style=null)}else s.style=a||null;o&&(s.textConfig=o),ei(i)}}function P$(r,e,t){if(!r.isGroup){var a=r,n=t.currentZ,i=t.currentZLevel;a.z=n,a.zlevel=i;var o=e.z2;o!=null&&(a.z2=o||0);for(var s=0;s<qa.length;s++)R$(a,e,qa[s])}}function R$(r,e,t){var a=t===Oa,n=a?e:Ef(e,t),i=n?n.z2:null,o;i!=null&&(o=a?r:r.ensureState(t),o.z2=i||0)}function cx(r,e,t,a){var n=r.get("renderItem"),i=r.coordinateSystem,o={};i&&(o=i.prepareCustoms?i.prepareCustoms(i):D$[i.type](i));for(var s=j({getWidth:a.getWidth,getHeight:a.getHeight,getZr:a.getZr,getDevicePixelRatio:a.getDevicePixelRatio,value:S,style:x,ordinalRawValue:w,styleEmphasis:b,visual:D,barLayout:M,currentSeriesIndices:I,font:L},o.api||{}),l={context:{},seriesId:r.id,seriesName:r.name,seriesIndex:r.seriesIndex,coordSys:o.coordSys,dataInsideLength:e.count(),encode:E$(r.getData())},u,f,h={},v={},c={},p={},d=0;d<qa.length;d++){var g=qa[d];c[g]=r.getModel(Ic[g]),p[g]=r.getModel(Lc[g])}function y(P){return P===u?f||(f=e.getItemModel(P)):e.getItemModel(P)}function m(P,R){return e.hasItemOption?P===u?h[R]||(h[R]=y(P).getModel(Ic[R])):y(P).getModel(Ic[R]):c[R]}function _(P,R){return e.hasItemOption?P===u?v[R]||(v[R]=y(P).getModel(Lc[R])):y(P).getModel(Lc[R]):p[R]}return function(P,R){return u=P,f=null,h={},v={},n&&n(j({dataIndexInside:P,dataIndex:e.getRawIndex(P),actionType:R?R.type:null},l),s)};function S(P,R){return R==null&&(R=u),e.getStore().get(e.getDimensionIndex(P||0),R)}function w(P,R){R==null&&(R=u),P=P||0;var E=e.getDimensionInfo(P);if(!E){var N=e.getDimensionIndex(P);return N>=0?e.getStore().get(N,R):void 0}var O=e.get(E.name,R),B=E&&E.ordinalMeta;return B?B.categories[O]:O}function x(P,R){R==null&&(R=u);var E=e.getItemVisual(R,"style"),N=E&&E.fill,O=E&&E.opacity,B=m(R,Oa).getItemStyle();N!=null&&(B.fill=N),O!=null&&(B.opacity=O);var F={inheritColor:$(N)?N:"#000"},H=_(R,Oa),X=kt(H,null,F,!1,!0);X.text=H.getShallow("show")?it(r.getFormattedLabel(R,Oa),eo(e,R)):null;var Q=uf(H,F,!1);return A(P,B),B=lx(B,X,Q),P&&T(B,P),B.legacy=!0,B}function b(P,R){R==null&&(R=u);var E=m(R,na).getItemStyle(),N=_(R,na),O=kt(N,null,null,!0,!0);O.text=N.getShallow("show")?Br(r.getFormattedLabel(R,na),r.getFormattedLabel(R,Oa),eo(e,R)):null;var B=uf(N,null,!0);return A(P,E),E=lx(E,O,B),P&&T(E,P),E.legacy=!0,E}function T(P,R){for(var E in R)Y(R,E)&&(P[E]=R[E])}function A(P,R){P&&(P.textFill&&(R.textFill=P.textFill),P.textPosition&&(R.textPosition=P.textPosition))}function D(P,R){if(R==null&&(R=u),Y(ox,P)){var E=e.getItemVisual(R,"style");return E?E[ox[P]]:null}if(Y(a$,P))return e.getItemVisual(R,P)}function M(P){if(i.type==="cartesian2d"){var R=i.getBaseAxis();return qN(j({axis:R},P))}}function I(){return t.getCurrentSeriesIndices()}function L(P){return mg(P,t)}}function E$(r){var e={};return C(r.dimensions,function(t){var a=r.getDimensionInfo(t);if(!a.isExtraCoord){var n=a.coordDim,i=e[n]=e[n]||[];i[a.coordDimIndex]=r.getDimensionIndex(t)}}),e}function Pc(r,e,t,a,n,i,o){if(!a){i.remove(e);return}var s=Ey(r,e,t,a,n,i);return s&&o.setItemGraphicEl(t,s),s&&Ft(s,a.focus,a.blurScope,a.emphasisDisabled),s}function Ey(r,e,t,a,n,i){var o=-1,s=e;e&&vI(e,a,n)&&(o=vt(i.childrenRef(),e),e=null);var l=!e,u=e;u?u.clearStates():(u=Py(a),s&&M$(s,u)),a.morph===!1?u.disableMorphing=!0:u.disableMorphing&&(u.disableMorphing=!1),Ze.normal.cfg=Ze.normal.conOpt=Ze.emphasis.cfg=Ze.emphasis.conOpt=Ze.blur.cfg=Ze.blur.conOpt=Ze.select.cfg=Ze.select.conOpt=null,Ze.isLegacy=!1,O$(u,t,a,n,l,Ze),k$(u,t,a,n,l),Ry(r,u,t,a,Ze,n,l),Y(a,"info")&&(aa(u).info=a.info);for(var f=0;f<qa.length;f++){var h=qa[f];if(h!==Oa){var v=Ef(a,h),c=ky(a,v,h);hI(h,u,v,c,Ze)}}return P$(u,a,n),a.type==="group"&&N$(r,u,t,a,n),o>=0?i.replaceAt(u,o):i.add(u),u}function vI(r,e,t){var a=aa(r),n=e.type,i=e.shape,o=e.style;return t.isUniversalTransitionEnabled()||n!=null&&n!==a.customGraphicType||n==="path"&&G$(i)&&cI(i)!==a.customPathData||n==="image"&&Y(o,"image")&&o.image!==a.customImagePath}function k$(r,e,t,a,n){var i=t.clipPath;if(i===!1)r&&r.getClipPath()&&r.removeClipPath();else if(i){var o=r.getClipPath();o&&vI(o,i,a)&&(o=null),o||(o=Py(i),r.setClipPath(o)),Ry(null,o,e,i,null,a,n)}}function O$(r,e,t,a,n,i){if(!r.isGroup){px(t,null,i),px(t,na,i);var o=i.normal.conOpt,s=i.emphasis.conOpt,l=i.blur.conOpt,u=i.select.conOpt;if(o!=null||s!=null||u!=null||l!=null){var f=r.getTextContent();if(o===!1)f&&r.removeTextContent();else{o=i.normal.conOpt=o||{type:"text"},f?f.clearStates():(f=Py(o),r.setTextContent(f)),Ry(null,f,e,o,null,a,n);for(var h=o&&o.style,v=0;v<qa.length;v++){var c=qa[v];if(c!==Oa){var p=i[c].conOpt;hI(c,f,p,ky(o,p,c),null)}}h?f.dirty():f.markRedraw()}}}}function px(r,e,t){var a=e?Ef(r,e):r,n=e?ky(r,a,na):r.style,i=r.type,o=a?a.textConfig:null,s=r.textContent,l=s?e?Ef(s,e):s:null;if(n&&(t.isLegacy||iI(n,i,!!o,!!l))){t.isLegacy=!0;var u=oI(n,i,!e);!o&&u.textConfig&&(o=u.textConfig),!l&&u.textContent&&(l=u.textContent)}if(!e&&l){var f=l;!f.type&&(f.type="text")}var h=e?t[e]:t.normal;h.cfg=o,h.conOpt=l}function Ef(r,e){return e?r?r[e]:null:r}function ky(r,e,t){var a=e&&e.style;return a==null&&t===na&&r&&(a=r.styleEmphasis),a}function N$(r,e,t,a,n){var i=a.children,o=i?i.length:0,s=a.$mergeChildren,l=s==="byName"||a.diffChildrenByName,u=s===!1;if(!(!o&&!l&&!u)){if(l){V$({api:r,oldChildren:e.children()||[],newChildren:i||[],dataIndex:t,seriesModel:n,group:e});return}u&&e.removeAll();for(var f=0;f<o;f++){var h=i[f],v=e.childAt(f);h?(h.ignore==null&&(h.ignore=!1),Ey(r,v,t,h,n,e)):v.ignore=!0}for(var c=e.childCount()-1;c>=f;c--){var p=e.childAt(c);B$(e,p,n)}}}function B$(r,e,t){e&&Ch(e,aa(r).option,t)}function V$(r){new ua(r.oldChildren,r.newChildren,dx,dx,r).add(gx).update(gx).remove(z$).execute()}function dx(r,e){var t=r&&r.name;return t??C$+e}function gx(r,e){var t=this.context,a=r!=null?t.newChildren[r]:null,n=e!=null?t.oldChildren[e]:null;Ey(t.api,n,t.dataIndex,a,t.seriesModel,t.group)}function z$(r){var e=this.context,t=e.oldChildren[r];t&&Ch(t,aa(t).option,e.seriesModel)}function cI(r){return r&&(r.pathData||r.d)}function G$(r){return r&&(Y(r,"pathData")||Y(r,"d"))}function F$(r){r.registerChartView(L$),r.registerSeriesModel(i$)}var En=bt(),yx=rt,Rc=U,H$=function(){function r(){this._dragging=!1,this.animationThreshold=15}return r.prototype.render=function(e,t,a,n){var i=t.get("value"),o=t.get("status");if(this._axisModel=e,this._axisPointerModel=t,this._api=a,!(!n&&this._lastValue===i&&this._lastStatus===o)){this._lastValue=i,this._lastStatus=o;var s=this._group,l=this._handle;if(!o||o==="hide"){s&&s.hide(),l&&l.hide();return}s&&s.show(),l&&l.show();var u={};this.makeElOption(u,i,e,t,a);var f=u.graphicKey;f!==this._lastGraphicKey&&this.clear(a),this._lastGraphicKey=f;var h=this._moveAnimation=this.determineAnimation(e,t);if(!s)s=this._group=new at,this.createPointerEl(s,u,e,t),this.createLabelEl(s,u,e,t),a.getZr().add(s);else{var v=ot(mx,t,h);this.updatePointerEl(s,u,v),this.updateLabelEl(s,u,v,t)}Sx(s,t,!0),this._renderHandle(i)}},r.prototype.remove=function(e){this.clear(e)},r.prototype.dispose=function(e){this.clear(e)},r.prototype.determineAnimation=function(e,t){var a=t.get("animation"),n=e.axis,i=n.type==="category",o=t.get("snap");if(!o&&!i)return!1;if(a==="auto"||a==null){var s=this.animationThreshold;if(i&&n.getBandWidth()>s)return!0;if(o){var l=ny(e).seriesDataCount,u=n.getExtent();return Math.abs(u[0]-u[1])/l>s}return!1}return a===!0},r.prototype.makeElOption=function(e,t,a,n,i){},r.prototype.createPointerEl=function(e,t,a,n){var i=t.pointer;if(i){var o=En(e).pointerEl=new si[i.type](yx(t.pointer));e.add(o)}},r.prototype.createLabelEl=function(e,t,a,n){if(t.label){var i=En(e).labelEl=new At(yx(t.label));e.add(i),_x(i,n)}},r.prototype.updatePointerEl=function(e,t,a){var n=En(e).pointerEl;n&&t.pointer&&(n.setStyle(t.pointer.style),a(n,{shape:t.pointer.shape}))},r.prototype.updateLabelEl=function(e,t,a,n){var i=En(e).labelEl;i&&(i.setStyle(t.label.style),a(i,{x:t.label.x,y:t.label.y}),_x(i,n))},r.prototype._renderHandle=function(e){if(!(this._dragging||!this.updateHandleTransform)){var t=this._axisPointerModel,a=this._api.getZr(),n=this._handle,i=t.getModel("handle"),o=t.get("status");if(!i.get("show")||!o||o==="hide"){n&&a.remove(n),this._handle=null;return}var s;this._handle||(s=!0,n=this._handle=ul(i.get("icon"),{cursor:"move",draggable:!0,onmousemove:function(u){ia(u.event)},onmousedown:Rc(this._onHandleDragMove,this,0,0),drift:Rc(this._onHandleDragMove,this),ondragend:Rc(this._onHandleDragEnd,this)}),a.add(n)),Sx(n,t,!1),n.setStyle(i.getItemStyle(null,["color","borderColor","borderWidth","opacity","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"]));var l=i.get("size");z(l)||(l=[l,l]),n.scaleX=l[0]/2,n.scaleY=l[1]/2,wo(this,"_doDispatchAxisPointer",i.get("throttle")||0,"fixRate"),this._moveHandleToValue(e,s)}},r.prototype._moveHandleToValue=function(e,t){mx(this._axisPointerModel,!t&&this._moveAnimation,this._handle,Ec(this.getHandleTransform(e,this._axisModel,this._axisPointerModel)))},r.prototype._onHandleDragMove=function(e,t){var a=this._handle;if(a){this._dragging=!0;var n=this.updateHandleTransform(Ec(a),[e,t],this._axisModel,this._axisPointerModel);this._payloadInfo=n,a.stopAnimation(),a.attr(Ec(n)),En(a).lastProp=null,this._doDispatchAxisPointer()}},r.prototype._doDispatchAxisPointer=function(){var e=this._handle;if(e){var t=this._payloadInfo,a=this._axisModel;this._api.dispatchAction({type:"updateAxisPointer",x:t.cursorPoint[0],y:t.cursorPoint[1],tooltipOption:t.tooltipOption,axesInfo:[{axisDim:a.axis.dim,axisIndex:a.componentIndex}]})}},r.prototype._onHandleDragEnd=function(){this._dragging=!1;var e=this._handle;if(e){var t=this._axisPointerModel.get("value");this._moveHandleToValue(t),this._api.dispatchAction({type:"hideTip"})}},r.prototype.clear=function(e){this._lastValue=null,this._lastStatus=null;var t=e.getZr(),a=this._group,n=this._handle;t&&a&&(this._lastGraphicKey=null,a&&t.remove(a),n&&t.remove(n),this._group=null,this._handle=null,this._payloadInfo=null),Hs(this,"_doDispatchAxisPointer")},r.prototype.doClear=function(){},r.prototype.buildLabel=function(e,t,a){return a=a||0,{x:e[a],y:e[1-a],width:t[a],height:t[1-a]}},r}();function mx(r,e,t,a){pI(En(t).lastProp,a)||(En(t).lastProp=a,e?Dt(t,a,r):(t.stopAnimation(),t.attr(a)))}function pI(r,e){if(tt(r)&&tt(e)){var t=!0;return C(e,function(a,n){t=t&&pI(r[n],a)}),!!t}else return r===e}function _x(r,e){r[e.get(["label","show"])?"show":"hide"]()}function Ec(r){return{x:r.x||0,y:r.y||0,rotation:r.rotation||0}}function Sx(r,e,t){var a=e.get("z"),n=e.get("zlevel");r&&r.traverse(function(i){i.type!=="group"&&(a!=null&&(i.z=a),n!=null&&(i.zlevel=n),i.silent=t)})}const Oy=H$;function Ny(r){var e=r.get("type"),t=r.getModel(e+"Style"),a;return e==="line"?(a=t.getLineStyle(),a.fill=null):e==="shadow"&&(a=t.getAreaStyle(),a.stroke=null),a}function dI(r,e,t,a,n){var i=t.get("value"),o=gI(i,e.axis,e.ecModel,t.get("seriesDataIndices"),{precision:t.get(["label","precision"]),formatter:t.get(["label","formatter"])}),s=t.getModel("label"),l=yo(s.get("padding")||0),u=s.getFont(),f=il(o,u),h=n.position,v=f.width+l[1]+l[3],c=f.height+l[0]+l[2],p=n.align;p==="right"&&(h[0]-=v),p==="center"&&(h[0]-=v/2);var d=n.verticalAlign;d==="bottom"&&(h[1]-=c),d==="middle"&&(h[1]-=c/2),W$(h,v,c,a);var g=s.get("backgroundColor");(!g||g==="auto")&&(g=e.get(["axisLine","lineStyle","color"])),r.label={x:h[0],y:h[1],style:kt(s,{text:o,font:u,fill:s.getTextColor(),padding:l,backgroundColor:g}),z2:10}}function W$(r,e,t,a){var n=a.getWidth(),i=a.getHeight();r[0]=Math.min(r[0]+e,n)-e,r[1]=Math.min(r[1]+t,i)-t,r[0]=Math.max(r[0],0),r[1]=Math.max(r[1],0)}function gI(r,e,t,a,n){r=e.scale.parse(r);var i=e.scale.getLabel({value:r},{precision:n.precision}),o=n.formatter;if(o){var s={value:Xg(e,{value:r}),axisDimension:e.dim,axisIndex:e.index,seriesData:[]};C(a,function(l){var u=t.getSeriesByIndex(l.seriesIndex),f=l.dataIndexInside,h=u&&u.getDataParams(f);h&&s.seriesData.push(h)}),$(o)?i=o.replace("{value}",i):K(o)&&(i=o(s))}return i}function By(r,e,t){var a=Fe();return oi(a,a,t.rotation),Gr(a,a,t.position),mr([r.dataToCoord(e),(t.labelOffset||0)+(t.labelDirection||1)*(t.labelMargin||0)],a)}function yI(r,e,t,a,n,i){var o=Te.innerTextLayout(t.rotation,0,t.labelDirection);t.labelMargin=n.get(["label","margin"]),dI(e,a,n,i,{position:By(a.axis,r,t),align:o.textAlign,verticalAlign:o.textVerticalAlign})}function Vy(r,e,t){return t=t||0,{x1:r[t],y1:r[1-t],x2:e[t],y2:e[1-t]}}function mI(r,e,t){return t=t||0,{x:r[t],y:r[1-t],width:e[t],height:e[1-t]}}function xx(r,e,t,a,n,i){return{cx:r,cy:e,r0:t,r:a,startAngle:n,endAngle:i,clockwise:!0}}var $$=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.makeElOption=function(t,a,n,i,o){var s=n.axis,l=s.grid,u=i.get("type"),f=bx(l,s).getOtherAxis(s).getGlobalExtent(),h=s.toGlobalCoord(s.dataToCoord(a,!0));if(u&&u!=="none"){var v=Ny(i),c=U$[u](s,h,f);c.style=v,t.graphicKey=c.type,t.pointer=c}var p=od(l.model,n);yI(a,t,p,n,i,o)},e.prototype.getHandleTransform=function(t,a,n){var i=od(a.axis.grid.model,a,{labelInside:!1});i.labelMargin=n.get(["handle","margin"]);var o=By(a.axis,t,i);return{x:o[0],y:o[1],rotation:i.rotation+(i.labelDirection<0?Math.PI:0)}},e.prototype.updateHandleTransform=function(t,a,n,i){var o=n.axis,s=o.grid,l=o.getGlobalExtent(!0),u=bx(s,o).getOtherAxis(o).getGlobalExtent(),f=o.dim==="x"?0:1,h=[t.x,t.y];h[f]+=a[f],h[f]=Math.min(l[1],h[f]),h[f]=Math.max(l[0],h[f]);var v=(u[1]+u[0])/2,c=[v,v];c[f]=h[f];var p=[{verticalAlign:"middle"},{align:"center"}];return{x:h[0],y:h[1],rotation:t.rotation,cursorPoint:c,tooltipOption:p[f]}},e}(Oy);function bx(r,e){var t={};return t[e.dim+"AxisIndex"]=e.index,r.getCartesian(t)}var U$={line:function(r,e,t){var a=Vy([e,t[0]],[e,t[1]],Tx(r));return{type:"Line",subPixelOptimize:!0,shape:a}},shadow:function(r,e,t){var a=Math.max(1,r.getBandWidth()),n=t[1]-t[0];return{type:"Rect",shape:mI([e-a/2,t[0]],[a,n],Tx(r))}}};function Tx(r){return r.dim==="x"?0:1}const Y$=$$;var Z$=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="axisPointer",e.defaultOption={show:"auto",z:50,type:"line",snap:!1,triggerTooltip:!0,triggerEmphasis:!0,value:null,status:null,link:[],animation:null,animationDurationUpdate:200,lineStyle:{color:"#B9BEC9",width:1,type:"dashed"},shadowStyle:{color:"rgba(210,219,238,0.2)"},label:{show:!0,formatter:null,precision:"auto",margin:3,color:"#fff",padding:[5,7,5,7],backgroundColor:"auto",borderColor:null,borderWidth:0,borderRadius:3},handle:{show:!1,icon:"M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4h1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7v-1.2h6.6z M13.3,22H6.7v-1.2h6.6z M13.3,19.6H6.7v-1.2h6.6z",size:45,margin:50,color:"#333",shadowBlur:3,shadowColor:"#aaa",shadowOffsetX:0,shadowOffsetY:2,throttle:40}},e}(Tt);const X$=Z$;var jr=bt(),q$=C;function _I(r,e,t){if(!mt.node){var a=e.getZr();jr(a).records||(jr(a).records={}),K$(a,e);var n=jr(a).records[r]||(jr(a).records[r]={});n.handler=t}}function K$(r,e){if(jr(r).initialized)return;jr(r).initialized=!0,t("click",ot(Ax,"click")),t("mousemove",ot(Ax,"mousemove")),t("globalout",J$);function t(a,n){r.on(a,function(i){var o=j$(e);q$(jr(r).records,function(s){s&&n(s,i,o.dispatchAction)}),Q$(o.pendings,e)})}}function Q$(r,e){var t=r.showTip.length,a=r.hideTip.length,n;t?n=r.showTip[t-1]:a&&(n=r.hideTip[a-1]),n&&(n.dispatchAction=null,e.dispatchAction(n))}function J$(r,e,t){r.handler("leave",null,t)}function Ax(r,e,t,a){e.handler(r,t,a)}function j$(r){var e={showTip:[],hideTip:[]},t=function(a){var n=e[a.type];n?n.push(a):(a.dispatchAction=t,r.dispatchAction(a))};return{dispatchAction:t,pendings:e}}function Ad(r,e){if(!mt.node){var t=e.getZr(),a=(jr(t).records||{})[r];a&&(jr(t).records[r]=null)}}var t6=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){var i=a.getComponent("tooltip"),o=t.get("triggerOn")||i&&i.get("triggerOn")||"mousemove|click";_I("axisPointer",n,function(s,l,u){o!=="none"&&(s==="leave"||o.indexOf(s)>=0)&&u({type:"updateAxisPointer",currTrigger:s,x:l&&l.offsetX,y:l&&l.offsetY})})},e.prototype.remove=function(t,a){Ad("axisPointer",a)},e.prototype.dispose=function(t,a){Ad("axisPointer",a)},e.type="axisPointer",e}(Ht);const e6=t6;function SI(r,e){var t=[],a=r.seriesIndex,n;if(a==null||!(n=e.getSeriesByIndex(a)))return{point:[]};var i=n.getData(),o=jn(i,r);if(o==null||o<0||z(o))return{point:[]};var s=i.getItemGraphicEl(o),l=n.coordinateSystem;if(n.getTooltipPosition)t=n.getTooltipPosition(o)||[];else if(l&&l.dataToPoint)if(r.isStacked){var u=l.getBaseAxis(),f=l.getOtherAxis(u),h=f.dim,v=u.dim,c=h==="x"||h==="radius"?1:0,p=i.mapDimension(v),d=[];d[c]=i.get(p,o),d[1-c]=i.get(i.getCalculationInfo("stackResultDimension"),o),t=l.dataToPoint(d)||[]}else t=l.dataToPoint(i.getValues(G(l.dimensions,function(y){return i.mapDimension(y)}),o))||[];else if(s){var g=s.getBoundingRect().clone();g.applyTransform(s.transform),t=[g.x+g.width/2,g.y+g.height/2]}return{point:t,el:s}}var Cx=bt();function r6(r,e,t){var a=r.currTrigger,n=[r.x,r.y],i=r,o=r.dispatchAction||U(t.dispatchAction,t),s=e.getComponent("axisPointer").coordSysAxesInfo;if(s){Uu(n)&&(n=SI({seriesIndex:i.seriesIndex,dataIndex:i.dataIndex},e).point);var l=Uu(n),u=i.axesInfo,f=s.axesInfo,h=a==="leave"||Uu(n),v={},c={},p={list:[],map:{}},d={showPointer:ot(n6,c),showTooltip:ot(i6,p)};C(s.coordSysMap,function(y,m){var _=l||y.containPoint(n);C(s.coordSysAxesInfo[m],function(S,w){var x=S.axis,b=u6(u,S);if(!h&&_&&(!u||b)){var T=b&&b.value;T==null&&!l&&(T=x.pointToData(n)),T!=null&&Dx(S,T,d,!1,v)}})});var g={};return C(f,function(y,m){var _=y.linkGroup;_&&!c[m]&&C(_.axesInfo,function(S,w){var x=c[w];if(S!==y&&x){var b=x.value;_.mapper&&(b=y.axis.scale.parse(_.mapper(b,Mx(S),Mx(y)))),g[y.key]=b}})}),C(g,function(y,m){Dx(f[m],y,d,!0,v)}),o6(c,f,v),s6(p,n,r,o),l6(f,o,t),v}}function Dx(r,e,t,a,n){var i=r.axis;if(!(i.scale.isBlank()||!i.containData(e))){if(!r.involveSeries){t.showPointer(r,e);return}var o=a6(e,r),s=o.payloadBatch,l=o.snapToValue;s[0]&&n.seriesIndex==null&&V(n,s[0]),!a&&r.snap&&i.containData(l)&&l!=null&&(e=l),t.showPointer(r,e,s),t.showTooltip(r,o,l)}}function a6(r,e){var t=e.axis,a=t.dim,n=r,i=[],o=Number.MAX_VALUE,s=-1;return C(e.seriesModels,function(l,u){var f=l.getData().mapDimensionsAll(a),h,v;if(l.getAxisTooltipData){var c=l.getAxisTooltipData(f,r,t);v=c.dataIndices,h=c.nestestValue}else{if(v=l.getData().indicesOfNearest(f[0],r,t.type==="category"?.5:null),!v.length)return;h=l.getData().get(f[0],v[0])}if(!(h==null||!isFinite(h))){var p=r-h,d=Math.abs(p);d<=o&&((d<o||p>=0&&s<0)&&(o=d,s=p,n=h,i.length=0),C(v,function(g){i.push({seriesIndex:l.seriesIndex,dataIndexInside:g,dataIndex:l.getData().getRawIndex(g)})}))}}),{payloadBatch:i,snapToValue:n}}function n6(r,e,t,a){r[e.key]={value:t,payloadBatch:a}}function i6(r,e,t,a){var n=t.payloadBatch,i=e.axis,o=i.model,s=e.axisPointerModel;if(!(!e.triggerTooltip||!n.length)){var l=e.coordSys.model,u=qs(l),f=r.map[u];f||(f=r.map[u]={coordSysId:l.id,coordSysIndex:l.componentIndex,coordSysType:l.type,coordSysMainType:l.mainType,dataByAxis:[]},r.list.push(f)),f.dataByAxis.push({axisDim:i.dim,axisIndex:o.componentIndex,axisType:o.type,axisId:o.id,value:a,valueLabelOpt:{precision:s.get(["label","precision"]),formatter:s.get(["label","formatter"])},seriesDataIndices:n.slice()})}}function o6(r,e,t){var a=t.axesInfo=[];C(e,function(n,i){var o=n.axisPointerModel.option,s=r[i];s?(!n.useHandle&&(o.status="show"),o.value=s.value,o.seriesDataIndices=(s.payloadBatch||[]).slice()):!n.useHandle&&(o.status="hide"),o.status==="show"&&a.push({axisDim:n.axis.dim,axisIndex:n.axis.model.componentIndex,value:o.value})})}function s6(r,e,t,a){if(Uu(e)||!r.list.length){a({type:"hideTip"});return}var n=((r.list[0].dataByAxis[0]||{}).seriesDataIndices||[])[0]||{};a({type:"showTip",escapeConnect:!0,x:e[0],y:e[1],tooltipOption:t.tooltipOption,position:t.position,dataIndexInside:n.dataIndexInside,dataIndex:n.dataIndex,seriesIndex:n.seriesIndex,dataByCoordSys:r.list})}function l6(r,e,t){var a=t.getZr(),n="axisPointerLastHighlights",i=Cx(a)[n]||{},o=Cx(a)[n]={};C(r,function(u,f){var h=u.axisPointerModel.option;h.status==="show"&&u.triggerEmphasis&&C(h.seriesDataIndices,function(v){var c=v.seriesIndex+" | "+v.dataIndex;o[c]=v})});var s=[],l=[];C(i,function(u,f){!o[f]&&l.push(u)}),C(o,function(u,f){!i[f]&&s.push(u)}),l.length&&t.dispatchAction({type:"downplay",escapeConnect:!0,notBlur:!0,batch:l}),s.length&&t.dispatchAction({type:"highlight",escapeConnect:!0,notBlur:!0,batch:s})}function u6(r,e){for(var t=0;t<(r||[]).length;t++){var a=r[t];if(e.axis.dim===a.axisDim&&e.axis.model.componentIndex===a.axisIndex)return a}}function Mx(r){var e=r.axis.model,t={},a=t.axisDim=r.axis.dim;return t.axisIndex=t[a+"AxisIndex"]=e.componentIndex,t.axisName=t[a+"AxisName"]=e.name,t.axisId=t[a+"AxisId"]=e.id,t}function Uu(r){return!r||r[0]==null||isNaN(r[0])||r[1]==null||isNaN(r[1])}function bl(r){vi.registerAxisPointerClass("CartesianAxisPointer",Y$),r.registerComponentModel(X$),r.registerComponentView(e6),r.registerPreprocessor(function(e){if(e){(!e.axisPointer||e.axisPointer.length===0)&&(e.axisPointer={});var t=e.axisPointer.link;t&&!z(t)&&(e.axisPointer.link=[t])}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,function(e,t){e.getComponent("axisPointer").coordSysAxesInfo=o5(e,t)}),r.registerAction({type:"updateAxisPointer",event:"updateAxisPointer",update:":updateAxisPointer"},r6)}function f6(r){gt(YD),gt(bl)}var h6=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.makeElOption=function(t,a,n,i,o){var s=n.axis;s.dim==="angle"&&(this.animationThreshold=Math.PI/18);var l=s.polar,u=l.getOtherAxis(s),f=u.getExtent(),h=s.dataToCoord(a),v=i.get("type");if(v&&v!=="none"){var c=Ny(i),p=c6[v](s,l,h,f);p.style=c,t.graphicKey=p.type,t.pointer=p}var d=i.get(["label","margin"]),g=v6(a,n,i,l,d);dI(t,n,i,o,g)},e}(Oy);function v6(r,e,t,a,n){var i=e.axis,o=i.dataToCoord(r),s=a.getAngleAxis().getExtent()[0];s=s/180*Math.PI;var l=a.getRadiusAxis().getExtent(),u,f,h;if(i.dim==="radius"){var v=Fe();oi(v,v,s),Gr(v,v,[a.cx,a.cy]),u=mr([o,-n],v);var c=e.getModel("axisLabel").get("rotate")||0,p=Te.innerTextLayout(s,c*Math.PI/180,-1);f=p.textAlign,h=p.textVerticalAlign}else{var d=l[1];u=a.coordToPoint([d+n,o]);var g=a.cx,y=a.cy;f=Math.abs(u[0]-g)/d<.3?"center":u[0]>g?"left":"right",h=Math.abs(u[1]-y)/d<.3?"middle":u[1]>y?"top":"bottom"}return{position:u,align:f,verticalAlign:h}}var c6={line:function(r,e,t,a){return r.dim==="angle"?{type:"Line",shape:Vy(e.coordToPoint([a[0],t]),e.coordToPoint([a[1],t]))}:{type:"Circle",shape:{cx:e.cx,cy:e.cy,r:t}}},shadow:function(r,e,t,a){var n=Math.max(1,r.getBandWidth()),i=Math.PI/180;return r.dim==="angle"?{type:"Sector",shape:xx(e.cx,e.cy,a[0],a[1],(-t-n/2)*i,(-t+n/2)*i)}:{type:"Sector",shape:xx(e.cx,e.cy,t-n/2,t+n/2,0,Math.PI*2)}}};const p6=h6;var d6=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.findAxisModel=function(t){var a,n=this.ecModel;return n.eachComponent(t,function(i){i.getCoordSysModel()===this&&(a=i)},this),a},e.type="polar",e.dependencies=["radiusAxis","angleAxis"],e.defaultOption={z:0,center:["50%","50%"],radius:"80%"},e}(Tt);const g6=d6;var zy=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.getCoordSysModel=function(){return this.getReferringComponents("polar",Xt).models[0]},e.type="polarAxis",e}(Tt);Kt(zy,pl);var y6=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="angleAxis",e}(zy),m6=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="radiusAxis",e}(zy),Gy=function(r){k(e,r);function e(t,a){return r.call(this,"radius",t,a)||this}return e.prototype.pointToData=function(t,a){return this.polar.pointToData(t,a)[this.dim==="radius"?0:1]},e}(wr);Gy.prototype.dataToRadius=wr.prototype.dataToCoord;Gy.prototype.radiusToData=wr.prototype.coordToData;var _6=bt(),Fy=function(r){k(e,r);function e(t,a){return r.call(this,"angle",t,a||[0,360])||this}return e.prototype.pointToData=function(t,a){return this.polar.pointToData(t,a)[this.dim==="radius"?0:1]},e.prototype.calculateCategoryInterval=function(){var t=this,a=t.getLabelModel(),n=t.scale,i=n.getExtent(),o=n.count();if(i[1]-i[0]<1)return 0;var s=i[0],l=t.dataToCoord(s+1)-t.dataToCoord(s),u=Math.abs(l),f=il(s==null?"":s+"",a.getFont(),"center","top"),h=Math.max(f.height,7),v=h/u;isNaN(v)&&(v=1/0);var c=Math.max(0,Math.floor(v)),p=_6(t.model),d=p.lastAutoInterval,g=p.lastTickCount;return d!=null&&g!=null&&Math.abs(d-c)<=1&&Math.abs(g-o)<=1&&d>c?c=d:(p.lastTickCount=o,p.lastAutoInterval=c),c},e}(wr);Fy.prototype.dataToAngle=wr.prototype.dataToCoord;Fy.prototype.angleToData=wr.prototype.coordToData;var xI=["radius","angle"],S6=function(){function r(e){this.dimensions=xI,this.type="polar",this.cx=0,this.cy=0,this._radiusAxis=new Gy,this._angleAxis=new Fy,this.axisPointerEnabled=!0,this.name=e||"",this._radiusAxis.polar=this._angleAxis.polar=this}return r.prototype.containPoint=function(e){var t=this.pointToCoord(e);return this._radiusAxis.contain(t[0])&&this._angleAxis.contain(t[1])},r.prototype.containData=function(e){return this._radiusAxis.containData(e[0])&&this._angleAxis.containData(e[1])},r.prototype.getAxis=function(e){var t="_"+e+"Axis";return this[t]},r.prototype.getAxes=function(){return[this._radiusAxis,this._angleAxis]},r.prototype.getAxesByScale=function(e){var t=[],a=this._angleAxis,n=this._radiusAxis;return a.scale.type===e&&t.push(a),n.scale.type===e&&t.push(n),t},r.prototype.getAngleAxis=function(){return this._angleAxis},r.prototype.getRadiusAxis=function(){return this._radiusAxis},r.prototype.getOtherAxis=function(e){var t=this._angleAxis;return e===t?this._radiusAxis:t},r.prototype.getBaseAxis=function(){return this.getAxesByScale("ordinal")[0]||this.getAxesByScale("time")[0]||this.getAngleAxis()},r.prototype.getTooltipAxes=function(e){var t=e!=null&&e!=="auto"?this.getAxis(e):this.getBaseAxis();return{baseAxes:[t],otherAxes:[this.getOtherAxis(t)]}},r.prototype.dataToPoint=function(e,t){return this.coordToPoint([this._radiusAxis.dataToRadius(e[0],t),this._angleAxis.dataToAngle(e[1],t)])},r.prototype.pointToData=function(e,t){var a=this.pointToCoord(e);return[this._radiusAxis.radiusToData(a[0],t),this._angleAxis.angleToData(a[1],t)]},r.prototype.pointToCoord=function(e){var t=e[0]-this.cx,a=e[1]-this.cy,n=this.getAngleAxis(),i=n.getExtent(),o=Math.min(i[0],i[1]),s=Math.max(i[0],i[1]);n.inverse?o=s-360:s=o+360;var l=Math.sqrt(t*t+a*a);t/=l,a/=l;for(var u=Math.atan2(-a,t)/Math.PI*180,f=u<o?1:-1;u<o||u>s;)u+=f*360;return[l,u]},r.prototype.coordToPoint=function(e){var t=e[0],a=e[1]/180*Math.PI,n=Math.cos(a)*t+this.cx,i=-Math.sin(a)*t+this.cy;return[n,i]},r.prototype.getArea=function(){var e=this.getAngleAxis(),t=this.getRadiusAxis(),a=t.getExtent().slice();a[0]>a[1]&&a.reverse();var n=e.getExtent(),i=Math.PI/180;return{cx:this.cx,cy:this.cy,r0:a[0],r:a[1],startAngle:-n[0]*i,endAngle:-n[1]*i,clockwise:e.inverse,contain:function(o,s){var l=o-this.cx,u=s-this.cy,f=l*l+u*u-1e-4,h=this.r,v=this.r0;return f<=h*h&&f>=v*v}}},r.prototype.convertToPixel=function(e,t,a){var n=Ix(t);return n===this?this.dataToPoint(a):null},r.prototype.convertFromPixel=function(e,t,a){var n=Ix(t);return n===this?this.pointToData(a):null},r}();function Ix(r){var e=r.seriesModel,t=r.polarModel;return t&&t.coordinateSystem||e&&e.coordinateSystem}const x6=S6;function w6(r,e,t){var a=e.get("center"),n=t.getWidth(),i=t.getHeight();r.cx=W(a[0],n),r.cy=W(a[1],i);var o=r.getRadiusAxis(),s=Math.min(n,i)/2,l=e.get("radius");l==null?l=[0,"100%"]:z(l)||(l=[0,l]);var u=[W(l[0],s),W(l[1],s)];o.inverse?o.setExtent(u[1],u[0]):o.setExtent(u[0],u[1])}function b6(r,e){var t=this,a=t.getAngleAxis(),n=t.getRadiusAxis();if(a.scale.setExtent(1/0,-1/0),n.scale.setExtent(1/0,-1/0),r.eachSeries(function(s){if(s.coordinateSystem===t){var l=s.getData();C(Sf(l,"radius"),function(u){n.scale.unionExtentFromData(l,u)}),C(Sf(l,"angle"),function(u){a.scale.unionExtentFromData(l,u)})}}),to(a.scale,a.model),to(n.scale,n.model),a.type==="category"&&!a.onBand){var i=a.getExtent(),o=360/a.scale.count();a.inverse?i[1]+=o:i[1]-=o,a.setExtent(i[0],i[1])}}function T6(r){return r.mainType==="angleAxis"}function Lx(r,e){var t;if(r.type=e.get("type"),r.scale=_h(e),r.onBand=e.get("boundaryGap")&&r.type==="category",r.inverse=e.get("inverse"),T6(e)){r.inverse=r.inverse!==e.get("clockwise");var a=e.get("startAngle"),n=(t=e.get("endAngle"))!==null&&t!==void 0?t:a+(r.inverse?-360:360);r.setExtent(a,n)}e.axis=r,r.model=e}var A6={dimensions:xI,create:function(r,e){var t=[];return r.eachComponent("polar",function(a,n){var i=new x6(n+"");i.update=b6;var o=i.getRadiusAxis(),s=i.getAngleAxis(),l=a.findAxisModel("radiusAxis"),u=a.findAxisModel("angleAxis");Lx(o,l),Lx(s,u),w6(i,a,e),t.push(i),a.coordinateSystem=i,i.model=a}),r.eachSeries(function(a){if(a.get("coordinateSystem")==="polar"){var n=a.getReferringComponents("polar",Xt).models[0];a.coordinateSystem=n.coordinateSystem}}),t}};const C6=A6;var D6=["axisLine","axisLabel","axisTick","minorTick","splitLine","minorSplitLine","splitArea"];function _u(r,e,t){e[1]>e[0]&&(e=e.slice().reverse());var a=r.coordToPoint([e[0],t]),n=r.coordToPoint([e[1],t]);return{x1:a[0],y1:a[1],x2:n[0],y2:n[1]}}function Su(r){var e=r.getRadiusAxis();return e.inverse?0:1}function Px(r){var e=r[0],t=r[r.length-1];e&&t&&Math.abs(Math.abs(e.coord-t.coord)-360)<1e-4&&r.pop()}var M6=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.axisPointerClass="PolarAxisPointer",t}return e.prototype.render=function(t,a){if(this.group.removeAll(),!!t.get("show")){var n=t.axis,i=n.polar,o=i.getRadiusAxis().getExtent(),s=n.getTicksCoords(),l=n.getMinorTicksCoords(),u=G(n.getViewLabels(),function(f){f=rt(f);var h=n.scale,v=h.type==="ordinal"?h.getRawOrdinalNumber(f.tickValue):f.tickValue;return f.coord=n.dataToCoord(v),f});Px(u),Px(s),C(D6,function(f){t.get([f,"show"])&&(!n.scale.isBlank()||f==="axisLine")&&I6[f](this.group,t,i,s,l,o,u)},this)}},e.type="angleAxis",e}(vi),I6={axisLine:function(r,e,t,a,n,i){var o=e.getModel(["axisLine","lineStyle"]),s=t.getAngleAxis(),l=Math.PI/180,u=s.getExtent(),f=Su(t),h=f?0:1,v,c=Math.abs(u[1]-u[0])===360?"Circle":"Arc";i[h]===0?v=new si[c]({shape:{cx:t.cx,cy:t.cy,r:i[f],startAngle:-u[0]*l,endAngle:-u[1]*l,clockwise:s.inverse},style:o.getLineStyle(),z2:1,silent:!0}):v=new eh({shape:{cx:t.cx,cy:t.cy,r:i[f],r0:i[h]},style:o.getLineStyle(),z2:1,silent:!0}),v.style.fill=null,r.add(v)},axisTick:function(r,e,t,a,n,i){var o=e.getModel("axisTick"),s=(o.get("inside")?-1:1)*o.get("length"),l=i[Su(t)],u=G(a,function(f){return new te({shape:_u(t,[l,l+s],f.coord)})});r.add(er(u,{style:j(o.getModel("lineStyle").getLineStyle(),{stroke:e.get(["axisLine","lineStyle","color"])})}))},minorTick:function(r,e,t,a,n,i){if(n.length){for(var o=e.getModel("axisTick"),s=e.getModel("minorTick"),l=(o.get("inside")?-1:1)*s.get("length"),u=i[Su(t)],f=[],h=0;h<n.length;h++)for(var v=0;v<n[h].length;v++)f.push(new te({shape:_u(t,[u,u+l],n[h][v].coord)}));r.add(er(f,{style:j(s.getModel("lineStyle").getLineStyle(),j(o.getLineStyle(),{stroke:e.get(["axisLine","lineStyle","color"])}))}))}},axisLabel:function(r,e,t,a,n,i,o){var s=e.getCategories(!0),l=e.getModel("axisLabel"),u=l.get("margin"),f=e.get("triggerEvent");C(o,function(h,v){var c=l,p=h.tickValue,d=i[Su(t)],g=t.coordToPoint([d+u,h.coord]),y=t.cx,m=t.cy,_=Math.abs(g[0]-y)/d<.3?"center":g[0]>y?"left":"right",S=Math.abs(g[1]-m)/d<.3?"middle":g[1]>m?"top":"bottom";if(s&&s[p]){var w=s[p];tt(w)&&w.textStyle&&(c=new Ot(w.textStyle,l,l.ecModel))}var x=new At({silent:Te.isLabelSilent(e),style:kt(c,{x:g[0],y:g[1],fill:c.getTextColor()||e.get(["axisLine","lineStyle","color"]),text:h.formattedLabel,align:_,verticalAlign:S})});if(r.add(x),f){var b=Te.makeAxisEventDataBase(e);b.targetType="axisLabel",b.value=h.rawLabel,nt(x).eventData=b}},this)},splitLine:function(r,e,t,a,n,i){var o=e.getModel("splitLine"),s=o.getModel("lineStyle"),l=s.get("color"),u=0;l=l instanceof Array?l:[l];for(var f=[],h=0;h<a.length;h++){var v=u++%l.length;f[v]=f[v]||[],f[v].push(new te({shape:_u(t,i,a[h].coord)}))}for(var h=0;h<f.length;h++)r.add(er(f[h],{style:j({stroke:l[h%l.length]},s.getLineStyle()),silent:!0,z:e.get("z")}))},minorSplitLine:function(r,e,t,a,n,i){if(n.length){for(var o=e.getModel("minorSplitLine"),s=o.getModel("lineStyle"),l=[],u=0;u<n.length;u++)for(var f=0;f<n[u].length;f++)l.push(new te({shape:_u(t,i,n[u][f].coord)}));r.add(er(l,{style:s.getLineStyle(),silent:!0,z:e.get("z")}))}},splitArea:function(r,e,t,a,n,i){if(a.length){var o=e.getModel("splitArea"),s=o.getModel("areaStyle"),l=s.get("color"),u=0;l=l instanceof Array?l:[l];for(var f=[],h=Math.PI/180,v=-a[0].coord*h,c=Math.min(i[0],i[1]),p=Math.max(i[0],i[1]),d=e.get("clockwise"),g=1,y=a.length;g<=y;g++){var m=g===y?a[0].coord:a[g].coord,_=u++%l.length;f[_]=f[_]||[],f[_].push(new Be({shape:{cx:t.cx,cy:t.cy,r0:c,r:p,startAngle:v,endAngle:-m*h,clockwise:d},silent:!0})),v=-m*h}for(var g=0;g<f.length;g++)r.add(er(f[g],{style:j({fill:l[g%l.length]},s.getAreaStyle()),silent:!0}))}}};const L6=M6;var P6=["axisLine","axisTickLabel","axisName"],R6=["splitLine","splitArea","minorSplitLine"],E6=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.axisPointerClass="PolarAxisPointer",t}return e.prototype.render=function(t,a){if(this.group.removeAll(),!!t.get("show")){var n=this._axisGroup,i=this._axisGroup=new at;this.group.add(i);var o=t.axis,s=o.polar,l=s.getAngleAxis(),u=o.getTicksCoords(),f=o.getMinorTicksCoords(),h=l.getExtent()[0],v=o.getExtent(),c=O6(s,t,h),p=new Te(t,c);C(P6,p.add,p),i.add(p.getGroup()),ll(n,i,t),C(R6,function(d){t.get([d,"show"])&&!o.scale.isBlank()&&k6[d](this.group,t,s,h,v,u,f)},this)}},e.type="radiusAxis",e}(vi),k6={splitLine:function(r,e,t,a,n,i){var o=e.getModel("splitLine"),s=o.getModel("lineStyle"),l=s.get("color"),u=0,f=t.getAngleAxis(),h=Math.PI/180,v=f.getExtent(),c=Math.abs(v[1]-v[0])===360?"Circle":"Arc";l=l instanceof Array?l:[l];for(var p=[],d=0;d<i.length;d++){var g=u++%l.length;p[g]=p[g]||[],p[g].push(new si[c]({shape:{cx:t.cx,cy:t.cy,r:Math.max(i[d].coord,0),startAngle:-v[0]*h,endAngle:-v[1]*h,clockwise:f.inverse}}))}for(var d=0;d<p.length;d++)r.add(er(p[d],{style:j({stroke:l[d%l.length],fill:null},s.getLineStyle()),silent:!0}))},minorSplitLine:function(r,e,t,a,n,i,o){if(o.length){for(var s=e.getModel("minorSplitLine"),l=s.getModel("lineStyle"),u=[],f=0;f<o.length;f++)for(var h=0;h<o[f].length;h++)u.push(new Qa({shape:{cx:t.cx,cy:t.cy,r:o[f][h].coord}}));r.add(er(u,{style:j({fill:null},l.getLineStyle()),silent:!0}))}},splitArea:function(r,e,t,a,n,i){if(i.length){var o=e.getModel("splitArea"),s=o.getModel("areaStyle"),l=s.get("color"),u=0;l=l instanceof Array?l:[l];for(var f=[],h=i[0].coord,v=1;v<i.length;v++){var c=u++%l.length;f[c]=f[c]||[],f[c].push(new Be({shape:{cx:t.cx,cy:t.cy,r0:h,r:i[v].coord,startAngle:0,endAngle:Math.PI*2},silent:!0})),h=i[v].coord}for(var v=0;v<f.length;v++)r.add(er(f[v],{style:j({fill:l[v%l.length]},s.getAreaStyle()),silent:!0}))}}};function O6(r,e,t){return{position:[r.cx,r.cy],rotation:t/180*Math.PI,labelDirection:-1,tickDirection:-1,nameDirection:1,labelRotate:e.getModel("axisLabel").get("rotate"),z2:1}}const N6=E6;function wI(r){return r.get("stack")||"__ec_stack_"+r.seriesIndex}function bI(r,e){return e.dim+r.model.componentIndex}function B6(r,e,t){var a={},n=V6(Lt(e.getSeriesByType(r),function(i){return!e.isSeriesFiltered(i)&&i.coordinateSystem&&i.coordinateSystem.type==="polar"}));e.eachSeriesByType(r,function(i){if(i.coordinateSystem.type==="polar"){var o=i.getData(),s=i.coordinateSystem,l=s.getBaseAxis(),u=bI(s,l),f=wI(i),h=n[u][f],v=h.offset,c=h.width,p=s.getOtherAxis(l),d=i.coordinateSystem.cx,g=i.coordinateSystem.cy,y=i.get("barMinHeight")||0,m=i.get("barMinAngle")||0;a[f]=a[f]||[];for(var _=o.mapDimension(p.dim),S=o.mapDimension(l.dim),w=Ya(o,_),x=l.dim!=="radius"||!i.get("roundCap",!0),b=p.dataToCoord(0),T=0,A=o.count();T<A;T++){var D=o.get(_,T),M=o.get(S,T),I=D>=0?"p":"n",L=b;w&&(a[f][M]||(a[f][M]={p:b,n:b}),L=a[f][M][I]);var P=void 0,R=void 0,E=void 0,N=void 0;if(p.dim==="radius"){var O=p.dataToCoord(D)-b,B=l.dataToCoord(M);Math.abs(O)<y&&(O=(O<0?-1:1)*y),P=L,R=L+O,E=B-v,N=E-c,w&&(a[f][M][I]=R)}else{var F=p.dataToCoord(D,x)-b,H=l.dataToCoord(M);Math.abs(F)<m&&(F=(F<0?-1:1)*m),P=H+v,R=P+c,E=L,N=L+F,w&&(a[f][M][I]=N)}o.setItemLayout(T,{cx:d,cy:g,r0:P,r:R,startAngle:-E*Math.PI/180,endAngle:-N*Math.PI/180,clockwise:E>=N})}}})}function V6(r){var e={};C(r,function(a,n){var i=a.getData(),o=a.coordinateSystem,s=o.getBaseAxis(),l=bI(o,s),u=s.getExtent(),f=s.type==="category"?s.getBandWidth():Math.abs(u[1]-u[0])/i.count(),h=e[l]||{bandWidth:f,remainedWidth:f,autoWidthCount:0,categoryGap:"20%",gap:"30%",stacks:{}},v=h.stacks;e[l]=h;var c=wI(a);v[c]||h.autoWidthCount++,v[c]=v[c]||{width:0,maxWidth:0};var p=W(a.get("barWidth"),f),d=W(a.get("barMaxWidth"),f),g=a.get("barGap"),y=a.get("barCategoryGap");p&&!v[c].width&&(p=Math.min(h.remainedWidth,p),v[c].width=p,h.remainedWidth-=p),d&&(v[c].maxWidth=d),g!=null&&(h.gap=g),y!=null&&(h.categoryGap=y)});var t={};return C(e,function(a,n){t[n]={};var i=a.stacks,o=a.bandWidth,s=W(a.categoryGap,o),l=W(a.gap,1),u=a.remainedWidth,f=a.autoWidthCount,h=(u-s)/(f+(f-1)*l);h=Math.max(h,0),C(i,function(d,g){var y=d.maxWidth;y&&y<h&&(y=Math.min(y,u),d.width&&(y=Math.min(y,d.width)),u-=y,d.width=y,f--)}),h=(u-s)/(f+(f-1)*l),h=Math.max(h,0);var v=0,c;C(i,function(d,g){d.width||(d.width=h),c=d,v+=d.width*(1+l)}),c&&(v-=c.width*l);var p=-v/2;C(i,function(d,g){t[n][g]=t[n][g]||{offset:p,width:d.width},p+=d.width*(1+l)})}),t}var z6={startAngle:90,clockwise:!0,splitNumber:12,axisLabel:{rotate:0}},G6={splitNumber:5},F6=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="polar",e}(Ht);function H6(r){gt(bl),vi.registerAxisPointerClass("PolarAxisPointer",p6),r.registerCoordinateSystem("polar",C6),r.registerComponentModel(g6),r.registerComponentView(F6),ro(r,"angle",y6,z6),ro(r,"radius",m6,G6),r.registerComponentView(L6),r.registerComponentView(N6),r.registerLayout(ot(B6,"bar"))}function Cd(r,e){e=e||{};var t=r.coordinateSystem,a=r.axis,n={},i=a.position,o=a.orient,s=t.getRect(),l=[s.x,s.x+s.width,s.y,s.y+s.height],u={horizontal:{top:l[2],bottom:l[3]},vertical:{left:l[0],right:l[1]}};n.position=[o==="vertical"?u.vertical[i]:l[0],o==="horizontal"?u.horizontal[i]:l[3]];var f={horizontal:0,vertical:1};n.rotation=Math.PI/2*f[o];var h={top:-1,bottom:1,right:1,left:-1};n.labelDirection=n.tickDirection=n.nameDirection=h[i],r.get(["axisTick","inside"])&&(n.tickDirection=-n.tickDirection),ie(e.labelInside,r.get(["axisLabel","inside"]))&&(n.labelDirection=-n.labelDirection);var v=e.rotate;return v==null&&(v=r.get(["axisLabel","rotate"])),n.labelRotation=i==="top"?-v:v,n.z2=1,n}var W6=["axisLine","axisTickLabel","axisName"],$6=["splitArea","splitLine"],U6=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.axisPointerClass="SingleAxisPointer",t}return e.prototype.render=function(t,a,n,i){var o=this.group;o.removeAll();var s=this._axisGroup;this._axisGroup=new at;var l=Cd(t),u=new Te(t,l);C(W6,u.add,u),o.add(this._axisGroup),o.add(u.getGroup()),C($6,function(f){t.get([f,"show"])&&Y6[f](this,this.group,this._axisGroup,t)},this),ll(s,this._axisGroup,t),r.prototype.render.call(this,t,a,n,i)},e.prototype.remove=function(){WD(this)},e.type="singleAxis",e}(vi),Y6={splitLine:function(r,e,t,a){var n=a.axis;if(!n.scale.isBlank()){var i=a.getModel("splitLine"),o=i.getModel("lineStyle"),s=o.get("color");s=s instanceof Array?s:[s];for(var l=o.get("width"),u=a.coordinateSystem.getRect(),f=n.isHorizontal(),h=[],v=0,c=n.getTicksCoords({tickModel:i}),p=[],d=[],g=0;g<c.length;++g){var y=n.toGlobalCoord(c[g].coord);f?(p[0]=y,p[1]=u.y,d[0]=y,d[1]=u.y+u.height):(p[0]=u.x,p[1]=y,d[0]=u.x+u.width,d[1]=y);var m=new te({shape:{x1:p[0],y1:p[1],x2:d[0],y2:d[1]},silent:!0});Qi(m.shape,l);var _=v++%s.length;h[_]=h[_]||[],h[_].push(m)}for(var S=o.getLineStyle(["color"]),g=0;g<h.length;++g)e.add(er(h[g],{style:j({stroke:s[g%s.length]},S),silent:!0}))}},splitArea:function(r,e,t,a){HD(r,t,a,a)}};const Z6=U6;var TI=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.getCoordSysModel=function(){return this},e.type="singleAxis",e.layoutMode="box",e.defaultOption={left:"5%",top:"5%",right:"5%",bottom:"5%",type:"value",position:"bottom",orient:"horizontal",axisLine:{show:!0,lineStyle:{width:1,type:"solid"}},tooltip:{show:!0},axisTick:{show:!0,length:6,lineStyle:{width:1}},axisLabel:{show:!0,interval:"auto"},splitLine:{show:!0,lineStyle:{type:"dashed",opacity:.2}}},e}(Tt);Kt(TI,pl.prototype);const kc=TI;var X6=function(r){k(e,r);function e(t,a,n,i,o){var s=r.call(this,t,a,n)||this;return s.type=i||"value",s.position=o||"bottom",s}return e.prototype.isHorizontal=function(){var t=this.position;return t==="top"||t==="bottom"},e.prototype.pointToData=function(t,a){return this.coordinateSystem.pointToData(t)[0]},e}(wr);const q6=X6;var AI=["single"],K6=function(){function r(e,t,a){this.type="single",this.dimension="single",this.dimensions=AI,this.axisPointerEnabled=!0,this.model=e,this._init(e,t,a)}return r.prototype._init=function(e,t,a){var n=this.dimension,i=new q6(n,_h(e),[0,0],e.get("type"),e.get("position")),o=i.type==="category";i.onBand=o&&e.get("boundaryGap"),i.inverse=e.get("inverse"),i.orient=e.get("orient"),e.axis=i,i.model=e,i.coordinateSystem=this,this._axis=i},r.prototype.update=function(e,t){e.eachSeries(function(a){if(a.coordinateSystem===this){var n=a.getData();C(n.mapDimensionsAll(this.dimension),function(i){this._axis.scale.unionExtentFromData(n,i)},this),to(this._axis.scale,this._axis.model)}},this)},r.prototype.resize=function(e,t){this._rect=Jt({left:e.get("left"),top:e.get("top"),right:e.get("right"),bottom:e.get("bottom"),width:e.get("width"),height:e.get("height")},{width:t.getWidth(),height:t.getHeight()}),this._adjustAxis()},r.prototype.getRect=function(){return this._rect},r.prototype._adjustAxis=function(){var e=this._rect,t=this._axis,a=t.isHorizontal(),n=a?[0,e.width]:[0,e.height],i=t.inverse?1:0;t.setExtent(n[i],n[1-i]),this._updateAxisTransform(t,a?e.x:e.y)},r.prototype._updateAxisTransform=function(e,t){var a=e.getExtent(),n=a[0]+a[1],i=e.isHorizontal();e.toGlobalCoord=i?function(o){return o+t}:function(o){return n-o+t},e.toLocalCoord=i?function(o){return o-t}:function(o){return n-o+t}},r.prototype.getAxis=function(){return this._axis},r.prototype.getBaseAxis=function(){return this._axis},r.prototype.getAxes=function(){return[this._axis]},r.prototype.getTooltipAxes=function(){return{baseAxes:[this.getAxis()],otherAxes:[]}},r.prototype.containPoint=function(e){var t=this.getRect(),a=this.getAxis(),n=a.orient;return n==="horizontal"?a.contain(a.toLocalCoord(e[0]))&&e[1]>=t.y&&e[1]<=t.y+t.height:a.contain(a.toLocalCoord(e[1]))&&e[0]>=t.y&&e[0]<=t.y+t.height},r.prototype.pointToData=function(e){var t=this.getAxis();return[t.coordToData(t.toLocalCoord(e[t.orient==="horizontal"?0:1]))]},r.prototype.dataToPoint=function(e){var t=this.getAxis(),a=this.getRect(),n=[],i=t.orient==="horizontal"?0:1;return e instanceof Array&&(e=e[0]),n[i]=t.toGlobalCoord(t.dataToCoord(+e)),n[1-i]=i===0?a.y+a.height/2:a.x+a.width/2,n},r.prototype.convertToPixel=function(e,t,a){var n=Rx(t);return n===this?this.dataToPoint(a):null},r.prototype.convertFromPixel=function(e,t,a){var n=Rx(t);return n===this?this.pointToData(a):null},r}();function Rx(r){var e=r.seriesModel,t=r.singleAxisModel;return t&&t.coordinateSystem||e&&e.coordinateSystem}function Q6(r,e){var t=[];return r.eachComponent("singleAxis",function(a,n){var i=new K6(a,r,e);i.name="single_"+n,i.resize(a,e),a.coordinateSystem=i,t.push(i)}),r.eachSeries(function(a){if(a.get("coordinateSystem")==="singleAxis"){var n=a.getReferringComponents("singleAxis",Xt).models[0];a.coordinateSystem=n&&n.coordinateSystem}}),t}var J6={create:Q6,dimensions:AI};const j6=J6;var Ex=["x","y"],tU=["width","height"],eU=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.makeElOption=function(t,a,n,i,o){var s=n.axis,l=s.coordinateSystem,u=Oc(l,1-kf(s)),f=l.dataToPoint(a)[0],h=i.get("type");if(h&&h!=="none"){var v=Ny(i),c=rU[h](s,f,u);c.style=v,t.graphicKey=c.type,t.pointer=c}var p=Cd(n);yI(a,t,p,n,i,o)},e.prototype.getHandleTransform=function(t,a,n){var i=Cd(a,{labelInside:!1});i.labelMargin=n.get(["handle","margin"]);var o=By(a.axis,t,i);return{x:o[0],y:o[1],rotation:i.rotation+(i.labelDirection<0?Math.PI:0)}},e.prototype.updateHandleTransform=function(t,a,n,i){var o=n.axis,s=o.coordinateSystem,l=kf(o),u=Oc(s,l),f=[t.x,t.y];f[l]+=a[l],f[l]=Math.min(u[1],f[l]),f[l]=Math.max(u[0],f[l]);var h=Oc(s,1-l),v=(h[1]+h[0])/2,c=[v,v];return c[l]=f[l],{x:f[0],y:f[1],rotation:t.rotation,cursorPoint:c,tooltipOption:{verticalAlign:"middle"}}},e}(Oy),rU={line:function(r,e,t){var a=Vy([e,t[0]],[e,t[1]],kf(r));return{type:"Line",subPixelOptimize:!0,shape:a}},shadow:function(r,e,t){var a=r.getBandWidth(),n=t[1]-t[0];return{type:"Rect",shape:mI([e-a/2,t[0]],[a,n],kf(r))}}};function kf(r){return r.isHorizontal()?0:1}function Oc(r,e){var t=r.getRect();return[t[Ex[e]],t[Ex[e]]+t[tU[e]]]}const aU=eU;var nU=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="single",e}(Ht);function iU(r){gt(bl),vi.registerAxisPointerClass("SingleAxisPointer",aU),r.registerComponentView(nU),r.registerComponentView(Z6),r.registerComponentModel(kc),ro(r,"single",kc,kc.defaultOption),r.registerCoordinateSystem("single",j6)}var oU=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,a,n){var i=mo(t);r.prototype.init.apply(this,arguments),kx(t,i)},e.prototype.mergeOption=function(t){r.prototype.mergeOption.apply(this,arguments),kx(this.option,t)},e.prototype.getCellSize=function(){return this.option.cellSize},e.type="calendar",e.defaultOption={z:2,left:80,top:60,cellSize:20,orient:"horizontal",splitLine:{show:!0,lineStyle:{color:"#000",width:1,type:"solid"}},itemStyle:{color:"#fff",borderWidth:1,borderColor:"#ccc"},dayLabel:{show:!0,firstDay:0,position:"start",margin:"50%",color:"#000"},monthLabel:{show:!0,position:"start",margin:5,align:"center",formatter:null,color:"#000"},yearLabel:{show:!0,position:null,margin:30,formatter:null,color:"#ccc",fontFamily:"sans-serif",fontWeight:"bolder",fontSize:20}},e}(Tt);function kx(r,e){var t=r.cellSize,a;z(t)?a=t:a=r.cellSize=[t,t],a.length===1&&(a[1]=a[0]);var n=G([0,1],function(i){return OE(e,i)&&(a[i]="auto"),a[i]!=null&&a[i]!=="auto"});Ua(r,e,{type:"box",ignoreSize:n})}const sU=oU;var lU=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){var i=this.group;i.removeAll();var o=t.coordinateSystem,s=o.getRangeInfo(),l=o.getOrient(),u=a.getLocaleModel();this._renderDayRect(t,s,i),this._renderLines(t,s,l,i),this._renderYearText(t,s,l,i),this._renderMonthText(t,u,l,i),this._renderWeekText(t,u,s,l,i)},e.prototype._renderDayRect=function(t,a,n){for(var i=t.coordinateSystem,o=t.getModel("itemStyle").getItemStyle(),s=i.getCellWidth(),l=i.getCellHeight(),u=a.start.time;u<=a.end.time;u=i.getNextNDay(u,1).time){var f=i.dataToRect([u],!1).tl,h=new wt({shape:{x:f[0],y:f[1],width:s,height:l},cursor:"default",style:o});n.add(h)}},e.prototype._renderLines=function(t,a,n,i){var o=this,s=t.coordinateSystem,l=t.getModel(["splitLine","lineStyle"]).getLineStyle(),u=t.get(["splitLine","show"]),f=l.lineWidth;this._tlpoints=[],this._blpoints=[],this._firstDayOfMonth=[],this._firstDayPoints=[];for(var h=a.start,v=0;h.time<=a.end.time;v++){p(h.formatedDate),v===0&&(h=s.getDateInfo(a.start.y+"-"+a.start.m));var c=h.date;c.setMonth(c.getMonth()+1),h=s.getDateInfo(c)}p(s.getNextNDay(a.end.time,1).formatedDate);function p(d){o._firstDayOfMonth.push(s.getDateInfo(d)),o._firstDayPoints.push(s.dataToRect([d],!1).tl);var g=o._getLinePointsOfOneWeek(t,d,n);o._tlpoints.push(g[0]),o._blpoints.push(g[g.length-1]),u&&o._drawSplitline(g,l,i)}u&&this._drawSplitline(o._getEdgesPoints(o._tlpoints,f,n),l,i),u&&this._drawSplitline(o._getEdgesPoints(o._blpoints,f,n),l,i)},e.prototype._getEdgesPoints=function(t,a,n){var i=[t[0].slice(),t[t.length-1].slice()],o=n==="horizontal"?0:1;return i[0][o]=i[0][o]-a/2,i[1][o]=i[1][o]+a/2,i},e.prototype._drawSplitline=function(t,a,n){var i=new Me({z2:20,shape:{points:t},style:a});n.add(i)},e.prototype._getLinePointsOfOneWeek=function(t,a,n){for(var i=t.coordinateSystem,o=i.getDateInfo(a),s=[],l=0;l<7;l++){var u=i.getNextNDay(o.time,l),f=i.dataToRect([u.time],!1);s[2*u.day]=f.tl,s[2*u.day+1]=f[n==="horizontal"?"bl":"tr"]}return s},e.prototype._formatterLabel=function(t,a){return $(t)&&t?RE(t,a):K(t)?t(a):a.nameMap},e.prototype._yearTextPositionControl=function(t,a,n,i,o){var s=a[0],l=a[1],u=["center","bottom"];i==="bottom"?(l+=o,u=["center","top"]):i==="left"?s-=o:i==="right"?(s+=o,u=["center","top"]):l-=o;var f=0;return(i==="left"||i==="right")&&(f=Math.PI/2),{rotation:f,x:s,y:l,style:{align:u[0],verticalAlign:u[1]}}},e.prototype._renderYearText=function(t,a,n,i){var o=t.getModel("yearLabel");if(o.get("show")){var s=o.get("margin"),l=o.get("position");l||(l=n!=="horizontal"?"top":"left");var u=[this._tlpoints[this._tlpoints.length-1],this._blpoints[0]],f=(u[0][0]+u[1][0])/2,h=(u[0][1]+u[1][1])/2,v=n==="horizontal"?0:1,c={top:[f,u[v][1]],bottom:[f,u[1-v][1]],left:[u[1-v][0],h],right:[u[v][0],h]},p=a.start.y;+a.end.y>+a.start.y&&(p=p+"-"+a.end.y);var d=o.get("formatter"),g={start:a.start.y,end:a.end.y,nameMap:p},y=this._formatterLabel(d,g),m=new At({z2:30,style:kt(o,{text:y})});m.attr(this._yearTextPositionControl(m,c[l],n,l,s)),i.add(m)}},e.prototype._monthTextPositionControl=function(t,a,n,i,o){var s="left",l="top",u=t[0],f=t[1];return n==="horizontal"?(f=f+o,a&&(s="center"),i==="start"&&(l="bottom")):(u=u+o,a&&(l="middle"),i==="start"&&(s="right")),{x:u,y:f,align:s,verticalAlign:l}},e.prototype._renderMonthText=function(t,a,n,i){var o=t.getModel("monthLabel");if(o.get("show")){var s=o.get("nameMap"),l=o.get("margin"),u=o.get("position"),f=o.get("align"),h=[this._tlpoints,this._blpoints];(!s||$(s))&&(s&&(a=Np(s)||a),s=a.get(["time","monthAbbr"])||[]);var v=u==="start"?0:1,c=n==="horizontal"?0:1;l=u==="start"?-l:l;for(var p=f==="center",d=0;d<h[v].length-1;d++){var g=h[v][d].slice(),y=this._firstDayOfMonth[d];if(p){var m=this._firstDayPoints[d];g[c]=(m[c]+h[0][d+1][c])/2}var _=o.get("formatter"),S=s[+y.m-1],w={yyyy:y.y,yy:(y.y+"").slice(2),MM:y.m,M:+y.m,nameMap:S},x=this._formatterLabel(_,w),b=new At({z2:30,style:V(kt(o,{text:x}),this._monthTextPositionControl(g,p,n,u,l))});i.add(b)}}},e.prototype._weekTextPositionControl=function(t,a,n,i,o){var s="center",l="middle",u=t[0],f=t[1],h=n==="start";return a==="horizontal"?(u=u+i+(h?1:-1)*o[0]/2,s=h?"right":"left"):(f=f+i+(h?1:-1)*o[1]/2,l=h?"bottom":"top"),{x:u,y:f,align:s,verticalAlign:l}},e.prototype._renderWeekText=function(t,a,n,i,o){var s=t.getModel("dayLabel");if(s.get("show")){var l=t.coordinateSystem,u=s.get("position"),f=s.get("nameMap"),h=s.get("margin"),v=l.getFirstDayOfWeek();if(!f||$(f)){f&&(a=Np(f)||a);var c=a.get(["time","dayOfWeekShort"]);f=c||G(a.get(["time","dayOfWeekAbbr"]),function(w){return w[0]})}var p=l.getNextNDay(n.end.time,7-n.lweek).time,d=[l.getCellWidth(),l.getCellHeight()];h=W(h,Math.min(d[1],d[0])),u==="start"&&(p=l.getNextNDay(n.start.time,-(7+n.fweek)).time,h=-h);for(var g=0;g<7;g++){var y=l.getNextNDay(p,g),m=l.dataToRect([y.time],!1).center,_=g;_=Math.abs((g+v)%7);var S=new At({z2:30,style:V(kt(s,{text:f[_]}),this._weekTextPositionControl(m,i,u,h,d))});o.add(S)}}},e.type="calendar",e}(Ht);const uU=lU;var Nc=864e5,fU=function(){function r(e,t,a){this.type="calendar",this.dimensions=r.dimensions,this.getDimensionsInfo=r.getDimensionsInfo,this._model=e}return r.getDimensionsInfo=function(){return[{name:"time",type:"time"},"value"]},r.prototype.getRangeInfo=function(){return this._rangeInfo},r.prototype.getModel=function(){return this._model},r.prototype.getRect=function(){return this._rect},r.prototype.getCellWidth=function(){return this._sw},r.prototype.getCellHeight=function(){return this._sh},r.prototype.getOrient=function(){return this._orient},r.prototype.getFirstDayOfWeek=function(){return this._firstDayOfWeek},r.prototype.getDateInfo=function(e){e=Hr(e);var t=e.getFullYear(),a=e.getMonth()+1,n=a<10?"0"+a:""+a,i=e.getDate(),o=i<10?"0"+i:""+i,s=e.getDay();return s=Math.abs((s+7-this.getFirstDayOfWeek())%7),{y:t+"",m:n,d:o,day:s,time:e.getTime(),formatedDate:t+"-"+n+"-"+o,date:e}},r.prototype.getNextNDay=function(e,t){return t=t||0,t===0?this.getDateInfo(e):(e=new Date(this.getDateInfo(e).time),e.setDate(e.getDate()+t),this.getDateInfo(e))},r.prototype.update=function(e,t){this._firstDayOfWeek=+this._model.getModel("dayLabel").get("firstDay"),this._orient=this._model.get("orient"),this._lineWidth=this._model.getModel("itemStyle").getItemStyle().lineWidth||0,this._rangeInfo=this._getRangeInfo(this._initRangeOption());var a=this._rangeInfo.weeks||1,n=["width","height"],i=this._model.getCellSize().slice(),o=this._model.getBoxLayoutParams(),s=this._orient==="horizontal"?[a,7]:[7,a];C([0,1],function(h){f(i,h)&&(o[n[h]]=i[h]*s[h])});var l={width:t.getWidth(),height:t.getHeight()},u=this._rect=Jt(o,l);C([0,1],function(h){f(i,h)||(i[h]=u[n[h]]/s[h])});function f(h,v){return h[v]!=null&&h[v]!=="auto"}this._sw=i[0],this._sh=i[1]},r.prototype.dataToPoint=function(e,t){z(e)&&(e=e[0]),t==null&&(t=!0);var a=this.getDateInfo(e),n=this._rangeInfo,i=a.formatedDate;if(t&&!(a.time>=n.start.time&&a.time<n.end.time+Nc))return[NaN,NaN];var o=a.day,s=this._getRangeInfo([n.start.time,i]).nthWeek;return this._orient==="vertical"?[this._rect.x+o*this._sw+this._sw/2,this._rect.y+s*this._sh+this._sh/2]:[this._rect.x+s*this._sw+this._sw/2,this._rect.y+o*this._sh+this._sh/2]},r.prototype.pointToData=function(e){var t=this.pointToDate(e);return t&&t.time},r.prototype.dataToRect=function(e,t){var a=this.dataToPoint(e,t);return{contentShape:{x:a[0]-(this._sw-this._lineWidth)/2,y:a[1]-(this._sh-this._lineWidth)/2,width:this._sw-this._lineWidth,height:this._sh-this._lineWidth},center:a,tl:[a[0]-this._sw/2,a[1]-this._sh/2],tr:[a[0]+this._sw/2,a[1]-this._sh/2],br:[a[0]+this._sw/2,a[1]+this._sh/2],bl:[a[0]-this._sw/2,a[1]+this._sh/2]}},r.prototype.pointToDate=function(e){var t=Math.floor((e[0]-this._rect.x)/this._sw)+1,a=Math.floor((e[1]-this._rect.y)/this._sh)+1,n=this._rangeInfo.range;return this._orient==="vertical"?this._getDateByWeeksAndDay(a,t-1,n):this._getDateByWeeksAndDay(t,a-1,n)},r.prototype.convertToPixel=function(e,t,a){var n=Ox(t);return n===this?n.dataToPoint(a):null},r.prototype.convertFromPixel=function(e,t,a){var n=Ox(t);return n===this?n.pointToData(a):null},r.prototype.containPoint=function(e){return console.warn("Not implemented."),!1},r.prototype._initRangeOption=function(){var e=this._model.get("range"),t;if(z(e)&&e.length===1&&(e=e[0]),z(e))t=e;else{var a=e.toString();if(/^\d{4}$/.test(a)&&(t=[a+"-01-01",a+"-12-31"]),/^\d{4}[\/|-]\d{1,2}$/.test(a)){var n=this.getDateInfo(a),i=n.date;i.setMonth(i.getMonth()+1);var o=this.getNextNDay(i,-1);t=[n.formatedDate,o.formatedDate]}/^\d{4}[\/|-]\d{1,2}[\/|-]\d{1,2}$/.test(a)&&(t=[a,a])}if(!t)return e;var s=this._getRangeInfo(t);return s.start.time>s.end.time&&t.reverse(),t},r.prototype._getRangeInfo=function(e){var t=[this.getDateInfo(e[0]),this.getDateInfo(e[1])],a;t[0].time>t[1].time&&(a=!0,t.reverse());var n=Math.floor(t[1].time/Nc)-Math.floor(t[0].time/Nc)+1,i=new Date(t[0].time),o=i.getDate(),s=t[1].date.getDate();i.setDate(o+n-1);var l=i.getDate();if(l!==s)for(var u=i.getTime()-t[1].time>0?1:-1;(l=i.getDate())!==s&&(i.getTime()-t[1].time)*u>0;)n-=u,i.setDate(l-u);var f=Math.floor((n+t[0].day+6)/7),h=a?-f+1:f-1;return a&&t.reverse(),{range:[t[0].formatedDate,t[1].formatedDate],start:t[0],end:t[1],allDay:n,weeks:f,nthWeek:h,fweek:t[0].day,lweek:t[1].day}},r.prototype._getDateByWeeksAndDay=function(e,t,a){var n=this._getRangeInfo(a);if(e>n.weeks||e===0&&t<n.fweek||e===n.weeks&&t>n.lweek)return null;var i=(e-1)*7-n.fweek+t,o=new Date(n.start.time);return o.setDate(+n.start.d+i),this.getDateInfo(o)},r.create=function(e,t){var a=[];return e.eachComponent("calendar",function(n){var i=new r(n);a.push(i),n.coordinateSystem=i}),e.eachSeries(function(n){n.get("coordinateSystem")==="calendar"&&(n.coordinateSystem=a[n.get("calendarIndex")||0])}),a},r.dimensions=["time","value"],r}();function Ox(r){var e=r.calendarModel,t=r.seriesModel,a=e?e.coordinateSystem:t?t.coordinateSystem:null;return a}const hU=fU;function vU(r){r.registerComponentModel(sU),r.registerComponentView(uU),r.registerCoordinateSystem("calendar",hU)}function cU(r,e){var t=r.existing;if(e.id=r.keyInfo.id,!e.type&&t&&(e.type=t.type),e.parentId==null){var a=e.parentOption;a?e.parentId=a.id:t&&(e.parentId=t.parentId)}e.parentOption=null}function Nx(r,e){var t;return C(e,function(a){r[a]!=null&&r[a]!=="auto"&&(t=!0)}),t}function pU(r,e,t){var a=V({},t),n=r[e],i=t.$action||"merge";i==="merge"?n?(ft(n,a,!0),Ua(n,a,{ignoreSize:!0}),vA(t,n),xu(t,n),xu(t,n,"shape"),xu(t,n,"style"),xu(t,n,"extra"),t.clipPath=n.clipPath):r[e]=a:i==="replace"?r[e]=a:i==="remove"&&n&&(r[e]=null)}var CI=["transition","enterFrom","leaveTo"],dU=CI.concat(["enterAnimation","updateAnimation","leaveAnimation"]);function xu(r,e,t){if(t&&(!r[t]&&e[t]&&(r[t]={}),r=r[t],e=e[t]),!(!r||!e))for(var a=t?CI:dU,n=0;n<a.length;n++){var i=a[n];r[i]==null&&e[i]!=null&&(r[i]=e[i])}}function gU(r,e){if(r&&(r.hv=e.hv=[Nx(e,["left","right"]),Nx(e,["top","bottom"])],r.type==="group")){var t=r,a=e;t.width==null&&(t.width=a.width=0),t.height==null&&(t.height=a.height=0)}}var yU=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.preventAutoZ=!0,t}return e.prototype.mergeOption=function(t,a){var n=this.option.elements;this.option.elements=null,r.prototype.mergeOption.call(this,t,a),this.option.elements=n},e.prototype.optionUpdated=function(t,a){var n=this.option,i=(a?n:t).elements,o=n.elements=a?[]:n.elements,s=[];this._flatten(i,s,null);var l=Jb(o,s,"normalMerge"),u=this._elOptionsToUpdate=[];C(l,function(f,h){var v=f.newOption;v&&(u.push(v),cU(f,v),pU(o,h,v),gU(o[h],v))},this),n.elements=Lt(o,function(f){return f&&delete f.$action,f!=null})},e.prototype._flatten=function(t,a,n){C(t,function(i){if(i){n&&(i.parentOption=n),a.push(i);var o=i.children;o&&o.length&&this._flatten(o,a,i),delete i.children}},this)},e.prototype.useElOptionsToUpdate=function(){var t=this._elOptionsToUpdate;return this._elOptionsToUpdate=null,t},e.type="graphic",e.defaultOption={elements:[]},e}(Tt),Bx={path:null,compoundPath:null,group:at,image:he,text:At},Je=bt(),mU=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(){this._elMap=Z()},e.prototype.render=function(t,a,n){t!==this._lastGraphicModel&&this._clear(),this._lastGraphicModel=t,this._updateElements(t),this._relocate(t,n)},e.prototype._updateElements=function(t){var a=t.useElOptionsToUpdate();if(a){var n=this._elMap,i=this.group,o=t.get("z"),s=t.get("zlevel");C(a,function(l){var u=Qt(l.id,null),f=u!=null?n.get(u):null,h=Qt(l.parentId,null),v=h!=null?n.get(h):i,c=l.type,p=l.style;c==="text"&&p&&l.hv&&l.hv[1]&&(p.textVerticalAlign=p.textBaseline=p.verticalAlign=p.align=null);var d=l.textContent,g=l.textConfig;if(p&&iI(p,c,!!g,!!d)){var y=oI(p,c,!0);!g&&y.textConfig&&(g=l.textConfig=y.textConfig),!d&&y.textContent&&(d=y.textContent)}var m=_U(l),_=l.$action||"merge",S=_==="merge",w=_==="replace";if(S){var x=!f,b=f;x?b=Vx(u,v,l.type,n):(b&&(Je(b).isNew=!1),fI(b)),b&&($u(b,m,t,{isInit:x}),zx(b,l,o,s))}else if(w){Yu(f,l,n,t);var T=Vx(u,v,l.type,n);T&&($u(T,m,t,{isInit:!0}),zx(T,l,o,s))}else _==="remove"&&(lI(f,l),Yu(f,l,n,t));var A=n.get(u);if(A&&d)if(S){var D=A.getTextContent();D?D.attr(d):A.setTextContent(new At(d))}else w&&A.setTextContent(new At(d));if(A){var M=l.clipPath;if(M){var I=M.type,L=void 0,x=!1;if(S){var P=A.getClipPath();x=!P||Je(P).type!==I,L=x?Dd(I):P}else w&&(x=!0,L=Dd(I));A.setClipPath(L),$u(L,M,t,{isInit:x}),Rf(L,M.keyframeAnimation,t)}var R=Je(A);A.setTextConfig(g),R.option=l,SU(A,t,l),co({el:A,componentModel:t,itemName:A.name,itemTooltipOption:l.tooltip}),Rf(A,l.keyframeAnimation,t)}})}},e.prototype._relocate=function(t,a){for(var n=t.option.elements,i=this.group,o=this._elMap,s=a.getWidth(),l=a.getHeight(),u=["x","y"],f=0;f<n.length;f++){var h=n[f],v=Qt(h.id,null),c=v!=null?o.get(v):null;if(!(!c||!c.isGroup)){var p=c.parent,d=p===i,g=Je(c),y=Je(p);g.width=W(g.option.width,d?s:y.width)||0,g.height=W(g.option.height,d?l:y.height)||0}}for(var f=n.length-1;f>=0;f--){var h=n[f],v=Qt(h.id,null),c=v!=null?o.get(v):null;if(c){var p=c.parent,y=Je(p),m=p===i?{width:s,height:l}:{width:y.width,height:y.height},_={},S=hh(c,h,m,null,{hv:h.hv,boundingMode:h.bounding},_);if(!Je(c).isNew&&S){for(var w=h.transition,x={},b=0;b<u.length;b++){var T=u[b],A=_[T];w&&(Qn(w)||vt(w,T)>=0)?x[T]=A:c[T]=A}Dt(c,x,t,0)}else c.attr(_)}}},e.prototype._clear=function(){var t=this,a=this._elMap;a.each(function(n){Yu(n,Je(n).option,a,t._lastGraphicModel)}),this._elMap=Z()},e.prototype.dispose=function(){this._clear()},e.type="graphic",e}(Ht);function Dd(r){var e=Y(Bx,r)?Bx[r]:yg(r),t=new e({});return Je(t).type=r,t}function Vx(r,e,t,a){var n=Dd(t);return e.add(n),a.set(r,n),Je(n).id=r,Je(n).isNew=!0,n}function Yu(r,e,t,a){var n=r&&r.parent;n&&(r.type==="group"&&r.traverse(function(i){Yu(i,e,t,a)}),Ch(r,e,a),t.removeKey(Je(r).id))}function zx(r,e,t,a){r.isGroup||C([["cursor",ir.prototype.cursor],["zlevel",a||0],["z",t||0],["z2",0]],function(n){var i=n[0];Y(e,i)?r[i]=it(e[i],n[1]):r[i]==null&&(r[i]=n[1])}),C(_t(e),function(n){if(n.indexOf("on")===0){var i=e[n];r[n]=K(i)?i:null}}),Y(e,"draggable")&&(r.draggable=e.draggable),e.name!=null&&(r.name=e.name),e.id!=null&&(r.id=e.id)}function _U(r){return r=V({},r),C(["id","parentId","$action","hv","bounding","textContent","clipPath"].concat(hA),function(e){delete r[e]}),r}function SU(r,e,t){var a=nt(r).eventData;!r.silent&&!r.ignore&&!a&&(a=nt(r).eventData={componentType:"graphic",componentIndex:e.componentIndex,name:r.name}),a&&(a.info=t.info)}function xU(r){r.registerComponentModel(yU),r.registerComponentView(mU),r.registerPreprocessor(function(e){var t=e.graphic;z(t)?!t[0]||!t[0].elements?e.graphic=[{elements:t}]:e.graphic=[e.graphic[0]]:t&&!t.elements&&(e.graphic=[{elements:[t]}])})}var Gx=["x","y","radius","angle","single"],wU=["cartesian2d","polar","singleAxis"];function bU(r){var e=r.get("coordinateSystem");return vt(wU,e)>=0}function Na(r){return r+"Axis"}function TU(r,e){var t=Z(),a=[],n=Z();r.eachComponent({mainType:"dataZoom",query:e},function(f){n.get(f.uid)||s(f)});var i;do i=!1,r.eachComponent("dataZoom",o);while(i);function o(f){!n.get(f.uid)&&l(f)&&(s(f),i=!0)}function s(f){n.set(f.uid,!0),a.push(f),u(f)}function l(f){var h=!1;return f.eachTargetAxis(function(v,c){var p=t.get(v);p&&p[c]&&(h=!0)}),h}function u(f){f.eachTargetAxis(function(h,v){(t.get(h)||t.set(h,[]))[v]=!0})}return a}function DI(r){var e=r.ecModel,t={infoList:[],infoMap:Z()};return r.eachTargetAxis(function(a,n){var i=e.getComponent(Na(a),n);if(i){var o=i.getCoordSysModel();if(o){var s=o.uid,l=t.infoMap.get(s);l||(l={model:o,axisModels:[]},t.infoList.push(l),t.infoMap.set(s,l)),l.axisModels.push(i)}}}),t}var Bc=function(){function r(){this.indexList=[],this.indexMap=[]}return r.prototype.add=function(e){this.indexMap[e]||(this.indexList.push(e),this.indexMap[e]=!0)},r}(),el=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._autoThrottle=!0,t._noTarget=!0,t._rangePropMode=["percent","percent"],t}return e.prototype.init=function(t,a,n){var i=Fx(t);this.settledOption=i,this.mergeDefaultAndTheme(t,n),this._doInit(i)},e.prototype.mergeOption=function(t){var a=Fx(t);ft(this.option,t,!0),ft(this.settledOption,a,!0),this._doInit(a)},e.prototype._doInit=function(t){var a=this.option;this._setDefaultThrottle(t),this._updateRangeUse(t);var n=this.settledOption;C([["start","startValue"],["end","endValue"]],function(i,o){this._rangePropMode[o]==="value"&&(a[i[0]]=n[i[0]]=null)},this),this._resetTarget()},e.prototype._resetTarget=function(){var t=this.get("orient",!0),a=this._targetAxisInfoMap=Z(),n=this._fillSpecifiedTargetAxis(a);n?this._orient=t||this._makeAutoOrientByTargetAxis():(this._orient=t||"horizontal",this._fillAutoTargetAxisByOrient(a,this._orient)),this._noTarget=!0,a.each(function(i){i.indexList.length&&(this._noTarget=!1)},this)},e.prototype._fillSpecifiedTargetAxis=function(t){var a=!1;return C(Gx,function(n){var i=this.getReferringComponents(Na(n),pP);if(i.specified){a=!0;var o=new Bc;C(i.models,function(s){o.add(s.componentIndex)}),t.set(n,o)}},this),a},e.prototype._fillAutoTargetAxisByOrient=function(t,a){var n=this.ecModel,i=!0;if(i){var o=a==="vertical"?"y":"x",s=n.findComponents({mainType:o+"Axis"});l(s,o)}if(i){var s=n.findComponents({mainType:"singleAxis",filter:function(f){return f.get("orient",!0)===a}});l(s,"single")}function l(u,f){var h=u[0];if(h){var v=new Bc;if(v.add(h.componentIndex),t.set(f,v),i=!1,f==="x"||f==="y"){var c=h.getReferringComponents("grid",Xt).models[0];c&&C(u,function(p){h.componentIndex!==p.componentIndex&&c===p.getReferringComponents("grid",Xt).models[0]&&v.add(p.componentIndex)})}}}i&&C(Gx,function(u){if(i){var f=n.findComponents({mainType:Na(u),filter:function(v){return v.get("type",!0)==="category"}});if(f[0]){var h=new Bc;h.add(f[0].componentIndex),t.set(u,h),i=!1}}},this)},e.prototype._makeAutoOrientByTargetAxis=function(){var t;return this.eachTargetAxis(function(a){!t&&(t=a)},this),t==="y"?"vertical":"horizontal"},e.prototype._setDefaultThrottle=function(t){if(t.hasOwnProperty("throttle")&&(this._autoThrottle=!1),this._autoThrottle){var a=this.ecModel.option;this.option.throttle=a.animation&&a.animationDurationUpdate>0?100:20}},e.prototype._updateRangeUse=function(t){var a=this._rangePropMode,n=this.get("rangeMode");C([["start","startValue"],["end","endValue"]],function(i,o){var s=t[i[0]]!=null,l=t[i[1]]!=null;s&&!l?a[o]="percent":!s&&l?a[o]="value":n?a[o]=n[o]:s&&(a[o]="percent")})},e.prototype.noTarget=function(){return this._noTarget},e.prototype.getFirstTargetAxisModel=function(){var t;return this.eachTargetAxis(function(a,n){t==null&&(t=this.ecModel.getComponent(Na(a),n))},this),t},e.prototype.eachTargetAxis=function(t,a){this._targetAxisInfoMap.each(function(n,i){C(n.indexList,function(o){t.call(a,i,o)})})},e.prototype.getAxisProxy=function(t,a){var n=this.getAxisModel(t,a);if(n)return n.__dzAxisProxy},e.prototype.getAxisModel=function(t,a){var n=this._targetAxisInfoMap.get(t);if(n&&n.indexMap[a])return this.ecModel.getComponent(Na(t),a)},e.prototype.setRawRange=function(t){var a=this.option,n=this.settledOption;C([["start","startValue"],["end","endValue"]],function(i){(t[i[0]]!=null||t[i[1]]!=null)&&(a[i[0]]=n[i[0]]=t[i[0]],a[i[1]]=n[i[1]]=t[i[1]])},this),this._updateRangeUse(t)},e.prototype.setCalculatedRange=function(t){var a=this.option;C(["start","startValue","end","endValue"],function(n){a[n]=t[n]})},e.prototype.getPercentRange=function(){var t=this.findRepresentativeAxisProxy();if(t)return t.getDataPercentWindow()},e.prototype.getValueRange=function(t,a){if(t==null&&a==null){var n=this.findRepresentativeAxisProxy();if(n)return n.getDataValueWindow()}else return this.getAxisProxy(t,a).getDataValueWindow()},e.prototype.findRepresentativeAxisProxy=function(t){if(t)return t.__dzAxisProxy;for(var a,n=this._targetAxisInfoMap.keys(),i=0;i<n.length;i++)for(var o=n[i],s=this._targetAxisInfoMap.get(o),l=0;l<s.indexList.length;l++){var u=this.getAxisProxy(o,s.indexList[l]);if(u.hostedBy(this))return u;a||(a=u)}return a},e.prototype.getRangePropMode=function(){return this._rangePropMode.slice()},e.prototype.getOrient=function(){return this._orient},e.type="dataZoom",e.dependencies=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","series","toolbox"],e.defaultOption={z:4,filterMode:"filter",start:0,end:100},e}(Tt);function Fx(r){var e={};return C(["start","end","startValue","endValue","throttle"],function(t){r.hasOwnProperty(t)&&(e[t]=r[t])}),e}var AU=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="dataZoom.select",e}(el);const CU=AU;var DU=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n,i){this.dataZoomModel=t,this.ecModel=a,this.api=n},e.type="dataZoom",e}(Ht);const Hy=DU;var MU=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="dataZoom.select",e}(Hy);const IU=MU;var Vi=C,Hx=ar,LU=function(){function r(e,t,a,n){this._dimName=e,this._axisIndex=t,this.ecModel=n,this._dataZoomModel=a}return r.prototype.hostedBy=function(e){return this._dataZoomModel===e},r.prototype.getDataValueWindow=function(){return this._valueWindow.slice()},r.prototype.getDataPercentWindow=function(){return this._percentWindow.slice()},r.prototype.getTargetSeriesModels=function(){var e=[];return this.ecModel.eachSeries(function(t){if(bU(t)){var a=Na(this._dimName),n=t.getReferringComponents(a,Xt).models[0];n&&this._axisIndex===n.componentIndex&&e.push(t)}},this),e},r.prototype.getAxisModel=function(){return this.ecModel.getComponent(this._dimName+"Axis",this._axisIndex)},r.prototype.getMinMaxSpan=function(){return rt(this._minMaxSpan)},r.prototype.calculateDataWindow=function(e){var t=this._dataExtent,a=this.getAxisModel(),n=a.axis.scale,i=this._dataZoomModel.getRangePropMode(),o=[0,100],s=[],l=[],u;Vi(["start","end"],function(v,c){var p=e[v],d=e[v+"Value"];i[c]==="percent"?(p==null&&(p=o[c]),d=n.parse(It(p,o,t))):(u=!0,d=d==null?t[c]:n.parse(d),p=It(d,t,o)),l[c]=d==null||isNaN(d)?t[c]:d,s[c]=p==null||isNaN(p)?o[c]:p}),Hx(l),Hx(s);var f=this._minMaxSpan;u?h(l,s,t,o,!1):h(s,l,o,t,!0);function h(v,c,p,d,g){var y=g?"Span":"ValueSpan";ci(0,v,p,"all",f["min"+y],f["max"+y]);for(var m=0;m<2;m++)c[m]=It(v[m],p,d,!0),g&&(c[m]=n.parse(c[m]))}return{valueWindow:l,percentWindow:s}},r.prototype.reset=function(e){if(e===this._dataZoomModel){var t=this.getTargetSeriesModels();this._dataExtent=PU(this,this._dimName,t),this._updateMinMaxSpan();var a=this.calculateDataWindow(e.settledOption);this._valueWindow=a.valueWindow,this._percentWindow=a.percentWindow,this._setAxisModel()}},r.prototype.filterData=function(e,t){if(e!==this._dataZoomModel)return;var a=this._dimName,n=this.getTargetSeriesModels(),i=e.get("filterMode"),o=this._valueWindow;if(i==="none")return;Vi(n,function(l){var u=l.getData(),f=u.mapDimensionsAll(a);if(f.length){if(i==="weakFilter"){var h=u.getStore(),v=G(f,function(c){return u.getDimensionIndex(c)},u);u.filterSelf(function(c){for(var p,d,g,y=0;y<f.length;y++){var m=h.get(v[y],c),_=!isNaN(m),S=m<o[0],w=m>o[1];if(_&&!S&&!w)return!0;_&&(g=!0),S&&(p=!0),w&&(d=!0)}return g&&p&&d})}else Vi(f,function(c){if(i==="empty")l.setData(u=u.map(c,function(d){return s(d)?d:NaN}));else{var p={};p[c]=o,u.selectRange(p)}});Vi(f,function(c){u.setApproximateExtent(o,c)})}});function s(l){return l>=o[0]&&l<=o[1]}},r.prototype._updateMinMaxSpan=function(){var e=this._minMaxSpan={},t=this._dataZoomModel,a=this._dataExtent;Vi(["min","max"],function(n){var i=t.get(n+"Span"),o=t.get(n+"ValueSpan");o!=null&&(o=this.getAxisModel().axis.scale.parse(o)),o!=null?i=It(a[0]+o,a,[0,100],!0):i!=null&&(o=It(i,[0,100],a,!0)-a[0]),e[n+"Span"]=i,e[n+"ValueSpan"]=o},this)},r.prototype._setAxisModel=function(){var e=this.getAxisModel(),t=this._percentWindow,a=this._valueWindow;if(t){var n=$b(a,[0,500]);n=Math.min(n,20);var i=e.axis.scale.rawExtentInfo;t[0]!==0&&i.setDeterminedMinMax("min",+a[0].toFixed(n)),t[1]!==100&&i.setDeterminedMinMax("max",+a[1].toFixed(n)),i.freeze()}},r}();function PU(r,e,t){var a=[1/0,-1/0];Vi(t,function(o){mB(a,o.getData(),e)});var n=r.getAxisModel(),i=$C(n.axis.scale,n,a).calculate();return[i.min,i.max]}var RU={getTargetSeries:function(r){function e(n){r.eachComponent("dataZoom",function(i){i.eachTargetAxis(function(o,s){var l=r.getComponent(Na(o),s);n(o,s,l,i)})})}e(function(n,i,o,s){o.__dzAxisProxy=null});var t=[];e(function(n,i,o,s){o.__dzAxisProxy||(o.__dzAxisProxy=new LU(n,i,s,r),t.push(o.__dzAxisProxy))});var a=Z();return C(t,function(n){C(n.getTargetSeriesModels(),function(i){a.set(i.uid,i)})}),a},overallReset:function(r,e){r.eachComponent("dataZoom",function(t){t.eachTargetAxis(function(a,n){t.getAxisProxy(a,n).reset(t)}),t.eachTargetAxis(function(a,n){t.getAxisProxy(a,n).filterData(t,e)})}),r.eachComponent("dataZoom",function(t){var a=t.findRepresentativeAxisProxy();if(a){var n=a.getDataPercentWindow(),i=a.getDataValueWindow();t.setCalculatedRange({start:n[0],end:n[1],startValue:i[0],endValue:i[1]})}})}};const EU=RU;function kU(r){r.registerAction("dataZoom",function(e,t){var a=TU(t,e);C(a,function(n){n.setRawRange({start:e.start,end:e.end,startValue:e.startValue,endValue:e.endValue})})})}var Wx=!1;function Wy(r){Wx||(Wx=!0,r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,EU),kU(r),r.registerSubTypeDefaulter("dataZoom",function(){return"slider"}))}function OU(r){r.registerComponentModel(CU),r.registerComponentView(IU),Wy(r)}var tr=function(){function r(){}return r}(),MI={};function zi(r,e){MI[r]=e}function II(r){return MI[r]}var NU=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.optionUpdated=function(){r.prototype.optionUpdated.apply(this,arguments);var t=this.ecModel;C(this.option.feature,function(a,n){var i=II(n);i&&(i.getDefaultOption&&(i.defaultOption=i.getDefaultOption(t)),ft(a,i.defaultOption))})},e.type="toolbox",e.layoutMode={type:"box",ignoreSize:!0},e.defaultOption={show:!0,z:6,orient:"horizontal",left:"right",top:"top",backgroundColor:"transparent",borderColor:"#ccc",borderRadius:0,borderWidth:0,padding:5,itemSize:15,itemGap:8,showTitle:!0,iconStyle:{borderColor:"#666",color:"none"},emphasis:{iconStyle:{borderColor:"#3E98C5"}},tooltip:{show:!1,position:"bottom"}},e}(Tt);const BU=NU;function VU(r,e,t){var a=e.getBoxLayoutParams(),n=e.get("padding"),i={width:t.getWidth(),height:t.getHeight()},o=Jt(a,i,n);qn(e.get("orient"),r,e.get("itemGap"),o.width,o.height),hh(r,a,i,n)}function LI(r,e){var t=yo(e.get("padding")),a=e.getItemStyle(["color","opacity"]);return a.fill=e.get("backgroundColor"),r=new wt({shape:{x:r.x-t[3],y:r.y-t[0],width:r.width+t[1]+t[3],height:r.height+t[0]+t[2],r:e.get("borderRadius")},style:a,silent:!0,z2:-1}),r}var zU=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.render=function(t,a,n,i){var o=this.group;if(o.removeAll(),!t.get("show"))return;var s=+t.get("itemSize"),l=t.get("orient")==="vertical",u=t.get("feature")||{},f=this._features||(this._features={}),h=[];C(u,function(p,d){h.push(d)}),new ua(this._featureNames||[],h).add(v).update(v).remove(ot(v,null)).execute(),this._featureNames=h;function v(p,d){var g=h[p],y=h[d],m=u[g],_=new Ot(m,t,t.ecModel),S;if(i&&i.newTitle!=null&&i.featureName===g&&(m.title=i.newTitle),g&&!y){if(GU(g))S={onclick:_.option.onclick,featureName:g};else{var w=II(g);if(!w)return;S=new w}f[g]=S}else if(S=f[y],!S)return;S.uid=go("toolbox-feature"),S.model=_,S.ecModel=a,S.api=n;var x=S instanceof tr;if(!g&&y){x&&S.dispose&&S.dispose(a,n);return}if(!_.get("show")||x&&S.unusable){x&&S.remove&&S.remove(a,n);return}c(_,S,g),_.setIconStatus=function(b,T){var A=this.option,D=this.iconPaths;A.iconStatus=A.iconStatus||{},A.iconStatus[b]=T,D[b]&&(T==="emphasis"?sa:la)(D[b])},S instanceof tr&&S.render&&S.render(_,a,n,i)}function c(p,d,g){var y=p.getModel("iconStyle"),m=p.getModel(["emphasis","iconStyle"]),_=d instanceof tr&&d.getIcons?d.getIcons():p.get("icon"),S=p.get("title")||{},w,x;$(_)?(w={},w[g]=_):w=_,$(S)?(x={},x[g]=S):x=S;var b=p.iconPaths={};C(w,function(T,A){var D=ul(T,{},{x:-s/2,y:-s/2,width:s,height:s});D.setStyle(y.getItemStyle());var M=D.ensureState("emphasis");M.style=m.getItemStyle();var I=new At({style:{text:x[A],align:m.get("textAlign"),borderRadius:m.get("textBorderRadius"),padding:m.get("textPadding"),fill:null,font:mg({fontStyle:m.get("textFontStyle"),fontFamily:m.get("textFontFamily"),fontSize:m.get("textFontSize"),fontWeight:m.get("textFontWeight")},a)},ignore:!0});D.setTextContent(I),co({el:D,componentModel:t,itemName:A,formatterParamsExtra:{title:x[A]}}),D.__title=x[A],D.on("mouseover",function(){var L=m.getItemStyle(),P=l?t.get("right")==null&&t.get("left")!=="right"?"right":"left":t.get("bottom")==null&&t.get("top")!=="bottom"?"bottom":"top";I.setStyle({fill:m.get("textFill")||L.fill||L.stroke||"#000",backgroundColor:m.get("textBackgroundColor")}),D.setTextConfig({position:m.get("textPosition")||P}),I.ignore=!t.get("showTitle"),n.enterEmphasis(this)}).on("mouseout",function(){p.get(["iconStatus",A])!=="emphasis"&&n.leaveEmphasis(this),I.hide()}),(p.get(["iconStatus",A])==="emphasis"?sa:la)(D),o.add(D),D.on("click",U(d.onclick,d,a,n,A)),b[A]=D})}VU(o,t,n),o.add(LI(o.getBoundingRect(),t)),l||o.eachChild(function(p){var d=p.__title,g=p.ensureState("emphasis"),y=g.textConfig||(g.textConfig={}),m=p.getTextContent(),_=m&&m.ensureState("emphasis");if(_&&!K(_)&&d){var S=_.style||(_.style={}),w=il(d,At.makeFont(S)),x=p.x+o.x,b=p.y+o.y+s,T=!1;b+w.height>n.getHeight()&&(y.position="top",T=!0);var A=T?-5-w.height:s+10;x+w.width/2>n.getWidth()?(y.position=["100%",A],S.align="right"):x-w.width/2<0&&(y.position=[0,A],S.align="left")}})},e.prototype.updateView=function(t,a,n,i){C(this._features,function(o){o instanceof tr&&o.updateView&&o.updateView(o.model,a,n,i)})},e.prototype.remove=function(t,a){C(this._features,function(n){n instanceof tr&&n.remove&&n.remove(t,a)}),this.group.removeAll()},e.prototype.dispose=function(t,a){C(this._features,function(n){n instanceof tr&&n.dispose&&n.dispose(t,a)})},e.type="toolbox",e}(Ht);function GU(r){return r.indexOf("my")===0}const FU=zU;var HU=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.onclick=function(t,a){var n=this.model,i=n.get("name")||t.get("title.0.text")||"echarts",o=a.getZr().painter.getType()==="svg",s=o?"svg":n.get("type",!0)||"png",l=a.getConnectedDataURL({type:s,backgroundColor:n.get("backgroundColor",!0)||t.get("backgroundColor")||"#fff",connectedBackgroundColor:n.get("connectedBackgroundColor"),excludeComponents:n.get("excludeComponents"),pixelRatio:n.get("pixelRatio")}),u=mt.browser;if(K(MouseEvent)&&(u.newEdge||!u.ie&&!u.edge)){var f=document.createElement("a");f.download=i+"."+s,f.target="_blank",f.href=l;var h=new MouseEvent("click",{view:document.defaultView,bubbles:!0,cancelable:!1});f.dispatchEvent(h)}else if(window.navigator.msSaveOrOpenBlob||o){var v=l.split(","),c=v[0].indexOf("base64")>-1,p=o?decodeURIComponent(v[1]):v[1];c&&(p=window.atob(p));var d=i+"."+s;if(window.navigator.msSaveOrOpenBlob){for(var g=p.length,y=new Uint8Array(g);g--;)y[g]=p.charCodeAt(g);var m=new Blob([y]);window.navigator.msSaveOrOpenBlob(m,d)}else{var _=document.createElement("iframe");document.body.appendChild(_);var S=_.contentWindow,w=S.document;w.open("image/svg+xml","replace"),w.write(p),w.close(),S.focus(),w.execCommand("SaveAs",!0,d),document.body.removeChild(_)}}else{var x=n.get("lang"),b='<body style="margin:0;"><img src="'+l+'" style="max-width:100%;" title="'+(x&&x[0]||"")+'" /></body>',T=window.open();T.document.write(b),T.document.title=i}},e.getDefaultOption=function(t){var a={show:!0,icon:"M4.7,22.9L29.3,45.5L54.7,23.4M4.6,43.6L4.6,58L53.8,58L53.8,43.6M29.2,45.1L29.2,0",title:t.getLocaleModel().get(["toolbox","saveAsImage","title"]),type:"png",connectedBackgroundColor:"#fff",name:"",excludeComponents:["toolbox"],lang:t.getLocaleModel().get(["toolbox","saveAsImage","lang"])};return a},e}(tr);const WU=HU;var $x="__ec_magicType_stack__",$U=[["line","bar"],["stack"]],UU=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.getIcons=function(){var t=this.model,a=t.get("icon"),n={};return C(t.get("type"),function(i){a[i]&&(n[i]=a[i])}),n},e.getDefaultOption=function(t){var a={show:!0,type:[],icon:{line:"M4.1,28.9h7.1l9.3-22l7.4,38l9.7-19.7l3,12.8h14.9M4.1,58h51.4",bar:"M6.7,22.9h10V48h-10V22.9zM24.9,13h10v35h-10V13zM43.2,2h10v46h-10V2zM3.1,58h53.7",stack:"M8.2,38.4l-8.4,4.1l30.6,15.3L60,42.5l-8.1-4.1l-21.5,11L8.2,38.4z M51.9,30l-8.1,4.2l-13.4,6.9l-13.9-6.9L8.2,30l-8.4,4.2l8.4,4.2l22.2,11l21.5-11l8.1-4.2L51.9,30z M51.9,21.7l-8.1,4.2L35.7,30l-5.3,2.8L24.9,30l-8.4-4.1l-8.3-4.2l-8.4,4.2L8.2,30l8.3,4.2l13.9,6.9l13.4-6.9l8.1-4.2l8.1-4.1L51.9,21.7zM30.4,2.2L-0.2,17.5l8.4,4.1l8.3,4.2l8.4,4.2l5.5,2.7l5.3-2.7l8.1-4.2l8.1-4.2l8.1-4.1L30.4,2.2z"},title:t.getLocaleModel().get(["toolbox","magicType","title"]),option:{},seriesIndex:{}};return a},e.prototype.onclick=function(t,a,n){var i=this.model,o=i.get(["seriesIndex",n]);if(Ux[n]){var s={series:[]},l=function(h){var v=h.subType,c=h.id,p=Ux[n](v,c,h,i);p&&(j(p,h.option),s.series.push(p));var d=h.coordinateSystem;if(d&&d.type==="cartesian2d"&&(n==="line"||n==="bar")){var g=d.getAxesByScale("ordinal")[0];if(g){var y=g.dim,m=y+"Axis",_=h.getReferringComponents(m,Xt).models[0],S=_.componentIndex;s[m]=s[m]||[];for(var w=0;w<=S;w++)s[m][S]=s[m][S]||{};s[m][S].boundaryGap=n==="bar"}}};C($U,function(h){vt(h,n)>=0&&C(h,function(v){i.setIconStatus(v,"normal")})}),i.setIconStatus(n,"emphasis"),t.eachComponent({mainType:"series",query:o==null?null:{seriesIndex:o}},l);var u,f=n;n==="stack"&&(u=ft({stack:i.option.title.tiled,tiled:i.option.title.stack},i.option.title),i.get(["iconStatus",n])!=="emphasis"&&(f="tiled")),a.dispatchAction({type:"changeMagicType",currentType:f,newOption:s,newTitle:u,featureName:"magicType"})}},e}(tr),Ux={line:function(r,e,t,a){if(r==="bar")return ft({id:e,type:"line",data:t.get("data"),stack:t.get("stack"),markPoint:t.get("markPoint"),markLine:t.get("markLine")},a.get(["option","line"])||{},!0)},bar:function(r,e,t,a){if(r==="line")return ft({id:e,type:"bar",data:t.get("data"),stack:t.get("stack"),markPoint:t.get("markPoint"),markLine:t.get("markLine")},a.get(["option","bar"])||{},!0)},stack:function(r,e,t,a){var n=t.get("stack")===$x;if(r==="line"||r==="bar")return a.setIconStatus("stack",n?"normal":"emphasis"),ft({id:e,stack:n?"":$x},a.get(["option","stack"])||{},!0)}};Ur({type:"changeMagicType",event:"magicTypeChanged",update:"prepareAndUpdate"},function(r,e){e.mergeOption(r.newOption)});const YU=UU;var Dh=new Array(60).join("-"),io="	";function ZU(r){var e={},t=[],a=[];return r.eachRawSeries(function(n){var i=n.coordinateSystem;if(i&&(i.type==="cartesian2d"||i.type==="polar")){var o=i.getBaseAxis();if(o.type==="category"){var s=o.dim+"_"+o.index;e[s]||(e[s]={categoryAxis:o,valueAxis:i.getOtherAxis(o),series:[]},a.push({axisDim:o.dim,axisIndex:o.index})),e[s].series.push(n)}else t.push(n)}else t.push(n)}),{seriesGroupByCategoryAxis:e,other:t,meta:a}}function XU(r){var e=[];return C(r,function(t,a){var n=t.categoryAxis,i=t.valueAxis,o=i.dim,s=[" "].concat(G(t.series,function(c){return c.name})),l=[n.model.getCategories()];C(t.series,function(c){var p=c.getRawData();l.push(c.getRawData().mapArray(p.mapDimension(o),function(d){return d}))});for(var u=[s.join(io)],f=0;f<l[0].length;f++){for(var h=[],v=0;v<l.length;v++)h.push(l[v][f]);u.push(h.join(io))}e.push(u.join(`
`))}),e.join(`

`+Dh+`

`)}function qU(r){return G(r,function(e){var t=e.getRawData(),a=[e.name],n=[];return t.each(t.dimensions,function(){for(var i=arguments.length,o=arguments[i-1],s=t.getName(o),l=0;l<i-1;l++)n[l]=arguments[l];a.push((s?s+io:"")+n.join(io))}),a.join(`
`)}).join(`

`+Dh+`

`)}function KU(r){var e=ZU(r);return{value:Lt([XU(e.seriesGroupByCategoryAxis),qU(e.other)],function(t){return!!t.replace(/[\n\t\s]/g,"")}).join(`

`+Dh+`

`),meta:e.meta}}function Of(r){return r.replace(/^\s\s*/,"").replace(/\s\s*$/,"")}function QU(r){var e=r.slice(0,r.indexOf(`
`));if(e.indexOf(io)>=0)return!0}var Md=new RegExp("["+io+"]+","g");function JU(r){for(var e=r.split(/\n+/g),t=Of(e.shift()).split(Md),a=[],n=G(t,function(l){return{name:l,data:[]}}),i=0;i<e.length;i++){var o=Of(e[i]).split(Md);a.push(o.shift());for(var s=0;s<o.length;s++)n[s]&&(n[s].data[i]=o[s])}return{series:n,categories:a}}function jU(r){for(var e=r.split(/\n+/g),t=Of(e.shift()),a=[],n=0;n<e.length;n++){var i=Of(e[n]);if(i){var o=i.split(Md),s="",l=void 0,u=!1;isNaN(o[0])?(u=!0,s=o[0],o=o.slice(1),a[n]={name:s,value:[]},l=a[n].value):l=a[n]=[];for(var f=0;f<o.length;f++)l.push(+o[f]);l.length===1&&(u?a[n].value=l[0]:a[n]=l[0])}}return{name:t,data:a}}function t8(r,e){var t=r.split(new RegExp(`
*`+Dh+`
*`,"g")),a={series:[]};return C(t,function(n,i){if(QU(n)){var o=JU(n),s=e[i],l=s.axisDim+"Axis";s&&(a[l]=a[l]||[],a[l][s.axisIndex]={data:o.categories},a.series=a.series.concat(o.series))}else{var o=jU(n);a.series.push(o)}}),a}var e8=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.onclick=function(t,a){setTimeout(function(){a.dispatchAction({type:"hideTip"})});var n=a.getDom(),i=this.model;this._dom&&n.removeChild(this._dom);var o=document.createElement("div");o.style.cssText="position:absolute;top:0;bottom:0;left:0;right:0;padding:5px",o.style.backgroundColor=i.get("backgroundColor")||"#fff";var s=document.createElement("h4"),l=i.get("lang")||[];s.innerHTML=l[0]||i.get("title"),s.style.cssText="margin:10px 20px",s.style.color=i.get("textColor");var u=document.createElement("div"),f=document.createElement("textarea");u.style.cssText="overflow:auto";var h=i.get("optionToContent"),v=i.get("contentToOption"),c=KU(t);if(K(h)){var p=h(a.getOption());$(p)?u.innerHTML=p:Ki(p)&&u.appendChild(p)}else{f.readOnly=i.get("readOnly");var d=f.style;d.cssText="display:block;width:100%;height:100%;font-family:monospace;font-size:14px;line-height:1.6rem;resize:none;box-sizing:border-box;outline:none",d.color=i.get("textColor"),d.borderColor=i.get("textareaBorderColor"),d.backgroundColor=i.get("textareaColor"),f.value=c.value,u.appendChild(f)}var g=c.meta,y=document.createElement("div");y.style.cssText="position:absolute;bottom:5px;left:0;right:0";var m="float:right;margin-right:20px;border:none;cursor:pointer;padding:2px 5px;font-size:12px;border-radius:3px",_=document.createElement("div"),S=document.createElement("div");m+=";background-color:"+i.get("buttonColor"),m+=";color:"+i.get("buttonTextColor");var w=this;function x(){n.removeChild(o),w._dom=null}sp(_,"click",x),sp(S,"click",function(){if(v==null&&h!=null||v!=null&&h==null){x();return}var b;try{K(v)?b=v(u,a.getOption()):b=t8(f.value,g)}catch(T){throw x(),new Error("Data view format error "+T)}b&&a.dispatchAction({type:"changeDataView",newOption:b}),x()}),_.innerHTML=l[1],S.innerHTML=l[2],S.style.cssText=_.style.cssText=m,!i.get("readOnly")&&y.appendChild(S),y.appendChild(_),o.appendChild(s),o.appendChild(u),o.appendChild(y),u.style.height=n.clientHeight-80+"px",n.appendChild(o),this._dom=o},e.prototype.remove=function(t,a){this._dom&&a.getDom().removeChild(this._dom)},e.prototype.dispose=function(t,a){this.remove(t,a)},e.getDefaultOption=function(t){var a={show:!0,readOnly:!1,optionToContent:null,contentToOption:null,icon:"M17.5,17.3H33 M17.5,17.3H33 M45.4,29.5h-28 M11.5,2v56H51V14.8L38.4,2H11.5z M38.4,2.2v12.7H51 M45.4,41.7h-28",title:t.getLocaleModel().get(["toolbox","dataView","title"]),lang:t.getLocaleModel().get(["toolbox","dataView","lang"]),backgroundColor:"#fff",textColor:"#000",textareaColor:"#fff",textareaBorderColor:"#333",buttonColor:"#c23531",buttonTextColor:"#fff"};return a},e}(tr);function r8(r,e){return G(r,function(t,a){var n=e&&e[a];if(tt(n)&&!z(n)){var i=tt(t)&&!z(t);i||(t={value:t});var o=n.name!=null&&t.name==null;return t=j(t,n),o&&delete t.name,t}else return t})}Ur({type:"changeDataView",event:"dataViewChanged",update:"prepareAndUpdate"},function(r,e){var t=[];C(r.newOption.series,function(a){var n=e.getSeriesByName(a.name)[0];if(!n)t.push(V({type:"scatter"},a));else{var i=n.get("data");t.push({name:a.name,data:r8(a.data,i)})}}),e.mergeOption(j({series:t},r.newOption))});const a8=e8;var PI=C,RI=bt();function n8(r,e){var t=$y(r);PI(e,function(a,n){for(var i=t.length-1;i>=0;i--){var o=t[i];if(o[n])break}if(i<0){var s=r.queryComponents({mainType:"dataZoom",subType:"select",id:n})[0];if(s){var l=s.getPercentRange();t[0][n]={dataZoomId:n,start:l[0],end:l[1]}}}}),t.push(e)}function i8(r){var e=$y(r),t=e[e.length-1];e.length>1&&e.pop();var a={};return PI(t,function(n,i){for(var o=e.length-1;o>=0;o--)if(n=e[o][i],n){a[i]=n;break}}),a}function o8(r){RI(r).snapshots=null}function s8(r){return $y(r).length}function $y(r){var e=RI(r);return e.snapshots||(e.snapshots=[{}]),e.snapshots}var l8=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.onclick=function(t,a){o8(t),a.dispatchAction({type:"restore",from:this.uid})},e.getDefaultOption=function(t){var a={show:!0,icon:"M3.8,33.4 M47,18.9h9.8V8.7 M56.3,20.1 C52.1,9,40.5,0.6,26.8,2.1C12.6,3.7,1.6,16.2,2.1,30.6 M13,41.1H3.1v10.2 M3.7,39.9c4.2,11.1,15.8,19.5,29.5,18 c14.2-1.6,25.2-14.1,24.7-28.5",title:t.getLocaleModel().get(["toolbox","restore","title"])};return a},e}(tr);Ur({type:"restore",event:"restore",update:"prepareAndUpdate"},function(r,e){e.resetOption("recreate")});const u8=l8;var f8=["grid","xAxis","yAxis","geo","graph","polar","radiusAxis","angleAxis","bmap"],h8=function(){function r(e,t,a){var n=this;this._targetInfoList=[];var i=Yx(t,e);C(v8,function(o,s){(!a||!a.include||vt(a.include,s)>=0)&&o(i,n._targetInfoList)})}return r.prototype.setOutputRanges=function(e,t){return this.matchOutputRanges(e,t,function(a,n,i){if((a.coordRanges||(a.coordRanges=[])).push(n),!a.coordRange){a.coordRange=n;var o=Vc[a.brushType](0,i,n);a.__rangeOffset={offset:Kx[a.brushType](o.values,a.range,[1,1]),xyMinMax:o.xyMinMax}}}),e},r.prototype.matchOutputRanges=function(e,t,a){C(e,function(n){var i=this.findTargetInfo(n,t);i&&i!==!0&&C(i.coordSyses,function(o){var s=Vc[n.brushType](1,o,n.range,!0);a(n,s.values,o,t)})},this)},r.prototype.setInputRanges=function(e,t){C(e,function(a){var n=this.findTargetInfo(a,t);if(a.range=a.range||[],n&&n!==!0){a.panelId=n.panelId;var i=Vc[a.brushType](0,n.coordSys,a.coordRange),o=a.__rangeOffset;a.range=o?Kx[a.brushType](i.values,o.offset,c8(i.xyMinMax,o.xyMinMax)):i.values}},this)},r.prototype.makePanelOpts=function(e,t){return G(this._targetInfoList,function(a){var n=a.getPanelRect();return{panelId:a.panelId,defaultBrushType:t?t(a):null,clipPath:zM(n),isTargetByCursor:FM(n,e,a.coordSysModel),getLinearBrushOtherExtent:GM(n)}})},r.prototype.controlSeries=function(e,t,a){var n=this.findTargetInfo(e,a);return n===!0||n&&vt(n.coordSyses,t.coordinateSystem)>=0},r.prototype.findTargetInfo=function(e,t){for(var a=this._targetInfoList,n=Yx(t,e),i=0;i<a.length;i++){var o=a[i],s=e.panelId;if(s){if(o.panelId===s)return o}else for(var l=0;l<Zx.length;l++)if(Zx[l](n,o))return o}return!0},r}();function Id(r){return r[0]>r[1]&&r.reverse(),r}function Yx(r,e){return ys(r,e,{includeMainTypes:f8})}var v8={grid:function(r,e){var t=r.xAxisModels,a=r.yAxisModels,n=r.gridModels,i=Z(),o={},s={};!t&&!a&&!n||(C(t,function(l){var u=l.axis.grid.model;i.set(u.id,u),o[u.id]=!0}),C(a,function(l){var u=l.axis.grid.model;i.set(u.id,u),s[u.id]=!0}),C(n,function(l){i.set(l.id,l),o[l.id]=!0,s[l.id]=!0}),i.each(function(l){var u=l.coordinateSystem,f=[];C(u.getCartesians(),function(h,v){(vt(t,h.getAxis("x").model)>=0||vt(a,h.getAxis("y").model)>=0)&&f.push(h)}),e.push({panelId:"grid--"+l.id,gridModel:l,coordSysModel:l,coordSys:f[0],coordSyses:f,getPanelRect:Xx.grid,xAxisDeclared:o[l.id],yAxisDeclared:s[l.id]})}))},geo:function(r,e){C(r.geoModels,function(t){var a=t.coordinateSystem;e.push({panelId:"geo--"+t.id,geoModel:t,coordSysModel:t,coordSys:a,coordSyses:[a],getPanelRect:Xx.geo})})}},Zx=[function(r,e){var t=r.xAxisModel,a=r.yAxisModel,n=r.gridModel;return!n&&t&&(n=t.axis.grid.model),!n&&a&&(n=a.axis.grid.model),n&&n===e.gridModel},function(r,e){var t=r.geoModel;return t&&t===e.geoModel}],Xx={grid:function(){return this.coordSys.master.getRect().clone()},geo:function(){var r=this.coordSys,e=r.getBoundingRect().clone();return e.applyTransform(Xn(r)),e}},Vc={lineX:ot(qx,0),lineY:ot(qx,1),rect:function(r,e,t,a){var n=r?e.pointToData([t[0][0],t[1][0]],a):e.dataToPoint([t[0][0],t[1][0]],a),i=r?e.pointToData([t[0][1],t[1][1]],a):e.dataToPoint([t[0][1],t[1][1]],a),o=[Id([n[0],i[0]]),Id([n[1],i[1]])];return{values:o,xyMinMax:o}},polygon:function(r,e,t,a){var n=[[1/0,-1/0],[1/0,-1/0]],i=G(t,function(o){var s=r?e.pointToData(o,a):e.dataToPoint(o,a);return n[0][0]=Math.min(n[0][0],s[0]),n[1][0]=Math.min(n[1][0],s[1]),n[0][1]=Math.max(n[0][1],s[0]),n[1][1]=Math.max(n[1][1],s[1]),s});return{values:i,xyMinMax:n}}};function qx(r,e,t,a){var n=t.getAxis(["x","y"][r]),i=Id(G([0,1],function(s){return e?n.coordToData(n.toLocalCoord(a[s]),!0):n.toGlobalCoord(n.dataToCoord(a[s]))})),o=[];return o[r]=i,o[1-r]=[NaN,NaN],{values:i,xyMinMax:o}}var Kx={lineX:ot(Qx,0),lineY:ot(Qx,1),rect:function(r,e,t){return[[r[0][0]-t[0]*e[0][0],r[0][1]-t[0]*e[0][1]],[r[1][0]-t[1]*e[1][0],r[1][1]-t[1]*e[1][1]]]},polygon:function(r,e,t){return G(r,function(a,n){return[a[0]-t[0]*e[n][0],a[1]-t[1]*e[n][1]]})}};function Qx(r,e,t,a){return[e[0]-a[r]*t[0],e[1]-a[r]*t[1]]}function c8(r,e){var t=Jx(r),a=Jx(e),n=[t[0]/a[0],t[1]/a[1]];return isNaN(n[0])&&(n[0]=1),isNaN(n[1])&&(n[1]=1),n}function Jx(r){return r?[r[0][1]-r[0][0],r[1][1]-r[1][0]]:[NaN,NaN]}const Uy=h8;var Ld=C,p8=uP("toolbox-dataZoom_"),d8=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.render=function(t,a,n,i){this._brushController||(this._brushController=new Ay(n.getZr()),this._brushController.on("brush",U(this._onBrush,this)).mount()),m8(t,a,this,i,n),y8(t,a)},e.prototype.onclick=function(t,a,n){g8[n].call(this)},e.prototype.remove=function(t,a){this._brushController&&this._brushController.unmount()},e.prototype.dispose=function(t,a){this._brushController&&this._brushController.dispose()},e.prototype._onBrush=function(t){var a=t.areas;if(!t.isEnd||!a.length)return;var n={},i=this.ecModel;this._brushController.updateCovers([]);var o=new Uy(Yy(this.model),i,{include:["grid"]});o.matchOutputRanges(a,i,function(u,f,h){if(h.type==="cartesian2d"){var v=u.brushType;v==="rect"?(s("x",h,f[0]),s("y",h,f[1])):s({lineX:"x",lineY:"y"}[v],h,f)}}),n8(i,n),this._dispatchZoomAction(n);function s(u,f,h){var v=f.getAxis(u),c=v.model,p=l(u,c,i),d=p.findRepresentativeAxisProxy(c).getMinMaxSpan();(d.minValueSpan!=null||d.maxValueSpan!=null)&&(h=ci(0,h.slice(),v.scale.getExtent(),0,d.minValueSpan,d.maxValueSpan)),p&&(n[p.id]={dataZoomId:p.id,startValue:h[0],endValue:h[1]})}function l(u,f,h){var v;return h.eachComponent({mainType:"dataZoom",subType:"select"},function(c){var p=c.getAxisModel(u,f.componentIndex);p&&(v=c)}),v}},e.prototype._dispatchZoomAction=function(t){var a=[];Ld(t,function(n,i){a.push(rt(n))}),a.length&&this.api.dispatchAction({type:"dataZoom",from:this.uid,batch:a})},e.getDefaultOption=function(t){var a={show:!0,filterMode:"filter",icon:{zoom:"M0,13.5h26.9 M13.5,26.9V0 M32.1,13.5H58V58H13.5 V32.1",back:"M22,1.4L9.9,13.5l12.3,12.3 M10.3,13.5H54.9v44.6 H10.3v-26"},title:t.getLocaleModel().get(["toolbox","dataZoom","title"]),brushStyle:{borderWidth:0,color:"rgba(210,219,238,0.2)"}};return a},e}(tr),g8={zoom:function(){var r=!this._isZoomActive;this.api.dispatchAction({type:"takeGlobalCursor",key:"dataZoomSelect",dataZoomSelectActive:r})},back:function(){this._dispatchZoomAction(i8(this.ecModel))}};function Yy(r){var e={xAxisIndex:r.get("xAxisIndex",!0),yAxisIndex:r.get("yAxisIndex",!0),xAxisId:r.get("xAxisId",!0),yAxisId:r.get("yAxisId",!0)};return e.xAxisIndex==null&&e.xAxisId==null&&(e.xAxisIndex="all"),e.yAxisIndex==null&&e.yAxisId==null&&(e.yAxisIndex="all"),e}function y8(r,e){r.setIconStatus("back",s8(e)>1?"emphasis":"normal")}function m8(r,e,t,a,n){var i=t._isZoomActive;a&&a.type==="takeGlobalCursor"&&(i=a.key==="dataZoomSelect"?a.dataZoomSelectActive:!1),t._isZoomActive=i,r.setIconStatus("zoom",i?"emphasis":"normal");var o=new Uy(Yy(r),e,{include:["grid"]}),s=o.makePanelOpts(n,function(l){return l.xAxisDeclared&&!l.yAxisDeclared?"lineX":!l.xAxisDeclared&&l.yAxisDeclared?"lineY":"rect"});t._brushController.setPanels(s).enableBrush(i&&s.length?{brushType:"auto",brushStyle:r.getModel("brushStyle").getItemStyle()}:!1)}FE("dataZoom",function(r){var e=r.getComponent("toolbox",0),t=["feature","dataZoom"];if(!e||e.get(t)==null)return;var a=e.getModel(t),n=[],i=Yy(a),o=ys(r,i);Ld(o.xAxisModels,function(l){return s(l,"xAxis","xAxisIndex")}),Ld(o.yAxisModels,function(l){return s(l,"yAxis","yAxisIndex")});function s(l,u,f){var h=l.componentIndex,v={type:"select",$fromToolbox:!0,filterMode:a.get("filterMode",!0)||"filter",id:p8+u+h};v[f]=h,n.push(v)}return n});const _8=d8;function S8(r){r.registerComponentModel(BU),r.registerComponentView(FU),zi("saveAsImage",WU),zi("magicType",YU),zi("dataView",a8),zi("dataZoom",_8),zi("restore",u8),gt(OU)}var x8=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="tooltip",e.dependencies=["axisPointer"],e.defaultOption={z:60,show:!0,showContent:!0,trigger:"item",triggerOn:"mousemove|click",alwaysShowContent:!1,displayMode:"single",renderMode:"auto",confine:null,showDelay:0,hideDelay:100,transitionDuration:.4,enterable:!1,backgroundColor:"#fff",shadowBlur:10,shadowColor:"rgba(0, 0, 0, .2)",shadowOffsetX:1,shadowOffsetY:2,borderRadius:4,borderWidth:1,padding:null,extraCssText:"",axisPointer:{type:"line",axis:"auto",animation:"auto",animationDurationUpdate:200,animationEasingUpdate:"exponentialOut",crossStyle:{color:"#999",width:1,type:"dashed",textStyle:{}}},textStyle:{color:"#666",fontSize:14}},e}(Tt);const w8=x8;function EI(r){var e=r.get("confine");return e!=null?!!e:r.get("renderMode")==="richText"}function kI(r){if(mt.domSupported){for(var e=document.documentElement.style,t=0,a=r.length;t<a;t++)if(r[t]in e)return r[t]}}var OI=kI(["transform","webkitTransform","OTransform","MozTransform","msTransform"]),b8=kI(["webkitTransition","transition","OTransition","MozTransition","msTransition"]);function NI(r,e){if(!r)return e;e=uA(e,!0);var t=r.indexOf(e);return r=t===-1?e:"-"+r.slice(0,t)+"-"+e,r.toLowerCase()}function T8(r,e){var t=r.currentStyle||document.defaultView&&document.defaultView.getComputedStyle(r);return t?e?t[e]:t:null}var A8=NI(b8,"transition"),Zy=NI(OI,"transform"),C8="position:absolute;display:block;border-style:solid;white-space:nowrap;z-index:9999999;"+(mt.transform3dSupported?"will-change:transform;":"");function D8(r){return r=r==="left"?"right":r==="right"?"left":r==="top"?"bottom":"top",r}function M8(r,e,t){if(!$(t)||t==="inside")return"";var a=r.get("backgroundColor"),n=r.get("borderWidth");e=ri(e);var i=D8(t),o=Math.max(Math.round(n)*1.5,6),s="",l=Zy+":",u;vt(["left","right"],i)>-1?(s+="top:50%",l+="translateY(-50%) rotate("+(u=i==="left"?-225:-45)+"deg)"):(s+="left:50%",l+="translateX(-50%) rotate("+(u=i==="top"?225:45)+"deg)");var f=u*Math.PI/180,h=o+n,v=h*Math.abs(Math.cos(f))+h*Math.abs(Math.sin(f)),c=Math.round(((v-Math.SQRT2*n)/2+Math.SQRT2*n-(v-h)/2)*100)/100;s+=";"+i+":-"+c+"px";var p=e+" solid "+n+"px;",d=["position:absolute;width:"+o+"px;height:"+o+"px;z-index:-1;",s+";"+l+";","border-bottom:"+p,"border-right:"+p,"background-color:"+a+";"];return'<div style="'+d.join("")+'"></div>'}function I8(r,e){var t="cubic-bezier(0.23,1,0.32,1)",a=" "+r/2+"s "+t,n="opacity"+a+",visibility"+a;return e||(a=" "+r+"s "+t,n+=mt.transformSupported?","+Zy+a:",left"+a+",top"+a),A8+":"+n}function jx(r,e,t){var a=r.toFixed(0)+"px",n=e.toFixed(0)+"px";if(!mt.transformSupported)return t?"top:"+n+";left:"+a+";":[["top",n],["left",a]];var i=mt.transform3dSupported,o="translate"+(i?"3d":"")+"("+a+","+n+(i?",0":"")+")";return t?"top:0;left:0;"+Zy+":"+o+";":[["top",0],["left",0],[OI,o]]}function L8(r){var e=[],t=r.get("fontSize"),a=r.getTextColor();a&&e.push("color:"+a),e.push("font:"+r.getFont()),t&&e.push("line-height:"+Math.round(t*3/2)+"px");var n=r.get("textShadowColor"),i=r.get("textShadowBlur")||0,o=r.get("textShadowOffsetX")||0,s=r.get("textShadowOffsetY")||0;return n&&i&&e.push("text-shadow:"+o+"px "+s+"px "+i+"px "+n),C(["decoration","align"],function(l){var u=r.get(l);u&&e.push("text-"+l+":"+u)}),e.join(";")}function P8(r,e,t){var a=[],n=r.get("transitionDuration"),i=r.get("backgroundColor"),o=r.get("shadowBlur"),s=r.get("shadowColor"),l=r.get("shadowOffsetX"),u=r.get("shadowOffsetY"),f=r.getModel("textStyle"),h=WA(r,"html"),v=l+"px "+u+"px "+o+"px "+s;return a.push("box-shadow:"+v),e&&n&&a.push(I8(n,t)),i&&a.push("background-color:"+i),C(["width","color","radius"],function(c){var p="border-"+c,d=uA(p),g=r.get(d);g!=null&&a.push(p+":"+g+(c==="color"?"":"px"))}),a.push(L8(f)),h!=null&&a.push("padding:"+yo(h).join("px ")+"px"),a.join(";")+";"}function tw(r,e,t,a,n){var i=e&&e.painter;if(t){var o=i&&i.getViewportRoot();o&&BL(r,o,t,a,n)}else{r[0]=a,r[1]=n;var s=i&&i.getViewportRootOffset();s&&(r[0]+=s.offsetLeft,r[1]+=s.offsetTop)}r[2]=r[0]/e.getWidth(),r[3]=r[1]/e.getHeight()}var R8=function(){function r(e,t){if(this._show=!1,this._styleCoord=[0,0,0,0],this._enterable=!0,this._alwaysShowContent=!1,this._firstShow=!0,this._longHide=!0,mt.wxa)return null;var a=document.createElement("div");a.domBelongToZr=!0,this.el=a;var n=this._zr=e.getZr(),i=t.appendTo,o=i&&($(i)?document.querySelector(i):Ki(i)?i:K(i)&&i(e.getDom()));tw(this._styleCoord,n,o,e.getWidth()/2,e.getHeight()/2),(o||e.getDom()).appendChild(a),this._api=e,this._container=o;var s=this;a.onmouseenter=function(){s._enterable&&(clearTimeout(s._hideTimeout),s._show=!0),s._inContent=!0},a.onmousemove=function(l){if(l=l||window.event,!s._enterable){var u=n.handler,f=n.painter.getViewportRoot();qe(f,l,!0),u.dispatch("mousemove",l)}},a.onmouseleave=function(){s._inContent=!1,s._enterable&&s._show&&s.hideLater(s._hideDelay)}}return r.prototype.update=function(e){if(!this._container){var t=this._api.getDom(),a=T8(t,"position"),n=t.style;n.position!=="absolute"&&a!=="absolute"&&(n.position="relative")}var i=e.get("alwaysShowContent");i&&this._moveIfResized(),this._alwaysShowContent=i,this.el.className=e.get("className")||""},r.prototype.show=function(e,t){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var a=this.el,n=a.style,i=this._styleCoord;a.innerHTML?n.cssText=C8+P8(e,!this._firstShow,this._longHide)+jx(i[0],i[1],!0)+("border-color:"+ri(t)+";")+(e.get("extraCssText")||"")+(";pointer-events:"+(this._enterable?"auto":"none")):n.display="none",this._show=!0,this._firstShow=!1,this._longHide=!1},r.prototype.setContent=function(e,t,a,n,i){var o=this.el;if(e==null){o.innerHTML="";return}var s="";if($(i)&&a.get("trigger")==="item"&&!EI(a)&&(s=M8(a,n,i)),$(e))o.innerHTML=e+s;else if(e){o.innerHTML="",z(e)||(e=[e]);for(var l=0;l<e.length;l++)Ki(e[l])&&e[l].parentNode!==o&&o.appendChild(e[l]);if(s&&o.childNodes.length){var u=document.createElement("div");u.innerHTML=s,o.appendChild(u)}}},r.prototype.setEnterable=function(e){this._enterable=e},r.prototype.getSize=function(){var e=this.el;return[e.offsetWidth,e.offsetHeight]},r.prototype.moveTo=function(e,t){var a=this._styleCoord;if(tw(a,this._zr,this._container,e,t),a[0]!=null&&a[1]!=null){var n=this.el.style,i=jx(a[0],a[1]);C(i,function(o){n[o[0]]=o[1]})}},r.prototype._moveIfResized=function(){var e=this._styleCoord[2],t=this._styleCoord[3];this.moveTo(e*this._zr.getWidth(),t*this._zr.getHeight())},r.prototype.hide=function(){var e=this,t=this.el.style;t.visibility="hidden",t.opacity="0",mt.transform3dSupported&&(t.willChange=""),this._show=!1,this._longHideTimeout=setTimeout(function(){return e._longHide=!0},500)},r.prototype.hideLater=function(e){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(e?(this._hideDelay=e,this._show=!1,this._hideTimeout=setTimeout(U(this.hide,this),e)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var e=this.el.parentNode;e&&e.removeChild(this.el),this.el=this._container=null},r}();const E8=R8;var k8=function(){function r(e){this._show=!1,this._styleCoord=[0,0,0,0],this._alwaysShowContent=!1,this._enterable=!0,this._zr=e.getZr(),rw(this._styleCoord,this._zr,e.getWidth()/2,e.getHeight()/2)}return r.prototype.update=function(e){var t=e.get("alwaysShowContent");t&&this._moveIfResized(),this._alwaysShowContent=t},r.prototype.show=function(){this._hideTimeout&&clearTimeout(this._hideTimeout),this.el.show(),this._show=!0},r.prototype.setContent=function(e,t,a,n,i){var o=this;tt(e)&&Mt(""),this.el&&this._zr.remove(this.el);var s=a.getModel("textStyle");this.el=new At({style:{rich:t.richTextStyles,text:e,lineHeight:22,borderWidth:1,borderColor:n,textShadowColor:s.get("textShadowColor"),fill:a.get(["textStyle","color"]),padding:WA(a,"richText"),verticalAlign:"top",align:"left"},z:a.get("z")}),C(["backgroundColor","borderRadius","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"],function(u){o.el.style[u]=a.get(u)}),C(["textShadowBlur","textShadowOffsetX","textShadowOffsetY"],function(u){o.el.style[u]=s.get(u)||0}),this._zr.add(this.el);var l=this;this.el.on("mouseover",function(){l._enterable&&(clearTimeout(l._hideTimeout),l._show=!0),l._inContent=!0}),this.el.on("mouseout",function(){l._enterable&&l._show&&l.hideLater(l._hideDelay),l._inContent=!1})},r.prototype.setEnterable=function(e){this._enterable=e},r.prototype.getSize=function(){var e=this.el,t=this.el.getBoundingRect(),a=ew(e.style);return[t.width+a.left+a.right,t.height+a.top+a.bottom]},r.prototype.moveTo=function(e,t){var a=this.el;if(a){var n=this._styleCoord;rw(n,this._zr,e,t),e=n[0],t=n[1];var i=a.style,o=Aa(i.borderWidth||0),s=ew(i);a.x=e+o+s.left,a.y=t+o+s.top,a.markRedraw()}},r.prototype._moveIfResized=function(){var e=this._styleCoord[2],t=this._styleCoord[3];this.moveTo(e*this._zr.getWidth(),t*this._zr.getHeight())},r.prototype.hide=function(){this.el&&this.el.hide(),this._show=!1},r.prototype.hideLater=function(e){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(e?(this._hideDelay=e,this._show=!1,this._hideTimeout=setTimeout(U(this.hide,this),e)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){this._zr.remove(this.el)},r}();function Aa(r){return Math.max(0,r)}function ew(r){var e=Aa(r.shadowBlur||0),t=Aa(r.shadowOffsetX||0),a=Aa(r.shadowOffsetY||0);return{left:Aa(e-t),right:Aa(e+t),top:Aa(e-a),bottom:Aa(e+a)}}function rw(r,e,t,a){r[0]=t,r[1]=a,r[2]=r[0]/e.getWidth(),r[3]=r[1]/e.getHeight()}var O8=new wt({shape:{x:-1,y:-1,width:2,height:2}}),N8=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,a){if(!(mt.node||!a.getDom())){var n=t.getComponent("tooltip"),i=this._renderMode=gP(n.get("renderMode"));this._tooltipContent=i==="richText"?new k8(a):new E8(a,{appendTo:n.get("appendToBody",!0)?"body":n.get("appendTo",!0)})}},e.prototype.render=function(t,a,n){if(!(mt.node||!n.getDom())){this.group.removeAll(),this._tooltipModel=t,this._ecModel=a,this._api=n;var i=this._tooltipContent;i.update(t),i.setEnterable(t.get("enterable")),this._initGlobalListener(),this._keepShow(),this._renderMode!=="richText"&&t.get("transitionDuration")?wo(this,"_updatePosition",50,"fixRate"):Hs(this,"_updatePosition")}},e.prototype._initGlobalListener=function(){var t=this._tooltipModel,a=t.get("triggerOn");_I("itemTooltip",this._api,U(function(n,i,o){a!=="none"&&(a.indexOf(n)>=0?this._tryShow(i,o):n==="leave"&&this._hide(o))},this))},e.prototype._keepShow=function(){var t=this._tooltipModel,a=this._ecModel,n=this._api,i=t.get("triggerOn");if(this._lastX!=null&&this._lastY!=null&&i!=="none"&&i!=="click"){var o=this;clearTimeout(this._refreshUpdateTimeout),this._refreshUpdateTimeout=setTimeout(function(){!n.isDisposed()&&o.manuallyShowTip(t,a,n,{x:o._lastX,y:o._lastY,dataByCoordSys:o._lastDataByCoordSys})})}},e.prototype.manuallyShowTip=function(t,a,n,i){if(!(i.from===this.uid||mt.node||!n.getDom())){var o=aw(i,n);this._ticket="";var s=i.dataByCoordSys,l=G8(i,a,n);if(l){var u=l.el.getBoundingRect().clone();u.applyTransform(l.el.transform),this._tryShow({offsetX:u.x+u.width/2,offsetY:u.y+u.height/2,target:l.el,position:i.position,positionDefault:"bottom"},o)}else if(i.tooltip&&i.x!=null&&i.y!=null){var f=O8;f.x=i.x,f.y=i.y,f.update(),nt(f).tooltipConfig={name:null,option:i.tooltip},this._tryShow({offsetX:i.x,offsetY:i.y,target:f},o)}else if(s)this._tryShow({offsetX:i.x,offsetY:i.y,position:i.position,dataByCoordSys:s,tooltipOption:i.tooltipOption},o);else if(i.seriesIndex!=null){if(this._manuallyAxisShowTip(t,a,n,i))return;var h=SI(i,a),v=h.point[0],c=h.point[1];v!=null&&c!=null&&this._tryShow({offsetX:v,offsetY:c,target:h.el,position:i.position,positionDefault:"bottom"},o)}else i.x!=null&&i.y!=null&&(n.dispatchAction({type:"updateAxisPointer",x:i.x,y:i.y}),this._tryShow({offsetX:i.x,offsetY:i.y,position:i.position,target:n.getZr().findHover(i.x,i.y).target},o))}},e.prototype.manuallyHideTip=function(t,a,n,i){var o=this._tooltipContent;this._tooltipModel&&o.hideLater(this._tooltipModel.get("hideDelay")),this._lastX=this._lastY=this._lastDataByCoordSys=null,i.from!==this.uid&&this._hide(aw(i,n))},e.prototype._manuallyAxisShowTip=function(t,a,n,i){var o=i.seriesIndex,s=i.dataIndex,l=a.getComponent("axisPointer").coordSysAxesInfo;if(!(o==null||s==null||l==null)){var u=a.getSeriesByIndex(o);if(u){var f=u.getData(),h=qo([f.getItemModel(s),u,(u.coordinateSystem||{}).model],this._tooltipModel);if(h.get("trigger")==="axis")return n.dispatchAction({type:"updateAxisPointer",seriesIndex:o,dataIndex:s,position:i.position}),!0}}},e.prototype._tryShow=function(t,a){var n=t.target,i=this._tooltipModel;if(i){this._lastX=t.offsetX,this._lastY=t.offsetY;var o=t.dataByCoordSys;if(o&&o.length)this._showAxisTooltip(o,t);else if(n){var s=nt(n);if(s.ssrType==="legend")return;this._lastDataByCoordSys=null;var l,u;zn(n,function(f){if(nt(f).dataIndex!=null)return l=f,!0;if(nt(f).tooltipConfig!=null)return u=f,!0},!0),l?this._showSeriesItemTooltip(t,l,a):u?this._showComponentItemTooltip(t,u,a):this._hide(a)}else this._lastDataByCoordSys=null,this._hide(a)}},e.prototype._showOrMove=function(t,a){var n=t.get("showDelay");a=U(a,this),clearTimeout(this._showTimout),n>0?this._showTimout=setTimeout(a,n):a()},e.prototype._showAxisTooltip=function(t,a){var n=this._ecModel,i=this._tooltipModel,o=[a.offsetX,a.offsetY],s=qo([a.tooltipOption],i),l=this._renderMode,u=[],f=ae("section",{blocks:[],noHeader:!0}),h=[],v=new wv;C(t,function(m){C(m.dataByAxis,function(_){var S=n.getComponent(_.axisDim+"Axis",_.axisIndex),w=_.value;if(!(!S||w==null)){var x=gI(w,S.axis,n,_.seriesDataIndices,_.valueLabelOpt),b=ae("section",{header:x,noHeader:!dr(x),sortBlocks:!0,blocks:[]});f.blocks.push(b),C(_.seriesDataIndices,function(T){var A=n.getSeriesByIndex(T.seriesIndex),D=T.dataIndexInside,M=A.getDataParams(D);if(!(M.dataIndex<0)){M.axisDim=_.axisDim,M.axisIndex=_.axisIndex,M.axisType=_.axisType,M.axisId=_.axisId,M.axisValue=Xg(S.axis,{value:w}),M.axisValueLabel=x,M.marker=v.makeTooltipMarker("item",ri(M.color),l);var I=G0(A.formatTooltip(D,!0,null)),L=I.frag;if(L){var P=qo([A],i).get("valueFormatter");b.blocks.push(P?V({valueFormatter:P},L):L)}I.text&&h.push(I.text),u.push(M)}})}})}),f.blocks.reverse(),h.reverse();var c=a.position,p=s.get("order"),d=Y0(f,v,l,p,n.get("useUTC"),s.get("textStyle"));d&&h.unshift(d);var g=l==="richText"?`

`:"<br/>",y=h.join(g);this._showOrMove(s,function(){this._updateContentNotChangedOnAxis(t,u)?this._updatePosition(s,c,o[0],o[1],this._tooltipContent,u):this._showTooltipContent(s,y,u,Math.random()+"",o[0],o[1],c,null,v)})},e.prototype._showSeriesItemTooltip=function(t,a,n){var i=this._ecModel,o=nt(a),s=o.seriesIndex,l=i.getSeriesByIndex(s),u=o.dataModel||l,f=o.dataIndex,h=o.dataType,v=u.getData(h),c=this._renderMode,p=t.positionDefault,d=qo([v.getItemModel(f),u,l&&(l.coordinateSystem||{}).model],this._tooltipModel,p?{position:p}:null),g=d.get("trigger");if(!(g!=null&&g!=="item")){var y=u.getDataParams(f,h),m=new wv;y.marker=m.makeTooltipMarker("item",ri(y.color),c);var _=G0(u.formatTooltip(f,!1,h)),S=d.get("order"),w=d.get("valueFormatter"),x=_.frag,b=x?Y0(w?V({valueFormatter:w},x):x,m,c,S,i.get("useUTC"),d.get("textStyle")):_.text,T="item_"+u.name+"_"+f;this._showOrMove(d,function(){this._showTooltipContent(d,b,y,T,t.offsetX,t.offsetY,t.position,t.target,m)}),n({type:"showTip",dataIndexInside:f,dataIndex:v.getRawIndex(f),seriesIndex:s,from:this.uid})}},e.prototype._showComponentItemTooltip=function(t,a,n){var i=nt(a),o=i.tooltipConfig,s=o.option||{};if($(s)){var l=s;s={content:l,formatter:l}}var u=[s],f=this._ecModel.getComponent(i.componentMainType,i.componentIndex);f&&u.push(f),u.push({formatter:s.content});var h=t.positionDefault,v=qo(u,this._tooltipModel,h?{position:h}:null),c=v.get("content"),p=Math.random()+"",d=new wv;this._showOrMove(v,function(){var g=rt(v.get("formatterParams")||{});this._showTooltipContent(v,c,g,p,t.offsetX,t.offsetY,t.position,a,d)}),n({type:"showTip",from:this.uid})},e.prototype._showTooltipContent=function(t,a,n,i,o,s,l,u,f){if(this._ticket="",!(!t.get("showContent")||!t.get("show"))){var h=this._tooltipContent;h.setEnterable(t.get("enterable"));var v=t.get("formatter");l=l||t.get("position");var c=a,p=this._getNearestPoint([o,s],n,t.get("trigger"),t.get("borderColor")),d=p.color;if(v)if($(v)){var g=t.ecModel.get("useUTC"),y=z(n)?n[0]:n,m=y&&y.axisType&&y.axisType.indexOf("time")>=0;c=v,m&&(c=oh(y.axisValue,c,g)),c=fA(c,n,!0)}else if(K(v)){var _=U(function(S,w){S===this._ticket&&(h.setContent(w,f,t,d,l),this._updatePosition(t,l,o,s,h,n,u))},this);this._ticket=i,c=v(n,i,_)}else c=v;h.setContent(c,f,t,d,l),h.show(t,d),this._updatePosition(t,l,o,s,h,n,u)}},e.prototype._getNearestPoint=function(t,a,n,i){if(n==="axis"||z(a))return{color:i||(this._renderMode==="html"?"#fff":"none")};if(!z(a))return{color:i||a.color||a.borderColor}},e.prototype._updatePosition=function(t,a,n,i,o,s,l){var u=this._api.getWidth(),f=this._api.getHeight();a=a||t.get("position");var h=o.getSize(),v=t.get("align"),c=t.get("verticalAlign"),p=l&&l.getBoundingRect().clone();if(l&&p.applyTransform(l.transform),K(a)&&(a=a([n,i],s,o.el,p,{viewSize:[u,f],contentSize:h.slice()})),z(a))n=W(a[0],u),i=W(a[1],f);else if(tt(a)){var d=a;d.width=h[0],d.height=h[1];var g=Jt(d,{width:u,height:f});n=g.x,i=g.y,v=null,c=null}else if($(a)&&l){var y=z8(a,p,h,t.get("borderWidth"));n=y[0],i=y[1]}else{var y=B8(n,i,o,u,f,v?null:20,c?null:20);n=y[0],i=y[1]}if(v&&(n-=nw(v)?h[0]/2:v==="right"?h[0]:0),c&&(i-=nw(c)?h[1]/2:c==="bottom"?h[1]:0),EI(t)){var y=V8(n,i,o,u,f);n=y[0],i=y[1]}o.moveTo(n,i)},e.prototype._updateContentNotChangedOnAxis=function(t,a){var n=this._lastDataByCoordSys,i=this._cbParamsList,o=!!n&&n.length===t.length;return o&&C(n,function(s,l){var u=s.dataByAxis||[],f=t[l]||{},h=f.dataByAxis||[];o=o&&u.length===h.length,o&&C(u,function(v,c){var p=h[c]||{},d=v.seriesDataIndices||[],g=p.seriesDataIndices||[];o=o&&v.value===p.value&&v.axisType===p.axisType&&v.axisId===p.axisId&&d.length===g.length,o&&C(d,function(y,m){var _=g[m];o=o&&y.seriesIndex===_.seriesIndex&&y.dataIndex===_.dataIndex}),i&&C(v.seriesDataIndices,function(y){var m=y.seriesIndex,_=a[m],S=i[m];_&&S&&S.data!==_.data&&(o=!1)})})}),this._lastDataByCoordSys=t,this._cbParamsList=a,!!o},e.prototype._hide=function(t){this._lastDataByCoordSys=null,t({type:"hideTip",from:this.uid})},e.prototype.dispose=function(t,a){mt.node||!a.getDom()||(Hs(this,"_updatePosition"),this._tooltipContent.dispose(),Ad("itemTooltip",a))},e.type="tooltip",e}(Ht);function qo(r,e,t){var a=e.ecModel,n;t?(n=new Ot(t,a,a),n=new Ot(e.option,n,a)):n=e;for(var i=r.length-1;i>=0;i--){var o=r[i];o&&(o instanceof Ot&&(o=o.get("tooltip",!0)),$(o)&&(o={formatter:o}),o&&(n=new Ot(o,n,a)))}return n}function aw(r,e){return r.dispatchAction||U(e.dispatchAction,e)}function B8(r,e,t,a,n,i,o){var s=t.getSize(),l=s[0],u=s[1];return i!=null&&(r+l+i+2>a?r-=l+i:r+=i),o!=null&&(e+u+o>n?e-=u+o:e+=o),[r,e]}function V8(r,e,t,a,n){var i=t.getSize(),o=i[0],s=i[1];return r=Math.min(r+o,a)-o,e=Math.min(e+s,n)-s,r=Math.max(r,0),e=Math.max(e,0),[r,e]}function z8(r,e,t,a){var n=t[0],i=t[1],o=Math.ceil(Math.SQRT2*a)+8,s=0,l=0,u=e.width,f=e.height;switch(r){case"inside":s=e.x+u/2-n/2,l=e.y+f/2-i/2;break;case"top":s=e.x+u/2-n/2,l=e.y-i-o;break;case"bottom":s=e.x+u/2-n/2,l=e.y+f+o;break;case"left":s=e.x-n-o,l=e.y+f/2-i/2;break;case"right":s=e.x+u+o,l=e.y+f/2-i/2}return[s,l]}function nw(r){return r==="center"||r==="middle"}function G8(r,e,t){var a=ag(r).queryOptionMap,n=a.keys()[0];if(!(!n||n==="series")){var i=ol(e,n,a.get(n),{useDefault:!1,enableAll:!1,enableNone:!1}),o=i.models[0];if(o){var s=t.getViewOfComponentModel(o),l;if(s.group.traverse(function(u){var f=nt(u).tooltipConfig;if(f&&f.name===r.name)return l=u,!0}),l)return{componentMainType:n,componentIndex:o.componentIndex,el:l}}}}const F8=N8;function H8(r){gt(bl),r.registerComponentModel(w8),r.registerComponentView(F8),r.registerAction({type:"showTip",event:"showTip",update:"tooltip:manuallyShowTip"},Yt),r.registerAction({type:"hideTip",event:"hideTip",update:"tooltip:manuallyHideTip"},Yt)}var W8=["rect","polygon","keep","clear"];function $8(r,e){var t=Pt(r?r.brush:[]);if(t.length){var a=[];C(t,function(l){var u=l.hasOwnProperty("toolbox")?l.toolbox:[];u instanceof Array&&(a=a.concat(u))});var n=r&&r.toolbox;z(n)&&(n=n[0]),n||(n={feature:{}},r.toolbox=[n]);var i=n.feature||(n.feature={}),o=i.brush||(i.brush={}),s=o.type||(o.type=[]);s.push.apply(s,a),U8(s),e&&!s.length&&s.push.apply(s,W8)}}function U8(r){var e={};C(r,function(t){e[t]=1}),r.length=0,C(e,function(t,a){r.push(a)})}var iw=C;function ow(r){if(r){for(var e in r)if(r.hasOwnProperty(e))return!0}}function Pd(r,e,t){var a={};return iw(e,function(i){var o=a[i]=n();iw(r[i],function(s,l){if(le.isValidType(l)){var u={type:l,visual:s};t&&t(u,i),o[l]=new le(u),l==="opacity"&&(u=rt(u),u.type="colorAlpha",o.__hidden.__alphaForOpacity=new le(u))}})}),a;function n(){var i=function(){};i.prototype.__hidden=i.prototype;var o=new i;return o}}function BI(r,e,t){var a;C(t,function(n){e.hasOwnProperty(n)&&ow(e[n])&&(a=!0)}),a&&C(t,function(n){e.hasOwnProperty(n)&&ow(e[n])?r[n]=rt(e[n]):delete r[n]})}function Y8(r,e,t,a,n,i){var o={};C(r,function(h){var v=le.prepareVisualTypes(e[h]);o[h]=v});var s;function l(h){return Bg(t,s,h)}function u(h,v){jA(t,s,h,v)}i==null?t.each(f):t.each([i],f);function f(h,v){s=i==null?h:v;var c=t.getRawDataItem(s);if(!(c&&c.visualMap===!1))for(var p=a.call(n,h),d=e[p],g=o[p],y=0,m=g.length;y<m;y++){var _=g[y];d[_]&&d[_].applyVisual(h,l,u)}}}function Z8(r,e,t,a){var n={};return C(r,function(i){var o=le.prepareVisualTypes(e[i]);n[i]=o}),{progress:function(o,s){var l;a!=null&&(l=s.getDimensionIndex(a));function u(w){return Bg(s,h,w)}function f(w,x){jA(s,h,w,x)}for(var h,v=s.getStore();(h=o.next())!=null;){var c=s.getRawDataItem(h);if(!(c&&c.visualMap===!1))for(var p=a!=null?v.get(l,h):h,d=t(p),g=e[d],y=n[d],m=0,_=y.length;m<_;m++){var S=y[m];g[S]&&g[S].applyVisual(p,u,f)}}}}}function X8(r){var e=r.brushType,t={point:function(a){return sw[e].point(a,t,r)},rect:function(a){return sw[e].rect(a,t,r)}};return t}var sw={lineX:lw(0),lineY:lw(1),rect:{point:function(r,e,t){return r&&t.boundingRect.contain(r[0],r[1])},rect:function(r,e,t){return r&&t.boundingRect.intersect(r)}},polygon:{point:function(r,e,t){return r&&t.boundingRect.contain(r[0],r[1])&&Pn(t.range,r[0],r[1])},rect:function(r,e,t){var a=t.range;if(!r||a.length<=1)return!1;var n=r.x,i=r.y,o=r.width,s=r.height,l=a[0];if(Pn(a,n,i)||Pn(a,n+o,i)||Pn(a,n,i+s)||Pn(a,n+o,i+s)||ht.create(r).contain(l[0],l[1])||ns(n,i,n+o,i,a)||ns(n,i,n,i+s,a)||ns(n+o,i,n+o,i+s,a)||ns(n,i+s,n+o,i+s,a))return!0}}};function lw(r){var e=["x","y"],t=["width","height"];return{point:function(a,n,i){if(a){var o=i.range,s=a[r];return Ko(s,o)}},rect:function(a,n,i){if(a){var o=i.range,s=[a[e[r]],a[e[r]]+a[t[r]]];return s[1]<s[0]&&s.reverse(),Ko(s[0],o)||Ko(s[1],o)||Ko(o[0],s)||Ko(o[1],s)}}}}function Ko(r,e){return e[0]<=r&&r<=e[1]}var uw=["inBrush","outOfBrush"],zc="__ecBrushSelect",Rd="__ecInBrushSelectEvent";function VI(r){r.eachComponent({mainType:"brush"},function(e){var t=e.brushTargetManager=new Uy(e.option,r);t.setInputRanges(e.areas,r)})}function q8(r,e,t){var a=[],n,i;r.eachComponent({mainType:"brush"},function(o){t&&t.type==="takeGlobalCursor"&&o.setBrushOption(t.key==="brush"?t.brushOption:{brushType:!1})}),VI(r),r.eachComponent({mainType:"brush"},function(o,s){var l={brushId:o.id,brushIndex:s,brushName:o.name,areas:rt(o.areas),selected:[]};a.push(l);var u=o.option,f=u.brushLink,h=[],v=[],c=[],p=!1;s||(n=u.throttleType,i=u.throttleDelay);var d=G(o.areas,function(w){var x=j8[w.brushType],b=j({boundingRect:x?x(w):void 0},w);return b.selectors=X8(b),b}),g=Pd(o.option,uw,function(w){w.mappingMethod="fixed"});z(f)&&C(f,function(w){h[w]=1});function y(w){return f==="all"||!!h[w]}function m(w){return!!w.length}r.eachSeries(function(w,x){var b=c[x]=[];w.subType==="parallel"?_(w,x):S(w,x,b)});function _(w,x){var b=w.coordinateSystem;p=p||b.hasAxisBrushed(),y(x)&&b.eachActiveState(w.getData(),function(T,A){T==="active"&&(v[A]=1)})}function S(w,x,b){if(!(!w.brushSelector||J8(o,x))&&(C(d,function(A){o.brushTargetManager.controlSeries(A,w,r)&&b.push(A),p=p||m(b)}),y(x)&&m(b))){var T=w.getData();T.each(function(A){fw(w,b,T,A)&&(v[A]=1)})}}r.eachSeries(function(w,x){var b={seriesId:w.id,seriesIndex:x,seriesName:w.name,dataIndex:[]};l.selected.push(b);var T=c[x],A=w.getData(),D=y(x)?function(M){return v[M]?(b.dataIndex.push(A.getRawIndex(M)),"inBrush"):"outOfBrush"}:function(M){return fw(w,T,A,M)?(b.dataIndex.push(A.getRawIndex(M)),"inBrush"):"outOfBrush"};(y(x)?p:m(T))&&Y8(uw,g,A,D)})}),K8(e,n,i,a,t)}function K8(r,e,t,a,n){if(n){var i=r.getZr();if(!i[Rd]){i[zc]||(i[zc]=Q8);var o=wo(i,zc,t,e);o(r,a)}}}function Q8(r,e){if(!r.isDisposed()){var t=r.getZr();t[Rd]=!0,r.dispatchAction({type:"brushSelect",batch:e}),t[Rd]=!1}}function fw(r,e,t,a){for(var n=0,i=e.length;n<i;n++){var o=e[n];if(r.brushSelector(a,t,o.selectors,o))return!0}}function J8(r,e){var t=r.option.seriesIndex;return t!=null&&t!=="all"&&(z(t)?vt(t,e)<0:e!==t)}var j8={rect:function(r){return hw(r.range)},polygon:function(r){for(var e,t=r.range,a=0,n=t.length;a<n;a++){e=e||[[1/0,-1/0],[1/0,-1/0]];var i=t[a];i[0]<e[0][0]&&(e[0][0]=i[0]),i[0]>e[0][1]&&(e[0][1]=i[0]),i[1]<e[1][0]&&(e[1][0]=i[1]),i[1]>e[1][1]&&(e[1][1]=i[1])}return e&&hw(e)}};function hw(r){return new ht(r[0][0],r[1][0],r[0][1]-r[0][0],r[1][1]-r[1][0])}var tY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,a){this.ecModel=t,this.api=a,this.model,(this._brushController=new Ay(a.getZr())).on("brush",U(this._onBrush,this)).mount()},e.prototype.render=function(t,a,n,i){this.model=t,this._updateController(t,a,n,i)},e.prototype.updateTransform=function(t,a,n,i){VI(a),this._updateController(t,a,n,i)},e.prototype.updateVisual=function(t,a,n,i){this.updateTransform(t,a,n,i)},e.prototype.updateView=function(t,a,n,i){this._updateController(t,a,n,i)},e.prototype._updateController=function(t,a,n,i){(!i||i.$from!==t.id)&&this._brushController.setPanels(t.brushTargetManager.makePanelOpts(n)).enableBrush(t.brushOption).updateCovers(t.areas.slice())},e.prototype.dispose=function(){this._brushController.dispose()},e.prototype._onBrush=function(t){var a=this.model.id,n=this.model.brushTargetManager.setOutputRanges(t.areas,this.ecModel);(!t.isEnd||t.removeOnClick)&&this.api.dispatchAction({type:"brush",brushId:a,areas:rt(n),$from:a}),t.isEnd&&this.api.dispatchAction({type:"brushEnd",brushId:a,areas:rt(n),$from:a})},e.type="brush",e}(Ht);const eY=tY;var rY="#ddd",aY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.areas=[],t.brushOption={},t}return e.prototype.optionUpdated=function(t,a){var n=this.option;!a&&BI(n,t,["inBrush","outOfBrush"]);var i=n.inBrush=n.inBrush||{};n.outOfBrush=n.outOfBrush||{color:rY},i.hasOwnProperty("liftZ")||(i.liftZ=5)},e.prototype.setAreas=function(t){t&&(this.areas=G(t,function(a){return vw(this.option,a)},this))},e.prototype.setBrushOption=function(t){this.brushOption=vw(this.option,t),this.brushType=this.brushOption.brushType},e.type="brush",e.dependencies=["geo","grid","xAxis","yAxis","parallel","series"],e.defaultOption={seriesIndex:"all",brushType:"rect",brushMode:"single",transformable:!0,brushStyle:{borderWidth:1,color:"rgba(210,219,238,0.3)",borderColor:"#D2DBEE"},throttleType:"fixRate",throttleDelay:0,removeOnClick:!0,z:1e4},e}(Tt);function vw(r,e){return ft({brushType:r.brushType,brushMode:r.brushMode,transformable:r.transformable,brushStyle:new Ot(r.brushStyle).getItemStyle(),removeOnClick:r.removeOnClick,z:r.z},e,!0)}const nY=aY;var iY=["rect","polygon","lineX","lineY","keep","clear"],oY=function(r){k(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.render=function(t,a,n){var i,o,s;a.eachComponent({mainType:"brush"},function(l){i=l.brushType,o=l.brushOption.brushMode||"single",s=s||!!l.areas.length}),this._brushType=i,this._brushMode=o,C(t.get("type",!0),function(l){t.setIconStatus(l,(l==="keep"?o==="multiple":l==="clear"?s:l===i)?"emphasis":"normal")})},e.prototype.updateView=function(t,a,n){this.render(t,a,n)},e.prototype.getIcons=function(){var t=this.model,a=t.get("icon",!0),n={};return C(t.get("type",!0),function(i){a[i]&&(n[i]=a[i])}),n},e.prototype.onclick=function(t,a,n){var i=this._brushType,o=this._brushMode;n==="clear"?(a.dispatchAction({type:"axisAreaSelect",intervals:[]}),a.dispatchAction({type:"brush",command:"clear",areas:[]})):a.dispatchAction({type:"takeGlobalCursor",key:"brush",brushOption:{brushType:n==="keep"?i:i===n?!1:n,brushMode:n==="keep"?o==="multiple"?"single":"multiple":o}})},e.getDefaultOption=function(t){var a={show:!0,type:iY.slice(),icon:{rect:"M7.3,34.7 M0.4,10V-0.2h9.8 M89.6,10V-0.2h-9.8 M0.4,60v10.2h9.8 M89.6,60v10.2h-9.8 M12.3,22.4V10.5h13.1 M33.6,10.5h7.8 M49.1,10.5h7.8 M77.5,22.4V10.5h-13 M12.3,31.1v8.2 M77.7,31.1v8.2 M12.3,47.6v11.9h13.1 M33.6,59.5h7.6 M49.1,59.5 h7.7 M77.5,47.6v11.9h-13",polygon:"M55.2,34.9c1.7,0,3.1,1.4,3.1,3.1s-1.4,3.1-3.1,3.1 s-3.1-1.4-3.1-3.1S53.5,34.9,55.2,34.9z M50.4,51c1.7,0,3.1,1.4,3.1,3.1c0,1.7-1.4,3.1-3.1,3.1c-1.7,0-3.1-1.4-3.1-3.1 C47.3,52.4,48.7,51,50.4,51z M55.6,37.1l1.5-7.8 M60.1,13.5l1.6-8.7l-7.8,4 M59,19l-1,5.3 M24,16.1l6.4,4.9l6.4-3.3 M48.5,11.6 l-5.9,3.1 M19.1,12.8L9.7,5.1l1.1,7.7 M13.4,29.8l1,7.3l6.6,1.6 M11.6,18.4l1,6.1 M32.8,41.9 M26.6,40.4 M27.3,40.2l6.1,1.6 M49.9,52.1l-5.6-7.6l-4.9-1.2",lineX:"M15.2,30 M19.7,15.6V1.9H29 M34.8,1.9H40.4 M55.3,15.6V1.9H45.9 M19.7,44.4V58.1H29 M34.8,58.1H40.4 M55.3,44.4 V58.1H45.9 M12.5,20.3l-9.4,9.6l9.6,9.8 M3.1,29.9h16.5 M62.5,20.3l9.4,9.6L62.3,39.7 M71.9,29.9H55.4",lineY:"M38.8,7.7 M52.7,12h13.2v9 M65.9,26.6V32 M52.7,46.3h13.2v-9 M24.9,12H11.8v9 M11.8,26.6V32 M24.9,46.3H11.8v-9 M48.2,5.1l-9.3-9l-9.4,9.2 M38.9-3.9V12 M48.2,53.3l-9.3,9l-9.4-9.2 M38.9,62.3V46.4",keep:"M4,10.5V1h10.3 M20.7,1h6.1 M33,1h6.1 M55.4,10.5V1H45.2 M4,17.3v6.6 M55.6,17.3v6.6 M4,30.5V40h10.3 M20.7,40 h6.1 M33,40h6.1 M55.4,30.5V40H45.2 M21,18.9h62.9v48.6H21V18.9z",clear:"M22,14.7l30.9,31 M52.9,14.7L22,45.7 M4.7,16.8V4.2h13.1 M26,4.2h7.8 M41.6,4.2h7.8 M70.3,16.8V4.2H57.2 M4.7,25.9v8.6 M70.3,25.9v8.6 M4.7,43.2v12.6h13.1 M26,55.8h7.8 M41.6,55.8h7.8 M70.3,43.2v12.6H57.2"},title:t.getLocaleModel().get(["toolbox","brush","title"])};return a},e}(tr);const sY=oY;function lY(r){r.registerComponentView(eY),r.registerComponentModel(nY),r.registerPreprocessor($8),r.registerVisual(r.PRIORITY.VISUAL.BRUSH,q8),r.registerAction({type:"brush",event:"brush",update:"updateVisual"},function(e,t){t.eachComponent({mainType:"brush",query:e},function(a){a.setAreas(e.areas)})}),r.registerAction({type:"brushSelect",event:"brushSelected",update:"none"},Yt),r.registerAction({type:"brushEnd",event:"brushEnd",update:"none"},Yt),zi("brush",sY)}var uY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.layoutMode={type:"box",ignoreSize:!0},t}return e.type="title",e.defaultOption={z:6,show:!0,text:"",target:"blank",subtext:"",subtarget:"blank",left:0,top:0,backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",borderWidth:0,padding:5,itemGap:10,textStyle:{fontSize:18,fontWeight:"bold",color:"#464646"},subtextStyle:{fontSize:12,color:"#6E7079"}},e}(Tt),fY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,a,n){if(this.group.removeAll(),!!t.get("show")){var i=this.group,o=t.getModel("textStyle"),s=t.getModel("subtextStyle"),l=t.get("textAlign"),u=it(t.get("textBaseline"),t.get("textVerticalAlign")),f=new At({style:kt(o,{text:t.get("text"),fill:o.getTextColor()},{disableBox:!0}),z2:10}),h=f.getBoundingRect(),v=t.get("subtext"),c=new At({style:kt(s,{text:v,fill:s.getTextColor(),y:h.height+t.get("itemGap"),verticalAlign:"top"},{disableBox:!0}),z2:10}),p=t.get("link"),d=t.get("sublink"),g=t.get("triggerEvent",!0);f.silent=!p&&!g,c.silent=!d&&!g,p&&f.on("click",function(){hf(p,"_"+t.get("target"))}),d&&c.on("click",function(){hf(d,"_"+t.get("subtarget"))}),nt(f).eventData=nt(c).eventData=g?{componentType:"title",componentIndex:t.componentIndex}:null,i.add(f),v&&i.add(c);var y=i.getBoundingRect(),m=t.getBoxLayoutParams();m.width=y.width,m.height=y.height;var _=Jt(m,{width:n.getWidth(),height:n.getHeight()},t.get("padding"));l||(l=t.get("left")||t.get("right"),l==="middle"&&(l="center"),l==="right"?_.x+=_.width:l==="center"&&(_.x+=_.width/2)),u||(u=t.get("top")||t.get("bottom"),u==="center"&&(u="middle"),u==="bottom"?_.y+=_.height:u==="middle"&&(_.y+=_.height/2),u=u||"top"),i.x=_.x,i.y=_.y,i.markRedraw();var S={align:l,verticalAlign:u};f.setStyle(S),c.setStyle(S),y=i.getBoundingRect();var w=_.margin,x=t.getItemStyle(["color","opacity"]);x.fill=t.get("backgroundColor");var b=new wt({shape:{x:y.x-w[3],y:y.y-w[0],width:y.width+w[1]+w[3],height:y.height+w[0]+w[2],r:t.get("borderRadius")},style:x,subPixelOptimize:!0,silent:!0});i.add(b)}},e.type="title",e}(Ht);function hY(r){r.registerComponentModel(uY),r.registerComponentView(fY)}var cw=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.layoutMode="box",t}return e.prototype.init=function(t,a,n){this.mergeDefaultAndTheme(t,n),this._initData()},e.prototype.mergeOption=function(t){r.prototype.mergeOption.apply(this,arguments),this._initData()},e.prototype.setCurrentIndex=function(t){t==null&&(t=this.option.currentIndex);var a=this._data.count();this.option.loop?t=(t%a+a)%a:(t>=a&&(t=a-1),t<0&&(t=0)),this.option.currentIndex=t},e.prototype.getCurrentIndex=function(){return this.option.currentIndex},e.prototype.isIndexMax=function(){return this.getCurrentIndex()>=this._data.count()-1},e.prototype.setPlayState=function(t){this.option.autoPlay=!!t},e.prototype.getPlayState=function(){return!!this.option.autoPlay},e.prototype._initData=function(){var t=this.option,a=t.data||[],n=t.axisType,i=this._names=[],o;n==="category"?(o=[],C(a,function(u,f){var h=Qt(uo(u),""),v;tt(u)?(v=rt(u),v.value=f):v=f,o.push(v),i.push(h)})):o=a;var s={category:"ordinal",time:"time",value:"number"}[n]||"number",l=this._data=new be([{name:"value",type:s}],this);l.initData(o,i)},e.prototype.getData=function(){return this._data},e.prototype.getCategories=function(){if(this.get("axisType")==="category")return this._names.slice()},e.type="timeline",e.defaultOption={z:4,show:!0,axisType:"time",realtime:!0,left:"20%",top:null,right:"20%",bottom:0,width:null,height:40,padding:5,controlPosition:"left",autoPlay:!1,rewind:!1,loop:!0,playInterval:2e3,currentIndex:0,itemStyle:{},label:{color:"#000"},data:[]},e}(Tt),zI=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="timeline.slider",e.defaultOption=ja(cw.defaultOption,{backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",borderWidth:0,orient:"horizontal",inverse:!1,tooltip:{trigger:"item"},symbol:"circle",symbolSize:12,lineStyle:{show:!0,width:2,color:"#DAE1F5"},label:{position:"auto",show:!0,interval:"auto",rotate:0,color:"#A4B1D7"},itemStyle:{color:"#A4B1D7",borderWidth:1},checkpointStyle:{symbol:"circle",symbolSize:15,color:"#316bf3",borderColor:"#fff",borderWidth:2,shadowBlur:2,shadowOffsetX:1,shadowOffsetY:1,shadowColor:"rgba(0, 0, 0, 0.3)",animation:!0,animationDuration:300,animationEasing:"quinticInOut"},controlStyle:{show:!0,showPlayBtn:!0,showPrevBtn:!0,showNextBtn:!0,itemSize:24,itemGap:12,position:"left",playIcon:"path://M31.6,53C17.5,53,6,41.5,6,27.4S17.5,1.8,31.6,1.8C45.7,1.8,57.2,13.3,57.2,27.4S45.7,53,31.6,53z M31.6,3.3 C18.4,3.3,7.5,14.1,7.5,27.4c0,13.3,10.8,24.1,24.1,24.1C44.9,51.5,55.7,40.7,55.7,27.4C55.7,14.1,44.9,3.3,31.6,3.3z M24.9,21.3 c0-2.2,1.6-3.1,3.5-2l10.5,6.1c1.899,1.1,1.899,2.9,0,4l-10.5,6.1c-1.9,1.1-3.5,0.2-3.5-2V21.3z",stopIcon:"path://M30.9,53.2C16.8,53.2,5.3,41.7,5.3,27.6S16.8,2,30.9,2C45,2,56.4,13.5,56.4,27.6S45,53.2,30.9,53.2z M30.9,3.5C17.6,3.5,6.8,14.4,6.8,27.6c0,13.3,10.8,24.1,24.101,24.1C44.2,51.7,55,40.9,55,27.6C54.9,14.4,44.1,3.5,30.9,3.5z M36.9,35.8c0,0.601-0.4,1-0.9,1h-1.3c-0.5,0-0.9-0.399-0.9-1V19.5c0-0.6,0.4-1,0.9-1H36c0.5,0,0.9,0.4,0.9,1V35.8z M27.8,35.8 c0,0.601-0.4,1-0.9,1h-1.3c-0.5,0-0.9-0.399-0.9-1V19.5c0-0.6,0.4-1,0.9-1H27c0.5,0,0.9,0.4,0.9,1L27.8,35.8L27.8,35.8z",nextIcon:"M2,18.5A1.52,1.52,0,0,1,.92,18a1.49,1.49,0,0,1,0-2.12L7.81,9.36,1,3.11A1.5,1.5,0,1,1,3,.89l8,7.34a1.48,1.48,0,0,1,.49,1.09,1.51,1.51,0,0,1-.46,1.1L3,18.08A1.5,1.5,0,0,1,2,18.5Z",prevIcon:"M10,.5A1.52,1.52,0,0,1,11.08,1a1.49,1.49,0,0,1,0,2.12L4.19,9.64,11,15.89a1.5,1.5,0,1,1-2,2.22L1,10.77A1.48,1.48,0,0,1,.5,9.68,1.51,1.51,0,0,1,1,8.58L9,.92A1.5,1.5,0,0,1,10,.5Z",prevBtnSize:18,nextBtnSize:18,color:"#A4B1D7",borderColor:"#A4B1D7",borderWidth:1},emphasis:{label:{show:!0,color:"#6f778d"},itemStyle:{color:"#316BF3"},controlStyle:{color:"#316BF3",borderColor:"#316BF3",borderWidth:2}},progress:{lineStyle:{color:"#316BF3"},itemStyle:{color:"#316BF3"},label:{color:"#6f778d"}},data:[]}),e}(cw);Kt(zI,Rg.prototype);const vY=zI;var cY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="timeline",e}(Ht);const pY=cY;var dY=function(r){k(e,r);function e(t,a,n,i){var o=r.call(this,t,a,n)||this;return o.type=i||"value",o}return e.prototype.getLabelModel=function(){return this.model.getModel("label")},e.prototype.isHorizontal=function(){return this.model.get("orient")==="horizontal"},e}(wr);const gY=dY;var Gc=Math.PI,pw=bt(),yY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,a){this.api=a},e.prototype.render=function(t,a,n){if(this.model=t,this.api=n,this.ecModel=a,this.group.removeAll(),t.get("show",!0)){var i=this._layout(t,n),o=this._createGroup("_mainGroup"),s=this._createGroup("_labelGroup"),l=this._axis=this._createAxis(i,t);t.formatTooltip=function(u){var f=l.scale.getLabel({value:u});return ae("nameValue",{noName:!0,value:f})},C(["AxisLine","AxisTick","Control","CurrentPointer"],function(u){this["_render"+u](i,o,l,t)},this),this._renderAxisLabel(i,s,l,t),this._position(i,t)}this._doPlayStop(),this._updateTicksStatus()},e.prototype.remove=function(){this._clearTimer(),this.group.removeAll()},e.prototype.dispose=function(){this._clearTimer()},e.prototype._layout=function(t,a){var n=t.get(["label","position"]),i=t.get("orient"),o=_Y(t,a),s;n==null||n==="auto"?s=i==="horizontal"?o.y+o.height/2<a.getHeight()/2?"-":"+":o.x+o.width/2<a.getWidth()/2?"+":"-":$(n)?s={horizontal:{top:"-",bottom:"+"},vertical:{left:"-",right:"+"}}[i][n]:s=n;var l={horizontal:"center",vertical:s>=0||s==="+"?"left":"right"},u={horizontal:s>=0||s==="+"?"top":"bottom",vertical:"middle"},f={horizontal:0,vertical:Gc/2},h=i==="vertical"?o.height:o.width,v=t.getModel("controlStyle"),c=v.get("show",!0),p=c?v.get("itemSize"):0,d=c?v.get("itemGap"):0,g=p+d,y=t.get(["label","rotate"])||0;y=y*Gc/180;var m,_,S,w=v.get("position",!0),x=c&&v.get("showPlayBtn",!0),b=c&&v.get("showPrevBtn",!0),T=c&&v.get("showNextBtn",!0),A=0,D=h;w==="left"||w==="bottom"?(x&&(m=[0,0],A+=g),b&&(_=[A,0],A+=g),T&&(S=[D-p,0],D-=g)):(x&&(m=[D-p,0],D-=g),b&&(_=[0,0],A+=g),T&&(S=[D-p,0],D-=g));var M=[A,D];return t.get("inverse")&&M.reverse(),{viewRect:o,mainLength:h,orient:i,rotation:f[i],labelRotation:y,labelPosOpt:s,labelAlign:t.get(["label","align"])||l[i],labelBaseline:t.get(["label","verticalAlign"])||t.get(["label","baseline"])||u[i],playPosition:m,prevBtnPosition:_,nextBtnPosition:S,axisExtent:M,controlSize:p,controlGap:d}},e.prototype._position=function(t,a){var n=this._mainGroup,i=this._labelGroup,o=t.viewRect;if(t.orient==="vertical"){var s=Fe(),l=o.x,u=o.y+o.height;Gr(s,s,[-l,-u]),oi(s,s,-Gc/2),Gr(s,s,[l,u]),o=o.clone(),o.applyTransform(s)}var f=m(o),h=m(n.getBoundingRect()),v=m(i.getBoundingRect()),c=[n.x,n.y],p=[i.x,i.y];p[0]=c[0]=f[0][0];var d=t.labelPosOpt;if(d==null||$(d)){var g=d==="+"?0:1;_(c,h,f,1,g),_(p,v,f,1,1-g)}else{var g=d>=0?0:1;_(c,h,f,1,g),p[1]=c[1]+d}n.setPosition(c),i.setPosition(p),n.rotation=i.rotation=t.rotation,y(n),y(i);function y(S){S.originX=f[0][0]-S.x,S.originY=f[1][0]-S.y}function m(S){return[[S.x,S.x+S.width],[S.y,S.y+S.height]]}function _(S,w,x,b,T){S[b]+=x[b][T]-w[b][T]}},e.prototype._createAxis=function(t,a){var n=a.getData(),i=a.get("axisType"),o=mY(a,i);o.getTicks=function(){return n.mapArray(["value"],function(u){return{value:u}})};var s=n.getDataExtent("value");o.setExtent(s[0],s[1]),o.calcNiceTicks();var l=new gY("value",o,t.axisExtent,i);return l.model=a,l},e.prototype._createGroup=function(t){var a=this[t]=new at;return this.group.add(a),a},e.prototype._renderAxisLine=function(t,a,n,i){var o=n.getExtent();if(i.get(["lineStyle","show"])){var s=new te({shape:{x1:o[0],y1:0,x2:o[1],y2:0},style:V({lineCap:"round"},i.getModel("lineStyle").getLineStyle()),silent:!0,z2:1});a.add(s);var l=this._progressLine=new te({shape:{x1:o[0],x2:this._currentPointer?this._currentPointer.x:o[0],y1:0,y2:0},style:j({lineCap:"round",lineWidth:s.style.lineWidth},i.getModel(["progress","lineStyle"]).getLineStyle()),silent:!0,z2:1});a.add(l)}},e.prototype._renderAxisTick=function(t,a,n,i){var o=this,s=i.getData(),l=n.scale.getTicks();this._tickSymbols=[],C(l,function(u){var f=n.dataToCoord(u.value),h=s.getItemModel(u.value),v=h.getModel("itemStyle"),c=h.getModel(["emphasis","itemStyle"]),p=h.getModel(["progress","itemStyle"]),d={x:f,y:0,onclick:U(o._changeTimeline,o,u.value)},g=dw(h,v,a,d);g.ensureState("emphasis").style=c.getItemStyle(),g.ensureState("progress").style=p.getItemStyle(),Zn(g);var y=nt(g);h.get("tooltip")?(y.dataIndex=u.value,y.dataModel=i):y.dataIndex=y.dataModel=null,o._tickSymbols.push(g)})},e.prototype._renderAxisLabel=function(t,a,n,i){var o=this,s=n.getLabelModel();if(s.get("show")){var l=i.getData(),u=n.getViewLabels();this._tickLabels=[],C(u,function(f){var h=f.tickValue,v=l.getItemModel(h),c=v.getModel("label"),p=v.getModel(["emphasis","label"]),d=v.getModel(["progress","label"]),g=n.dataToCoord(f.tickValue),y=new At({x:g,y:0,rotation:t.labelRotation-t.rotation,onclick:U(o._changeTimeline,o,h),silent:!1,style:kt(c,{text:f.formattedLabel,align:t.labelAlign,verticalAlign:t.labelBaseline})});y.ensureState("emphasis").style=kt(p),y.ensureState("progress").style=kt(d),a.add(y),Zn(y),pw(y).dataIndex=h,o._tickLabels.push(y)})}},e.prototype._renderControl=function(t,a,n,i){var o=t.controlSize,s=t.rotation,l=i.getModel("controlStyle").getItemStyle(),u=i.getModel(["emphasis","controlStyle"]).getItemStyle(),f=i.getPlayState(),h=i.get("inverse",!0);v(t.nextBtnPosition,"next",U(this._changeTimeline,this,h?"-":"+")),v(t.prevBtnPosition,"prev",U(this._changeTimeline,this,h?"+":"-")),v(t.playPosition,f?"stop":"play",U(this._handlePlayClick,this,!f),!0);function v(c,p,d,g){if(c){var y=_r(it(i.get(["controlStyle",p+"BtnSize"]),o),o),m=[0,-y/2,y,y],_=SY(i,p+"Icon",m,{x:c[0],y:c[1],originX:o/2,originY:0,rotation:g?-s:0,rectHover:!0,style:l,onclick:d});_.ensureState("emphasis").style=u,a.add(_),Zn(_)}}},e.prototype._renderCurrentPointer=function(t,a,n,i){var o=i.getData(),s=i.getCurrentIndex(),l=o.getItemModel(s).getModel("checkpointStyle"),u=this,f={onCreate:function(h){h.draggable=!0,h.drift=U(u._handlePointerDrag,u),h.ondragend=U(u._handlePointerDragend,u),gw(h,u._progressLine,s,n,i,!0)},onUpdate:function(h){gw(h,u._progressLine,s,n,i)}};this._currentPointer=dw(l,l,this._mainGroup,{},this._currentPointer,f)},e.prototype._handlePlayClick=function(t){this._clearTimer(),this.api.dispatchAction({type:"timelinePlayChange",playState:t,from:this.uid})},e.prototype._handlePointerDrag=function(t,a,n){this._clearTimer(),this._pointerChangeTimeline([n.offsetX,n.offsetY])},e.prototype._handlePointerDragend=function(t){this._pointerChangeTimeline([t.offsetX,t.offsetY],!0)},e.prototype._pointerChangeTimeline=function(t,a){var n=this._toAxisCoord(t)[0],i=this._axis,o=ar(i.getExtent().slice());n>o[1]&&(n=o[1]),n<o[0]&&(n=o[0]),this._currentPointer.x=n,this._currentPointer.markRedraw();var s=this._progressLine;s&&(s.shape.x2=n,s.dirty());var l=this._findNearestTick(n),u=this.model;(a||l!==u.getCurrentIndex()&&u.get("realtime"))&&this._changeTimeline(l)},e.prototype._doPlayStop=function(){var t=this;this._clearTimer(),this.model.getPlayState()&&(this._timer=setTimeout(function(){var a=t.model;t._changeTimeline(a.getCurrentIndex()+(a.get("rewind",!0)?-1:1))},this.model.get("playInterval")))},e.prototype._toAxisCoord=function(t){var a=this._mainGroup.getLocalTransform();return mr(t,a,!0)},e.prototype._findNearestTick=function(t){var a=this.model.getData(),n=1/0,i,o=this._axis;return a.each(["value"],function(s,l){var u=o.dataToCoord(s),f=Math.abs(u-t);f<n&&(n=f,i=l)}),i},e.prototype._clearTimer=function(){this._timer&&(clearTimeout(this._timer),this._timer=null)},e.prototype._changeTimeline=function(t){var a=this.model.getCurrentIndex();t==="+"?t=a+1:t==="-"&&(t=a-1),this.api.dispatchAction({type:"timelineChange",currentIndex:t,from:this.uid})},e.prototype._updateTicksStatus=function(){var t=this.model.getCurrentIndex(),a=this._tickSymbols,n=this._tickLabels;if(a)for(var i=0;i<a.length;i++)a&&a[i]&&a[i].toggleState("progress",i<t);if(n)for(var i=0;i<n.length;i++)n&&n[i]&&n[i].toggleState("progress",pw(n[i]).dataIndex<=t)},e.type="timeline.slider",e}(pY);function mY(r,e){if(e=e||r.get("type"),e)switch(e){case"category":return new $g({ordinalMeta:r.getCategories(),extent:[1/0,-1/0]});case"time":return new HC({locale:r.ecModel.getLocaleModel(),useUTC:r.ecModel.get("useUTC")});default:return new Za}}function _Y(r,e){return Jt(r.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()},r.get("padding"))}function SY(r,e,t,a){var n=a.style,i=ul(r.get(["controlStyle",e]),a||{},new ht(t[0],t[1],t[2],t[3]));return n&&i.setStyle(n),i}function dw(r,e,t,a,n,i){var o=e.get("color");if(n)n.setColor(o),t.add(n),i&&i.onUpdate(n);else{var s=r.get("symbol");n=qt(s,-1,-1,2,2,o),n.setStyle("strokeNoScale",!0),t.add(n),i&&i.onCreate(n)}var l=e.getItemStyle(["color"]);n.setStyle(l),a=ft({rectHover:!0,z2:100},a,!0);var u=bo(r.get("symbolSize"));a.scaleX=u[0]/2,a.scaleY=u[1]/2;var f=ui(r.get("symbolOffset"),u);f&&(a.x=(a.x||0)+f[0],a.y=(a.y||0)+f[1]);var h=r.get("symbolRotate");return a.rotation=(h||0)*Math.PI/180||0,n.attr(a),n.updateTransform(),n}function gw(r,e,t,a,n,i){if(!r.dragging){var o=n.getModel("checkpointStyle"),s=a.dataToCoord(n.getData().get("value",t));if(i||!o.get("animation",!0))r.attr({x:s,y:0}),e&&e.attr({shape:{x2:s}});else{var l={duration:o.get("animationDuration",!0),easing:o.get("animationEasing",!0)};r.stopAnimation(null,!0),r.animateTo({x:s,y:0},l),e&&e.animateTo({shape:{x2:s}},l)}}}const xY=yY;function wY(r){r.registerAction({type:"timelineChange",event:"timelineChanged",update:"prepareAndUpdate"},function(e,t,a){var n=t.getComponent("timeline");return n&&e.currentIndex!=null&&(n.setCurrentIndex(e.currentIndex),!n.get("loop",!0)&&n.isIndexMax()&&n.getPlayState()&&(n.setPlayState(!1),a.dispatchAction({type:"timelinePlayChange",playState:!1,from:e.from}))),t.resetOption("timeline",{replaceMerge:n.get("replaceMerge",!0)}),j({currentIndex:n.option.currentIndex},e)}),r.registerAction({type:"timelinePlayChange",event:"timelinePlayChanged",update:"update"},function(e,t){var a=t.getComponent("timeline");a&&e.playState!=null&&a.setPlayState(e.playState)})}function bY(r){var e=r&&r.timeline;z(e)||(e=e?[e]:[]),C(e,function(t){t&&TY(t)})}function TY(r){var e=r.type,t={number:"value",time:"time"};if(t[e]&&(r.axisType=t[e],delete r.type),yw(r),kn(r,"controlPosition")){var a=r.controlStyle||(r.controlStyle={});kn(a,"position")||(a.position=r.controlPosition),a.position==="none"&&!kn(a,"show")&&(a.show=!1,delete a.position),delete r.controlPosition}C(r.data||[],function(n){tt(n)&&!z(n)&&(!kn(n,"value")&&kn(n,"name")&&(n.value=n.name),yw(n))})}function yw(r){var e=r.itemStyle||(r.itemStyle={}),t=e.emphasis||(e.emphasis={}),a=r.label||r.label||{},n=a.normal||(a.normal={}),i={normal:1,emphasis:1};C(a,function(o,s){!i[s]&&!kn(n,s)&&(n[s]=o)}),t.label&&!kn(a,"emphasis")&&(a.emphasis=t.label,delete t.label)}function kn(r,e){return r.hasOwnProperty(e)}function AY(r){r.registerComponentModel(vY),r.registerComponentView(xY),r.registerSubTypeDefaulter("timeline",function(){return"slider"}),wY(r),r.registerPreprocessor(bY)}function Xy(r,e){if(!r)return!1;for(var t=z(r)?r:[r],a=0;a<t.length;a++)if(t[a]&&t[a][e])return!0;return!1}function wu(r){Jn(r,"label",["show"])}var bu=bt(),GI=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.createdBySelf=!1,t}return e.prototype.init=function(t,a,n){this.mergeDefaultAndTheme(t,n),this._mergeOption(t,n,!1,!0)},e.prototype.isAnimationEnabled=function(){if(mt.node)return!1;var t=this.__hostSeries;return this.getShallow("animation")&&t&&t.isAnimationEnabled()},e.prototype.mergeOption=function(t,a){this._mergeOption(t,a,!1,!1)},e.prototype._mergeOption=function(t,a,n,i){var o=this.mainType;n||a.eachSeries(function(s){var l=s.get(this.mainType,!0),u=bu(s)[o];if(!l||!l.data){bu(s)[o]=null;return}u?u._mergeOption(l,a,!0):(i&&wu(l),C(l.data,function(f){f instanceof Array?(wu(f[0]),wu(f[1])):wu(f)}),u=this.createMarkerModelFromSeries(l,this,a),V(u,{mainType:this.mainType,seriesIndex:s.seriesIndex,name:s.name,createdBySelf:!0}),u.__hostSeries=s),bu(s)[o]=u},this)},e.prototype.formatTooltip=function(t,a,n){var i=this.getData(),o=this.getRawValue(t),s=i.getName(t);return ae("section",{header:this.name,blocks:[ae("nameValue",{name:s,value:o,noName:!s,noValue:o==null})]})},e.prototype.getData=function(){return this._data},e.prototype.setData=function(t){this._data=t},e.getMarkerModelFromSeries=function(t,a){return bu(t)[a]},e.type="marker",e.dependencies=["series","grid","polar","geo"],e}(Tt);Kt(GI,Rg.prototype);const Ka=GI;var CY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.createMarkerModelFromSeries=function(t,a,n){return new e(t,a,n)},e.type="markPoint",e.defaultOption={z:5,symbol:"pin",symbolSize:50,tooltip:{trigger:"item"},label:{show:!0,position:"inside"},itemStyle:{borderWidth:2},emphasis:{label:{show:!0}}},e}(Ka);const DY=CY;function Ed(r){return!(isNaN(parseFloat(r.x))&&isNaN(parseFloat(r.y)))}function MY(r){return!isNaN(parseFloat(r.x))&&!isNaN(parseFloat(r.y))}function Tu(r,e,t,a,n,i){var o=[],s=Ya(e,a),l=s?e.getCalculationInfo("stackResultDimension"):a,u=qy(e,l,r),f=e.indicesOfNearest(l,u)[0];o[n]=e.get(t,f),o[i]=e.get(l,f);var h=e.get(a,f),v=Er(e.get(a,f));return v=Math.min(v,20),v>=0&&(o[i]=+o[i].toFixed(v)),[o,h]}var Fc={min:ot(Tu,"min"),max:ot(Tu,"max"),average:ot(Tu,"average"),median:ot(Tu,"median")};function rl(r,e){if(e){var t=r.getData(),a=r.coordinateSystem,n=a&&a.dimensions;if(!MY(e)&&!z(e.coord)&&z(n)){var i=FI(e,t,a,r);if(e=rt(e),e.type&&Fc[e.type]&&i.baseAxis&&i.valueAxis){var o=vt(n,i.baseAxis.dim),s=vt(n,i.valueAxis.dim),l=Fc[e.type](t,i.baseDataDim,i.valueDataDim,o,s);e.coord=l[0],e.value=l[1]}else e.coord=[e.xAxis!=null?e.xAxis:e.radiusAxis,e.yAxis!=null?e.yAxis:e.angleAxis]}if(e.coord==null||!z(n))e.coord=[];else for(var u=e.coord,f=0;f<2;f++)Fc[u[f]]&&(u[f]=qy(t,t.mapDimension(n[f]),u[f]));return e}}function FI(r,e,t,a){var n={};return r.valueIndex!=null||r.valueDim!=null?(n.valueDataDim=r.valueIndex!=null?e.getDimension(r.valueIndex):r.valueDim,n.valueAxis=t.getAxis(IY(a,n.valueDataDim)),n.baseAxis=t.getOtherAxis(n.valueAxis),n.baseDataDim=e.mapDimension(n.baseAxis.dim)):(n.baseAxis=a.getBaseAxis(),n.valueAxis=t.getOtherAxis(n.baseAxis),n.baseDataDim=e.mapDimension(n.baseAxis.dim),n.valueDataDim=e.mapDimension(n.valueAxis.dim)),n}function IY(r,e){var t=r.getData().getDimensionInfo(e);return t&&t.coordDim}function al(r,e){return r&&r.containData&&e.coord&&!Ed(e)?r.containData(e.coord):!0}function LY(r,e,t){return r&&r.containZone&&e.coord&&t.coord&&!Ed(e)&&!Ed(t)?r.containZone(e.coord,t.coord):!0}function HI(r,e){return r?function(t,a,n,i){var o=i<2?t.coord&&t.coord[i]:t.value;return za(o,e[i])}:function(t,a,n,i){return za(t.value,e[i])}}function qy(r,e,t){if(t==="average"){var a=0,n=0;return r.each(e,function(i,o){isNaN(i)||(a+=i,n++)}),a/n}else return t==="median"?r.getMedian(e):r.getDataExtent(e)[t==="max"?1:0]}var Hc=bt(),PY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(){this.markerGroupMap=Z()},e.prototype.render=function(t,a,n){var i=this,o=this.markerGroupMap;o.each(function(s){Hc(s).keep=!1}),a.eachSeries(function(s){var l=Ka.getMarkerModelFromSeries(s,i.type);l&&i.renderSeries(s,l,a,n)}),o.each(function(s){!Hc(s).keep&&i.group.remove(s.group)})},e.prototype.markKeep=function(t){Hc(t).keep=!0},e.prototype.toggleBlurSeries=function(t,a){var n=this;C(t,function(i){var o=Ka.getMarkerModelFromSeries(i,n.type);if(o){var s=o.getData();s.eachItemGraphicEl(function(l){l&&(a?xT(l):fg(l))})}})},e.type="marker",e}(Ht);const Ky=PY;function mw(r,e,t){var a=e.coordinateSystem;r.each(function(n){var i=r.getItemModel(n),o,s=W(i.get("x"),t.getWidth()),l=W(i.get("y"),t.getHeight());if(!isNaN(s)&&!isNaN(l))o=[s,l];else if(e.getMarkerPosition)o=e.getMarkerPosition(r.getValues(r.dimensions,n));else if(a){var u=r.get(a.dimensions[0],n),f=r.get(a.dimensions[1],n);o=a.dataToPoint([u,f])}isNaN(s)||(o[0]=s),isNaN(l)||(o[1]=l),r.setItemLayout(n,o)})}var RY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.updateTransform=function(t,a,n){a.eachSeries(function(i){var o=Ka.getMarkerModelFromSeries(i,"markPoint");o&&(mw(o.getData(),i,n),this.markerGroupMap.get(i.id).updateLayout())},this)},e.prototype.renderSeries=function(t,a,n,i){var o=t.coordinateSystem,s=t.id,l=t.getData(),u=this.markerGroupMap,f=u.get(s)||u.set(s,new gl),h=EY(o,t,a);a.setData(h),mw(a.getData(),t,i),h.each(function(v){var c=h.getItemModel(v),p=c.getShallow("symbol"),d=c.getShallow("symbolSize"),g=c.getShallow("symbolRotate"),y=c.getShallow("symbolOffset"),m=c.getShallow("symbolKeepAspect");if(K(p)||K(d)||K(g)||K(y)){var _=a.getRawValue(v),S=a.getDataParams(v);K(p)&&(p=p(_,S)),K(d)&&(d=d(_,S)),K(g)&&(g=g(_,S)),K(y)&&(y=y(_,S))}var w=c.getModel("itemStyle").getItemStyle(),x=hl(l,"color");w.fill||(w.fill=x),h.setItemVisual(v,{symbol:p,symbolSize:d,symbolRotate:g,symbolOffset:y,symbolKeepAspect:m,style:w})}),f.updateData(h),this.group.add(f.group),h.eachItemGraphicEl(function(v){v.traverse(function(c){nt(c).dataModel=a})}),this.markKeep(f),f.group.silent=a.get("silent")||t.get("silent")},e.type="markPoint",e}(Ky);function EY(r,e,t){var a;r?a=G(r&&r.dimensions,function(s){var l=e.getData().getDimensionInfo(e.getData().mapDimension(s))||{};return V(V({},l),{name:s,ordinalMeta:null})}):a=[{name:"value",type:"float"}];var n=new be(a,t),i=G(t.get("data"),ot(rl,e));r&&(i=Lt(i,ot(al,r)));var o=HI(!!r,a);return n.initData(i,null,o),n}const kY=RY;function OY(r){r.registerComponentModel(DY),r.registerComponentView(kY),r.registerPreprocessor(function(e){Xy(e.series,"markPoint")&&(e.markPoint=e.markPoint||{})})}var NY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.createMarkerModelFromSeries=function(t,a,n){return new e(t,a,n)},e.type="markLine",e.defaultOption={z:5,symbol:["circle","arrow"],symbolSize:[8,16],symbolOffset:0,precision:2,tooltip:{trigger:"item"},label:{show:!0,position:"end",distance:5},lineStyle:{type:"dashed"},emphasis:{label:{show:!0},lineStyle:{width:3}},animationEasing:"linear"},e}(Ka);const BY=NY;var Au=bt(),VY=function(r,e,t,a){var n=r.getData(),i;if(z(a))i=a;else{var o=a.type;if(o==="min"||o==="max"||o==="average"||o==="median"||a.xAxis!=null||a.yAxis!=null){var s=void 0,l=void 0;if(a.yAxis!=null||a.xAxis!=null)s=e.getAxis(a.yAxis!=null?"y":"x"),l=ie(a.yAxis,a.xAxis);else{var u=FI(a,n,e,r);s=u.valueAxis;var f=MC(n,u.valueDataDim);l=qy(n,f,o)}var h=s.dim==="x"?0:1,v=1-h,c=rt(a),p={coord:[]};c.type=null,c.coord=[],c.coord[v]=-1/0,p.coord[v]=1/0;var d=t.get("precision");d>=0&&Ct(l)&&(l=+l.toFixed(Math.min(d,20))),c.coord[h]=p.coord[h]=l,i=[c,p,{type:o,valueIndex:a.valueIndex,value:l}]}else i=[]}var g=[rl(r,i[0]),rl(r,i[1]),V({},i[2])];return g[2].type=g[2].type||null,ft(g[2],g[0]),ft(g[2],g[1]),g};function Nf(r){return!isNaN(r)&&!isFinite(r)}function _w(r,e,t,a){var n=1-r,i=a.dimensions[r];return Nf(e[n])&&Nf(t[n])&&e[r]===t[r]&&a.getAxis(i).containData(e[r])}function zY(r,e){if(r.type==="cartesian2d"){var t=e[0].coord,a=e[1].coord;if(t&&a&&(_w(1,t,a,r)||_w(0,t,a,r)))return!0}return al(r,e[0])&&al(r,e[1])}function Wc(r,e,t,a,n){var i=a.coordinateSystem,o=r.getItemModel(e),s,l=W(o.get("x"),n.getWidth()),u=W(o.get("y"),n.getHeight());if(!isNaN(l)&&!isNaN(u))s=[l,u];else{if(a.getMarkerPosition)s=a.getMarkerPosition(r.getValues(r.dimensions,e));else{var f=i.dimensions,h=r.get(f[0],e),v=r.get(f[1],e);s=i.dataToPoint([h,v])}if(hi(i,"cartesian2d")){var c=i.getAxis("x"),p=i.getAxis("y"),f=i.dimensions;Nf(r.get(f[0],e))?s[0]=c.toGlobalCoord(c.getExtent()[t?0:1]):Nf(r.get(f[1],e))&&(s[1]=p.toGlobalCoord(p.getExtent()[t?0:1]))}isNaN(l)||(s[0]=l),isNaN(u)||(s[1]=u)}r.setItemLayout(e,s)}var GY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.updateTransform=function(t,a,n){a.eachSeries(function(i){var o=Ka.getMarkerModelFromSeries(i,"markLine");if(o){var s=o.getData(),l=Au(o).from,u=Au(o).to;l.each(function(f){Wc(l,f,!0,i,n),Wc(u,f,!1,i,n)}),s.each(function(f){s.setItemLayout(f,[l.getItemLayout(f),u.getItemLayout(f)])}),this.markerGroupMap.get(i.id).updateLayout()}},this)},e.prototype.renderSeries=function(t,a,n,i){var o=t.coordinateSystem,s=t.id,l=t.getData(),u=this.markerGroupMap,f=u.get(s)||u.set(s,new _y);this.group.add(f.group);var h=FY(o,t,a),v=h.from,c=h.to,p=h.line;Au(a).from=v,Au(a).to=c,a.setData(p);var d=a.get("symbol"),g=a.get("symbolSize"),y=a.get("symbolRotate"),m=a.get("symbolOffset");z(d)||(d=[d,d]),z(g)||(g=[g,g]),z(y)||(y=[y,y]),z(m)||(m=[m,m]),h.from.each(function(S){_(v,S,!0),_(c,S,!1)}),p.each(function(S){var w=p.getItemModel(S).getModel("lineStyle").getLineStyle();p.setItemLayout(S,[v.getItemLayout(S),c.getItemLayout(S)]),w.stroke==null&&(w.stroke=v.getItemVisual(S,"style").fill),p.setItemVisual(S,{fromSymbolKeepAspect:v.getItemVisual(S,"symbolKeepAspect"),fromSymbolOffset:v.getItemVisual(S,"symbolOffset"),fromSymbolRotate:v.getItemVisual(S,"symbolRotate"),fromSymbolSize:v.getItemVisual(S,"symbolSize"),fromSymbol:v.getItemVisual(S,"symbol"),toSymbolKeepAspect:c.getItemVisual(S,"symbolKeepAspect"),toSymbolOffset:c.getItemVisual(S,"symbolOffset"),toSymbolRotate:c.getItemVisual(S,"symbolRotate"),toSymbolSize:c.getItemVisual(S,"symbolSize"),toSymbol:c.getItemVisual(S,"symbol"),style:w})}),f.updateData(p),h.line.eachItemGraphicEl(function(S){nt(S).dataModel=a,S.traverse(function(w){nt(w).dataModel=a})});function _(S,w,x){var b=S.getItemModel(w);Wc(S,w,x,t,i);var T=b.getModel("itemStyle").getItemStyle();T.fill==null&&(T.fill=hl(l,"color")),S.setItemVisual(w,{symbolKeepAspect:b.get("symbolKeepAspect"),symbolOffset:it(b.get("symbolOffset",!0),m[x?0:1]),symbolRotate:it(b.get("symbolRotate",!0),y[x?0:1]),symbolSize:it(b.get("symbolSize"),g[x?0:1]),symbol:it(b.get("symbol",!0),d[x?0:1]),style:T})}this.markKeep(f),f.group.silent=a.get("silent")||t.get("silent")},e.type="markLine",e}(Ky);function FY(r,e,t){var a;r?a=G(r&&r.dimensions,function(u){var f=e.getData().getDimensionInfo(e.getData().mapDimension(u))||{};return V(V({},f),{name:u,ordinalMeta:null})}):a=[{name:"value",type:"float"}];var n=new be(a,t),i=new be(a,t),o=new be([],t),s=G(t.get("data"),ot(VY,e,r,t));r&&(s=Lt(s,ot(zY,r)));var l=HI(!!r,a);return n.initData(G(s,function(u){return u[0]}),null,l),i.initData(G(s,function(u){return u[1]}),null,l),o.initData(G(s,function(u){return u[2]})),o.hasItemOption=!0,{from:n,to:i,line:o}}const HY=GY;function WY(r){r.registerComponentModel(BY),r.registerComponentView(HY),r.registerPreprocessor(function(e){Xy(e.series,"markLine")&&(e.markLine=e.markLine||{})})}var $Y=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.createMarkerModelFromSeries=function(t,a,n){return new e(t,a,n)},e.type="markArea",e.defaultOption={z:1,tooltip:{trigger:"item"},animation:!1,label:{show:!0,position:"top"},itemStyle:{borderWidth:0},emphasis:{label:{show:!0,position:"top"}}},e}(Ka);const UY=$Y;var Cu=bt(),YY=function(r,e,t,a){var n=a[0],i=a[1];if(!(!n||!i)){var o=rl(r,n),s=rl(r,i),l=o.coord,u=s.coord;l[0]=ie(l[0],-1/0),l[1]=ie(l[1],-1/0),u[0]=ie(u[0],1/0),u[1]=ie(u[1],1/0);var f=Ud([{},o,s]);return f.coord=[o.coord,s.coord],f.x0=o.x,f.y0=o.y,f.x1=s.x,f.y1=s.y,f}};function Bf(r){return!isNaN(r)&&!isFinite(r)}function Sw(r,e,t,a){var n=1-r;return Bf(e[n])&&Bf(t[n])}function ZY(r,e){var t=e.coord[0],a=e.coord[1],n={coord:t,x:e.x0,y:e.y0},i={coord:a,x:e.x1,y:e.y1};return hi(r,"cartesian2d")?t&&a&&(Sw(1,t,a)||Sw(0,t,a))?!0:LY(r,n,i):al(r,n)||al(r,i)}function xw(r,e,t,a,n){var i=a.coordinateSystem,o=r.getItemModel(e),s,l=W(o.get(t[0]),n.getWidth()),u=W(o.get(t[1]),n.getHeight());if(!isNaN(l)&&!isNaN(u))s=[l,u];else{if(a.getMarkerPosition){var f=r.getValues(["x0","y0"],e),h=r.getValues(["x1","y1"],e),v=i.clampData(f),c=i.clampData(h),p=[];t[0]==="x0"?p[0]=v[0]>c[0]?h[0]:f[0]:p[0]=v[0]>c[0]?f[0]:h[0],t[1]==="y0"?p[1]=v[1]>c[1]?h[1]:f[1]:p[1]=v[1]>c[1]?f[1]:h[1],s=a.getMarkerPosition(p,t,!0)}else{var d=r.get(t[0],e),g=r.get(t[1],e),y=[d,g];i.clampData&&i.clampData(y,y),s=i.dataToPoint(y,!0)}if(hi(i,"cartesian2d")){var m=i.getAxis("x"),_=i.getAxis("y"),d=r.get(t[0],e),g=r.get(t[1],e);Bf(d)?s[0]=m.toGlobalCoord(m.getExtent()[t[0]==="x0"?0:1]):Bf(g)&&(s[1]=_.toGlobalCoord(_.getExtent()[t[1]==="y0"?0:1]))}isNaN(l)||(s[0]=l),isNaN(u)||(s[1]=u)}return s}var ww=[["x0","y0"],["x1","y0"],["x1","y1"],["x0","y1"]],XY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.updateTransform=function(t,a,n){a.eachSeries(function(i){var o=Ka.getMarkerModelFromSeries(i,"markArea");if(o){var s=o.getData();s.each(function(l){var u=G(ww,function(h){return xw(s,l,h,i,n)});s.setItemLayout(l,u);var f=s.getItemGraphicEl(l);f.setShape("points",u)})}},this)},e.prototype.renderSeries=function(t,a,n,i){var o=t.coordinateSystem,s=t.id,l=t.getData(),u=this.markerGroupMap,f=u.get(s)||u.set(s,{group:new at});this.group.add(f.group),this.markKeep(f);var h=qY(o,t,a);a.setData(h),h.each(function(v){var c=G(ww,function(T){return xw(h,v,T,t,i)}),p=o.getAxis("x").scale,d=o.getAxis("y").scale,g=p.getExtent(),y=d.getExtent(),m=[p.parse(h.get("x0",v)),p.parse(h.get("x1",v))],_=[d.parse(h.get("y0",v)),d.parse(h.get("y1",v))];ar(m),ar(_);var S=!(g[0]>m[1]||g[1]<m[0]||y[0]>_[1]||y[1]<_[0]),w=!S;h.setItemLayout(v,{points:c,allClipped:w});var x=h.getItemModel(v).getModel("itemStyle").getItemStyle(),b=hl(l,"color");x.fill||(x.fill=b,$(x.fill)&&(x.fill=Ju(x.fill,.4))),x.stroke||(x.stroke=b),h.setItemVisual(v,"style",x)}),h.diff(Cu(f).data).add(function(v){var c=h.getItemLayout(v);if(!c.allClipped){var p=new De({shape:{points:c.points}});h.setItemGraphicEl(v,p),f.group.add(p)}}).update(function(v,c){var p=Cu(f).data.getItemGraphicEl(c),d=h.getItemLayout(v);d.allClipped?p&&f.group.remove(p):(p?Dt(p,{shape:{points:d.points}},a,v):p=new De({shape:{points:d.points}}),h.setItemGraphicEl(v,p),f.group.add(p))}).remove(function(v){var c=Cu(f).data.getItemGraphicEl(v);f.group.remove(c)}).execute(),h.eachItemGraphicEl(function(v,c){var p=h.getItemModel(c),d=h.getItemVisual(c,"style");v.useStyle(h.getItemVisual(c,"style")),fe(v,re(p),{labelFetcher:a,labelDataIndex:c,defaultText:h.getName(c)||"",inheritColor:$(d.fill)?Ju(d.fill,1):"#000"}),ue(v,p),Ft(v,null,null,p.get(["emphasis","disabled"])),nt(v).dataModel=a}),Cu(f).data=h,f.group.silent=a.get("silent")||t.get("silent")},e.type="markArea",e}(Ky);function qY(r,e,t){var a,n,i=["x0","y0","x1","y1"];if(r){var o=G(r&&r.dimensions,function(u){var f=e.getData(),h=f.getDimensionInfo(f.mapDimension(u))||{};return V(V({},h),{name:u,ordinalMeta:null})});n=G(i,function(u,f){return{name:u,type:o[f%2].type}}),a=new be(n,t)}else n=[{name:"value",type:"float"}],a=new be(n,t);var s=G(t.get("data"),ot(YY,e,r,t));r&&(s=Lt(s,ot(ZY,r)));var l=r?function(u,f,h,v){var c=u.coord[Math.floor(v/2)][v%2];return za(c,n[v])}:function(u,f,h,v){return za(u.value,n[v])};return a.initData(s,null,l),a.hasItemOption=!0,a}const KY=XY;function QY(r){r.registerComponentModel(UY),r.registerComponentView(KY),r.registerPreprocessor(function(e){Xy(e.series,"markArea")&&(e.markArea=e.markArea||{})})}var JY=function(r,e){if(e==="all")return{type:"all",title:r.getLocaleModel().get(["legend","selector","all"])};if(e==="inverse")return{type:"inverse",title:r.getLocaleModel().get(["legend","selector","inverse"])}},jY=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.layoutMode={type:"box",ignoreSize:!0},t}return e.prototype.init=function(t,a,n){this.mergeDefaultAndTheme(t,n),t.selected=t.selected||{},this._updateSelector(t)},e.prototype.mergeOption=function(t,a){r.prototype.mergeOption.call(this,t,a),this._updateSelector(t)},e.prototype._updateSelector=function(t){var a=t.selector,n=this.ecModel;a===!0&&(a=t.selector=["all","inverse"]),z(a)&&C(a,function(i,o){$(i)&&(i={type:i}),a[o]=ft(i,JY(n,i.type))})},e.prototype.optionUpdated=function(){this._updateData(this.ecModel);var t=this._data;if(t[0]&&this.get("selectedMode")==="single"){for(var a=!1,n=0;n<t.length;n++){var i=t[n].get("name");if(this.isSelected(i)){this.select(i),a=!0;break}}!a&&this.select(t[0].get("name"))}},e.prototype._updateData=function(t){var a=[],n=[];t.eachRawSeries(function(l){var u=l.name;n.push(u);var f;if(l.legendVisualProvider){var h=l.legendVisualProvider,v=h.getAllNames();t.isSeriesFiltered(l)||(n=n.concat(v)),v.length?a=a.concat(v):f=!0}else f=!0;f&&rg(l)&&a.push(l.name)}),this._availableNames=n;var i=this.get("data")||a,o=Z(),s=G(i,function(l){return($(l)||Ct(l))&&(l={name:l}),o.get(l.name)?null:(o.set(l.name,!0),new Ot(l,this,this.ecModel))},this);this._data=Lt(s,function(l){return!!l})},e.prototype.getData=function(){return this._data},e.prototype.select=function(t){var a=this.option.selected,n=this.get("selectedMode");if(n==="single"){var i=this._data;C(i,function(o){a[o.get("name")]=!1})}a[t]=!0},e.prototype.unSelect=function(t){this.get("selectedMode")!=="single"&&(this.option.selected[t]=!1)},e.prototype.toggleSelected=function(t){var a=this.option.selected;a.hasOwnProperty(t)||(a[t]=!0),this[a[t]?"unSelect":"select"](t)},e.prototype.allSelect=function(){var t=this._data,a=this.option.selected;C(t,function(n){a[n.get("name",!0)]=!0})},e.prototype.inverseSelect=function(){var t=this._data,a=this.option.selected;C(t,function(n){var i=n.get("name",!0);a.hasOwnProperty(i)||(a[i]=!0),a[i]=!a[i]})},e.prototype.isSelected=function(t){var a=this.option.selected;return!(a.hasOwnProperty(t)&&!a[t])&&vt(this._availableNames,t)>=0},e.prototype.getOrient=function(){return this.get("orient")==="vertical"?{index:1,name:"vertical"}:{index:0,name:"horizontal"}},e.type="legend.plain",e.dependencies=["series"],e.defaultOption={z:4,show:!0,orient:"horizontal",left:"center",top:0,align:"auto",backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",borderRadius:0,borderWidth:0,padding:5,itemGap:10,itemWidth:25,itemHeight:14,symbolRotate:"inherit",symbolKeepAspect:!0,inactiveColor:"#ccc",inactiveBorderColor:"#ccc",inactiveBorderWidth:"auto",itemStyle:{color:"inherit",opacity:"inherit",borderColor:"inherit",borderWidth:"auto",borderCap:"inherit",borderJoin:"inherit",borderDashOffset:"inherit",borderMiterLimit:"inherit"},lineStyle:{width:"auto",color:"inherit",inactiveColor:"#ccc",inactiveWidth:2,opacity:"inherit",type:"inherit",cap:"inherit",join:"inherit",dashOffset:"inherit",miterLimit:"inherit"},textStyle:{color:"#333"},selectedMode:!0,selector:!1,selectorLabel:{show:!0,borderRadius:10,padding:[3,5,3,5],fontSize:12,fontFamily:"sans-serif",color:"#666",borderWidth:1,borderColor:"#666"},emphasis:{selectorLabel:{show:!0,color:"#eee",backgroundColor:"#666"}},selectorPosition:"auto",selectorItemGap:7,selectorButtonGap:10,tooltip:{show:!1}},e}(Tt);const kd=jY;var Pi=ot,Od=C,Du=at,t7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.newlineDisabled=!1,t}return e.prototype.init=function(){this.group.add(this._contentGroup=new Du),this.group.add(this._selectorGroup=new Du),this._isFirstRender=!0},e.prototype.getContentGroup=function(){return this._contentGroup},e.prototype.getSelectorGroup=function(){return this._selectorGroup},e.prototype.render=function(t,a,n){var i=this._isFirstRender;if(this._isFirstRender=!1,this.resetInner(),!!t.get("show",!0)){var o=t.get("align"),s=t.get("orient");(!o||o==="auto")&&(o=t.get("left")==="right"&&s==="vertical"?"right":"left");var l=t.get("selector",!0),u=t.get("selectorPosition",!0);l&&(!u||u==="auto")&&(u=s==="horizontal"?"end":"start"),this.renderInner(o,t,a,n,l,s,u);var f=t.getBoxLayoutParams(),h={width:n.getWidth(),height:n.getHeight()},v=t.get("padding"),c=Jt(f,h,v),p=this.layoutInner(t,o,c,i,l,u),d=Jt(j({width:p.width,height:p.height},f),h,v);this.group.x=d.x-p.x,this.group.y=d.y-p.y,this.group.markRedraw(),this.group.add(this._backgroundEl=LI(p,t))}},e.prototype.resetInner=function(){this.getContentGroup().removeAll(),this._backgroundEl&&this.group.remove(this._backgroundEl),this.getSelectorGroup().removeAll()},e.prototype.renderInner=function(t,a,n,i,o,s,l){var u=this.getContentGroup(),f=Z(),h=a.get("selectedMode"),v=[];n.eachRawSeries(function(c){!c.get("legendHoverLink")&&v.push(c.id)}),Od(a.getData(),function(c,p){var d=c.get("name");if(!this.newlineDisabled&&(d===""||d===`
`)){var g=new Du;g.newline=!0,u.add(g);return}var y=n.getSeriesByName(d)[0];if(!f.get(d))if(y){var m=y.getData(),_=m.getVisual("legendLineStyle")||{},S=m.getVisual("legendIcon"),w=m.getVisual("style"),x=this._createItem(y,d,p,c,a,t,_,w,S,h,i);x.on("click",Pi(bw,d,null,i,v)).on("mouseover",Pi(Nd,y.name,null,i,v)).on("mouseout",Pi(Bd,y.name,null,i,v)),n.ssr&&x.eachChild(function(b){var T=nt(b);T.seriesIndex=y.seriesIndex,T.dataIndex=p,T.ssrType="legend"}),f.set(d,!0)}else n.eachRawSeries(function(b){if(!f.get(d)&&b.legendVisualProvider){var T=b.legendVisualProvider;if(!T.containName(d))return;var A=T.indexOfName(d),D=T.getItemVisual(A,"style"),M=T.getItemVisual(A,"legendIcon"),I=He(D.fill);I&&I[3]===0&&(I[3]=.2,D=V(V({},D),{fill:ra(I,"rgba")}));var L=this._createItem(b,d,p,c,a,t,{},D,M,h,i);L.on("click",Pi(bw,null,d,i,v)).on("mouseover",Pi(Nd,null,d,i,v)).on("mouseout",Pi(Bd,null,d,i,v)),n.ssr&&L.eachChild(function(P){var R=nt(P);R.seriesIndex=b.seriesIndex,R.dataIndex=p,R.ssrType="legend"}),f.set(d,!0)}},this)},this),o&&this._createSelector(o,a,i,s,l)},e.prototype._createSelector=function(t,a,n,i,o){var s=this.getSelectorGroup();Od(t,function(u){var f=u.type,h=new At({style:{x:0,y:0,align:"center",verticalAlign:"middle"},onclick:function(){n.dispatchAction({type:f==="all"?"legendAllSelect":"legendInverseSelect"})}});s.add(h);var v=a.getModel("selectorLabel"),c=a.getModel(["emphasis","selectorLabel"]);fe(h,{normal:v,emphasis:c},{defaultText:u.title}),Zn(h)})},e.prototype._createItem=function(t,a,n,i,o,s,l,u,f,h,v){var c=t.visualDrawType,p=o.get("itemWidth"),d=o.get("itemHeight"),g=o.isSelected(a),y=i.get("symbolRotate"),m=i.get("symbolKeepAspect"),_=i.get("icon");f=_||f||"roundRect";var S=e7(f,i,l,u,c,g,v),w=new Du,x=i.getModel("textStyle");if(K(t.getLegendIcon)&&(!_||_==="inherit"))w.add(t.getLegendIcon({itemWidth:p,itemHeight:d,icon:f,iconRotate:y,itemStyle:S.itemStyle,lineStyle:S.lineStyle,symbolKeepAspect:m}));else{var b=_==="inherit"&&t.getData().getVisual("symbol")?y==="inherit"?t.getData().getVisual("symbolRotate"):y:0;w.add(r7({itemWidth:p,itemHeight:d,icon:f,iconRotate:b,itemStyle:S.itemStyle,lineStyle:S.lineStyle,symbolKeepAspect:m}))}var T=s==="left"?p+5:-5,A=s,D=o.get("formatter"),M=a;$(D)&&D?M=D.replace("{name}",a??""):K(D)&&(M=D(a));var I=g?x.getTextColor():i.get("inactiveColor");w.add(new At({style:kt(x,{text:M,x:T,y:d/2,fill:I,align:A,verticalAlign:"middle"},{inheritColor:I})}));var L=new wt({shape:w.getBoundingRect(),style:{fill:"transparent"}}),P=i.getModel("tooltip");return P.get("show")&&co({el:L,componentModel:o,itemName:a,itemTooltipOption:P.option}),w.add(L),w.eachChild(function(R){R.silent=!0}),L.silent=!h,this.getContentGroup().add(w),Zn(w),w.__legendDataIndex=n,w},e.prototype.layoutInner=function(t,a,n,i,o,s){var l=this.getContentGroup(),u=this.getSelectorGroup();qn(t.get("orient"),l,t.get("itemGap"),n.width,n.height);var f=l.getBoundingRect(),h=[-f.x,-f.y];if(u.markRedraw(),l.markRedraw(),o){qn("horizontal",u,t.get("selectorItemGap",!0));var v=u.getBoundingRect(),c=[-v.x,-v.y],p=t.get("selectorButtonGap",!0),d=t.getOrient().index,g=d===0?"width":"height",y=d===0?"height":"width",m=d===0?"y":"x";s==="end"?c[d]+=f[g]+p:h[d]+=v[g]+p,c[1-d]+=f[y]/2-v[y]/2,u.x=c[0],u.y=c[1],l.x=h[0],l.y=h[1];var _={x:0,y:0};return _[g]=f[g]+p+v[g],_[y]=Math.max(f[y],v[y]),_[m]=Math.min(0,v[m]+c[1-d]),_}else return l.x=h[0],l.y=h[1],this.group.getBoundingRect()},e.prototype.remove=function(){this.getContentGroup().removeAll(),this._isFirstRender=!0},e.type="legend.plain",e}(Ht);function e7(r,e,t,a,n,i,o){function s(g,y){g.lineWidth==="auto"&&(g.lineWidth=y.lineWidth>0?2:0),Od(g,function(m,_){g[_]==="inherit"&&(g[_]=y[_])})}var l=e.getModel("itemStyle"),u=l.getItemStyle(),f=r.lastIndexOf("empty",0)===0?"fill":"stroke",h=l.getShallow("decal");u.decal=!h||h==="inherit"?a.decal:ji(h,o),u.fill==="inherit"&&(u.fill=a[n]),u.stroke==="inherit"&&(u.stroke=a[f]),u.opacity==="inherit"&&(u.opacity=(n==="fill"?a:t).opacity),s(u,a);var v=e.getModel("lineStyle"),c=v.getLineStyle();if(s(c,t),u.fill==="auto"&&(u.fill=a.fill),u.stroke==="auto"&&(u.stroke=a.fill),c.stroke==="auto"&&(c.stroke=a.fill),!i){var p=e.get("inactiveBorderWidth"),d=u[f];u.lineWidth=p==="auto"?a.lineWidth>0&&d?2:0:u.lineWidth,u.fill=e.get("inactiveColor"),u.stroke=e.get("inactiveBorderColor"),c.stroke=v.get("inactiveColor"),c.lineWidth=v.get("inactiveWidth")}return{itemStyle:u,lineStyle:c}}function r7(r){var e=r.icon||"roundRect",t=qt(e,0,0,r.itemWidth,r.itemHeight,r.itemStyle.fill,r.symbolKeepAspect);return t.setStyle(r.itemStyle),t.rotation=(r.iconRotate||0)*Math.PI/180,t.setOrigin([r.itemWidth/2,r.itemHeight/2]),e.indexOf("empty")>-1&&(t.style.stroke=t.style.fill,t.style.fill="#fff",t.style.lineWidth=2),t}function bw(r,e,t,a){Bd(r,e,t,a),t.dispatchAction({type:"legendToggleSelect",name:r??e}),Nd(r,e,t,a)}function WI(r){for(var e=r.getZr().storage.getDisplayList(),t,a=0,n=e.length;a<n&&!(t=e[a].states.emphasis);)a++;return t&&t.hoverLayer}function Nd(r,e,t,a){WI(t)||t.dispatchAction({type:"highlight",seriesName:r,name:e,excludeSeriesId:a})}function Bd(r,e,t,a){WI(t)||t.dispatchAction({type:"downplay",seriesName:r,name:e,excludeSeriesId:a})}const $I=t7;function a7(r){var e=r.findComponents({mainType:"legend"});e&&e.length&&r.filterSeries(function(t){for(var a=0;a<e.length;a++)if(!e[a].isSelected(t.name))return!1;return!0})}function Qo(r,e,t){var a={},n=r==="toggleSelected",i;return t.eachComponent("legend",function(o){n&&i!=null?o[i?"select":"unSelect"](e.name):r==="allSelect"||r==="inverseSelect"?o[r]():(o[r](e.name),i=o.isSelected(e.name));var s=o.getData();C(s,function(l){var u=l.get("name");if(!(u===`
`||u==="")){var f=o.isSelected(u);a.hasOwnProperty(u)?a[u]=a[u]&&f:a[u]=f}})}),r==="allSelect"||r==="inverseSelect"?{selected:a}:{name:e.name,selected:a}}function n7(r){r.registerAction("legendToggleSelect","legendselectchanged",ot(Qo,"toggleSelected")),r.registerAction("legendAllSelect","legendselectall",ot(Qo,"allSelect")),r.registerAction("legendInverseSelect","legendinverseselect",ot(Qo,"inverseSelect")),r.registerAction("legendSelect","legendselected",ot(Qo,"select")),r.registerAction("legendUnSelect","legendunselected",ot(Qo,"unSelect"))}function UI(r){r.registerComponentModel(kd),r.registerComponentView($I),r.registerProcessor(r.PRIORITY.PROCESSOR.SERIES_FILTER,a7),r.registerSubTypeDefaulter("legend",function(){return"plain"}),n7(r)}var i7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.setScrollDataIndex=function(t){this.option.scrollDataIndex=t},e.prototype.init=function(t,a,n){var i=mo(t);r.prototype.init.call(this,t,a,n),Tw(this,t,i)},e.prototype.mergeOption=function(t,a){r.prototype.mergeOption.call(this,t,a),Tw(this,this.option,t)},e.type="legend.scroll",e.defaultOption=ja(kd.defaultOption,{scrollDataIndex:0,pageButtonItemGap:5,pageButtonGap:null,pageButtonPosition:"end",pageFormatter:"{current}/{total}",pageIcons:{horizontal:["M0,0L12,-10L12,10z","M0,0L-12,-10L-12,10z"],vertical:["M0,0L20,0L10,-20z","M0,0L20,0L10,20z"]},pageIconColor:"#2f4554",pageIconInactiveColor:"#aaa",pageIconSize:15,pageTextStyle:{color:"#333"},animationDurationUpdate:800}),e}(kd);function Tw(r,e,t){var a=r.getOrient(),n=[1,1];n[a.index]=0,Ua(e,t,{type:"box",ignoreSize:!!n})}const o7=i7;var Aw=at,$c=["width","height"],Uc=["x","y"],s7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.newlineDisabled=!0,t._currentIndex=0,t}return e.prototype.init=function(){r.prototype.init.call(this),this.group.add(this._containerGroup=new Aw),this._containerGroup.add(this.getContentGroup()),this.group.add(this._controllerGroup=new Aw)},e.prototype.resetInner=function(){r.prototype.resetInner.call(this),this._controllerGroup.removeAll(),this._containerGroup.removeClipPath(),this._containerGroup.__rectSize=null},e.prototype.renderInner=function(t,a,n,i,o,s,l){var u=this;r.prototype.renderInner.call(this,t,a,n,i,o,s,l);var f=this._controllerGroup,h=a.get("pageIconSize",!0),v=z(h)?h:[h,h];p("pagePrev",0);var c=a.getModel("pageTextStyle");f.add(new At({name:"pageText",style:{text:"xx/xx",fill:c.getTextColor(),font:c.getFont(),verticalAlign:"middle",align:"center"},silent:!0})),p("pageNext",1);function p(d,g){var y=d+"DataIndex",m=ul(a.get("pageIcons",!0)[a.getOrient().name][g],{onclick:U(u._pageGo,u,y,a,i)},{x:-v[0]/2,y:-v[1]/2,width:v[0],height:v[1]});m.name=d,f.add(m)}},e.prototype.layoutInner=function(t,a,n,i,o,s){var l=this.getSelectorGroup(),u=t.getOrient().index,f=$c[u],h=Uc[u],v=$c[1-u],c=Uc[1-u];o&&qn("horizontal",l,t.get("selectorItemGap",!0));var p=t.get("selectorButtonGap",!0),d=l.getBoundingRect(),g=[-d.x,-d.y],y=rt(n);o&&(y[f]=n[f]-d[f]-p);var m=this._layoutContentAndController(t,i,y,u,f,v,c,h);if(o){if(s==="end")g[u]+=m[f]+p;else{var _=d[f]+p;g[u]-=_,m[h]-=_}m[f]+=d[f]+p,g[1-u]+=m[c]+m[v]/2-d[v]/2,m[v]=Math.max(m[v],d[v]),m[c]=Math.min(m[c],d[c]+g[1-u]),l.x=g[0],l.y=g[1],l.markRedraw()}return m},e.prototype._layoutContentAndController=function(t,a,n,i,o,s,l,u){var f=this.getContentGroup(),h=this._containerGroup,v=this._controllerGroup;qn(t.get("orient"),f,t.get("itemGap"),i?n.width:null,i?null:n.height),qn("horizontal",v,t.get("pageButtonItemGap",!0));var c=f.getBoundingRect(),p=v.getBoundingRect(),d=this._showController=c[o]>n[o],g=[-c.x,-c.y];a||(g[i]=f[u]);var y=[0,0],m=[-p.x,-p.y],_=it(t.get("pageButtonGap",!0),t.get("itemGap",!0));if(d){var S=t.get("pageButtonPosition",!0);S==="end"?m[i]+=n[o]-p[o]:y[i]+=p[o]+_}m[1-i]+=c[s]/2-p[s]/2,f.setPosition(g),h.setPosition(y),v.setPosition(m);var w={x:0,y:0};if(w[o]=d?n[o]:c[o],w[s]=Math.max(c[s],p[s]),w[l]=Math.min(0,p[l]+m[1-i]),h.__rectSize=n[o],d){var x={x:0,y:0};x[o]=Math.max(n[o]-p[o]-_,0),x[s]=w[s],h.setClipPath(new wt({shape:x})),h.__rectSize=x[o]}else v.eachChild(function(T){T.attr({invisible:!0,silent:!0})});var b=this._getPageInfo(t);return b.pageIndex!=null&&Dt(f,{x:b.contentPosition[0],y:b.contentPosition[1]},d?t:null),this._updatePageInfoView(t,b),w},e.prototype._pageGo=function(t,a,n){var i=this._getPageInfo(a)[t];i!=null&&n.dispatchAction({type:"legendScroll",scrollDataIndex:i,legendId:a.id})},e.prototype._updatePageInfoView=function(t,a){var n=this._controllerGroup;C(["pagePrev","pageNext"],function(f){var h=f+"DataIndex",v=a[h]!=null,c=n.childOfName(f);c&&(c.setStyle("fill",v?t.get("pageIconColor",!0):t.get("pageIconInactiveColor",!0)),c.cursor=v?"pointer":"default")});var i=n.childOfName("pageText"),o=t.get("pageFormatter"),s=a.pageIndex,l=s!=null?s+1:0,u=a.pageCount;i&&o&&i.setStyle("text",$(o)?o.replace("{current}",l==null?"":l+"").replace("{total}",u==null?"":u+""):o({current:l,total:u}))},e.prototype._getPageInfo=function(t){var a=t.get("scrollDataIndex",!0),n=this.getContentGroup(),i=this._containerGroup.__rectSize,o=t.getOrient().index,s=$c[o],l=Uc[o],u=this._findTargetItemIndex(a),f=n.children(),h=f[u],v=f.length,c=v?1:0,p={contentPosition:[n.x,n.y],pageCount:c,pageIndex:c-1,pagePrevDataIndex:null,pageNextDataIndex:null};if(!h)return p;var d=S(h);p.contentPosition[o]=-d.s;for(var g=u+1,y=d,m=d,_=null;g<=v;++g)_=S(f[g]),(!_&&m.e>y.s+i||_&&!w(_,y.s))&&(m.i>y.i?y=m:y=_,y&&(p.pageNextDataIndex==null&&(p.pageNextDataIndex=y.i),++p.pageCount)),m=_;for(var g=u-1,y=d,m=d,_=null;g>=-1;--g)_=S(f[g]),(!_||!w(m,_.s))&&y.i<m.i&&(m=y,p.pagePrevDataIndex==null&&(p.pagePrevDataIndex=y.i),++p.pageCount,++p.pageIndex),y=_;return p;function S(x){if(x){var b=x.getBoundingRect(),T=b[l]+x[l];return{s:T,e:T+b[s],i:x.__legendDataIndex}}}function w(x,b){return x.e>=b&&x.s<=b+i}},e.prototype._findTargetItemIndex=function(t){if(!this._showController)return 0;var a,n=this.getContentGroup(),i;return n.eachChild(function(o,s){var l=o.__legendDataIndex;i==null&&l!=null&&(i=s),l===t&&(a=s)}),a??i},e.type="legend.scroll",e}($I);const l7=s7;function u7(r){r.registerAction("legendScroll","legendscroll",function(e,t){var a=e.scrollDataIndex;a!=null&&t.eachComponent({mainType:"legend",subType:"scroll",query:e},function(n){n.setScrollDataIndex(a)})})}function f7(r){gt(UI),r.registerComponentModel(o7),r.registerComponentView(l7),u7(r)}function h7(r){gt(UI),gt(f7)}var v7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="dataZoom.inside",e.defaultOption=ja(el.defaultOption,{disabled:!1,zoomLock:!1,zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0}),e}(el);const c7=v7;var Qy=bt();function p7(r,e,t){Qy(r).coordSysRecordMap.each(function(a){var n=a.dataZoomInfoMap.get(e.uid);n&&(n.getRange=t)})}function d7(r,e){for(var t=Qy(r).coordSysRecordMap,a=t.keys(),n=0;n<a.length;n++){var i=a[n],o=t.get(i),s=o.dataZoomInfoMap;if(s){var l=e.uid,u=s.get(l);u&&(s.removeKey(l),s.keys().length||YI(t,o))}}}function YI(r,e){if(e){r.removeKey(e.model.uid);var t=e.controller;t&&t.dispose()}}function g7(r,e){var t={model:e,containsPoint:ot(m7,e),dispatchAction:ot(y7,r),dataZoomInfoMap:null,controller:null},a=t.controller=new xl(r.getZr());return C(["pan","zoom","scrollMove"],function(n){a.on(n,function(i){var o=[];t.dataZoomInfoMap.each(function(s){if(i.isAvailableBehavior(s.model.option)){var l=(s.getRange||{})[n],u=l&&l(s.dzReferCoordSysInfo,t.model.mainType,t.controller,i);!s.model.get("disabled",!0)&&u&&o.push({dataZoomId:s.model.id,start:u[0],end:u[1]})}}),o.length&&t.dispatchAction(o)})}),t}function y7(r,e){r.isDisposed()||r.dispatchAction({type:"dataZoom",animation:{easing:"cubicOut",duration:100},batch:e})}function m7(r,e,t,a){return r.coordinateSystem.containPoint([t,a])}function _7(r){var e,t="type_",a={type_true:2,type_move:1,type_false:0,type_undefined:-1},n=!0;return r.each(function(i){var o=i.model,s=o.get("disabled",!0)?!1:o.get("zoomLock",!0)?"move":!0;a[t+s]>a[t+e]&&(e=s),n=n&&o.get("preventDefaultMouseMove",!0)}),{controlType:e,opt:{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!0,preventDefaultMouseMove:!!n}}}function S7(r){r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,function(e,t){var a=Qy(t),n=a.coordSysRecordMap||(a.coordSysRecordMap=Z());n.each(function(i){i.dataZoomInfoMap=null}),e.eachComponent({mainType:"dataZoom",subType:"inside"},function(i){var o=DI(i);C(o.infoList,function(s){var l=s.model.uid,u=n.get(l)||n.set(l,g7(t,s.model)),f=u.dataZoomInfoMap||(u.dataZoomInfoMap=Z());f.set(i.uid,{dzReferCoordSysInfo:s,model:i,getRange:null})})}),n.each(function(i){var o=i.controller,s,l=i.dataZoomInfoMap;if(l){var u=l.keys()[0];u!=null&&(s=l.get(u))}if(!s){YI(n,i);return}var f=_7(l);o.enable(f.controlType,f.opt),o.setPointerChecker(i.containsPoint),wo(i,"dispatchAction",s.model.get("throttle",!0),"fixRate")})})}var x7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="dataZoom.inside",t}return e.prototype.render=function(t,a,n){if(r.prototype.render.apply(this,arguments),t.noTarget()){this._clear();return}this.range=t.getPercentRange(),p7(n,t,{pan:U(Yc.pan,this),zoom:U(Yc.zoom,this),scrollMove:U(Yc.scrollMove,this)})},e.prototype.dispose=function(){this._clear(),r.prototype.dispose.apply(this,arguments)},e.prototype._clear=function(){d7(this.api,this.dataZoomModel),this.range=null},e.type="dataZoom.inside",e}(Hy),Yc={zoom:function(r,e,t,a){var n=this.range,i=n.slice(),o=r.axisModels[0];if(o){var s=Zc[e](null,[a.originX,a.originY],o,t,r),l=(s.signal>0?s.pixelStart+s.pixelLength-s.pixel:s.pixel-s.pixelStart)/s.pixelLength*(i[1]-i[0])+i[0],u=Math.max(1/a.scale,0);i[0]=(i[0]-l)*u+l,i[1]=(i[1]-l)*u+l;var f=this.dataZoomModel.findRepresentativeAxisProxy().getMinMaxSpan();if(ci(0,i,[0,100],0,f.minSpan,f.maxSpan),this.range=i,n[0]!==i[0]||n[1]!==i[1])return i}},pan:Cw(function(r,e,t,a,n,i){var o=Zc[a]([i.oldX,i.oldY],[i.newX,i.newY],e,n,t);return o.signal*(r[1]-r[0])*o.pixel/o.pixelLength}),scrollMove:Cw(function(r,e,t,a,n,i){var o=Zc[a]([0,0],[i.scrollDelta,i.scrollDelta],e,n,t);return o.signal*(r[1]-r[0])*i.scrollDelta})};function Cw(r){return function(e,t,a,n){var i=this.range,o=i.slice(),s=e.axisModels[0];if(s){var l=r(o,s,e,t,a,n);if(ci(l,o,[0,100],"all"),this.range=o,i[0]!==o[0]||i[1]!==o[1])return o}}}var Zc={grid:function(r,e,t,a,n){var i=t.axis,o={},s=n.model.coordinateSystem.getRect();return r=r||[0,0],i.dim==="x"?(o.pixel=e[0]-r[0],o.pixelLength=s.width,o.pixelStart=s.x,o.signal=i.inverse?1:-1):(o.pixel=e[1]-r[1],o.pixelLength=s.height,o.pixelStart=s.y,o.signal=i.inverse?-1:1),o},polar:function(r,e,t,a,n){var i=t.axis,o={},s=n.model.coordinateSystem,l=s.getRadiusAxis().getExtent(),u=s.getAngleAxis().getExtent();return r=r?s.pointToCoord(r):[0,0],e=s.pointToCoord(e),t.mainType==="radiusAxis"?(o.pixel=e[0]-r[0],o.pixelLength=l[1]-l[0],o.pixelStart=l[0],o.signal=i.inverse?1:-1):(o.pixel=e[1]-r[1],o.pixelLength=u[1]-u[0],o.pixelStart=u[0],o.signal=i.inverse?-1:1),o},singleAxis:function(r,e,t,a,n){var i=t.axis,o=n.model.coordinateSystem.getRect(),s={};return r=r||[0,0],i.orient==="horizontal"?(s.pixel=e[0]-r[0],s.pixelLength=o.width,s.pixelStart=o.x,s.signal=i.inverse?1:-1):(s.pixel=e[1]-r[1],s.pixelLength=o.height,s.pixelStart=o.y,s.signal=i.inverse?-1:1),s}};const w7=x7;function ZI(r){Wy(r),r.registerComponentModel(c7),r.registerComponentView(w7),S7(r)}var b7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="dataZoom.slider",e.layoutMode="box",e.defaultOption=ja(el.defaultOption,{show:!0,right:"ph",top:"ph",width:"ph",height:"ph",left:null,bottom:null,borderColor:"#d2dbee",borderRadius:3,backgroundColor:"rgba(47,69,84,0)",dataBackground:{lineStyle:{color:"#d2dbee",width:.5},areaStyle:{color:"#d2dbee",opacity:.2}},selectedDataBackground:{lineStyle:{color:"#8fb0f7",width:.5},areaStyle:{color:"#8fb0f7",opacity:.2}},fillerColor:"rgba(135,175,274,0.2)",handleIcon:"path://M-9.35,34.56V42m0-40V9.5m-2,0h4a2,2,0,0,1,2,2v21a2,2,0,0,1-2,2h-4a2,2,0,0,1-2-2v-21A2,2,0,0,1-11.35,9.5Z",handleSize:"100%",handleStyle:{color:"#fff",borderColor:"#ACB8D1"},moveHandleSize:7,moveHandleIcon:"path://M-320.9-50L-320.9-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-348-41-339-50-320.9-50z M-212.3-50L-212.3-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-239.4-41-230.4-50-212.3-50z M-103.7-50L-103.7-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-130.9-41-121.8-50-103.7-50z",moveHandleStyle:{color:"#D2DBEE",opacity:.7},showDetail:!0,showDataShadow:"auto",realtime:!0,zoomLock:!1,textStyle:{color:"#6E7079"},brushSelect:!0,brushStyle:{color:"rgba(135,175,274,0.15)"},emphasis:{handleStyle:{borderColor:"#8FB0F7"},moveHandleStyle:{color:"#8FB0F7"}}}),e}(el);const T7=b7;var Jo=wt,Dw=7,A7=1,Xc=30,C7=7,jo="horizontal",Mw="vertical",D7=5,M7=["line","bar","candlestick","scatter"],I7={easing:"cubicOut",duration:100,delay:0},L7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._displayables={},t}return e.prototype.init=function(t,a){this.api=a,this._onBrush=U(this._onBrush,this),this._onBrushEnd=U(this._onBrushEnd,this)},e.prototype.render=function(t,a,n,i){if(r.prototype.render.apply(this,arguments),wo(this,"_dispatchZoomAction",t.get("throttle"),"fixRate"),this._orient=t.getOrient(),t.get("show")===!1){this.group.removeAll();return}if(t.noTarget()){this._clear(),this.group.removeAll();return}(!i||i.type!=="dataZoom"||i.from!==this.uid)&&this._buildView(),this._updateView()},e.prototype.dispose=function(){this._clear(),r.prototype.dispose.apply(this,arguments)},e.prototype._clear=function(){Hs(this,"_dispatchZoomAction");var t=this.api.getZr();t.off("mousemove",this._onBrush),t.off("mouseup",this._onBrushEnd)},e.prototype._buildView=function(){var t=this.group;t.removeAll(),this._brushing=!1,this._displayables.brushRect=null,this._resetLocation(),this._resetInterval();var a=this._displayables.sliderGroup=new at;this._renderBackground(),this._renderHandle(),this._renderDataShadow(),t.add(a),this._positionGroup()},e.prototype._resetLocation=function(){var t=this.dataZoomModel,a=this.api,n=t.get("brushSelect"),i=n?C7:0,o=this._findCoordRect(),s={width:a.getWidth(),height:a.getHeight()},l=this._orient===jo?{right:s.width-o.x-o.width,top:s.height-Xc-Dw-i,width:o.width,height:Xc}:{right:Dw,top:o.y,width:Xc,height:o.height},u=mo(t.option);C(["right","top","width","height"],function(h){u[h]==="ph"&&(u[h]=l[h])});var f=Jt(u,s);this._location={x:f.x,y:f.y},this._size=[f.width,f.height],this._orient===Mw&&this._size.reverse()},e.prototype._positionGroup=function(){var t=this.group,a=this._location,n=this._orient,i=this.dataZoomModel.getFirstTargetAxisModel(),o=i&&i.get("inverse"),s=this._displayables.sliderGroup,l=(this._dataShadowInfo||{}).otherAxisInverse;s.attr(n===jo&&!o?{scaleY:l?1:-1,scaleX:1}:n===jo&&o?{scaleY:l?1:-1,scaleX:-1}:n===Mw&&!o?{scaleY:l?-1:1,scaleX:1,rotation:Math.PI/2}:{scaleY:l?-1:1,scaleX:-1,rotation:Math.PI/2});var u=t.getBoundingRect([s]);t.x=a.x-u.x,t.y=a.y-u.y,t.markRedraw()},e.prototype._getViewExtent=function(){return[0,this._size[0]]},e.prototype._renderBackground=function(){var t=this.dataZoomModel,a=this._size,n=this._displayables.sliderGroup,i=t.get("brushSelect");n.add(new Jo({silent:!0,shape:{x:0,y:0,width:a[0],height:a[1]},style:{fill:t.get("backgroundColor")},z2:-40}));var o=new Jo({shape:{x:0,y:0,width:a[0],height:a[1]},style:{fill:"transparent"},z2:0,onclick:U(this._onClickPanel,this)}),s=this.api.getZr();i?(o.on("mousedown",this._onBrushStart,this),o.cursor="crosshair",s.on("mousemove",this._onBrush),s.on("mouseup",this._onBrushEnd)):(s.off("mousemove",this._onBrush),s.off("mouseup",this._onBrushEnd)),n.add(o)},e.prototype._renderDataShadow=function(){var t=this._dataShadowInfo=this._prepareDataShadowInfo();if(this._displayables.dataShadowSegs=[],!t)return;var a=this._size,n=this._shadowSize||[],i=t.series,o=i.getRawData(),s=i.getShadowDim&&i.getShadowDim(),l=s&&o.getDimensionInfo(s)?i.getShadowDim():t.otherDim;if(l==null)return;var u=this._shadowPolygonPts,f=this._shadowPolylinePts;if(o!==this._shadowData||l!==this._shadowDim||a[0]!==n[0]||a[1]!==n[1]){var h=o.getDataExtent(l),v=(h[1]-h[0])*.3;h=[h[0]-v,h[1]+v];var c=[0,a[1]],p=[0,a[0]],d=[[a[0],0],[0,0]],g=[],y=p[1]/(o.count()-1),m=0,_=Math.round(o.count()/a[0]),S;o.each([l],function(A,D){if(_>0&&D%_){m+=y;return}var M=A==null||isNaN(A)||A==="",I=M?0:It(A,h,c,!0);M&&!S&&D?(d.push([d[d.length-1][0],0]),g.push([g[g.length-1][0],0])):!M&&S&&(d.push([m,0]),g.push([m,0])),d.push([m,I]),g.push([m,I]),m+=y,S=M}),u=this._shadowPolygonPts=d,f=this._shadowPolylinePts=g}this._shadowData=o,this._shadowDim=l,this._shadowSize=[a[0],a[1]];var w=this.dataZoomModel;function x(A){var D=w.getModel(A?"selectedDataBackground":"dataBackground"),M=new at,I=new De({shape:{points:u},segmentIgnoreThreshold:1,style:D.getModel("areaStyle").getAreaStyle(),silent:!0,z2:-20}),L=new Me({shape:{points:f},segmentIgnoreThreshold:1,style:D.getModel("lineStyle").getLineStyle(),silent:!0,z2:-19});return M.add(I),M.add(L),M}for(var b=0;b<3;b++){var T=x(b===1);this._displayables.sliderGroup.add(T),this._displayables.dataShadowSegs.push(T)}},e.prototype._prepareDataShadowInfo=function(){var t=this.dataZoomModel,a=t.get("showDataShadow");if(a!==!1){var n,i=this.ecModel;return t.eachTargetAxis(function(o,s){var l=t.getAxisProxy(o,s).getTargetSeriesModels();C(l,function(u){if(!n&&!(a!==!0&&vt(M7,u.get("type"))<0)){var f=i.getComponent(Na(o),s).axis,h=P7(o),v,c=u.coordinateSystem;h!=null&&c.getOtherAxis&&(v=c.getOtherAxis(f).inverse),h=u.getData().mapDimension(h),n={thisAxis:f,series:u,thisDim:o,otherDim:h,otherAxisInverse:v}}},this)},this),n}},e.prototype._renderHandle=function(){var t=this.group,a=this._displayables,n=a.handles=[null,null],i=a.handleLabels=[null,null],o=this._displayables.sliderGroup,s=this._size,l=this.dataZoomModel,u=this.api,f=l.get("borderRadius")||0,h=l.get("brushSelect"),v=a.filler=new Jo({silent:h,style:{fill:l.get("fillerColor")},textConfig:{position:"inside"}});o.add(v),o.add(new Jo({silent:!0,subPixelOptimize:!0,shape:{x:0,y:0,width:s[0],height:s[1],r:f},style:{stroke:l.get("dataBackgroundColor")||l.get("borderColor"),lineWidth:A7,fill:"rgba(0,0,0,0)"}})),C([0,1],function(_){var S=l.get("handleIcon");!pf[S]&&S.indexOf("path://")<0&&S.indexOf("image://")<0&&(S="path://"+S);var w=qt(S,-1,0,2,2,null,!0);w.attr({cursor:Iw(this._orient),draggable:!0,drift:U(this._onDragMove,this,_),ondragend:U(this._onDragEnd,this),onmouseover:U(this._showDataInfo,this,!0),onmouseout:U(this._showDataInfo,this,!1),z2:5});var x=w.getBoundingRect(),b=l.get("handleSize");this._handleHeight=W(b,this._size[1]),this._handleWidth=x.width/x.height*this._handleHeight,w.setStyle(l.getModel("handleStyle").getItemStyle()),w.style.strokeNoScale=!0,w.rectHover=!0,w.ensureState("emphasis").style=l.getModel(["emphasis","handleStyle"]).getItemStyle(),Zn(w);var T=l.get("handleColor");T!=null&&(w.style.fill=T),o.add(n[_]=w);var A=l.getModel("textStyle");t.add(i[_]=new At({silent:!0,invisible:!0,style:kt(A,{x:0,y:0,text:"",verticalAlign:"middle",align:"center",fill:A.getTextColor(),font:A.getFont()}),z2:10}))},this);var c=v;if(h){var p=W(l.get("moveHandleSize"),s[1]),d=a.moveHandle=new wt({style:l.getModel("moveHandleStyle").getItemStyle(),silent:!0,shape:{r:[0,0,2,2],y:s[1]-.5,height:p}}),g=p*.8,y=a.moveHandleIcon=qt(l.get("moveHandleIcon"),-g/2,-g/2,g,g,"#fff",!0);y.silent=!0,y.y=s[1]+p/2-.5,d.ensureState("emphasis").style=l.getModel(["emphasis","moveHandleStyle"]).getItemStyle();var m=Math.min(s[1]/2,Math.max(p,10));c=a.moveZone=new wt({invisible:!0,shape:{y:s[1]-m,height:p+m}}),c.on("mouseover",function(){u.enterEmphasis(d)}).on("mouseout",function(){u.leaveEmphasis(d)}),o.add(d),o.add(y),o.add(c)}c.attr({draggable:!0,cursor:Iw(this._orient),drift:U(this._onDragMove,this,"all"),ondragstart:U(this._showDataInfo,this,!0),ondragend:U(this._onDragEnd,this),onmouseover:U(this._showDataInfo,this,!0),onmouseout:U(this._showDataInfo,this,!1)})},e.prototype._resetInterval=function(){var t=this._range=this.dataZoomModel.getPercentRange(),a=this._getViewExtent();this._handleEnds=[It(t[0],[0,100],a,!0),It(t[1],[0,100],a,!0)]},e.prototype._updateInterval=function(t,a){var n=this.dataZoomModel,i=this._handleEnds,o=this._getViewExtent(),s=n.findRepresentativeAxisProxy().getMinMaxSpan(),l=[0,100];ci(a,i,o,n.get("zoomLock")?"all":t,s.minSpan!=null?It(s.minSpan,l,o,!0):null,s.maxSpan!=null?It(s.maxSpan,l,o,!0):null);var u=this._range,f=this._range=ar([It(i[0],o,l,!0),It(i[1],o,l,!0)]);return!u||u[0]!==f[0]||u[1]!==f[1]},e.prototype._updateView=function(t){var a=this._displayables,n=this._handleEnds,i=ar(n.slice()),o=this._size;C([0,1],function(c){var p=a.handles[c],d=this._handleHeight;p.attr({scaleX:d/2,scaleY:d/2,x:n[c]+(c?-1:1),y:o[1]/2-d/2})},this),a.filler.setShape({x:i[0],y:0,width:i[1]-i[0],height:o[1]});var s={x:i[0],width:i[1]-i[0]};a.moveHandle&&(a.moveHandle.setShape(s),a.moveZone.setShape(s),a.moveZone.getBoundingRect(),a.moveHandleIcon&&a.moveHandleIcon.attr("x",s.x+s.width/2));for(var l=a.dataShadowSegs,u=[0,i[0],i[1],o[0]],f=0;f<l.length;f++){var h=l[f],v=h.getClipPath();v||(v=new wt,h.setClipPath(v)),v.setShape({x:u[f],y:0,width:u[f+1]-u[f],height:o[1]})}this._updateDataInfo(t)},e.prototype._updateDataInfo=function(t){var a=this.dataZoomModel,n=this._displayables,i=n.handleLabels,o=this._orient,s=["",""];if(a.get("showDetail")){var l=a.findRepresentativeAxisProxy();if(l){var u=l.getAxisModel().axis,f=this._range,h=t?l.calculateDataWindow({start:f[0],end:f[1]}).valueWindow:l.getDataValueWindow();s=[this._formatLabel(h[0],u),this._formatLabel(h[1],u)]}}var v=ar(this._handleEnds.slice());c.call(this,0),c.call(this,1);function c(p){var d=Xn(n.handles[p].parent,this.group),g=nh(p===0?"right":"left",d),y=this._handleWidth/2+D7,m=mr([v[p]+(p===0?-y:y),this._size[1]/2],d);i[p].setStyle({x:m[0],y:m[1],verticalAlign:o===jo?"middle":g,align:o===jo?g:"center",text:s[p]})}},e.prototype._formatLabel=function(t,a){var n=this.dataZoomModel,i=n.get("labelFormatter"),o=n.get("labelPrecision");(o==null||o==="auto")&&(o=a.getPixelPrecision());var s=t==null||isNaN(t)?"":a.type==="category"||a.type==="time"?a.scale.getLabel({value:Math.round(t)}):t.toFixed(Math.min(o,20));return K(i)?i(t,s):$(i)?i.replace("{value}",s):s},e.prototype._showDataInfo=function(t){t=this._dragging||t;var a=this._displayables,n=a.handleLabels;n[0].attr("invisible",!t),n[1].attr("invisible",!t),a.moveHandle&&this.api[t?"enterEmphasis":"leaveEmphasis"](a.moveHandle,1)},e.prototype._onDragMove=function(t,a,n,i){this._dragging=!0,ia(i.event);var o=this._displayables.sliderGroup.getLocalTransform(),s=mr([a,n],o,!0),l=this._updateInterval(t,s[0]),u=this.dataZoomModel.get("realtime");this._updateView(!u),l&&u&&this._dispatchZoomAction(!0)},e.prototype._onDragEnd=function(){this._dragging=!1,this._showDataInfo(!1);var t=this.dataZoomModel.get("realtime");!t&&this._dispatchZoomAction(!1)},e.prototype._onClickPanel=function(t){var a=this._size,n=this._displayables.sliderGroup.transformCoordToLocal(t.offsetX,t.offsetY);if(!(n[0]<0||n[0]>a[0]||n[1]<0||n[1]>a[1])){var i=this._handleEnds,o=(i[0]+i[1])/2,s=this._updateInterval("all",n[0]-o);this._updateView(),s&&this._dispatchZoomAction(!1)}},e.prototype._onBrushStart=function(t){var a=t.offsetX,n=t.offsetY;this._brushStart=new ut(a,n),this._brushing=!0,this._brushStartTime=+new Date},e.prototype._onBrushEnd=function(t){if(this._brushing){var a=this._displayables.brushRect;if(this._brushing=!1,!!a){a.attr("ignore",!0);var n=a.shape,i=+new Date;if(!(i-this._brushStartTime<200&&Math.abs(n.width)<5)){var o=this._getViewExtent(),s=[0,100];this._range=ar([It(n.x,o,s,!0),It(n.x+n.width,o,s,!0)]),this._handleEnds=[n.x,n.x+n.width],this._updateView(),this._dispatchZoomAction(!1)}}}},e.prototype._onBrush=function(t){this._brushing&&(ia(t.event),this._updateBrushRect(t.offsetX,t.offsetY))},e.prototype._updateBrushRect=function(t,a){var n=this._displayables,i=this.dataZoomModel,o=n.brushRect;o||(o=n.brushRect=new Jo({silent:!0,style:i.getModel("brushStyle").getItemStyle()}),n.sliderGroup.add(o)),o.attr("ignore",!1);var s=this._brushStart,l=this._displayables.sliderGroup,u=l.transformCoordToLocal(t,a),f=l.transformCoordToLocal(s.x,s.y),h=this._size;u[0]=Math.max(Math.min(h[0],u[0]),0),o.setShape({x:f[0],y:0,width:u[0]-f[0],height:h[1]})},e.prototype._dispatchZoomAction=function(t){var a=this._range;this.api.dispatchAction({type:"dataZoom",from:this.uid,dataZoomId:this.dataZoomModel.id,animation:t?I7:null,start:a[0],end:a[1]})},e.prototype._findCoordRect=function(){var t,a=DI(this.dataZoomModel).infoList;if(!t&&a.length){var n=a[0].model.coordinateSystem;t=n.getRect&&n.getRect()}if(!t){var i=this.api.getWidth(),o=this.api.getHeight();t={x:i*.2,y:o*.2,width:i*.6,height:o*.6}}return t},e.type="dataZoom.slider",e}(Hy);function P7(r){var e={x:"y",y:"x",radius:"angle",angle:"radius"};return e[r]}function Iw(r){return r==="vertical"?"ns-resize":"ew-resize"}const R7=L7;function XI(r){r.registerComponentModel(T7),r.registerComponentView(R7),Wy(r)}function E7(r){gt(ZI),gt(XI)}var qI={get:function(r,e,t){var a=rt((k7[r]||{})[e]);return t&&z(a)?a[a.length-1]:a}},k7={color:{active:["#006edd","#e0ffff"],inactive:["rgba(0,0,0,0)"]},colorHue:{active:[0,360],inactive:[0,0]},colorSaturation:{active:[.3,1],inactive:[0,0]},colorLightness:{active:[.9,.5],inactive:[0,0]},colorAlpha:{active:[.3,1],inactive:[0,0]},opacity:{active:[.3,1],inactive:[0,0]},symbol:{active:["circle","roundRect","diamond"],inactive:["none"]},symbolSize:{active:[10,50],inactive:[0,0]}},Lw=le.mapVisual,O7=le.eachVisual,N7=z,Pw=C,B7=ar,V7=It,Vf=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.stateList=["inRange","outOfRange"],t.replacableOptionKeys=["inRange","outOfRange","target","controller","color"],t.layoutMode={type:"box",ignoreSize:!0},t.dataBound=[-1/0,1/0],t.targetVisuals={},t.controllerVisuals={},t}return e.prototype.init=function(t,a,n){this.mergeDefaultAndTheme(t,n)},e.prototype.optionUpdated=function(t,a){var n=this.option;!a&&BI(n,t,this.replacableOptionKeys),this.textStyleModel=this.getModel("textStyle"),this.resetItemSize(),this.completeVisualOption()},e.prototype.resetVisual=function(t){var a=this.stateList;t=U(t,this),this.controllerVisuals=Pd(this.option.controller,a,t),this.targetVisuals=Pd(this.option.target,a,t)},e.prototype.getItemSymbol=function(){return null},e.prototype.getTargetSeriesIndices=function(){var t=this.option.seriesIndex,a=[];return t==null||t==="all"?this.ecModel.eachSeries(function(n,i){a.push(i)}):a=Pt(t),a},e.prototype.eachTargetSeries=function(t,a){C(this.getTargetSeriesIndices(),function(n){var i=this.ecModel.getSeriesByIndex(n);i&&t.call(a,i)},this)},e.prototype.isTargetSeries=function(t){var a=!1;return this.eachTargetSeries(function(n){n===t&&(a=!0)}),a},e.prototype.formatValueText=function(t,a,n){var i=this.option,o=i.precision,s=this.dataBound,l=i.formatter,u;n=n||["<",">"],z(t)&&(t=t.slice(),u=!0);var f=a?t:u?[h(t[0]),h(t[1])]:h(t);if($(l))return l.replace("{value}",u?f[0]:f).replace("{value2}",u?f[1]:f);if(K(l))return u?l(t[0],t[1]):l(t);if(u)return t[0]===s[0]?n[0]+" "+f[1]:t[1]===s[1]?n[1]+" "+f[0]:f[0]+" - "+f[1];return f;function h(v){return v===s[0]?"min":v===s[1]?"max":(+v).toFixed(Math.min(o,20))}},e.prototype.resetExtent=function(){var t=this.option,a=B7([t.min,t.max]);this._dataExtent=a},e.prototype.getDataDimensionIndex=function(t){var a=this.option.dimension;if(a!=null)return t.getDimensionIndex(a);for(var n=t.dimensions,i=n.length-1;i>=0;i--){var o=n[i],s=t.getDimensionInfo(o);if(!s.isCalculationCoord)return s.storeDimIndex}},e.prototype.getExtent=function(){return this._dataExtent.slice()},e.prototype.completeVisualOption=function(){var t=this.ecModel,a=this.option,n={inRange:a.inRange,outOfRange:a.outOfRange},i=a.target||(a.target={}),o=a.controller||(a.controller={});ft(i,n),ft(o,n);var s=this.isCategory();l.call(this,i),l.call(this,o),u.call(this,i,"inRange","outOfRange"),f.call(this,o);function l(h){N7(a.color)&&!h.inRange&&(h.inRange={color:a.color.slice().reverse()}),h.inRange=h.inRange||{color:t.get("gradientColor")}}function u(h,v,c){var p=h[v],d=h[c];p&&!d&&(d=h[c]={},Pw(p,function(g,y){if(le.isValidType(y)){var m=qI.get(y,"inactive",s);m!=null&&(d[y]=m,y==="color"&&!d.hasOwnProperty("opacity")&&!d.hasOwnProperty("colorAlpha")&&(d.opacity=[0,0]))}}))}function f(h){var v=(h.inRange||{}).symbol||(h.outOfRange||{}).symbol,c=(h.inRange||{}).symbolSize||(h.outOfRange||{}).symbolSize,p=this.get("inactiveColor"),d=this.getItemSymbol(),g=d||"roundRect";Pw(this.stateList,function(y){var m=this.itemSize,_=h[y];_||(_=h[y]={color:s?p:[p]}),_.symbol==null&&(_.symbol=v&&rt(v)||(s?g:[g])),_.symbolSize==null&&(_.symbolSize=c&&rt(c)||(s?m[0]:[m[0],m[0]])),_.symbol=Lw(_.symbol,function(x){return x==="none"?g:x});var S=_.symbolSize;if(S!=null){var w=-1/0;O7(S,function(x){x>w&&(w=x)}),_.symbolSize=Lw(S,function(x){return V7(x,[0,w],[0,m[0]],!0)})}},this)}},e.prototype.resetItemSize=function(){this.itemSize=[parseFloat(this.get("itemWidth")),parseFloat(this.get("itemHeight"))]},e.prototype.isCategory=function(){return!!this.option.categories},e.prototype.setSelected=function(t){},e.prototype.getSelected=function(){return null},e.prototype.getValueState=function(t){return null},e.prototype.getVisualMeta=function(t){return null},e.type="visualMap",e.dependencies=["series"],e.defaultOption={show:!0,z:4,seriesIndex:"all",min:0,max:200,left:0,right:null,top:null,bottom:0,itemWidth:null,itemHeight:null,inverse:!1,orient:"vertical",backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",contentColor:"#5793f3",inactiveColor:"#aaa",borderWidth:0,padding:5,textGap:10,precision:0,textStyle:{color:"#333"}},e}(Tt),Rw=[20,140],z7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.optionUpdated=function(t,a){r.prototype.optionUpdated.apply(this,arguments),this.resetExtent(),this.resetVisual(function(n){n.mappingMethod="linear",n.dataExtent=this.getExtent()}),this._resetRange()},e.prototype.resetItemSize=function(){r.prototype.resetItemSize.apply(this,arguments);var t=this.itemSize;(t[0]==null||isNaN(t[0]))&&(t[0]=Rw[0]),(t[1]==null||isNaN(t[1]))&&(t[1]=Rw[1])},e.prototype._resetRange=function(){var t=this.getExtent(),a=this.option.range;!a||a.auto?(t.auto=1,this.option.range=t):z(a)&&(a[0]>a[1]&&a.reverse(),a[0]=Math.max(a[0],t[0]),a[1]=Math.min(a[1],t[1]))},e.prototype.completeVisualOption=function(){r.prototype.completeVisualOption.apply(this,arguments),C(this.stateList,function(t){var a=this.option.controller[t].symbolSize;a&&a[0]!==a[1]&&(a[0]=a[1]/3)},this)},e.prototype.setSelected=function(t){this.option.range=t.slice(),this._resetRange()},e.prototype.getSelected=function(){var t=this.getExtent(),a=ar((this.get("range")||[]).slice());return a[0]>t[1]&&(a[0]=t[1]),a[1]>t[1]&&(a[1]=t[1]),a[0]<t[0]&&(a[0]=t[0]),a[1]<t[0]&&(a[1]=t[0]),a},e.prototype.getValueState=function(t){var a=this.option.range,n=this.getExtent();return(a[0]<=n[0]||a[0]<=t)&&(a[1]>=n[1]||t<=a[1])?"inRange":"outOfRange"},e.prototype.findTargetDataIndices=function(t){var a=[];return this.eachTargetSeries(function(n){var i=[],o=n.getData();o.each(this.getDataDimensionIndex(o),function(s,l){t[0]<=s&&s<=t[1]&&i.push(l)},this),a.push({seriesId:n.id,dataIndex:i})},this),a},e.prototype.getVisualMeta=function(t){var a=Ew(this,"outOfRange",this.getExtent()),n=Ew(this,"inRange",this.option.range.slice()),i=[];function o(c,p){i.push({value:c,color:t(c,p)})}for(var s=0,l=0,u=n.length,f=a.length;l<f&&(!n.length||a[l]<=n[0]);l++)a[l]<n[s]&&o(a[l],"outOfRange");for(var h=1;s<u;s++,h=0)h&&i.length&&o(n[s],"outOfRange"),o(n[s],"inRange");for(var h=1;l<f;l++)(!n.length||n[n.length-1]<a[l])&&(h&&(i.length&&o(i[i.length-1].value,"outOfRange"),h=0),o(a[l],"outOfRange"));var v=i.length;return{stops:i,outerColors:[v?i[0].color:"transparent",v?i[v-1].color:"transparent"]}},e.type="visualMap.continuous",e.defaultOption=ja(Vf.defaultOption,{align:"auto",calculable:!1,hoverLink:!0,realtime:!0,handleIcon:"path://M-11.39,9.77h0a3.5,3.5,0,0,1-3.5,3.5h-22a3.5,3.5,0,0,1-3.5-3.5h0a3.5,3.5,0,0,1,3.5-3.5h22A3.5,3.5,0,0,1-11.39,9.77Z",handleSize:"120%",handleStyle:{borderColor:"#fff",borderWidth:1},indicatorIcon:"circle",indicatorSize:"50%",indicatorStyle:{borderColor:"#fff",borderWidth:2,shadowBlur:2,shadowOffsetX:1,shadowOffsetY:1,shadowColor:"rgba(0,0,0,0.2)"}}),e}(Vf);function Ew(r,e,t){if(t[0]===t[1])return t.slice();for(var a=200,n=(t[1]-t[0])/a,i=t[0],o=[],s=0;s<=a&&i<t[1];s++)o.push(i),i+=n;return o.push(t[1]),o}const G7=z7;var F7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.autoPositionValues={left:1,right:1,top:1,bottom:1},t}return e.prototype.init=function(t,a){this.ecModel=t,this.api=a},e.prototype.render=function(t,a,n,i){if(this.visualMapModel=t,t.get("show")===!1){this.group.removeAll();return}this.doRender(t,a,n,i)},e.prototype.renderBackground=function(t){var a=this.visualMapModel,n=yo(a.get("padding")||0),i=t.getBoundingRect();t.add(new wt({z2:-1,silent:!0,shape:{x:i.x-n[3],y:i.y-n[0],width:i.width+n[3]+n[1],height:i.height+n[0]+n[2]},style:{fill:a.get("backgroundColor"),stroke:a.get("borderColor"),lineWidth:a.get("borderWidth")}}))},e.prototype.getControllerVisual=function(t,a,n){n=n||{};var i=n.forceState,o=this.visualMapModel,s={};if(a==="color"){var l=o.get("contentColor");s.color=l}function u(c){return s[c]}function f(c,p){s[c]=p}var h=o.controllerVisuals[i||o.getValueState(t)],v=le.prepareVisualTypes(h);return C(v,function(c){var p=h[c];n.convertOpacityToAlpha&&c==="opacity"&&(c="colorAlpha",p=h.__alphaForOpacity),le.dependsOn(c,a)&&p&&p.applyVisual(t,u,f)}),s[a]},e.prototype.positionGroup=function(t){var a=this.visualMapModel,n=this.api;hh(t,a.getBoxLayoutParams(),{width:n.getWidth(),height:n.getHeight()})},e.prototype.doRender=function(t,a,n,i){},e.type="visualMap",e}(Ht);const KI=F7;var kw=[["left","right","width"],["top","bottom","height"]];function QI(r,e,t){var a=r.option,n=a.align;if(n!=null&&n!=="auto")return n;for(var i={width:e.getWidth(),height:e.getHeight()},o=a.orient==="horizontal"?1:0,s=kw[o],l=[0,null,10],u={},f=0;f<3;f++)u[kw[1-o][f]]=l[f],u[s[f]]=f===2?t[0]:a[s[f]];var h=[["x","width",3],["y","height",0]][o],v=Jt(u,i,a.padding);return s[(v.margin[h[2]]||0)+v[h[0]]+v[h[1]]*.5<i[h[1]]*.5?0:1]}function Zu(r,e){return C(r||[],function(t){t.dataIndex!=null&&(t.dataIndexInside=t.dataIndex,t.dataIndex=null),t.highlightKey="visualMap"+(e?e.componentIndex:"")}),r}var Ir=It,H7=C,Ow=Math.min,qc=Math.max,W7=12,$7=6,U7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._shapes={},t._dataInterval=[],t._handleEnds=[],t._hoverLinkDataIndices=[],t}return e.prototype.init=function(t,a){r.prototype.init.call(this,t,a),this._hoverLinkFromSeriesMouseOver=U(this._hoverLinkFromSeriesMouseOver,this),this._hideIndicator=U(this._hideIndicator,this)},e.prototype.doRender=function(t,a,n,i){(!i||i.type!=="selectDataRange"||i.from!==this.uid)&&this._buildView()},e.prototype._buildView=function(){this.group.removeAll();var t=this.visualMapModel,a=this.group;this._orient=t.get("orient"),this._useHandle=t.get("calculable"),this._resetInterval(),this._renderBar(a);var n=t.get("text");this._renderEndsText(a,n,0),this._renderEndsText(a,n,1),this._updateView(!0),this.renderBackground(a),this._updateView(),this._enableHoverLinkToSeries(),this._enableHoverLinkFromSeries(),this.positionGroup(a)},e.prototype._renderEndsText=function(t,a,n){if(a){var i=a[1-n];i=i!=null?i+"":"";var o=this.visualMapModel,s=o.get("textGap"),l=o.itemSize,u=this._shapes.mainGroup,f=this._applyTransform([l[0]/2,n===0?-s:l[1]+s],u),h=this._applyTransform(n===0?"bottom":"top",u),v=this._orient,c=this.visualMapModel.textStyleModel;this.group.add(new At({style:kt(c,{x:f[0],y:f[1],verticalAlign:v==="horizontal"?"middle":h,align:v==="horizontal"?h:"center",text:i})}))}},e.prototype._renderBar=function(t){var a=this.visualMapModel,n=this._shapes,i=a.itemSize,o=this._orient,s=this._useHandle,l=QI(a,this.api,i),u=n.mainGroup=this._createBarGroup(l),f=new at;u.add(f),f.add(n.outOfRange=Nw()),f.add(n.inRange=Nw(null,s?Vw(this._orient):null,U(this._dragHandle,this,"all",!1),U(this._dragHandle,this,"all",!0))),f.setClipPath(new wt({shape:{x:0,y:0,width:i[0],height:i[1],r:3}}));var h=a.textStyleModel.getTextRect("国"),v=qc(h.width,h.height);s&&(n.handleThumbs=[],n.handleLabels=[],n.handleLabelPoints=[],this._createHandle(a,u,0,i,v,o),this._createHandle(a,u,1,i,v,o)),this._createIndicator(a,u,i,v,o),t.add(u)},e.prototype._createHandle=function(t,a,n,i,o,s){var l=U(this._dragHandle,this,n,!1),u=U(this._dragHandle,this,n,!0),f=_r(t.get("handleSize"),i[0]),h=qt(t.get("handleIcon"),-f/2,-f/2,f,f,null,!0),v=Vw(this._orient);h.attr({cursor:v,draggable:!0,drift:l,ondragend:u,onmousemove:function(y){ia(y.event)}}),h.x=i[0]/2,h.useStyle(t.getModel("handleStyle").getItemStyle()),h.setStyle({strokeNoScale:!0,strokeFirst:!0}),h.style.lineWidth*=2,h.ensureState("emphasis").style=t.getModel(["emphasis","handleStyle"]).getItemStyle(),Bn(h,!0),a.add(h);var c=this.visualMapModel.textStyleModel,p=new At({cursor:v,draggable:!0,drift:l,onmousemove:function(y){ia(y.event)},ondragend:u,style:kt(c,{x:0,y:0,text:""})});p.ensureState("blur").style={opacity:.1},p.stateTransition={duration:200},this.group.add(p);var d=[f,0],g=this._shapes;g.handleThumbs[n]=h,g.handleLabelPoints[n]=d,g.handleLabels[n]=p},e.prototype._createIndicator=function(t,a,n,i,o){var s=_r(t.get("indicatorSize"),n[0]),l=qt(t.get("indicatorIcon"),-s/2,-s/2,s,s,null,!0);l.attr({cursor:"move",invisible:!0,silent:!0,x:n[0]/2});var u=t.getModel("indicatorStyle").getItemStyle();if(l instanceof he){var f=l.style;l.useStyle(V({image:f.image,x:f.x,y:f.y,width:f.width,height:f.height},u))}else l.useStyle(u);a.add(l);var h=this.visualMapModel.textStyleModel,v=new At({silent:!0,invisible:!0,style:kt(h,{x:0,y:0,text:""})});this.group.add(v);var c=[(o==="horizontal"?i/2:$7)+n[0]/2,0],p=this._shapes;p.indicator=l,p.indicatorLabel=v,p.indicatorLabelPoint=c,this._firstShowIndicator=!0},e.prototype._dragHandle=function(t,a,n,i){if(this._useHandle){if(this._dragging=!a,!a){var o=this._applyTransform([n,i],this._shapes.mainGroup,!0);this._updateInterval(t,o[1]),this._hideIndicator(),this._updateView()}a===!this.visualMapModel.get("realtime")&&this.api.dispatchAction({type:"selectDataRange",from:this.uid,visualMapId:this.visualMapModel.id,selected:this._dataInterval.slice()}),a?!this._hovering&&this._clearHoverLinkToSeries():Bw(this.visualMapModel)&&this._doHoverLinkToSeries(this._handleEnds[t],!1)}},e.prototype._resetInterval=function(){var t=this.visualMapModel,a=this._dataInterval=t.getSelected(),n=t.getExtent(),i=[0,t.itemSize[1]];this._handleEnds=[Ir(a[0],n,i,!0),Ir(a[1],n,i,!0)]},e.prototype._updateInterval=function(t,a){a=a||0;var n=this.visualMapModel,i=this._handleEnds,o=[0,n.itemSize[1]];ci(a,i,o,t,0);var s=n.getExtent();this._dataInterval=[Ir(i[0],o,s,!0),Ir(i[1],o,s,!0)]},e.prototype._updateView=function(t){var a=this.visualMapModel,n=a.getExtent(),i=this._shapes,o=[0,a.itemSize[1]],s=t?o:this._handleEnds,l=this._createBarVisual(this._dataInterval,n,s,"inRange"),u=this._createBarVisual(n,n,o,"outOfRange");i.inRange.setStyle({fill:l.barColor}).setShape("points",l.barPoints),i.outOfRange.setStyle({fill:u.barColor}).setShape("points",u.barPoints),this._updateHandle(s,l)},e.prototype._createBarVisual=function(t,a,n,i){var o={forceState:i,convertOpacityToAlpha:!0},s=this._makeColorGradient(t,o),l=[this.getControllerVisual(t[0],"symbolSize",o),this.getControllerVisual(t[1],"symbolSize",o)],u=this._createBarPoints(n,l);return{barColor:new ho(0,0,0,1,s),barPoints:u,handlesColor:[s[0].color,s[s.length-1].color]}},e.prototype._makeColorGradient=function(t,a){var n=100,i=[],o=(t[1]-t[0])/n;i.push({color:this.getControllerVisual(t[0],"color",a),offset:0});for(var s=1;s<n;s++){var l=t[0]+o*s;if(l>t[1])break;i.push({color:this.getControllerVisual(l,"color",a),offset:s/n})}return i.push({color:this.getControllerVisual(t[1],"color",a),offset:1}),i},e.prototype._createBarPoints=function(t,a){var n=this.visualMapModel.itemSize;return[[n[0]-a[0],t[0]],[n[0],t[0]],[n[0],t[1]],[n[0]-a[1],t[1]]]},e.prototype._createBarGroup=function(t){var a=this._orient,n=this.visualMapModel.get("inverse");return new at(a==="horizontal"&&!n?{scaleX:t==="bottom"?1:-1,rotation:Math.PI/2}:a==="horizontal"&&n?{scaleX:t==="bottom"?-1:1,rotation:-Math.PI/2}:a==="vertical"&&!n?{scaleX:t==="left"?1:-1,scaleY:-1}:{scaleX:t==="left"?1:-1})},e.prototype._updateHandle=function(t,a){if(this._useHandle){var n=this._shapes,i=this.visualMapModel,o=n.handleThumbs,s=n.handleLabels,l=i.itemSize,u=i.getExtent();H7([0,1],function(f){var h=o[f];h.setStyle("fill",a.handlesColor[f]),h.y=t[f];var v=Ir(t[f],[0,l[1]],u,!0),c=this.getControllerVisual(v,"symbolSize");h.scaleX=h.scaleY=c/l[0],h.x=l[0]-c/2;var p=mr(n.handleLabelPoints[f],Xn(h,this.group));s[f].setStyle({x:p[0],y:p[1],text:i.formatValueText(this._dataInterval[f]),verticalAlign:"middle",align:this._orient==="vertical"?this._applyTransform("left",n.mainGroup):"center"})},this)}},e.prototype._showIndicator=function(t,a,n,i){var o=this.visualMapModel,s=o.getExtent(),l=o.itemSize,u=[0,l[1]],f=this._shapes,h=f.indicator;if(h){h.attr("invisible",!1);var v={convertOpacityToAlpha:!0},c=this.getControllerVisual(t,"color",v),p=this.getControllerVisual(t,"symbolSize"),d=Ir(t,s,u,!0),g=l[0]-p/2,y={x:h.x,y:h.y};h.y=d,h.x=g;var m=mr(f.indicatorLabelPoint,Xn(h,this.group)),_=f.indicatorLabel;_.attr("invisible",!1);var S=this._applyTransform("left",f.mainGroup),w=this._orient,x=w==="horizontal";_.setStyle({text:(n||"")+o.formatValueText(a),verticalAlign:x?S:"middle",align:x?"center":S});var b={x:g,y:d,style:{fill:c}},T={style:{x:m[0],y:m[1]}};if(o.ecModel.isAnimationEnabled()&&!this._firstShowIndicator){var A={duration:100,easing:"cubicInOut",additive:!0};h.x=y.x,h.y=y.y,h.animateTo(b,A),_.animateTo(T,A)}else h.attr(b),_.attr(T);this._firstShowIndicator=!1;var D=this._shapes.handleLabels;if(D)for(var M=0;M<D.length;M++)this.api.enterBlur(D[M])}},e.prototype._enableHoverLinkToSeries=function(){var t=this;this._shapes.mainGroup.on("mousemove",function(a){if(t._hovering=!0,!t._dragging){var n=t.visualMapModel.itemSize,i=t._applyTransform([a.offsetX,a.offsetY],t._shapes.mainGroup,!0,!0);i[1]=Ow(qc(0,i[1]),n[1]),t._doHoverLinkToSeries(i[1],0<=i[0]&&i[0]<=n[0])}}).on("mouseout",function(){t._hovering=!1,!t._dragging&&t._clearHoverLinkToSeries()})},e.prototype._enableHoverLinkFromSeries=function(){var t=this.api.getZr();this.visualMapModel.option.hoverLink?(t.on("mouseover",this._hoverLinkFromSeriesMouseOver,this),t.on("mouseout",this._hideIndicator,this)):this._clearHoverLinkFromSeries()},e.prototype._doHoverLinkToSeries=function(t,a){var n=this.visualMapModel,i=n.itemSize;if(n.option.hoverLink){var o=[0,i[1]],s=n.getExtent();t=Ow(qc(o[0],t),o[1]);var l=Y7(n,s,o),u=[t-l,t+l],f=Ir(t,o,s,!0),h=[Ir(u[0],o,s,!0),Ir(u[1],o,s,!0)];u[0]<o[0]&&(h[0]=-1/0),u[1]>o[1]&&(h[1]=1/0),a&&(h[0]===-1/0?this._showIndicator(f,h[1],"< ",l):h[1]===1/0?this._showIndicator(f,h[0],"> ",l):this._showIndicator(f,f,"≈ ",l));var v=this._hoverLinkDataIndices,c=[];(a||Bw(n))&&(c=this._hoverLinkDataIndices=n.findTargetDataIndices(h));var p=vP(v,c);this._dispatchHighDown("downplay",Zu(p[0],n)),this._dispatchHighDown("highlight",Zu(p[1],n))}},e.prototype._hoverLinkFromSeriesMouseOver=function(t){var a;if(zn(t.target,function(l){var u=nt(l);if(u.dataIndex!=null)return a=u,!0},!0),!!a){var n=this.ecModel.getSeriesByIndex(a.seriesIndex),i=this.visualMapModel;if(i.isTargetSeries(n)){var o=n.getData(a.dataType),s=o.getStore().get(i.getDataDimensionIndex(o),a.dataIndex);isNaN(s)||this._showIndicator(s,s)}}},e.prototype._hideIndicator=function(){var t=this._shapes;t.indicator&&t.indicator.attr("invisible",!0),t.indicatorLabel&&t.indicatorLabel.attr("invisible",!0);var a=this._shapes.handleLabels;if(a)for(var n=0;n<a.length;n++)this.api.leaveBlur(a[n])},e.prototype._clearHoverLinkToSeries=function(){this._hideIndicator();var t=this._hoverLinkDataIndices;this._dispatchHighDown("downplay",Zu(t,this.visualMapModel)),t.length=0},e.prototype._clearHoverLinkFromSeries=function(){this._hideIndicator();var t=this.api.getZr();t.off("mouseover",this._hoverLinkFromSeriesMouseOver),t.off("mouseout",this._hideIndicator)},e.prototype._applyTransform=function(t,a,n,i){var o=Xn(a,i?null:this.group);return z(t)?mr(t,o,n):nh(t,o,n)},e.prototype._dispatchHighDown=function(t,a){a&&a.length&&this.api.dispatchAction({type:t,batch:a})},e.prototype.dispose=function(){this._clearHoverLinkFromSeries(),this._clearHoverLinkToSeries()},e.type="visualMap.continuous",e}(KI);function Nw(r,e,t,a){return new De({shape:{points:r},draggable:!!t,cursor:e,drift:t,onmousemove:function(n){ia(n.event)},ondragend:a})}function Y7(r,e,t){var a=W7/2,n=r.get("hoverLinkDataSize");return n&&(a=Ir(n,e,t,!0)/2),a}function Bw(r){var e=r.get("hoverLinkOnHandle");return!!(e??r.get("realtime"))}function Vw(r){return r==="vertical"?"ns-resize":"ew-resize"}const Z7=U7;var X7={type:"selectDataRange",event:"dataRangeSelected",update:"update"},q7=function(r,e){e.eachComponent({mainType:"visualMap",query:r},function(t){t.setSelected(r.selected)})},K7=[{createOnAllSeries:!0,reset:function(r,e){var t=[];return e.eachComponent("visualMap",function(a){var n=r.pipelineContext;!a.isTargetSeries(r)||n&&n.large||t.push(Z8(a.stateList,a.targetVisuals,U(a.getValueState,a),a.getDataDimensionIndex(r.getData())))}),t}},{createOnAllSeries:!0,reset:function(r,e){var t=r.getData(),a=[];e.eachComponent("visualMap",function(n){if(n.isTargetSeries(r)){var i=n.getVisualMeta(U(Q7,null,r,n))||{stops:[],outerColors:[]},o=n.getDataDimensionIndex(t);o>=0&&(i.dimension=o,a.push(i))}}),r.getData().setVisual("visualMeta",a)}}];function Q7(r,e,t,a){for(var n=e.targetVisuals[a],i=le.prepareVisualTypes(n),o={color:hl(r.getData(),"color")},s=0,l=i.length;s<l;s++){var u=i[s],f=n[u==="opacity"?"__alphaForOpacity":u];f&&f.applyVisual(t,h,v)}return o.color;function h(c){return o[c]}function v(c,p){o[c]=p}}var zw=C;function J7(r){var e=r&&r.visualMap;z(e)||(e=e?[e]:[]),zw(e,function(t){if(t){Ri(t,"splitList")&&!Ri(t,"pieces")&&(t.pieces=t.splitList,delete t.splitList);var a=t.pieces;a&&z(a)&&zw(a,function(n){tt(n)&&(Ri(n,"start")&&!Ri(n,"min")&&(n.min=n.start),Ri(n,"end")&&!Ri(n,"max")&&(n.max=n.end))})}})}function Ri(r,e){return r&&r.hasOwnProperty&&r.hasOwnProperty(e)}var Gw=!1;function JI(r){Gw||(Gw=!0,r.registerSubTypeDefaulter("visualMap",function(e){return!e.categories&&(!(e.pieces?e.pieces.length>0:e.splitNumber>0)||e.calculable)?"continuous":"piecewise"}),r.registerAction(X7,q7),C(K7,function(e){r.registerVisual(r.PRIORITY.VISUAL.COMPONENT,e)}),r.registerPreprocessor(J7))}function jI(r){r.registerComponentModel(G7),r.registerComponentView(Z7),JI(r)}var j7=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._pieceList=[],t}return e.prototype.optionUpdated=function(t,a){r.prototype.optionUpdated.apply(this,arguments),this.resetExtent();var n=this._mode=this._determineMode();this._pieceList=[],t9[this._mode].call(this,this._pieceList),this._resetSelected(t,a);var i=this.option.categories;this.resetVisual(function(o,s){n==="categories"?(o.mappingMethod="category",o.categories=rt(i)):(o.dataExtent=this.getExtent(),o.mappingMethod="piecewise",o.pieceList=G(this._pieceList,function(l){return l=rt(l),s!=="inRange"&&(l.visual=null),l}))})},e.prototype.completeVisualOption=function(){var t=this.option,a={},n=le.listVisualTypes(),i=this.isCategory();C(t.pieces,function(s){C(n,function(l){s.hasOwnProperty(l)&&(a[l]=1)})}),C(a,function(s,l){var u=!1;C(this.stateList,function(f){u=u||o(t,f,l)||o(t.target,f,l)},this),!u&&C(this.stateList,function(f){(t[f]||(t[f]={}))[l]=qI.get(l,f==="inRange"?"active":"inactive",i)})},this);function o(s,l,u){return s&&s[l]&&s[l].hasOwnProperty(u)}r.prototype.completeVisualOption.apply(this,arguments)},e.prototype._resetSelected=function(t,a){var n=this.option,i=this._pieceList,o=(a?n:t).selected||{};if(n.selected=o,C(i,function(l,u){var f=this.getSelectedMapKey(l);o.hasOwnProperty(f)||(o[f]=!0)},this),n.selectedMode==="single"){var s=!1;C(i,function(l,u){var f=this.getSelectedMapKey(l);o[f]&&(s?o[f]=!1:s=!0)},this)}},e.prototype.getItemSymbol=function(){return this.get("itemSymbol")},e.prototype.getSelectedMapKey=function(t){return this._mode==="categories"?t.value+"":t.index+""},e.prototype.getPieceList=function(){return this._pieceList},e.prototype._determineMode=function(){var t=this.option;return t.pieces&&t.pieces.length>0?"pieces":this.option.categories?"categories":"splitNumber"},e.prototype.setSelected=function(t){this.option.selected=rt(t)},e.prototype.getValueState=function(t){var a=le.findPieceIndex(t,this._pieceList);return a!=null&&this.option.selected[this.getSelectedMapKey(this._pieceList[a])]?"inRange":"outOfRange"},e.prototype.findTargetDataIndices=function(t){var a=[],n=this._pieceList;return this.eachTargetSeries(function(i){var o=[],s=i.getData();s.each(this.getDataDimensionIndex(s),function(l,u){var f=le.findPieceIndex(l,n);f===t&&o.push(u)},this),a.push({seriesId:i.id,dataIndex:o})},this),a},e.prototype.getRepresentValue=function(t){var a;if(this.isCategory())a=t.value;else if(t.value!=null)a=t.value;else{var n=t.interval||[];a=n[0]===-1/0&&n[1]===1/0?0:(n[0]+n[1])/2}return a},e.prototype.getVisualMeta=function(t){if(this.isCategory())return;var a=[],n=["",""],i=this;function o(f,h){var v=i.getRepresentValue({interval:f});h||(h=i.getValueState(v));var c=t(v,h);f[0]===-1/0?n[0]=c:f[1]===1/0?n[1]=c:a.push({value:f[0],color:c},{value:f[1],color:c})}var s=this._pieceList.slice();if(!s.length)s.push({interval:[-1/0,1/0]});else{var l=s[0].interval[0];l!==-1/0&&s.unshift({interval:[-1/0,l]}),l=s[s.length-1].interval[1],l!==1/0&&s.push({interval:[l,1/0]})}var u=-1/0;return C(s,function(f){var h=f.interval;h&&(h[0]>u&&o([u,h[0]],"outOfRange"),o(h.slice()),u=h[1])},this),{stops:a,outerColors:n}},e.type="visualMap.piecewise",e.defaultOption=ja(Vf.defaultOption,{selected:null,minOpen:!1,maxOpen:!1,align:"auto",itemWidth:20,itemHeight:14,itemSymbol:"roundRect",pieces:null,categories:null,splitNumber:5,selectedMode:"multiple",itemGap:10,hoverLink:!0}),e}(Vf),t9={splitNumber:function(r){var e=this.option,t=Math.min(e.precision,20),a=this.getExtent(),n=e.splitNumber;n=Math.max(parseInt(n,10),1),e.splitNumber=n;for(var i=(a[1]-a[0])/n;+i.toFixed(t)!==i&&t<5;)t++;e.precision=t,i=+i.toFixed(t),e.minOpen&&r.push({interval:[-1/0,a[0]],close:[0,0]});for(var o=0,s=a[0];o<n;s+=i,o++){var l=o===n-1?a[1]:s+i;r.push({interval:[s,l],close:[1,1]})}e.maxOpen&&r.push({interval:[a[1],1/0],close:[0,0]}),Rm(r),C(r,function(u,f){u.index=f,u.text=this.formatValueText(u.interval)},this)},categories:function(r){var e=this.option;C(e.categories,function(t){r.push({text:this.formatValueText(t,!0),value:t})},this),Fw(e,r)},pieces:function(r){var e=this.option;C(e.pieces,function(t,a){tt(t)||(t={value:t});var n={text:"",index:a};if(t.label!=null&&(n.text=t.label),t.hasOwnProperty("value")){var i=n.value=t.value;n.interval=[i,i],n.close=[1,1]}else{for(var o=n.interval=[],s=n.close=[0,0],l=[1,0,1],u=[-1/0,1/0],f=[],h=0;h<2;h++){for(var v=[["gte","gt","min"],["lte","lt","max"]][h],c=0;c<3&&o[h]==null;c++)o[h]=t[v[c]],s[h]=l[c],f[h]=c===2;o[h]==null&&(o[h]=u[h])}f[0]&&o[1]===1/0&&(s[0]=0),f[1]&&o[0]===-1/0&&(s[1]=0),o[0]===o[1]&&s[0]&&s[1]&&(n.value=o[0])}n.visual=le.retrieveVisuals(t),r.push(n)},this),Fw(e,r),Rm(r),C(r,function(t){var a=t.close,n=[["<","≤"][a[1]],[">","≥"][a[0]]];t.text=t.text||this.formatValueText(t.value!=null?t.value:t.interval,!1,n)},this)}};function Fw(r,e){var t=r.inverse;(r.orient==="vertical"?!t:t)&&e.reverse()}const e9=j7;var r9=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.doRender=function(){var t=this.group;t.removeAll();var a=this.visualMapModel,n=a.get("textGap"),i=a.textStyleModel,o=i.getFont(),s=i.getTextColor(),l=this._getItemAlign(),u=a.itemSize,f=this._getViewData(),h=f.endsText,v=ie(a.get("showLabel",!0),!h);h&&this._renderEndsText(t,h[0],u,v,l),C(f.viewPieceList,function(c){var p=c.piece,d=new at;d.onclick=U(this._onItemClick,this,p),this._enableHoverLink(d,c.indexInModelPieceList);var g=a.getRepresentValue(p);if(this._createItemSymbol(d,g,[0,0,u[0],u[1]]),v){var y=this.visualMapModel.getValueState(g);d.add(new At({style:{x:l==="right"?-n:u[0]+n,y:u[1]/2,text:p.text,verticalAlign:"middle",align:l,font:o,fill:s,opacity:y==="outOfRange"?.5:1}}))}t.add(d)},this),h&&this._renderEndsText(t,h[1],u,v,l),qn(a.get("orient"),t,a.get("itemGap")),this.renderBackground(t),this.positionGroup(t)},e.prototype._enableHoverLink=function(t,a){var n=this;t.on("mouseover",function(){return i("highlight")}).on("mouseout",function(){return i("downplay")});var i=function(o){var s=n.visualMapModel;s.option.hoverLink&&n.api.dispatchAction({type:o,batch:Zu(s.findTargetDataIndices(a),s)})}},e.prototype._getItemAlign=function(){var t=this.visualMapModel,a=t.option;if(a.orient==="vertical")return QI(t,this.api,t.itemSize);var n=a.align;return(!n||n==="auto")&&(n="left"),n},e.prototype._renderEndsText=function(t,a,n,i,o){if(a){var s=new at,l=this.visualMapModel.textStyleModel;s.add(new At({style:kt(l,{x:i?o==="right"?n[0]:0:n[0]/2,y:n[1]/2,verticalAlign:"middle",align:i?o:"center",text:a})})),t.add(s)}},e.prototype._getViewData=function(){var t=this.visualMapModel,a=G(t.getPieceList(),function(s,l){return{piece:s,indexInModelPieceList:l}}),n=t.get("text"),i=t.get("orient"),o=t.get("inverse");return(i==="horizontal"?o:!o)?a.reverse():n&&(n=n.slice().reverse()),{viewPieceList:a,endsText:n}},e.prototype._createItemSymbol=function(t,a,n){t.add(qt(this.getControllerVisual(a,"symbol"),n[0],n[1],n[2],n[3],this.getControllerVisual(a,"color")))},e.prototype._onItemClick=function(t){var a=this.visualMapModel,n=a.option,i=n.selectedMode;if(i){var o=rt(n.selected),s=a.getSelectedMapKey(t);i==="single"||i===!0?(o[s]=!0,C(o,function(l,u){o[u]=u===s})):o[s]=!o[s],this.api.dispatchAction({type:"selectDataRange",from:this.uid,visualMapId:this.visualMapModel.id,selected:o})}},e.type="visualMap.piecewise",e}(KI);const a9=r9;function tL(r){r.registerComponentModel(e9),r.registerComponentView(a9),JI(r)}function n9(r){gt(jI),gt(tL)}var i9={label:{enabled:!0},decal:{show:!1}},Hw=bt(),o9={};function s9(r,e){var t=r.getModel("aria");if(!t.get("enabled"))return;var a=rt(i9);ft(a.label,r.getLocaleModel().get("aria"),!1),ft(t.option,a,!1),n(),i();function n(){var u=t.getModel("decal"),f=u.get("show");if(f){var h=Z();r.eachSeries(function(v){if(!v.isColorBySeries()){var c=h.get(v.type);c||(c={},h.set(v.type,c)),Hw(v).scope=c}}),r.eachRawSeries(function(v){if(r.isSeriesFiltered(v))return;if(K(v.enableAriaDecal)){v.enableAriaDecal();return}var c=v.getData();if(v.isColorBySeries()){var m=zp(v.ecModel,v.name,o9,r.getSeriesCount()),_=c.getVisual("decal");c.setVisual("decal",S(_,m))}else{var p=v.getRawData(),d={},g=Hw(v).scope;c.each(function(w){var x=c.getRawIndex(w);d[x]=w});var y=p.count();p.each(function(w){var x=d[w],b=p.getName(w)||w+"",T=zp(v.ecModel,b,g,y),A=c.getItemVisual(x,"decal");c.setItemVisual(x,"decal",S(A,T))})}function S(w,x){var b=w?V(V({},x),w):x;return b.dirty=!0,b}})}}function i(){var u=r.getLocaleModel().get("aria"),f=t.getModel("label");if(f.option=j(f.option,u),!!f.get("enabled")){var h=e.getZr().dom;if(f.get("description")){h.setAttribute("aria-label",f.get("description"));return}var v=r.getSeriesCount(),c=f.get(["data","maxCount"])||10,p=f.get(["series","maxCount"])||10,d=Math.min(v,p),g;if(!(v<1)){var y=s();if(y){var m=f.get(["general","withTitle"]);g=o(m,{title:y})}else g=f.get(["general","withoutTitle"]);var _=[],S=v>1?f.get(["series","multiple","prefix"]):f.get(["series","single","prefix"]);g+=o(S,{seriesCount:v}),r.eachSeries(function(T,A){if(A<d){var D=void 0,M=T.get("name"),I=M?"withName":"withoutName";D=v>1?f.get(["series","multiple",I]):f.get(["series","single",I]),D=o(D,{seriesId:T.seriesIndex,seriesName:T.get("name"),seriesType:l(T.subType)});var L=T.getData();if(L.count()>c){var P=f.get(["data","partialData"]);D+=o(P,{displayCnt:c})}else D+=f.get(["data","allData"]);for(var R=f.get(["data","separator","middle"]),E=f.get(["data","separator","end"]),N=[],O=0;O<L.count();O++)if(O<c){var B=L.getName(O),F=L.getValues(O),H=f.get(["data",B?"withName":"withoutName"]);N.push(o(H,{name:B,value:F.join(R)}))}D+=N.join(R)+E,_.push(D)}});var w=f.getModel(["series","multiple","separator"]),x=w.get("middle"),b=w.get("end");g+=_.join(x)+b,h.setAttribute("aria-label",g)}}}function o(u,f){if(!$(u))return u;var h=u;return C(f,function(v,c){h=h.replace(new RegExp("\\{\\s*"+c+"\\s*\\}","g"),v)}),h}function s(){var u=r.get("title");return u&&u.length&&(u=u[0]),u&&u.text}function l(u){var f=r.getLocaleModel().get(["series","typeNames"]);return f[u]||f.chart}}function l9(r){if(!(!r||!r.aria)){var e=r.aria;e.show!=null&&(e.enabled=e.show),e.label=e.label||{},C(["description","general","series","data"],function(t){e[t]!=null&&(e.label[t]=e[t])})}}function u9(r){r.registerPreprocessor(l9),r.registerVisual(r.PRIORITY.VISUAL.ARIA,s9)}var Ww={value:"eq","<":"lt","<=":"lte",">":"gt",">=":"gte","=":"eq","!=":"ne","<>":"ne"},f9=function(){function r(e){var t=this._condVal=$(e)?new RegExp(e):DL(e)?e:null;if(t==null){var a="";Mt(a)}}return r.prototype.evaluate=function(e){var t=typeof e;return $(t)?this._condVal.test(e):Ct(t)?this._condVal.test(e+""):!1},r}(),h9=function(){function r(){}return r.prototype.evaluate=function(){return this.value},r}(),v9=function(){function r(){}return r.prototype.evaluate=function(){for(var e=this.children,t=0;t<e.length;t++)if(!e[t].evaluate())return!1;return!0},r}(),c9=function(){function r(){}return r.prototype.evaluate=function(){for(var e=this.children,t=0;t<e.length;t++)if(e[t].evaluate())return!0;return!1},r}(),p9=function(){function r(){}return r.prototype.evaluate=function(){return!this.child.evaluate()},r}(),d9=function(){function r(){}return r.prototype.evaluate=function(){for(var e=!!this.valueParser,t=this.getValue,a=t(this.valueGetterParam),n=e?this.valueParser(a):null,i=0;i<this.subCondList.length;i++)if(!this.subCondList[i].evaluate(e?n:a))return!1;return!0},r}();function Jy(r,e){if(r===!0||r===!1){var t=new h9;return t.value=r,t}var a="";return eL(r)||Mt(a),r.and?$w("and",r,e):r.or?$w("or",r,e):r.not?g9(r,e):y9(r,e)}function $w(r,e,t){var a=e[r],n="";z(a)||Mt(n),a.length||Mt(n);var i=r==="and"?new v9:new c9;return i.children=G(a,function(o){return Jy(o,t)}),i.children.length||Mt(n),i}function g9(r,e){var t=r.not,a="";eL(t)||Mt(a);var n=new p9;return n.child=Jy(t,e),n.child||Mt(a),n}function y9(r,e){for(var t="",a=e.prepareGetValue(r),n=[],i=_t(r),o=r.parser,s=o?LA(o):null,l=0;l<i.length;l++){var u=i[l];if(!(u==="parser"||e.valueGetterAttrMap.get(u))){var f=Y(Ww,u)?Ww[u]:u,h=r[u],v=s?s(h):h,c=Tk(f,v)||f==="reg"&&new f9(v);c||Mt(t),n.push(c)}}n.length||Mt(t);var p=new d9;return p.valueGetterParam=a,p.valueParser=s,p.getValue=e.getValue,p.subCondList=n,p}function eL(r){return tt(r)&&!ge(r)}var m9=function(){function r(e,t){this._cond=Jy(e,t)}return r.prototype.evaluate=function(){return this._cond.evaluate()},r}();function _9(r,e){return new m9(r,e)}var S9={type:"echarts:filter",transform:function(r){for(var e=r.upstream,t,a=_9(r.config,{valueGetterAttrMap:Z({dimension:!0}),prepareGetValue:function(s){var l="",u=s.dimension;Y(s,"dimension")||Mt(l);var f=e.getDimensionInfo(u);return f||Mt(l),{dimIdx:f.index}},getValue:function(s){return e.retrieveValueFromItem(t,s.dimIdx)}}),n=[],i=0,o=e.count();i<o;i++)t=e.getRawDataItem(i),a.evaluate()&&n.push(t);return{data:n}}},x9={type:"echarts:sort",transform:function(r){var e=r.upstream,t=r.config,a="",n=Pt(t);n.length||Mt(a);var i=[];C(n,function(f){var h=f.dimension,v=f.order,c=f.parser,p=f.incomparable;if(h==null&&Mt(a),v!=="asc"&&v!=="desc"&&Mt(a),p&&p!=="min"&&p!=="max"){var d="";Mt(d)}if(v!=="asc"&&v!=="desc"){var g="";Mt(g)}var y=e.getDimensionInfo(h);y||Mt(a);var m=c?LA(c):null;c&&!m&&Mt(a),i.push({dimIdx:y.index,parser:m,comparator:new RA(v,p)})});var o=e.sourceFormat;o!==ye&&o!==lr&&Mt(a);for(var s=[],l=0,u=e.count();l<u;l++)s.push(e.getRawDataItem(l));return s.sort(function(f,h){for(var v=0;v<i.length;v++){var c=i[v],p=e.retrieveValueFromItem(f,c.dimIdx),d=e.retrieveValueFromItem(h,c.dimIdx);c.parser&&(p=c.parser(p),d=c.parser(d));var g=c.comparator.evaluate(p,d);if(g!==0)return g}return 0}),{data:s}}};function w9(r){r.registerTransform(S9),r.registerTransform(x9)}var b9=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="dataset",t}return e.prototype.init=function(t,a,n){r.prototype.init.call(this,t,a,n),this._sourceManager=new NA(this),$0(this)},e.prototype.mergeOption=function(t,a){r.prototype.mergeOption.call(this,t,a),$0(this)},e.prototype.optionUpdated=function(){this._sourceManager.dirty()},e.prototype.getSourceManager=function(){return this._sourceManager},e.type="dataset",e.defaultOption={seriesLayoutBy:Vr},e}(Tt),T9=function(r){k(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="dataset",t}return e.type="dataset",e}(Ht);function A9(r){r.registerComponentModel(b9),r.registerComponentView(T9)}var Dr=Wr.CMD;function Wi(r,e){return Math.abs(r-e)<1e-5}function Vd(r){var e=r.data,t=r.len(),a=[],n,i=0,o=0,s=0,l=0;function u(L,P){n&&n.length>2&&a.push(n),n=[L,P]}function f(L,P,R,E){Wi(L,R)&&Wi(P,E)||n.push(L,P,R,E,R,E)}function h(L,P,R,E,N,O){var B=Math.abs(P-L),F=Math.tan(B/4)*4/3,H=P<L?-1:1,X=Math.cos(L),Q=Math.sin(L),J=Math.cos(P),ct=Math.sin(P),St=X*N+R,pt=Q*O+E,et=J*N+R,dt=ct*O+E,st=N*F*H,q=O*F*H;n.push(St-st*Q,pt+q*X,et+st*ct,dt-q*J,et,dt)}for(var v,c,p,d,g=0;g<t;){var y=e[g++],m=g===1;switch(m&&(i=e[g],o=e[g+1],s=i,l=o,(y===Dr.L||y===Dr.C||y===Dr.Q)&&(n=[s,l])),y){case Dr.M:i=s=e[g++],o=l=e[g++],u(s,l);break;case Dr.L:v=e[g++],c=e[g++],f(i,o,v,c),i=v,o=c;break;case Dr.C:n.push(e[g++],e[g++],e[g++],e[g++],i=e[g++],o=e[g++]);break;case Dr.Q:v=e[g++],c=e[g++],p=e[g++],d=e[g++],n.push(i+2/3*(v-i),o+2/3*(c-o),p+2/3*(v-p),d+2/3*(c-d),p,d),i=p,o=d;break;case Dr.A:var _=e[g++],S=e[g++],w=e[g++],x=e[g++],b=e[g++],T=e[g++]+b;g+=1;var A=!e[g++];v=Math.cos(b)*w+_,c=Math.sin(b)*x+S,m?(s=v,l=c,u(s,l)):f(i,o,v,c),i=Math.cos(T)*w+_,o=Math.sin(T)*x+S;for(var D=(A?-1:1)*Math.PI/2,M=b;A?M>T:M<T;M+=D){var I=A?Math.max(M+D,T):Math.min(M+D,T);h(M,I,_,S,w,x)}break;case Dr.R:s=i=e[g++],l=o=e[g++],v=s+e[g++],c=l+e[g++],u(v,l),f(v,l,v,c),f(v,c,s,c),f(s,c,s,l),f(s,l,v,l);break;case Dr.Z:n&&f(i,o,s,l),i=s,o=l;break}}return n&&n.length>2&&a.push(n),a}function zd(r,e,t,a,n,i,o,s,l,u){if(Wi(r,t)&&Wi(e,a)&&Wi(n,o)&&Wi(i,s)){l.push(o,s);return}var f=2/u,h=f*f,v=o-r,c=s-e,p=Math.sqrt(v*v+c*c);v/=p,c/=p;var d=t-r,g=a-e,y=n-o,m=i-s,_=d*d+g*g,S=y*y+m*m;if(_<h&&S<h){l.push(o,s);return}var w=v*d+c*g,x=-v*y-c*m,b=_-w*w,T=S-x*x;if(b<h&&w>=0&&T<h&&x>=0){l.push(o,s);return}var A=[],D=[];Wa(r,t,n,o,.5,A),Wa(e,a,i,s,.5,D),zd(A[0],D[0],A[1],D[1],A[2],D[2],A[3],D[3],l,u),zd(A[4],D[4],A[5],D[5],A[6],D[6],A[7],D[7],l,u)}function C9(r,e){var t=Vd(r),a=[];e=e||1;for(var n=0;n<t.length;n++){var i=t[n],o=[],s=i[0],l=i[1];o.push(s,l);for(var u=2;u<i.length;){var f=i[u++],h=i[u++],v=i[u++],c=i[u++],p=i[u++],d=i[u++];zd(s,l,f,h,v,c,p,d,o,e),s=p,l=d}a.push(o)}return a}function rL(r,e,t){var a=r[e],n=r[1-e],i=Math.abs(a/n),o=Math.ceil(Math.sqrt(i*t)),s=Math.floor(t/o);s===0&&(s=1,o=t);for(var l=[],u=0;u<o;u++)l.push(s);var f=o*s,h=t-f;if(h>0)for(var u=0;u<h;u++)l[u%o]+=1;return l}function Uw(r,e,t){for(var a=r.r0,n=r.r,i=r.startAngle,o=r.endAngle,s=Math.abs(o-i),l=s*n,u=n-a,f=l>Math.abs(u),h=rL([l,u],f?0:1,e),v=(f?s:u)/h.length,c=0;c<h.length;c++)for(var p=(f?u:s)/h[c],d=0;d<h[c];d++){var g={};f?(g.startAngle=i+v*c,g.endAngle=i+v*(c+1),g.r0=a+p*d,g.r=a+p*(d+1)):(g.startAngle=i+p*d,g.endAngle=i+p*(d+1),g.r0=a+v*c,g.r=a+v*(c+1)),g.clockwise=r.clockwise,g.cx=r.cx,g.cy=r.cy,t.push(g)}}function D9(r,e,t){for(var a=r.width,n=r.height,i=a>n,o=rL([a,n],i?0:1,e),s=i?"width":"height",l=i?"height":"width",u=i?"x":"y",f=i?"y":"x",h=r[s]/o.length,v=0;v<o.length;v++)for(var c=r[l]/o[v],p=0;p<o[v];p++){var d={};d[u]=v*h,d[f]=p*c,d[s]=h,d[l]=c,d.x+=r.x,d.y+=r.y,t.push(d)}}function Yw(r,e,t,a){return r*a-t*e}function M9(r,e,t,a,n,i,o,s){var l=t-r,u=a-e,f=o-n,h=s-i,v=Yw(f,h,l,u);if(Math.abs(v)<1e-6)return null;var c=r-n,p=e-i,d=Yw(c,p,f,h)/v;return d<0||d>1?null:new ut(d*l+r,d*u+e)}function I9(r,e,t){var a=new ut;ut.sub(a,t,e),a.normalize();var n=new ut;ut.sub(n,r,e);var i=n.dot(a);return i}function Ei(r,e){var t=r[r.length-1];t&&t[0]===e[0]&&t[1]===e[1]||r.push(e)}function L9(r,e,t){for(var a=r.length,n=[],i=0;i<a;i++){var o=r[i],s=r[(i+1)%a],l=M9(o[0],o[1],s[0],s[1],e.x,e.y,t.x,t.y);l&&n.push({projPt:I9(l,e,t),pt:l,idx:i})}if(n.length<2)return[{points:r},{points:r}];n.sort(function(g,y){return g.projPt-y.projPt});var u=n[0],f=n[n.length-1];if(f.idx<u.idx){var h=u;u=f,f=h}for(var v=[u.pt.x,u.pt.y],c=[f.pt.x,f.pt.y],p=[v],d=[c],i=u.idx+1;i<=f.idx;i++)Ei(p,r[i].slice());Ei(p,c),Ei(p,v);for(var i=f.idx+1;i<=u.idx+a;i++)Ei(d,r[i%a].slice());return Ei(d,v),Ei(d,c),[{points:p},{points:d}]}function Zw(r){var e=r.points,t=[],a=[];Jf(e,t,a);var n=new ht(t[0],t[1],a[0]-t[0],a[1]-t[1]),i=n.width,o=n.height,s=n.x,l=n.y,u=new ut,f=new ut;return i>o?(u.x=f.x=s+i/2,u.y=l,f.y=l+o):(u.y=f.y=l+o/2,u.x=s,f.x=s+i),L9(e,u,f)}function zf(r,e,t,a){if(t===1)a.push(e);else{var n=Math.floor(t/2),i=r(e);zf(r,i[0],n,a),zf(r,i[1],t-n,a)}return a}function P9(r,e){for(var t=[],a=0;a<e;a++)t.push(vg(r));return t}function R9(r,e){e.setStyle(r.style),e.z=r.z,e.z2=r.z2,e.zlevel=r.zlevel}function E9(r){for(var e=[],t=0;t<r.length;)e.push([r[t++],r[t++]]);return e}function k9(r,e){var t=[],a=r.shape,n;switch(r.type){case"rect":D9(a,e,t),n=wt;break;case"sector":Uw(a,e,t),n=Be;break;case"circle":Uw({r0:0,r:a.r,startAngle:0,endAngle:Math.PI*2,cx:a.cx,cy:a.cy},e,t),n=Be;break;default:var i=r.getComputedTransform(),o=i?Math.sqrt(Math.max(i[0]*i[0]+i[1]*i[1],i[2]*i[2]+i[3]*i[3])):1,s=G(C9(r.getUpdatedPathProxy(),o),function(y){return E9(y)}),l=s.length;if(l===0)zf(Zw,{points:s[0]},e,t);else if(l===e)for(var u=0;u<l;u++)t.push({points:s[u]});else{var f=0,h=G(s,function(y){var m=[],_=[];Jf(y,m,_);var S=(_[1]-m[1])*(_[0]-m[0]);return f+=S,{poly:y,area:S}});h.sort(function(y,m){return m.area-y.area});for(var v=e,u=0;u<l;u++){var c=h[u];if(v<=0)break;var p=u===l-1?v:Math.ceil(c.area/f*e);p<0||(zf(Zw,{points:c.poly},p,t),v-=p)}}n=De;break}if(!n)return P9(r,e);for(var d=[],u=0;u<t.length;u++){var g=new n;g.setShape(t[u]),R9(r,g),d.push(g)}return d}function O9(r,e){var t=r.length,a=e.length;if(t===a)return[r,e];for(var n=[],i=[],o=t<a?r:e,s=Math.min(t,a),l=Math.abs(a-t)/6,u=(s-2)/6,f=Math.ceil(l/u)+1,h=[o[0],o[1]],v=l,c=2;c<s;){var p=o[c-2],d=o[c-1],g=o[c++],y=o[c++],m=o[c++],_=o[c++],S=o[c++],w=o[c++];if(v<=0){h.push(g,y,m,_,S,w);continue}for(var x=Math.min(v,f-1)+1,b=1;b<=x;b++){var T=b/x;Wa(p,g,m,S,T,n),Wa(d,y,_,w,T,i),p=n[3],d=i[3],h.push(n[1],i[1],n[2],i[2],p,d),g=n[5],y=i[5],m=n[6],_=i[6]}v-=x-1}return o===r?[h,e]:[r,h]}function Xw(r,e){for(var t=r.length,a=r[t-2],n=r[t-1],i=[],o=0;o<e.length;)i[o++]=a,i[o++]=n;return i}function N9(r,e){for(var t,a,n,i=[],o=[],s=0;s<Math.max(r.length,e.length);s++){var l=r[s],u=e[s],f=void 0,h=void 0;l?u?(t=O9(l,u),f=t[0],h=t[1],a=f,n=h):(h=Xw(n||l,l),f=l):(f=Xw(a||u,u),h=u),i.push(f),o.push(h)}return[i,o]}function qw(r){for(var e=0,t=0,a=0,n=r.length,i=0,o=n-2;i<n;o=i,i+=2){var s=r[o],l=r[o+1],u=r[i],f=r[i+1],h=s*f-u*l;e+=h,t+=(s+u)*h,a+=(l+f)*h}return e===0?[r[0]||0,r[1]||0]:[t/e/3,a/e/3,e]}function B9(r,e,t,a){for(var n=(r.length-2)/6,i=1/0,o=0,s=r.length,l=s-2,u=0;u<n;u++){for(var f=u*6,h=0,v=0;v<s;v+=2){var c=v===0?f:(f+v-2)%l+2,p=r[c]-t[0],d=r[c+1]-t[1],g=e[v]-a[0],y=e[v+1]-a[1],m=g-p,_=y-d;h+=m*m+_*_}h<i&&(i=h,o=u)}return o}function V9(r){for(var e=[],t=r.length,a=0;a<t;a+=2)e[a]=r[t-a-2],e[a+1]=r[t-a-1];return e}function z9(r,e,t,a){for(var n=[],i,o=0;o<r.length;o++){var s=r[o],l=e[o],u=qw(s),f=qw(l);i==null&&(i=u[2]<0!=f[2]<0);var h=[],v=[],c=0,p=1/0,d=[],g=s.length;i&&(s=V9(s));for(var y=B9(s,l,u,f)*6,m=g-2,_=0;_<m;_+=2){var S=(y+_)%m+2;h[_+2]=s[S]-u[0],h[_+3]=s[S+1]-u[1]}if(h[0]=s[y]-u[0],h[1]=s[y+1]-u[1],t>0)for(var w=a/t,x=-a/2;x<=a/2;x+=w){for(var b=Math.sin(x),T=Math.cos(x),A=0,_=0;_<s.length;_+=2){var D=h[_],M=h[_+1],I=l[_]-f[0],L=l[_+1]-f[1],P=I*T-L*b,R=I*b+L*T;d[_]=P,d[_+1]=R;var E=P-D,N=R-M;A+=E*E+N*N}if(A<p){p=A,c=x;for(var O=0;O<d.length;O++)v[O]=d[O]}}else for(var B=0;B<g;B+=2)v[B]=l[B]-f[0],v[B+1]=l[B+1]-f[1];n.push({from:h,to:v,fromCp:u,toCp:f,rotation:-c})}return n}function Gf(r){return r.__isCombineMorphing}var aL="__mOriginal_";function Ff(r,e,t){var a=aL+e,n=r[a]||r[e];r[a]||(r[a]=r[e]);var i=t.replace,o=t.after,s=t.before;r[e]=function(){var l=arguments,u;return s&&s.apply(this,l),i?u=i.apply(this,l):u=n.apply(this,l),o&&o.apply(this,l),u}}function Ms(r,e){var t=aL+e;r[t]&&(r[e]=r[t],r[t]=null)}function Kw(r,e){for(var t=0;t<r.length;t++)for(var a=r[t],n=0;n<a.length;){var i=a[n],o=a[n+1];a[n++]=e[0]*i+e[2]*o+e[4],a[n++]=e[1]*i+e[3]*o+e[5]}}function nL(r,e){var t=r.getUpdatedPathProxy(),a=e.getUpdatedPathProxy(),n=N9(Vd(t),Vd(a)),i=n[0],o=n[1],s=r.getComputedTransform(),l=e.getComputedTransform();function u(){this.transform=null}s&&Kw(i,s),l&&Kw(o,l),Ff(e,"updateTransform",{replace:u}),e.transform=null;var f=z9(i,o,10,Math.PI),h=[];Ff(e,"buildPath",{replace:function(v){for(var c=e.__morphT,p=1-c,d=[],g=0;g<f.length;g++){var y=f[g],m=y.from,_=y.to,S=y.rotation*c,w=y.fromCp,x=y.toCp,b=Math.sin(S),T=Math.cos(S);Lu(d,w,x,c);for(var A=0;A<m.length;A+=2){var D=m[A],M=m[A+1],I=_[A],L=_[A+1],P=D*p+I*c,R=M*p+L*c;h[A]=P*T-R*b+d[0],h[A+1]=P*b+R*T+d[1]}var E=h[0],N=h[1];v.moveTo(E,N);for(var A=2;A<m.length;){var I=h[A++],L=h[A++],O=h[A++],B=h[A++],F=h[A++],H=h[A++];E===I&&N===L&&O===F&&B===H?v.lineTo(F,H):v.bezierCurveTo(I,L,O,B,F,H),E=F,N=H}}}})}function jy(r,e,t){if(!r||!e)return e;var a=t.done,n=t.during;nL(r,e),e.__morphT=0;function i(){Ms(e,"buildPath"),Ms(e,"updateTransform"),e.__morphT=-1,e.createPathProxy(),e.dirtyShape()}return e.animateTo({__morphT:1},j({during:function(o){e.dirtyShape(),n&&n(o)},done:function(){i(),a&&a()}},t)),e}function G9(r,e,t,a,n,i){var o=16;r=n===t?0:Math.round(32767*(r-t)/(n-t)),e=i===a?0:Math.round(32767*(e-a)/(i-a));for(var s=0,l,u=(1<<o)/2;u>0;u/=2){var f=0,h=0;(r&u)>0&&(f=1),(e&u)>0&&(h=1),s+=u*u*(3*f^h),h===0&&(f===1&&(r=u-1-r,e=u-1-e),l=r,r=e,e=l)}return s}function Hf(r){var e=1/0,t=1/0,a=-1/0,n=-1/0,i=G(r,function(s){var l=s.getBoundingRect(),u=s.getComputedTransform(),f=l.x+l.width/2+(u?u[4]:0),h=l.y+l.height/2+(u?u[5]:0);return e=Math.min(f,e),t=Math.min(h,t),a=Math.max(f,a),n=Math.max(h,n),[f,h]}),o=G(i,function(s,l){return{cp:s,z:G9(s[0],s[1],e,t,a,n),path:r[l]}});return o.sort(function(s,l){return s.z-l.z}).map(function(s){return s.path})}function iL(r){return k9(r.path,r.count)}function Gd(){return{fromIndividuals:[],toIndividuals:[],count:0}}function F9(r,e,t){var a=[];function n(w){for(var x=0;x<w.length;x++){var b=w[x];Gf(b)?n(b.childrenRef()):b instanceof yt&&a.push(b)}}n(r);var i=a.length;if(!i)return Gd();var o=t.dividePath||iL,s=o({path:e,count:i});if(s.length!==i)return console.error("Invalid morphing: unmatched splitted path"),Gd();a=Hf(a),s=Hf(s);for(var l=t.done,u=t.during,f=t.individualDelay,h=new Jr,v=0;v<i;v++){var c=a[v],p=s[v];p.parent=e,p.copyTransform(h),f||nL(c,p)}e.__isCombineMorphing=!0,e.childrenRef=function(){return s};function d(w){for(var x=0;x<s.length;x++)s[x].addSelfToZr(w)}Ff(e,"addSelfToZr",{after:function(w){d(w)}}),Ff(e,"removeSelfFromZr",{after:function(w){for(var x=0;x<s.length;x++)s[x].removeSelfFromZr(w)}});function g(){e.__isCombineMorphing=!1,e.__morphT=-1,e.childrenRef=null,Ms(e,"addSelfToZr"),Ms(e,"removeSelfFromZr")}var y=s.length;if(f)for(var m=y,_=function(){m--,m===0&&(g(),l&&l())},v=0;v<y;v++){var S=f?j({delay:(t.delay||0)+f(v,y,a[v],s[v]),done:_},t):t;jy(a[v],s[v],S)}else e.__morphT=0,e.animateTo({__morphT:1},j({during:function(w){for(var x=0;x<y;x++){var b=s[x];b.__morphT=e.__morphT,b.dirtyShape()}u&&u(w)},done:function(){g();for(var w=0;w<r.length;w++)Ms(r[w],"updateTransform");l&&l()}},t));return e.__zr&&d(e.__zr),{fromIndividuals:a,toIndividuals:s,count:y}}function H9(r,e,t){var a=e.length,n=[],i=t.dividePath||iL;function o(c){for(var p=0;p<c.length;p++){var d=c[p];Gf(d)?o(d.childrenRef()):d instanceof yt&&n.push(d)}}if(Gf(r)){o(r.childrenRef());var s=n.length;if(s<a)for(var l=0,u=s;u<a;u++)n.push(vg(n[l++%s]));n.length=a}else{n=i({path:r,count:a});for(var f=r.getComputedTransform(),u=0;u<n.length;u++)n[u].setLocalTransform(f);if(n.length!==a)return console.error("Invalid morphing: unmatched splitted path"),Gd()}n=Hf(n),e=Hf(e);for(var h=t.individualDelay,u=0;u<a;u++){var v=h?j({delay:(t.delay||0)+h(u,a,n[u],e[u])},t):t;jy(n[u],e[u],v)}return{fromIndividuals:n,toIndividuals:e,count:e.length}}function Qw(r){return z(r[0])}function Jw(r,e){for(var t=[],a=r.length,n=0;n<a;n++)t.push({one:r[n],many:[]});for(var n=0;n<e.length;n++){var i=e[n].length,o=void 0;for(o=0;o<i;o++)t[o%a].many.push(e[n][o])}for(var s=0,n=a-1;n>=0;n--)if(!t[n].many.length){var l=t[s].many;if(l.length<=1)if(s)s=0;else return t;var i=l.length,u=Math.ceil(i/2);t[n].many=l.slice(u,i),t[s].many=l.slice(0,u),s++}return t}var W9={clone:function(r){for(var e=[],t=1-Math.pow(1-r.path.style.opacity,1/r.count),a=0;a<r.count;a++){var n=vg(r.path);n.setStyle("opacity",t),e.push(n)}return e},split:null};function Kc(r,e,t,a,n,i){if(!r.length||!e.length)return;var o=vo("update",a,n);if(!(o&&o.duration>0))return;var s=a.getModel("universalTransition").get("delay"),l=Object.assign({setToFinal:!0},o),u,f;Qw(r)&&(u=r,f=e),Qw(e)&&(u=e,f=r);function h(y,m,_,S,w){var x=y.many,b=y.one;if(x.length===1&&!w){var T=m?x[0]:b,A=m?b:x[0];if(Gf(T))h({many:[T],one:A},!0,_,S,!0);else{var D=s?j({delay:s(_,S)},l):l;jy(T,A,D),i(T,A,T,A,D)}}else for(var M=j({dividePath:W9[t],individualDelay:s&&function(N,O,B,F){return s(N+_,S)}},l),I=m?F9(x,b,M):H9(b,x,M),L=I.fromIndividuals,P=I.toIndividuals,R=L.length,E=0;E<R;E++){var D=s?j({delay:s(E,R)},l):l;i(L[E],P[E],m?x[E]:y.one,m?y.one:x[E],D)}}for(var v=u?u===r:r.length>e.length,c=u?Jw(f,u):Jw(v?e:r,[v?r:e]),p=0,d=0;d<c.length;d++)p+=c[d].many.length;for(var g=0,d=0;d<c.length;d++)h(c[d],v,g,p),g+=c[d].many.length}function Ln(r){if(!r)return[];if(z(r)){for(var e=[],t=0;t<r.length;t++)e.push(Ln(r[t]));return e}var a=[];return r.traverse(function(n){n instanceof yt&&!n.disableMorphing&&!n.invisible&&!n.ignore&&a.push(n)}),a}var oL=1e4,$9=0,jw=1,tb=2,U9=bt();function Y9(r,e){for(var t=r.dimensions,a=0;a<t.length;a++){var n=r.getDimensionInfo(t[a]);if(n&&n.otherDims[e]===0)return t[a]}}function Z9(r,e,t){var a=r.getDimensionInfo(t),n=a&&a.ordinalMeta;if(a){var i=r.get(a.name,e);return n&&n.categories[i]||i+""}}function eb(r,e,t,a){var n=a?"itemChildGroupId":"itemGroupId",i=Y9(r,n);if(i){var o=Z9(r,e,i);return o}var s=r.getRawDataItem(e),l=a?"childGroupId":"groupId";if(s&&s[l])return s[l]+"";if(!a)return t||r.getId(e)}function rb(r){var e=[];return C(r,function(t){var a=t.data,n=t.dataGroupId;if(!(a.count()>oL))for(var i=a.getIndices(),o=0;o<i.length;o++)e.push({data:a,groupId:eb(a,o,n,!1),childGroupId:eb(a,o,n,!0),divide:t.divide,dataIndex:o})}),e}function Qc(r,e,t){r.traverse(function(a){a instanceof yt&&Bt(a,{style:{opacity:0}},e,{dataIndex:t,isFrom:!0})})}function Jc(r){if(r.parent){var e=r.getComputedTransform();r.setLocalTransform(e),r.parent.remove(r)}}function ki(r){r.stopAnimation(),r.isGroup&&r.traverse(function(e){e.stopAnimation()})}function X9(r,e,t){var a=vo("update",t,e);a&&r.traverse(function(n){if(n instanceof ir){var i=nE(n);i&&n.animateFrom({style:i},a)}})}function q9(r,e){var t=r.length;if(t!==e.length)return!1;for(var a=0;a<t;a++){var n=r[a],i=e[a];if(n.data.getId(n.dataIndex)!==i.data.getId(i.dataIndex))return!1}return!0}function sL(r,e,t){var a=rb(r),n=rb(e);function i(_,S,w,x,b){(w||_)&&S.animateFrom({style:w&&w!==_?V(V({},w.style),_.style):_.style},b)}var o=!1,s=$9,l=Z(),u=Z();a.forEach(function(_){_.groupId&&l.set(_.groupId,!0),_.childGroupId&&u.set(_.childGroupId,!0)});for(var f=0;f<n.length;f++){var h=n[f].groupId;if(u.get(h)){s=jw;break}var v=n[f].childGroupId;if(v&&l.get(v)){s=tb;break}}function c(_,S){return function(w){var x=w.data,b=w.dataIndex;return S?x.getId(b):_?s===jw?w.childGroupId:w.groupId:s===tb?w.childGroupId:w.groupId}}var p=q9(a,n),d={};if(!p)for(var f=0;f<n.length;f++){var g=n[f],y=g.data.getItemGraphicEl(g.dataIndex);y&&(d[y.id]=!0)}function m(_,S){var w=a[S],x=n[_],b=x.data.hostModel,T=w.data.getItemGraphicEl(w.dataIndex),A=x.data.getItemGraphicEl(x.dataIndex);if(T===A){A&&X9(A,x.dataIndex,b);return}T&&d[T.id]||A&&(ki(A),T?(ki(T),Jc(T),o=!0,Kc(Ln(T),Ln(A),x.divide,b,_,i)):Qc(A,b,_))}new ua(a,n,c(!0,p),c(!1,p),null,"multiple").update(m).updateManyToOne(function(_,S){var w=n[_],x=w.data,b=x.hostModel,T=x.getItemGraphicEl(w.dataIndex),A=Lt(G(S,function(D){return a[D].data.getItemGraphicEl(a[D].dataIndex)}),function(D){return D&&D!==T&&!d[D.id]});T&&(ki(T),A.length?(C(A,function(D){ki(D),Jc(D)}),o=!0,Kc(Ln(A),Ln(T),w.divide,b,_,i)):Qc(T,b,w.dataIndex))}).updateOneToMany(function(_,S){var w=a[S],x=w.data.getItemGraphicEl(w.dataIndex);if(!(x&&d[x.id])){var b=Lt(G(_,function(A){return n[A].data.getItemGraphicEl(n[A].dataIndex)}),function(A){return A&&A!==x}),T=n[_[0]].data.hostModel;b.length&&(C(b,function(A){return ki(A)}),x?(ki(x),Jc(x),o=!0,Kc(Ln(x),Ln(b),w.divide,T,_[0],i)):C(b,function(A){return Qc(A,T,_[0])}))}}).updateManyToMany(function(_,S){new ua(S,_,function(w){return a[w].data.getId(a[w].dataIndex)},function(w){return n[w].data.getId(n[w].dataIndex)}).update(function(w,x){m(_[w],S[x])}).execute()}).execute(),o&&C(e,function(_){var S=_.data,w=S.hostModel,x=w&&t.getViewOfSeriesModel(w),b=vo("update",w,0);x&&w.isAnimationEnabled()&&b&&b.duration>0&&x.group.traverse(function(T){T instanceof yt&&!T.animators.length&&T.animateFrom({style:{opacity:0}},b)})})}function ab(r){var e=r.getModel("universalTransition").get("seriesKey");return e||r.id}function nb(r){return z(r)?r.sort().join(","):r}function Da(r){if(r.hostModel)return r.hostModel.getModel("universalTransition").get("divideShape")}function K9(r,e){var t=Z(),a=Z(),n=Z();return C(r.oldSeries,function(i,o){var s=r.oldDataGroupIds[o],l=r.oldData[o],u=ab(i),f=nb(u);a.set(f,{dataGroupId:s,data:l}),z(u)&&C(u,function(h){n.set(h,{key:f,dataGroupId:s,data:l})})}),C(e.updatedSeries,function(i){if(i.isUniversalTransitionEnabled()&&i.isAnimationEnabled()){var o=i.get("dataGroupId"),s=i.getData(),l=ab(i),u=nb(l),f=a.get(u);if(f)t.set(u,{oldSeries:[{dataGroupId:f.dataGroupId,divide:Da(f.data),data:f.data}],newSeries:[{dataGroupId:o,divide:Da(s),data:s}]});else if(z(l)){var h=[];C(l,function(p){var d=a.get(p);d.data&&h.push({dataGroupId:d.dataGroupId,divide:Da(d.data),data:d.data})}),h.length&&t.set(u,{oldSeries:h,newSeries:[{dataGroupId:o,data:s,divide:Da(s)}]})}else{var v=n.get(l);if(v){var c=t.get(v.key);c||(c={oldSeries:[{dataGroupId:v.dataGroupId,data:v.data,divide:Da(v.data)}],newSeries:[]},t.set(v.key,c)),c.newSeries.push({dataGroupId:o,data:s,divide:Da(s)})}}}}),t}function ib(r,e){for(var t=0;t<r.length;t++){var a=e.seriesIndex!=null&&e.seriesIndex===r[t].seriesIndex||e.seriesId!=null&&e.seriesId===r[t].id;if(a)return t}}function Q9(r,e,t,a){var n=[],i=[];C(Pt(r.from),function(o){var s=ib(e.oldSeries,o);s>=0&&n.push({dataGroupId:e.oldDataGroupIds[s],data:e.oldData[s],divide:Da(e.oldData[s]),groupIdDim:o.dimension})}),C(Pt(r.to),function(o){var s=ib(t.updatedSeries,o);if(s>=0){var l=t.updatedSeries[s].getData();i.push({dataGroupId:e.oldDataGroupIds[s],data:l,divide:Da(l),groupIdDim:o.dimension})}}),n.length>0&&i.length>0&&sL(n,i,a)}function J9(r){r.registerUpdateLifecycle("series:beforeupdate",function(e,t,a){C(Pt(a.seriesTransition),function(n){C(Pt(n.to),function(i){for(var o=a.updatedSeries,s=0;s<o.length;s++)(i.seriesIndex!=null&&i.seriesIndex===o[s].seriesIndex||i.seriesId!=null&&i.seriesId===o[s].id)&&(o[s][Fu]=!0)})})}),r.registerUpdateLifecycle("series:transition",function(e,t,a){var n=U9(t);if(n.oldSeries&&a.updatedSeries&&a.optionChanged){var i=a.seriesTransition;if(i)C(Pt(i),function(c){Q9(c,n,a,t)});else{var o=K9(n,a);C(o.keys(),function(c){var p=o.get(c);sL(p.oldSeries,p.newSeries,t)})}C(a.updatedSeries,function(c){c[Fu]&&(c[Fu]=!1)})}for(var s=e.getSeries(),l=n.oldSeries=[],u=n.oldDataGroupIds=[],f=n.oldData=[],h=0;h<s.length;h++){var v=s[h].getData();v.count()<oL&&(l.push(s[h]),u.push(s[h].get("dataGroupId")),f.push(v))}})}gt([OV]);gt([MV]);gt([az,Sz,Ez,m5,O5,MG,nF,$F,d3,b3,k3,BH,f4,b4,W4,K4,cW,bW,NW,$W,r$,F$]);gt(f6);gt(H6);gt(rM);gt(iU);gt(HM);gt(vU);gt(xU);gt(S8);gt(H8);gt(bl);gt(lY);gt(hY);gt(AY);gt(OY);gt(WY);gt(QY);gt(h7);gt(E7);gt(ZI);gt(XI);gt(n9);gt(jI);gt(tL);gt(u9);gt(w9);gt(A9);gt(J9);gt(ZB);const j9={id:"charts_main"},tZ=ob({__name:"ChatEChartsIndex",setup(r){function e(){let t=cN(document.getElementById("charts_main")),a=+new Date(1968,9,3),n=24*3600*1e3,i=[],o=[Math.random()*300];for(let u=1;u<2e4;u++){var s=new Date(a+=n);i.push([s.getFullYear(),s.getMonth()+1,s.getDate()].join("/")),o.push(Math.round((Math.random()-.5)*20+o[u-1]))}let l={tooltip:{trigger:"axis",position:function(u){return[u[0],"10%"]}},title:{left:"center",text:"TEST"},toolbox:{feature:{dataZoom:{yAxisIndex:"none"},restore:{},saveAsImage:{}}},xAxis:{type:"category",boundaryGap:!1,data:i},yAxis:{type:"value",boundaryGap:[0,"100%"]},dataZoom:[{type:"inside",start:0,end:10},{start:0,end:10}],series:[{name:"Fake Data",type:"line",symbol:"none",sampling:"lttb",itemStyle:{color:"rgb(255, 70, 131)"},areaStyle:{color:new ho(0,0,0,1,[{offset:0,color:"rgb(255, 158, 68)"},{offset:1,color:"rgb(255, 70, 131)"}])},data:o}]};t.setOption(l)}return lL(()=>{e()}),(t,a)=>(sb(),lb("div",j9))}}),eZ=uL(tZ,[["__scopeId","data-v-7d285f58"]]),rZ={style:{"background-color":"#d2d2fa",height:"100vh",display:"grid","place-items":"center"}},nZ=ob({__name:"StatisticsView",setup(r){return(e,t)=>(sb(),lb("div",rZ,[fL(eZ)]))}});export{nZ as default};
